"""Auto-generated file, do not edit by hand. 34 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_34 = [NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['[5-7]|80[367]|90[1289]|[89][1-8]']), NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['9(?:0[1289]|[1-8])'])]
