"""Per-prefix data, mapping each prefix to a dict of locale:name.

Auto-generated file, do not edit by hand.
"""
from ..util import u

# Copyright (C) 2011-2026 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

data = {
 '9171652':{'en': 'Saunsar, Madhya Pradesh'},
 '9171653':{'en': 'Saunsar, Madhya Pradesh'},
 '9171654':{'en': 'Saunsar, Madhya Pradesh'},
 '9171655':{'en': 'Saunsar, Madhya Pradesh'},
 '9171656':{'en': 'Saunsar, Madhya Pradesh'},
 '9171657':{'en': 'Saunsar, Madhya Pradesh'},
 '9171662':{'en': 'Chaurai, Madhya Pradesh'},
 '9171663':{'en': 'Chaurai, Madhya Pradesh'},
 '9171664':{'en': 'Chaurai, Madhya Pradesh'},
 '9171665':{'en': 'Chaurai, Madhya Pradesh'},
 '9171666':{'en': 'Chaurai, Madhya Pradesh'},
 '9171667':{'en': 'Chaurai, Madhya Pradesh'},
 '9171672':{'en': 'Amarwada, Madhya Pradesh'},
 '9171673':{'en': 'Amarwada, Madhya Pradesh'},
 '9171674':{'en': 'Amarwada, Madhya Pradesh'},
 '9171675':{'en': 'Amarwada, Madhya Pradesh'},
 '9171676':{'en': 'Amarwada, Madhya Pradesh'},
 '9171677':{'en': 'Amarwada, Madhya Pradesh'},
 '9171682':{'en': 'Harrai, Madhya Pradesh'},
 '9171683':{'en': 'Harrai, Madhya Pradesh'},
 '9171684':{'en': 'Harrai, Madhya Pradesh'},
 '9171685':{'en': 'Harrai, Madhya Pradesh'},
 '9171686':{'en': 'Harrai, Madhya Pradesh'},
 '9171687':{'en': 'Harrai, Madhya Pradesh'},
 '9171692':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171693':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171694':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171695':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171696':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171697':{'en': 'Batkakhapa, Madhya Pradesh'},
 '9171702':{'en': 'Chumur, Maharashtra'},
 '9171703':{'en': 'Chumur, Maharashtra'},
 '9171704':{'en': 'Chumur, Maharashtra'},
 '9171705':{'en': 'Chumur, Maharashtra'},
 '9171706':{'en': 'Chumur, Maharashtra'},
 '9171707':{'en': 'Chumur, Maharashtra'},
 '9171712':{'en': 'Gond Pipri, Maharashtra'},
 '9171713':{'en': 'Gond Pipri, Maharashtra'},
 '9171714':{'en': 'Gond Pipri, Maharashtra'},
 '9171715':{'en': 'Gond Pipri, Maharashtra'},
 '9171716':{'en': 'Gond Pipri, Maharashtra'},
 '9171717':{'en': 'Gond Pipri, Maharashtra'},
 '9171722':{'en': 'Chandrapur, Maharashtra'},
 '9171723':{'en': 'Chandrapur, Maharashtra'},
 '9171724':{'en': 'Chandrapur, Maharashtra'},
 '9171725':{'en': 'Chandrapur, Maharashtra'},
 '9171726':{'en': 'Chandrapur, Maharashtra'},
 '9171727':{'en': 'Chandrapur, Maharashtra'},
 '9171732':{'en': 'Rajura, Maharashtra'},
 '9171733':{'en': 'Rajura, Maharashtra'},
 '9171734':{'en': 'Rajura, Maharashtra'},
 '9171735':{'en': 'Rajura, Maharashtra'},
 '9171736':{'en': 'Rajura, Maharashtra'},
 '9171737':{'en': 'Rajura, Maharashtra'},
 '9171742':{'en': 'Mul, Maharashtra'},
 '9171743':{'en': 'Mul, Maharashtra'},
 '9171744':{'en': 'Mul, Maharashtra'},
 '9171745':{'en': 'Mul, Maharashtra'},
 '9171746':{'en': 'Mul, Maharashtra'},
 '9171747':{'en': 'Mul, Maharashtra'},
 '9171752':{'en': 'Bhadrawati, Maharashtra'},
 '9171753':{'en': 'Bhadrawati, Maharashtra'},
 '9171754':{'en': 'Bhadrawati, Maharashtra'},
 '9171755':{'en': 'Bhadrawati, Maharashtra'},
 '9171756':{'en': 'Bhadrawati, Maharashtra'},
 '9171757':{'en': 'Bhadrawati, Maharashtra'},
 '9171762':{'en': 'Warora, Maharashtra'},
 '9171763':{'en': 'Warora, Maharashtra'},
 '9171764':{'en': 'Warora, Maharashtra'},
 '9171765':{'en': 'Warora, Maharashtra'},
 '9171766':{'en': 'Warora, Maharashtra'},
 '9171767':{'en': 'Warora, Maharashtra'},
 '9171772':{'en': 'Brahmapuri, Maharashtra'},
 '9171773':{'en': 'Brahmapuri, Maharashtra'},
 '9171774':{'en': 'Brahmapuri, Maharashtra'},
 '9171775':{'en': 'Brahmapuri, Maharashtra'},
 '9171776':{'en': 'Brahmapuri, Maharashtra'},
 '9171777':{'en': 'Brahmapuri, Maharashtra'},
 '9171782':{'en': 'Sinderwahi, Maharashtra'},
 '9171783':{'en': 'Sinderwahi, Maharashtra'},
 '9171784':{'en': 'Sinderwahi, Maharashtra'},
 '9171785':{'en': 'Sinderwahi, Maharashtra'},
 '9171786':{'en': 'Sinderwahi, Maharashtra'},
 '9171787':{'en': 'Sinderwahi, Maharashtra'},
 '9171792':{'en': 'Nagbhir, Maharashtra'},
 '9171793':{'en': 'Nagbhir, Maharashtra'},
 '9171794':{'en': 'Nagbhir, Maharashtra'},
 '9171795':{'en': 'Nagbhir, Maharashtra'},
 '9171796':{'en': 'Nagbhir, Maharashtra'},
 '9171797':{'en': 'Nagbhir, Maharashtra'},
 '9171802':{'en': 'Salekasa, Maharashtra'},
 '9171803':{'en': 'Salekasa, Maharashtra'},
 '9171804':{'en': 'Salekasa, Maharashtra'},
 '9171805':{'en': 'Salekasa, Maharashtra'},
 '9171806':{'en': 'Salekasa, Maharashtra'},
 '9171807':{'en': 'Salekasa, Maharashtra'},
 '9171812':{'en': 'Lakhandur, Maharashtra'},
 '9171813':{'en': 'Lakhandur, Maharashtra'},
 '9171814':{'en': 'Lakhandur, Maharashtra'},
 '9171815':{'en': 'Lakhandur, Maharashtra'},
 '9171816':{'en': 'Lakhandur, Maharashtra'},
 '9171817':{'en': 'Lakhandur, Maharashtra'},
 '9171822':{'en': 'Gondia, Maharashtra'},
 '9171823':{'en': 'Gondia, Maharashtra'},
 '9171824':{'en': 'Gondia, Maharashtra'},
 '9171825':{'en': 'Gondia, Maharashtra'},
 '9171826':{'en': 'Gondia, Maharashtra'},
 '9171827':{'en': 'Gondia, Maharashtra'},
 '9171832':{'en': 'Tumsar, Maharashtra'},
 '9171833':{'en': 'Tumsar, Maharashtra'},
 '9171834':{'en': 'Tumsar, Maharashtra'},
 '9171835':{'en': 'Tumsar, Maharashtra'},
 '9171836':{'en': 'Tumsar, Maharashtra'},
 '9171837':{'en': 'Tumsar, Maharashtra'},
 '9171842':{'en': 'Bhandara, Maharashtra'},
 '9171843':{'en': 'Bhandara, Maharashtra'},
 '9171844':{'en': 'Bhandara, Maharashtra'},
 '9171845':{'en': 'Bhandara, Maharashtra'},
 '9171846':{'en': 'Bhandara, Maharashtra'},
 '9171847':{'en': 'Bhandara, Maharashtra'},
 '9171852':{'en': 'Pauni, Maharashtra'},
 '9171853':{'en': 'Pauni, Maharashtra'},
 '9171854':{'en': 'Pauni, Maharashtra'},
 '9171855':{'en': 'Pauni, Maharashtra'},
 '9171856':{'en': 'Pauni, Maharashtra'},
 '9171857':{'en': 'Pauni, Maharashtra'},
 '9171862':{'en': 'Sakoli, Maharashtra'},
 '9171863':{'en': 'Sakoli, Maharashtra'},
 '9171864':{'en': 'Sakoli, Maharashtra'},
 '9171865':{'en': 'Sakoli, Maharashtra'},
 '9171866':{'en': 'Sakoli, Maharashtra'},
 '9171867':{'en': 'Sakoli, Maharashtra'},
 '9171872':{'en': 'Goregaon, Maharashtra'},
 '9171873':{'en': 'Goregaon, Maharashtra'},
 '9171874':{'en': 'Goregaon, Maharashtra'},
 '9171875':{'en': 'Goregaon, Maharashtra'},
 '9171876':{'en': 'Goregaon, Maharashtra'},
 '9171877':{'en': 'Goregaon, Maharashtra'},
 '9171892':{'en': 'Amagaon, Maharashtra'},
 '9171893':{'en': 'Amagaon, Maharashtra'},
 '9171894':{'en': 'Amagaon, Maharashtra'},
 '9171895':{'en': 'Amagaon, Maharashtra'},
 '9171896':{'en': 'Amagaon, Maharashtra'},
 '9171897':{'en': 'Amagaon, Maharashtra'},
 '9171962':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171963':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171964':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171965':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171966':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171967':{'en': 'Arjuni Morgaon, Maharashtra'},
 '9171972':{'en': 'Mohadi, Maharashtra'},
 '9171973':{'en': 'Mohadi, Maharashtra'},
 '9171974':{'en': 'Mohadi, Maharashtra'},
 '9171975':{'en': 'Mohadi, Maharashtra'},
 '9171976':{'en': 'Mohadi, Maharashtra'},
 '9171977':{'en': 'Mohadi, Maharashtra'},
 '9171982':{'en': 'Tirora, Maharashtra'},
 '9171983':{'en': 'Tirora, Maharashtra'},
 '9171984':{'en': 'Tirora, Maharashtra'},
 '9171985':{'en': 'Tirora, Maharashtra'},
 '9171986':{'en': 'Tirora, Maharashtra'},
 '9171987':{'en': 'Tirora, Maharashtra'},
 '9171992':{'en': 'Deori, Maharashtra'},
 '9171993':{'en': 'Deori, Maharashtra'},
 '9171994':{'en': 'Deori, Maharashtra'},
 '9171995':{'en': 'Deori, Maharashtra'},
 '9171996':{'en': 'Deori, Maharashtra'},
 '9171997':{'en': 'Deori, Maharashtra'},
 '9172012':{'en': 'Kalamb, Maharashtra'},
 '9172013':{'en': 'Kalamb, Maharashtra'},
 '9172014':{'en': 'Kalamb, Maharashtra'},
 '9172015':{'en': 'Kalamb, Maharashtra'},
 '9172016':{'en': 'Kalamb, Maharashtra'},
 '9172017':{'en': 'Kalamb, Maharashtra'},
 '9172022':{'en': 'Ralegaon, Maharashtra'},
 '9172023':{'en': 'Ralegaon, Maharashtra'},
 '9172024':{'en': 'Ralegaon, Maharashtra'},
 '9172025':{'en': 'Ralegaon, Maharashtra'},
 '9172026':{'en': 'Ralegaon, Maharashtra'},
 '9172027':{'en': 'Ralegaon, Maharashtra'},
 '9172032':{'en': 'Babhulgaon, Maharashtra'},
 '9172033':{'en': 'Babhulgaon, Maharashtra'},
 '9172034':{'en': 'Babhulgaon, Maharashtra'},
 '9172035':{'en': 'Babhulgaon, Maharashtra'},
 '9172036':{'en': 'Babhulgaon, Maharashtra'},
 '9172037':{'en': 'Babhulgaon, Maharashtra'},
 '917212':{'en': 'Amravati, Maharashtra'},
 '917213':{'en': 'Amravati, Maharashtra'},
 '917214':{'en': 'Amravati, Maharashtra'},
 '917215':{'en': 'Amravati, Maharashtra'},
 '917216':{'en': 'Amravati, Maharashtra'},
 '917217':{'en': 'Amravati, Maharashtra'},
 '9172202':{'en': 'Chhikaldara, Maharashtra'},
 '9172203':{'en': 'Chhikaldara, Maharashtra'},
 '9172204':{'en': 'Chhikaldara, Maharashtra'},
 '9172205':{'en': 'Chhikaldara, Maharashtra'},
 '9172206':{'en': 'Chhikaldara, Maharashtra'},
 '9172207':{'en': 'Chhikaldara, Maharashtra'},
 '9172212':{'en': 'Nandgaon, Maharashtra'},
 '9172213':{'en': 'Nandgaon, Maharashtra'},
 '9172214':{'en': 'Nandgaon, Maharashtra'},
 '9172215':{'en': 'Nandgaon, Maharashtra'},
 '9172216':{'en': 'Nandgaon, Maharashtra'},
 '9172217':{'en': 'Nandgaon, Maharashtra'},
 '9172222':{'en': 'Chandurrly, Maharashtra'},
 '9172223':{'en': 'Chandurrly, Maharashtra'},
 '9172224':{'en': 'Chandurrly, Maharashtra'},
 '9172225':{'en': 'Chandurrly, Maharashtra'},
 '9172226':{'en': 'Chandurrly, Maharashtra'},
 '9172227':{'en': 'Chandurrly, Maharashtra'},
 '9172232':{'en': 'Achalpur, Maharashtra'},
 '9172233':{'en': 'Achalpur, Maharashtra'},
 '9172234':{'en': 'Achalpur, Maharashtra'},
 '9172235':{'en': 'Achalpur, Maharashtra'},
 '9172236':{'en': 'Achalpur, Maharashtra'},
 '9172237':{'en': 'Achalpur, Maharashtra'},
 '9172242':{'en': 'Daryapur, Maharashtra'},
 '9172243':{'en': 'Daryapur, Maharashtra'},
 '9172244':{'en': 'Daryapur, Maharashtra'},
 '9172245':{'en': 'Daryapur, Maharashtra'},
 '9172246':{'en': 'Daryapur, Maharashtra'},
 '9172247':{'en': 'Daryapur, Maharashtra'},
 '9172252':{'en': 'Tiwasa, Maharashtra'},
 '9172253':{'en': 'Tiwasa, Maharashtra'},
 '9172254':{'en': 'Tiwasa, Maharashtra'},
 '9172255':{'en': 'Tiwasa, Maharashtra'},
 '9172256':{'en': 'Tiwasa, Maharashtra'},
 '9172257':{'en': 'Tiwasa, Maharashtra'},
 '9172262':{'en': 'Dharani, Maharashtra'},
 '9172263':{'en': 'Dharani, Maharashtra'},
 '9172264':{'en': 'Dharani, Maharashtra'},
 '9172265':{'en': 'Dharani, Maharashtra'},
 '9172266':{'en': 'Dharani, Maharashtra'},
 '9172267':{'en': 'Dharani, Maharashtra'},
 '9172272':{'en': 'Chandurbazar, Maharashtra'},
 '9172273':{'en': 'Chandurbazar, Maharashtra'},
 '9172274':{'en': 'Chandurbazar, Maharashtra'},
 '9172275':{'en': 'Chandurbazar, Maharashtra'},
 '9172276':{'en': 'Chandurbazar, Maharashtra'},
 '9172277':{'en': 'Chandurbazar, Maharashtra'},
 '9172282':{'en': 'Morshi, Maharashtra'},
 '9172283':{'en': 'Morshi, Maharashtra'},
 '9172284':{'en': 'Morshi, Maharashtra'},
 '9172285':{'en': 'Morshi, Maharashtra'},
 '9172286':{'en': 'Morshi, Maharashtra'},
 '9172287':{'en': 'Morshi, Maharashtra'},
 '9172292':{'en': 'Warlydwarud, Maharashtra'},
 '9172293':{'en': 'Warlydwarud, Maharashtra'},
 '9172294':{'en': 'Warlydwarud, Maharashtra'},
 '9172295':{'en': 'Warlydwarud, Maharashtra'},
 '9172296':{'en': 'Warlydwarud, Maharashtra'},
 '9172297':{'en': 'Warlydwarud, Maharashtra'},
 '9172302':{'en': 'Ghatanji, Maharashtra'},
 '9172303':{'en': 'Ghatanji, Maharashtra'},
 '9172304':{'en': 'Ghatanji, Maharashtra'},
 '9172305':{'en': 'Ghatanji, Maharashtra'},
 '9172306':{'en': 'Ghatanji, Maharashtra'},
 '9172307':{'en': 'Ghatanji, Maharashtra'},
 '9172312':{'en': 'Umarkhed, Maharashtra'},
 '9172313':{'en': 'Umarkhed, Maharashtra'},
 '9172314':{'en': 'Umarkhed, Maharashtra'},
 '9172315':{'en': 'Umarkhed, Maharashtra'},
 '9172316':{'en': 'Umarkhed, Maharashtra'},
 '9172317':{'en': 'Umarkhed, Maharashtra'},
 '9172322':{'en': 'Yeotmal, Maharashtra'},
 '9172323':{'en': 'Yeotmal, Maharashtra'},
 '9172324':{'en': 'Yeotmal, Maharashtra'},
 '9172325':{'en': 'Yeotmal, Maharashtra'},
 '9172326':{'en': 'Yeotmal, Maharashtra'},
 '9172327':{'en': 'Yeotmal, Maharashtra'},
 '9172332':{'en': 'Pusad, Maharashtra'},
 '9172333':{'en': 'Pusad, Maharashtra'},
 '9172334':{'en': 'Pusad, Maharashtra'},
 '9172335':{'en': 'Pusad, Maharashtra'},
 '9172336':{'en': 'Pusad, Maharashtra'},
 '9172337':{'en': 'Pusad, Maharashtra'},
 '9172342':{'en': 'Digras, Maharashtra'},
 '9172343':{'en': 'Digras, Maharashtra'},
 '9172344':{'en': 'Digras, Maharashtra'},
 '9172345':{'en': 'Digras, Maharashtra'},
 '9172346':{'en': 'Digras, Maharashtra'},
 '9172347':{'en': 'Digras, Maharashtra'},
 '9172352':{'en': 'Pandharkawada, Maharashtra'},
 '9172353':{'en': 'Pandharkawada, Maharashtra'},
 '9172354':{'en': 'Pandharkawada, Maharashtra'},
 '9172355':{'en': 'Pandharkawada, Maharashtra'},
 '9172356':{'en': 'Pandharkawada, Maharashtra'},
 '9172357':{'en': 'Pandharkawada, Maharashtra'},
 '9172362':{'en': 'Maregaon, Maharashtra'},
 '9172363':{'en': 'Maregaon, Maharashtra'},
 '9172364':{'en': 'Maregaon, Maharashtra'},
 '9172365':{'en': 'Maregaon, Maharashtra'},
 '9172366':{'en': 'Maregaon, Maharashtra'},
 '9172367':{'en': 'Maregaon, Maharashtra'},
 '9172372':{'en': 'Marigaon, Maharashtra'},
 '9172373':{'en': 'Marigaon, Maharashtra'},
 '9172374':{'en': 'Marigaon, Maharashtra'},
 '9172375':{'en': 'Marigaon, Maharashtra'},
 '9172376':{'en': 'Marigaon, Maharashtra'},
 '9172377':{'en': 'Marigaon, Maharashtra'},
 '9172382':{'en': 'Darwaha, Maharashtra'},
 '9172383':{'en': 'Darwaha, Maharashtra'},
 '9172384':{'en': 'Darwaha, Maharashtra'},
 '9172385':{'en': 'Darwaha, Maharashtra'},
 '9172386':{'en': 'Darwaha, Maharashtra'},
 '9172387':{'en': 'Darwaha, Maharashtra'},
 '9172392':{'en': 'Wani, Maharashtra'},
 '9172393':{'en': 'Wani, Maharashtra'},
 '9172394':{'en': 'Wani, Maharashtra'},
 '9172395':{'en': 'Wani, Maharashtra'},
 '9172396':{'en': 'Wani, Maharashtra'},
 '9172397':{'en': 'Wani, Maharashtra'},
 '917242':{'en': 'Akola, Maharashtra'},
 '917243':{'en': 'Akola, Maharashtra'},
 '917244':{'en': 'Akola, Maharashtra'},
 '917245':{'en': 'Akola, Maharashtra'},
 '917246':{'en': 'Akola, Maharashtra'},
 '917247':{'en': 'Akola, Maharashtra'},
 '9172512':{'en': 'Risod, Maharashtra'},
 '9172513':{'en': 'Risod, Maharashtra'},
 '9172514':{'en': 'Risod, Maharashtra'},
 '9172515':{'en': 'Risod, Maharashtra'},
 '9172516':{'en': 'Risod, Maharashtra'},
 '9172517':{'en': 'Risod, Maharashtra'},
 '9172522':{'en': 'Washim, Maharashtra'},
 '9172523':{'en': 'Washim, Maharashtra'},
 '9172524':{'en': 'Washim, Maharashtra'},
 '9172525':{'en': 'Washim, Maharashtra'},
 '9172526':{'en': 'Washim, Maharashtra'},
 '9172527':{'en': 'Washim, Maharashtra'},
 '9172532':{'en': 'Mangrulpur, Maharashtra'},
 '9172533':{'en': 'Mangrulpur, Maharashtra'},
 '9172534':{'en': 'Mangrulpur, Maharashtra'},
 '9172535':{'en': 'Mangrulpur, Maharashtra'},
 '9172536':{'en': 'Mangrulpur, Maharashtra'},
 '9172537':{'en': 'Mangrulpur, Maharashtra'},
 '9172542':{'en': 'Malgaon, Maharashtra'},
 '9172543':{'en': 'Malgaon, Maharashtra'},
 '9172544':{'en': 'Malgaon, Maharashtra'},
 '9172545':{'en': 'Malgaon, Maharashtra'},
 '9172546':{'en': 'Malgaon, Maharashtra'},
 '9172547':{'en': 'Malgaon, Maharashtra'},
 '9172552':{'en': 'Barshi Takli, Maharashtra'},
 '9172553':{'en': 'Barshi Takli, Maharashtra'},
 '9172554':{'en': 'Barshi Takli, Maharashtra'},
 '9172555':{'en': 'Barshi Takli, Maharashtra'},
 '9172556':{'en': 'Barshi Takli, Maharashtra'},
 '9172557':{'en': 'Barshi Takli, Maharashtra'},
 '9172562':{'en': 'Murtizapur, Maharashtra'},
 '9172563':{'en': 'Murtizapur, Maharashtra'},
 '9172564':{'en': 'Murtizapur, Maharashtra'},
 '9172565':{'en': 'Murtizapur, Maharashtra'},
 '9172566':{'en': 'Murtizapur, Maharashtra'},
 '9172567':{'en': 'Murtizapur, Maharashtra'},
 '9172572':{'en': 'Balapur, Maharashtra'},
 '9172573':{'en': 'Balapur, Maharashtra'},
 '9172574':{'en': 'Balapur, Maharashtra'},
 '9172575':{'en': 'Balapur, Maharashtra'},
 '9172576':{'en': 'Balapur, Maharashtra'},
 '9172577':{'en': 'Balapur, Maharashtra'},
 '9172582':{'en': 'Akot, Maharashtra'},
 '9172583':{'en': 'Akot, Maharashtra'},
 '9172584':{'en': 'Akot, Maharashtra'},
 '9172585':{'en': 'Akot, Maharashtra'},
 '9172586':{'en': 'Akot, Maharashtra'},
 '9172587':{'en': 'Akot, Maharashtra'},
 '9172602':{'en': 'Lonar, Maharashtra'},
 '9172603':{'en': 'Lonar, Maharashtra'},
 '9172604':{'en': 'Lonar, Maharashtra'},
 '9172605':{'en': 'Lonar, Maharashtra'},
 '9172606':{'en': 'Lonar, Maharashtra'},
 '9172607':{'en': 'Lonar, Maharashtra'},
 '9172612':{'en': 'Deolgaonraja, Maharashtra'},
 '9172613':{'en': 'Deolgaonraja, Maharashtra'},
 '9172614':{'en': 'Deolgaonraja, Maharashtra'},
 '9172615':{'en': 'Deolgaonraja, Maharashtra'},
 '9172616':{'en': 'Deolgaonraja, Maharashtra'},
 '9172617':{'en': 'Deolgaonraja, Maharashtra'},
 '9172622':{'en': 'Buldhana, Maharashtra'},
 '9172623':{'en': 'Buldhana, Maharashtra'},
 '9172624':{'en': 'Buldhana, Maharashtra'},
 '9172625':{'en': 'Buldhana, Maharashtra'},
 '9172626':{'en': 'Buldhana, Maharashtra'},
 '9172627':{'en': 'Buldhana, Maharashtra'},
 '9172632':{'en': 'Khamgaon, Maharashtra'},
 '9172633':{'en': 'Khamgaon, Maharashtra'},
 '9172634':{'en': 'Khamgaon, Maharashtra'},
 '9172635':{'en': 'Khamgaon, Maharashtra'},
 '9172636':{'en': 'Khamgaon, Maharashtra'},
 '9172637':{'en': 'Khamgaon, Maharashtra'},
 '9172642':{'en': 'Chikhali, Maharashtra'},
 '9172643':{'en': 'Chikhali, Maharashtra'},
 '9172644':{'en': 'Chikhali, Maharashtra'},
 '9172645':{'en': 'Chikhali, Maharashtra'},
 '9172646':{'en': 'Chikhali, Maharashtra'},
 '9172647':{'en': 'Chikhali, Maharashtra'},
 '9172652':{'en': 'Nandura, Maharashtra'},
 '9172653':{'en': 'Nandura, Maharashtra'},
 '9172654':{'en': 'Nandura, Maharashtra'},
 '9172655':{'en': 'Nandura, Maharashtra'},
 '9172656':{'en': 'Nandura, Maharashtra'},
 '9172657':{'en': 'Nandura, Maharashtra'},
 '9172662':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172663':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172664':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172665':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172666':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172667':{'en': 'Jalgaonjamod, Maharashtra'},
 '9172672':{'en': 'Malkapur, Maharashtra'},
 '9172673':{'en': 'Malkapur, Maharashtra'},
 '9172674':{'en': 'Malkapur, Maharashtra'},
 '9172675':{'en': 'Malkapur, Maharashtra'},
 '9172676':{'en': 'Malkapur, Maharashtra'},
 '9172677':{'en': 'Malkapur, Maharashtra'},
 '9172682':{'en': 'Mekhar, Maharashtra'},
 '9172683':{'en': 'Mekhar, Maharashtra'},
 '9172684':{'en': 'Mekhar, Maharashtra'},
 '9172685':{'en': 'Mekhar, Maharashtra'},
 '9172686':{'en': 'Mekhar, Maharashtra'},
 '9172687':{'en': 'Mekhar, Maharashtra'},
 '9172692':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172693':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172694':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172695':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172696':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172697':{'en': 'Sindkhedaraja, Maharashtra'},
 '9172702':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172703':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172704':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172705':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172706':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172707':{'en': 'Sonkatch, Madhya Pradesh'},
 '9172712':{'en': 'Bagli, Madhya Pradesh'},
 '9172713':{'en': 'Bagli, Madhya Pradesh'},
 '9172714':{'en': 'Bagli, Madhya Pradesh'},
 '9172715':{'en': 'Bagli, Madhya Pradesh'},
 '9172716':{'en': 'Bagli, Madhya Pradesh'},
 '9172717':{'en': 'Bagli, Madhya Pradesh'},
 '9172722':{'en': 'Dewas, Madhya Pradesh'},
 '9172723':{'en': 'Dewas, Madhya Pradesh'},
 '9172724':{'en': 'Dewas, Madhya Pradesh'},
 '9172725':{'en': 'Dewas, Madhya Pradesh'},
 '9172726':{'en': 'Dewas, Madhya Pradesh'},
 '9172727':{'en': 'Dewas, Madhya Pradesh'},
 '9172732':{'en': 'Kannod, Madhya Pradesh'},
 '9172733':{'en': 'Kannod, Madhya Pradesh'},
 '9172734':{'en': 'Kannod, Madhya Pradesh'},
 '9172735':{'en': 'Kannod, Madhya Pradesh'},
 '9172736':{'en': 'Kannod, Madhya Pradesh'},
 '9172737':{'en': 'Kannod, Madhya Pradesh'},
 '9172742':{'en': 'Khategaon, Madhya Pradesh'},
 '9172743':{'en': 'Khategaon, Madhya Pradesh'},
 '9172744':{'en': 'Khategaon, Madhya Pradesh'},
 '9172745':{'en': 'Khategaon, Madhya Pradesh'},
 '9172746':{'en': 'Khategaon, Madhya Pradesh'},
 '9172747':{'en': 'Khategaon, Madhya Pradesh'},
 '9172792':{'en': 'Nandnva, Maharashtra'},
 '9172793':{'en': 'Nandnva, Maharashtra'},
 '9172794':{'en': 'Nandnva, Maharashtra'},
 '9172795':{'en': 'Nandnva, Maharashtra'},
 '9172796':{'en': 'Nandnva, Maharashtra'},
 '9172797':{'en': 'Nandnva, Maharashtra'},
 '9172802':{'en': 'Barwaha, Madhya Pradesh'},
 '9172803':{'en': 'Barwaha, Madhya Pradesh'},
 '9172804':{'en': 'Barwaha, Madhya Pradesh'},
 '9172805':{'en': 'Barwaha, Madhya Pradesh'},
 '9172806':{'en': 'Barwaha, Madhya Pradesh'},
 '9172807':{'en': 'Barwaha, Madhya Pradesh'},
 '9172812':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172813':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172814':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172815':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172816':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172817':{'en': 'Sendhwa, Madhya Pradesh'},
 '9172822':{'en': 'Khargone, Madhya Pradesh'},
 '9172823':{'en': 'Khargone, Madhya Pradesh'},
 '9172824':{'en': 'Khargone, Madhya Pradesh'},
 '9172825':{'en': 'Khargone, Madhya Pradesh'},
 '9172826':{'en': 'Khargone, Madhya Pradesh'},
 '9172827':{'en': 'Khargone, Madhya Pradesh'},
 '9172832':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172833':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172834':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172835':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172836':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172837':{'en': 'Maheshwar, Madhya Pradesh'},
 '9172842':{'en': 'Rajpur, Madhya Pradesh'},
 '9172843':{'en': 'Rajpur, Madhya Pradesh'},
 '9172844':{'en': 'Rajpur, Madhya Pradesh'},
 '9172845':{'en': 'Rajpur, Madhya Pradesh'},
 '9172846':{'en': 'Rajpur, Madhya Pradesh'},
 '9172847':{'en': 'Rajpur, Madhya Pradesh'},
 '9172852':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172853':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172854':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172855':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172856':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172857':{'en': 'Kasrawad, Madhya Pradesh'},
 '9172862':{'en': 'Khetia, Madhya Pradesh'},
 '9172863':{'en': 'Khetia, Madhya Pradesh'},
 '9172864':{'en': 'Khetia, Madhya Pradesh'},
 '9172865':{'en': 'Khetia, Madhya Pradesh'},
 '9172866':{'en': 'Khetia, Madhya Pradesh'},
 '9172867':{'en': 'Khetia, Madhya Pradesh'},
 '9172872':{'en': 'Gogaon, Madhya Pradesh'},
 '9172873':{'en': 'Gogaon, Madhya Pradesh'},
 '9172874':{'en': 'Gogaon, Madhya Pradesh'},
 '9172875':{'en': 'Gogaon, Madhya Pradesh'},
 '9172876':{'en': 'Gogaon, Madhya Pradesh'},
 '9172877':{'en': 'Gogaon, Madhya Pradesh'},
 '9172882':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172883':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172884':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172885':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172886':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172887':{'en': 'Bhikangaon, Madhya Pradesh'},
 '9172892':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172893':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172894':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172895':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172896':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172897':{'en': 'Zhirnia, Madhya Pradesh'},
 '9172902':{'en': 'Badwani, Madhya Pradesh'},
 '9172903':{'en': 'Badwani, Madhya Pradesh'},
 '9172904':{'en': 'Badwani, Madhya Pradesh'},
 '9172905':{'en': 'Badwani, Madhya Pradesh'},
 '9172906':{'en': 'Badwani, Madhya Pradesh'},
 '9172907':{'en': 'Badwani, Madhya Pradesh'},
 '9172912':{'en': 'Manawar, Madhya Pradesh'},
 '9172913':{'en': 'Manawar, Madhya Pradesh'},
 '9172914':{'en': 'Manawar, Madhya Pradesh'},
 '9172915':{'en': 'Manawar, Madhya Pradesh'},
 '9172916':{'en': 'Manawar, Madhya Pradesh'},
 '9172917':{'en': 'Manawar, Madhya Pradesh'},
 '9172922':{'en': 'Dhar, Madhya Pradesh'},
 '9172923':{'en': 'Dhar, Madhya Pradesh'},
 '9172924':{'en': 'Dhar, Madhya Pradesh'},
 '9172925':{'en': 'Dhar, Madhya Pradesh'},
 '9172926':{'en': 'Dhar, Madhya Pradesh'},
 '9172927':{'en': 'Dhar, Madhya Pradesh'},
 '9172942':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172943':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172944':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172945':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172946':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172947':{'en': 'Dharampuri, Madhya Pradesh'},
 '9172952':{'en': 'Badnawar, Madhya Pradesh'},
 '9172953':{'en': 'Badnawar, Madhya Pradesh'},
 '9172954':{'en': 'Badnawar, Madhya Pradesh'},
 '9172955':{'en': 'Badnawar, Madhya Pradesh'},
 '9172956':{'en': 'Badnawar, Madhya Pradesh'},
 '9172957':{'en': 'Badnawar, Madhya Pradesh'},
 '9172962':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172963':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172964':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172965':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172966':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172967':{'en': 'Sardarpur, Madhya Pradesh'},
 '9172972':{'en': 'Kukshi, Madhya Pradesh'},
 '9172973':{'en': 'Kukshi, Madhya Pradesh'},
 '9172974':{'en': 'Kukshi, Madhya Pradesh'},
 '9172975':{'en': 'Kukshi, Madhya Pradesh'},
 '9172976':{'en': 'Kukshi, Madhya Pradesh'},
 '9172977':{'en': 'Kukshi, Madhya Pradesh'},
 '917312':{'en': 'Indore, Madhya Pradesh'},
 '917313':{'en': 'Indore, Madhya Pradesh'},
 '917314':{'en': 'Indore, Madhya Pradesh'},
 '917315':{'en': 'Indore, Madhya Pradesh'},
 '917316':{'en': 'Indore, Madhya Pradesh'},
 '917317':{'en': 'Indore, Madhya Pradesh'},
 '9173202':{'en': 'Pandhana, Madhya Pradesh'},
 '9173203':{'en': 'Pandhana, Madhya Pradesh'},
 '9173204':{'en': 'Pandhana, Madhya Pradesh'},
 '9173205':{'en': 'Pandhana, Madhya Pradesh'},
 '9173206':{'en': 'Pandhana, Madhya Pradesh'},
 '9173207':{'en': 'Pandhana, Madhya Pradesh'},
 '9173212':{'en': 'Sanwer, Madhya Pradesh'},
 '9173213':{'en': 'Sanwer, Madhya Pradesh'},
 '9173214':{'en': 'Sanwer, Madhya Pradesh'},
 '9173215':{'en': 'Sanwer, Madhya Pradesh'},
 '9173216':{'en': 'Sanwer, Madhya Pradesh'},
 '9173217':{'en': 'Sanwer, Madhya Pradesh'},
 '9173222':{'en': 'Depalpur, Madhya Pradesh'},
 '9173223':{'en': 'Depalpur, Madhya Pradesh'},
 '9173224':{'en': 'Depalpur, Madhya Pradesh'},
 '9173225':{'en': 'Depalpur, Madhya Pradesh'},
 '9173226':{'en': 'Depalpur, Madhya Pradesh'},
 '9173227':{'en': 'Depalpur, Madhya Pradesh'},
 '9173232':{'en': 'Punasa, Madhya Pradesh'},
 '9173233':{'en': 'Punasa, Madhya Pradesh'},
 '9173234':{'en': 'Punasa, Madhya Pradesh'},
 '9173235':{'en': 'Punasa, Madhya Pradesh'},
 '9173236':{'en': 'Punasa, Madhya Pradesh'},
 '9173237':{'en': 'Punasa, Madhya Pradesh'},
 '9173242':{'en': 'Mhow, Madhya Pradesh'},
 '9173243':{'en': 'Mhow, Madhya Pradesh'},
 '9173244':{'en': 'Mhow, Madhya Pradesh'},
 '9173245':{'en': 'Mhow, Madhya Pradesh'},
 '9173246':{'en': 'Mhow, Madhya Pradesh'},
 '9173247':{'en': 'Mhow, Madhya Pradesh'},
 '9173252':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173253':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173254':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173255':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173256':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173257':{'en': 'Burhanpur, Madhya Pradesh'},
 '9173262':{'en': 'Baldi, Madhya Pradesh'},
 '9173263':{'en': 'Baldi, Madhya Pradesh'},
 '9173264':{'en': 'Baldi, Madhya Pradesh'},
 '9173265':{'en': 'Baldi, Madhya Pradesh'},
 '9173266':{'en': 'Baldi, Madhya Pradesh'},
 '9173267':{'en': 'Baldi, Madhya Pradesh'},
 '9173272':{'en': 'Harsud, Madhya Pradesh'},
 '9173273':{'en': 'Harsud, Madhya Pradesh'},
 '9173274':{'en': 'Harsud, Madhya Pradesh'},
 '9173275':{'en': 'Harsud, Madhya Pradesh'},
 '9173276':{'en': 'Harsud, Madhya Pradesh'},
 '9173277':{'en': 'Harsud, Madhya Pradesh'},
 '9173282':{'en': 'Khalwa, Madhya Pradesh'},
 '9173283':{'en': 'Khalwa, Madhya Pradesh'},
 '9173284':{'en': 'Khalwa, Madhya Pradesh'},
 '9173285':{'en': 'Khalwa, Madhya Pradesh'},
 '9173286':{'en': 'Khalwa, Madhya Pradesh'},
 '9173287':{'en': 'Khalwa, Madhya Pradesh'},
 '9173292':{'en': 'Khakner, Madhya Pradesh'},
 '9173293':{'en': 'Khakner, Madhya Pradesh'},
 '9173294':{'en': 'Khakner, Madhya Pradesh'},
 '9173295':{'en': 'Khakner, Madhya Pradesh'},
 '9173296':{'en': 'Khakner, Madhya Pradesh'},
 '9173297':{'en': 'Khakner, Madhya Pradesh'},
 '917332':{'en': 'Khandwa, Madhya Pradesh'},
 '917333':{'en': 'Khandwa, Madhya Pradesh'},
 '917334':{'en': 'Khandwa, Madhya Pradesh'},
 '917335':{'en': 'Khandwa, Madhya Pradesh'},
 '917336':{'en': 'Khandwa, Madhya Pradesh'},
 '917337':{'en': 'Khandwa, Madhya Pradesh'},
 '917342':{'en': 'Ujjain, Madhya Pradesh'},
 '917343':{'en': 'Ujjain, Madhya Pradesh'},
 '917344':{'en': 'Ujjain, Madhya Pradesh'},
 '917345':{'en': 'Ujjain, Madhya Pradesh'},
 '917346':{'en': 'Ujjain, Madhya Pradesh'},
 '917347':{'en': 'Ujjain, Madhya Pradesh'},
 '9173602':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173603':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173604':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173605':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173606':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173607':{'en': 'Shujalpur, Madhya Pradesh'},
 '9173612':{'en': 'Susner, Madhya Pradesh'},
 '9173613':{'en': 'Susner, Madhya Pradesh'},
 '9173614':{'en': 'Susner, Madhya Pradesh'},
 '9173615':{'en': 'Susner, Madhya Pradesh'},
 '9173616':{'en': 'Susner, Madhya Pradesh'},
 '9173617':{'en': 'Susner, Madhya Pradesh'},
 '9173622':{'en': 'Agar, Madhya Pradesh'},
 '9173623':{'en': 'Agar, Madhya Pradesh'},
 '9173624':{'en': 'Agar, Madhya Pradesh'},
 '9173625':{'en': 'Agar, Madhya Pradesh'},
 '9173626':{'en': 'Agar, Madhya Pradesh'},
 '9173627':{'en': 'Agar, Madhya Pradesh'},
 '9173632':{'en': 'Berchha, Madhya Pradesh'},
 '9173633':{'en': 'Berchha, Madhya Pradesh'},
 '9173634':{'en': 'Berchha, Madhya Pradesh'},
 '9173635':{'en': 'Berchha, Madhya Pradesh'},
 '9173636':{'en': 'Berchha, Madhya Pradesh'},
 '9173637':{'en': 'Berchha, Madhya Pradesh'},
 '9173642':{'en': 'Shajapur, Madhya Pradesh'},
 '9173643':{'en': 'Shajapur, Madhya Pradesh'},
 '9173644':{'en': 'Shajapur, Madhya Pradesh'},
 '9173645':{'en': 'Shajapur, Madhya Pradesh'},
 '9173646':{'en': 'Shajapur, Madhya Pradesh'},
 '9173647':{'en': 'Shajapur, Madhya Pradesh'},
 '9173652':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173653':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173654':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173655':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173656':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173657':{'en': 'Mahidpurcity, Madhya Pradesh'},
 '9173662':{'en': 'Khachrod, Madhya Pradesh'},
 '9173663':{'en': 'Khachrod, Madhya Pradesh'},
 '9173664':{'en': 'Khachrod, Madhya Pradesh'},
 '9173665':{'en': 'Khachrod, Madhya Pradesh'},
 '9173666':{'en': 'Khachrod, Madhya Pradesh'},
 '9173667':{'en': 'Khachrod, Madhya Pradesh'},
 '9173672':{'en': 'Badnagar, Madhya Pradesh'},
 '9173673':{'en': 'Badnagar, Madhya Pradesh'},
 '9173674':{'en': 'Badnagar, Madhya Pradesh'},
 '9173675':{'en': 'Badnagar, Madhya Pradesh'},
 '9173676':{'en': 'Badnagar, Madhya Pradesh'},
 '9173677':{'en': 'Badnagar, Madhya Pradesh'},
 '9173682':{'en': 'Ghatia, Madhya Pradesh'},
 '9173683':{'en': 'Ghatia, Madhya Pradesh'},
 '9173684':{'en': 'Ghatia, Madhya Pradesh'},
 '9173685':{'en': 'Ghatia, Madhya Pradesh'},
 '9173686':{'en': 'Ghatia, Madhya Pradesh'},
 '9173687':{'en': 'Ghatia, Madhya Pradesh'},
 '9173692':{'en': 'Tarana, Madhya Pradesh'},
 '9173693':{'en': 'Tarana, Madhya Pradesh'},
 '9173694':{'en': 'Tarana, Madhya Pradesh'},
 '9173695':{'en': 'Tarana, Madhya Pradesh'},
 '9173696':{'en': 'Tarana, Madhya Pradesh'},
 '9173697':{'en': 'Tarana, Madhya Pradesh'},
 '9173702':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173703':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173704':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173705':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173706':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173707':{'en': 'Khilchipur, Madhya Pradesh'},
 '9173712':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173713':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173714':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173715':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173716':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173717':{'en': 'Sarangpur, Madhya Pradesh'},
 '9173722':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173723':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173724':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173725':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173726':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173727':{'en': 'Rajgarh, Madhya Pradesh'},
 '9173742':{'en': 'Biaora, Madhya Pradesh'},
 '9173743':{'en': 'Biaora, Madhya Pradesh'},
 '9173744':{'en': 'Biaora, Madhya Pradesh'},
 '9173745':{'en': 'Biaora, Madhya Pradesh'},
 '9173746':{'en': 'Biaora, Madhya Pradesh'},
 '9173747':{'en': 'Biaora, Madhya Pradesh'},
 '9173752':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173753':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173754':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173755':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173756':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173757':{'en': 'Narsingharh, Madhya Pradesh'},
 '9173902':{'en': 'Thandla, Madhya Pradesh'},
 '9173903':{'en': 'Thandla, Madhya Pradesh'},
 '9173904':{'en': 'Thandla, Madhya Pradesh'},
 '9173905':{'en': 'Thandla, Madhya Pradesh'},
 '9173906':{'en': 'Thandla, Madhya Pradesh'},
 '9173907':{'en': 'Thandla, Madhya Pradesh'},
 '9173912':{'en': 'Petlawad, Madhya Pradesh'},
 '9173913':{'en': 'Petlawad, Madhya Pradesh'},
 '9173914':{'en': 'Petlawad, Madhya Pradesh'},
 '9173915':{'en': 'Petlawad, Madhya Pradesh'},
 '9173916':{'en': 'Petlawad, Madhya Pradesh'},
 '9173917':{'en': 'Petlawad, Madhya Pradesh'},
 '9173922':{'en': 'Jhabua, Madhya Pradesh'},
 '9173923':{'en': 'Jhabua, Madhya Pradesh'},
 '9173924':{'en': 'Jhabua, Madhya Pradesh'},
 '9173925':{'en': 'Jhabua, Madhya Pradesh'},
 '9173926':{'en': 'Jhabua, Madhya Pradesh'},
 '9173927':{'en': 'Jhabua, Madhya Pradesh'},
 '9173932':{'en': 'Jobat, Madhya Pradesh'},
 '9173933':{'en': 'Jobat, Madhya Pradesh'},
 '9173934':{'en': 'Jobat, Madhya Pradesh'},
 '9173935':{'en': 'Jobat, Madhya Pradesh'},
 '9173936':{'en': 'Jobat, Madhya Pradesh'},
 '9173937':{'en': 'Jobat, Madhya Pradesh'},
 '9173942':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173943':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173944':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173945':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173946':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173947':{'en': 'Alirajpur, Madhya Pradesh'},
 '9173952':{'en': 'Sondhwa, Madhya Pradesh'},
 '9173953':{'en': 'Sondhwa, Madhya Pradesh'},
 '9173954':{'en': 'Sondhwa, Madhya Pradesh'},
 '9173955':{'en': 'Sondhwa, Madhya Pradesh'},
 '9173956':{'en': 'Sondhwa, Madhya Pradesh'},
 '9173957':{'en': 'Sondhwa, Madhya Pradesh'},
 '9174102':{'en': 'Alot, Madhya Pradesh'},
 '9174103':{'en': 'Alot, Madhya Pradesh'},
 '9174104':{'en': 'Alot, Madhya Pradesh'},
 '9174105':{'en': 'Alot, Madhya Pradesh'},
 '9174106':{'en': 'Alot, Madhya Pradesh'},
 '9174107':{'en': 'Alot, Madhya Pradesh'},
 '9174122':{'en': 'Ratlam, Madhya Pradesh'},
 '9174123':{'en': 'Ratlam, Madhya Pradesh'},
 '9174124':{'en': 'Ratlam, Madhya Pradesh'},
 '9174125':{'en': 'Ratlam, Madhya Pradesh'},
 '9174126':{'en': 'Ratlam, Madhya Pradesh'},
 '9174127':{'en': 'Ratlam, Madhya Pradesh'},
 '9174132':{'en': 'Sailana, Madhya Pradesh'},
 '9174133':{'en': 'Sailana, Madhya Pradesh'},
 '9174134':{'en': 'Sailana, Madhya Pradesh'},
 '9174135':{'en': 'Sailana, Madhya Pradesh'},
 '9174136':{'en': 'Sailana, Madhya Pradesh'},
 '9174137':{'en': 'Sailana, Madhya Pradesh'},
 '9174142':{'en': 'Jaora, Madhya Pradesh'},
 '9174143':{'en': 'Jaora, Madhya Pradesh'},
 '9174144':{'en': 'Jaora, Madhya Pradesh'},
 '9174145':{'en': 'Jaora, Madhya Pradesh'},
 '9174146':{'en': 'Jaora, Madhya Pradesh'},
 '9174147':{'en': 'Jaora, Madhya Pradesh'},
 '9174202':{'en': 'Jawad, Madhya Pradesh'},
 '9174203':{'en': 'Jawad, Madhya Pradesh'},
 '9174204':{'en': 'Jawad, Madhya Pradesh'},
 '9174205':{'en': 'Jawad, Madhya Pradesh'},
 '9174206':{'en': 'Jawad, Madhya Pradesh'},
 '9174207':{'en': 'Jawad, Madhya Pradesh'},
 '9174212':{'en': 'Manasa, Madhya Pradesh'},
 '9174213':{'en': 'Manasa, Madhya Pradesh'},
 '9174214':{'en': 'Manasa, Madhya Pradesh'},
 '9174215':{'en': 'Manasa, Madhya Pradesh'},
 '9174216':{'en': 'Manasa, Madhya Pradesh'},
 '9174217':{'en': 'Manasa, Madhya Pradesh'},
 '9174222':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174223':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174224':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174225':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174226':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174227':{'en': 'Mandsaur, Madhya Pradesh'},
 '9174232':{'en': 'Neemuch, Madhya Pradesh'},
 '9174233':{'en': 'Neemuch, Madhya Pradesh'},
 '9174234':{'en': 'Neemuch, Madhya Pradesh'},
 '9174235':{'en': 'Neemuch, Madhya Pradesh'},
 '9174236':{'en': 'Neemuch, Madhya Pradesh'},
 '9174237':{'en': 'Neemuch, Madhya Pradesh'},
 '9174242':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174243':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174244':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174245':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174246':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174247':{'en': 'Malhargarh, Madhya Pradesh'},
 '9174252':{'en': 'Garoth, Madhya Pradesh'},
 '9174253':{'en': 'Garoth, Madhya Pradesh'},
 '9174254':{'en': 'Garoth, Madhya Pradesh'},
 '9174255':{'en': 'Garoth, Madhya Pradesh'},
 '9174256':{'en': 'Garoth, Madhya Pradesh'},
 '9174257':{'en': 'Garoth, Madhya Pradesh'},
 '9174262':{'en': 'Sitamau, Madhya Pradesh'},
 '9174263':{'en': 'Sitamau, Madhya Pradesh'},
 '9174264':{'en': 'Sitamau, Madhya Pradesh'},
 '9174265':{'en': 'Sitamau, Madhya Pradesh'},
 '9174266':{'en': 'Sitamau, Madhya Pradesh'},
 '9174267':{'en': 'Sitamau, Madhya Pradesh'},
 '9174272':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174273':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174274':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174275':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174276':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174277':{'en': 'Bhanpura, Madhya Pradesh'},
 '9174302':{'en': 'Khanpur, Rajasthan'},
 '9174303':{'en': 'Khanpur, Rajasthan'},
 '9174304':{'en': 'Khanpur, Rajasthan'},
 '9174305':{'en': 'Khanpur, Rajasthan'},
 '9174306':{'en': 'Khanpur, Rajasthan'},
 '9174307':{'en': 'Khanpur, Rajasthan'},
 '9174312':{'en': 'Aklera, Rajasthan'},
 '9174313':{'en': 'Aklera, Rajasthan'},
 '9174314':{'en': 'Aklera, Rajasthan'},
 '9174315':{'en': 'Aklera, Rajasthan'},
 '9174316':{'en': 'Aklera, Rajasthan'},
 '9174317':{'en': 'Aklera, Rajasthan'},
 '9174322':{'en': 'Jhalawar, Rajasthan'},
 '9174323':{'en': 'Jhalawar, Rajasthan'},
 '9174324':{'en': 'Jhalawar, Rajasthan'},
 '9174325':{'en': 'Jhalawar, Rajasthan'},
 '9174326':{'en': 'Jhalawar, Rajasthan'},
 '9174327':{'en': 'Jhalawar, Rajasthan'},
 '9174332':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174333':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174334':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174335':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174336':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174337':{'en': 'Pachpahar/Bhawanimandi, Rajasthan'},
 '9174342':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174343':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174344':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174345':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174346':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174347':{'en': 'Pirawa/Raipur, Rajasthan'},
 '9174352':{'en': 'Gangdhar, Rajasthan'},
 '9174353':{'en': 'Gangdhar, Rajasthan'},
 '9174354':{'en': 'Gangdhar, Rajasthan'},
 '9174355':{'en': 'Gangdhar, Rajasthan'},
 '9174356':{'en': 'Gangdhar, Rajasthan'},
 '9174357':{'en': 'Gangdhar, Rajasthan'},
 '9174362':{'en': 'Hindoli, Rajasthan'},
 '9174363':{'en': 'Hindoli, Rajasthan'},
 '9174364':{'en': 'Hindoli, Rajasthan'},
 '9174365':{'en': 'Hindoli, Rajasthan'},
 '9174366':{'en': 'Hindoli, Rajasthan'},
 '9174367':{'en': 'Hindoli, Rajasthan'},
 '9174372':{'en': 'Nainwa, Rajasthan'},
 '9174373':{'en': 'Nainwa, Rajasthan'},
 '9174374':{'en': 'Nainwa, Rajasthan'},
 '9174375':{'en': 'Nainwa, Rajasthan'},
 '9174376':{'en': 'Nainwa, Rajasthan'},
 '9174377':{'en': 'Nainwa, Rajasthan'},
 '9174382':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '9174383':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '9174384':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '9174385':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '9174386':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '9174387':{'en': 'Keshoraipatan/Patan, Rajasthan'},
 '917442':{'en': 'Ladpura/Kota, Rajasthan'},
 '917443':{'en': 'Ladpura/Kota, Rajasthan'},
 '917444':{'en': 'Ladpura/Kota, Rajasthan'},
 '917445':{'en': 'Ladpura/Kota, Rajasthan'},
 '917446':{'en': 'Ladpura/Kota, Rajasthan'},
 '917447':{'en': 'Ladpura/Kota, Rajasthan'},
 '9174502':{'en': 'Sangod, Rajasthan'},
 '9174503':{'en': 'Sangod, Rajasthan'},
 '9174504':{'en': 'Sangod, Rajasthan'},
 '9174505':{'en': 'Sangod, Rajasthan'},
 '9174506':{'en': 'Sangod, Rajasthan'},
 '9174507':{'en': 'Sangod, Rajasthan'},
 '9174512':{'en': 'Atru, Rajasthan'},
 '9174513':{'en': 'Atru, Rajasthan'},
 '9174514':{'en': 'Atru, Rajasthan'},
 '9174515':{'en': 'Atru, Rajasthan'},
 '9174516':{'en': 'Atru, Rajasthan'},
 '9174517':{'en': 'Atru, Rajasthan'},
 '9174522':{'en': 'Chhabra, Rajasthan'},
 '9174523':{'en': 'Chhabra, Rajasthan'},
 '9174524':{'en': 'Chhabra, Rajasthan'},
 '9174525':{'en': 'Chhabra, Rajasthan'},
 '9174526':{'en': 'Chhabra, Rajasthan'},
 '9174527':{'en': 'Chhabra, Rajasthan'},
 '9174532':{'en': 'Baran, Rajasthan'},
 '9174533':{'en': 'Baran, Rajasthan'},
 '9174534':{'en': 'Baran, Rajasthan'},
 '9174535':{'en': 'Baran, Rajasthan'},
 '9174536':{'en': 'Baran, Rajasthan'},
 '9174537':{'en': 'Baran, Rajasthan'},
 '9174542':{'en': 'Chhipaborad, Rajasthan'},
 '9174543':{'en': 'Chhipaborad, Rajasthan'},
 '9174544':{'en': 'Chhipaborad, Rajasthan'},
 '9174545':{'en': 'Chhipaborad, Rajasthan'},
 '9174546':{'en': 'Chhipaborad, Rajasthan'},
 '9174547':{'en': 'Chhipaborad, Rajasthan'},
 '9174552':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174553':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174554':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174555':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174556':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174557':{'en': 'Digod/Sultanpur, Rajasthan'},
 '9174562':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174563':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174564':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174565':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174566':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174567':{'en': 'Kishanganj/Bhanwargarh, Rajasthan'},
 '9174572':{'en': 'Mangrol, Rajasthan'},
 '9174573':{'en': 'Mangrol, Rajasthan'},
 '9174574':{'en': 'Mangrol, Rajasthan'},
 '9174575':{'en': 'Mangrol, Rajasthan'},
 '9174576':{'en': 'Mangrol, Rajasthan'},
 '9174577':{'en': 'Mangrol, Rajasthan'},
 '9174582':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174583':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174584':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174585':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174586':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174587':{'en': 'Pipalda/Sumerganj Mandi, Rajasthan'},
 '9174592':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174593':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174594':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174595':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174596':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174597':{'en': 'Ramganj Mandi, Rajasthan'},
 '9174602':{'en': 'Sahabad, Rajasthan'},
 '9174603':{'en': 'Sahabad, Rajasthan'},
 '9174604':{'en': 'Sahabad, Rajasthan'},
 '9174605':{'en': 'Sahabad, Rajasthan'},
 '9174606':{'en': 'Sahabad, Rajasthan'},
 '9174607':{'en': 'Sahabad, Rajasthan'},
 '9174612':{'en': 'Mahuwa, Rajasthan'},
 '9174613':{'en': 'Mahuwa, Rajasthan'},
 '9174614':{'en': 'Mahuwa, Rajasthan'},
 '9174615':{'en': 'Mahuwa, Rajasthan'},
 '9174616':{'en': 'Mahuwa, Rajasthan'},
 '9174617':{'en': 'Mahuwa, Rajasthan'},
 '9174622':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174623':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174624':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174625':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174626':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174627':{'en': 'Sawaimadhopur, Rajasthan'},
 '9174632':{'en': 'Gangapur, Rajasthan'},
 '9174633':{'en': 'Gangapur, Rajasthan'},
 '9174634':{'en': 'Gangapur, Rajasthan'},
 '9174635':{'en': 'Gangapur, Rajasthan'},
 '9174636':{'en': 'Gangapur, Rajasthan'},
 '9174637':{'en': 'Gangapur, Rajasthan'},
 '9174642':{'en': 'Karauli, Rajasthan'},
 '9174643':{'en': 'Karauli, Rajasthan'},
 '9174644':{'en': 'Karauli, Rajasthan'},
 '9174645':{'en': 'Karauli, Rajasthan'},
 '9174646':{'en': 'Karauli, Rajasthan'},
 '9174647':{'en': 'Karauli, Rajasthan'},
 '9174652':{'en': 'Sapotra, Rajasthan'},
 '9174653':{'en': 'Sapotra, Rajasthan'},
 '9174654':{'en': 'Sapotra, Rajasthan'},
 '9174655':{'en': 'Sapotra, Rajasthan'},
 '9174656':{'en': 'Sapotra, Rajasthan'},
 '9174657':{'en': 'Sapotra, Rajasthan'},
 '9174662':{'en': 'Bonli, Rajasthan'},
 '9174663':{'en': 'Bonli, Rajasthan'},
 '9174664':{'en': 'Bonli, Rajasthan'},
 '9174665':{'en': 'Bonli, Rajasthan'},
 '9174666':{'en': 'Bonli, Rajasthan'},
 '9174667':{'en': 'Bonli, Rajasthan'},
 '9174672':{'en': 'Bamanwas, Rajasthan'},
 '9174673':{'en': 'Bamanwas, Rajasthan'},
 '9174674':{'en': 'Bamanwas, Rajasthan'},
 '9174675':{'en': 'Bamanwas, Rajasthan'},
 '9174676':{'en': 'Bamanwas, Rajasthan'},
 '9174677':{'en': 'Bamanwas, Rajasthan'},
 '9174682':{'en': 'Khandar, Rajasthan'},
 '9174683':{'en': 'Khandar, Rajasthan'},
 '9174684':{'en': 'Khandar, Rajasthan'},
 '9174685':{'en': 'Khandar, Rajasthan'},
 '9174686':{'en': 'Khandar, Rajasthan'},
 '9174687':{'en': 'Khandar, Rajasthan'},
 '9174692':{'en': 'Hindaun, Rajasthan'},
 '9174693':{'en': 'Hindaun, Rajasthan'},
 '9174694':{'en': 'Hindaun, Rajasthan'},
 '9174695':{'en': 'Hindaun, Rajasthan'},
 '9174696':{'en': 'Hindaun, Rajasthan'},
 '9174697':{'en': 'Hindaun, Rajasthan'},
 '917472':{'en': 'Bundi, Rajasthan'},
 '917473':{'en': 'Bundi, Rajasthan'},
 '917474':{'en': 'Bundi, Rajasthan'},
 '917475':{'en': 'Bundi, Rajasthan'},
 '917476':{'en': 'Bundi, Rajasthan'},
 '917477':{'en': 'Bundi, Rajasthan'},
 '9174802':{'en': 'Goharganj, Madhya Pradesh'},
 '9174803':{'en': 'Goharganj, Madhya Pradesh'},
 '9174804':{'en': 'Goharganj, Madhya Pradesh'},
 '9174805':{'en': 'Goharganj, Madhya Pradesh'},
 '9174806':{'en': 'Goharganj, Madhya Pradesh'},
 '9174807':{'en': 'Goharganj, Madhya Pradesh'},
 '9174812':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174813':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174814':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174815':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174816':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174817':{'en': 'Gairatganj, Madhya Pradesh'},
 '9174822':{'en': 'Raisen, Madhya Pradesh'},
 '9174823':{'en': 'Raisen, Madhya Pradesh'},
 '9174824':{'en': 'Raisen, Madhya Pradesh'},
 '9174825':{'en': 'Raisen, Madhya Pradesh'},
 '9174826':{'en': 'Raisen, Madhya Pradesh'},
 '9174827':{'en': 'Raisen, Madhya Pradesh'},
 '9174842':{'en': 'Silwani, Madhya Pradesh'},
 '9174843':{'en': 'Silwani, Madhya Pradesh'},
 '9174844':{'en': 'Silwani, Madhya Pradesh'},
 '9174845':{'en': 'Silwani, Madhya Pradesh'},
 '9174846':{'en': 'Silwani, Madhya Pradesh'},
 '9174847':{'en': 'Silwani, Madhya Pradesh'},
 '9174852':{'en': 'Udaipura, Madhya Pradesh'},
 '9174853':{'en': 'Udaipura, Madhya Pradesh'},
 '9174854':{'en': 'Udaipura, Madhya Pradesh'},
 '9174855':{'en': 'Udaipura, Madhya Pradesh'},
 '9174856':{'en': 'Udaipura, Madhya Pradesh'},
 '9174857':{'en': 'Udaipura, Madhya Pradesh'},
 '9174862':{'en': 'Bareli, Madhya Pradesh'},
 '9174863':{'en': 'Bareli, Madhya Pradesh'},
 '9174864':{'en': 'Bareli, Madhya Pradesh'},
 '9174865':{'en': 'Bareli, Madhya Pradesh'},
 '9174866':{'en': 'Bareli, Madhya Pradesh'},
 '9174867':{'en': 'Bareli, Madhya Pradesh'},
 '9174872':{'en': 'Begamganj, Madhya Pradesh'},
 '9174873':{'en': 'Begamganj, Madhya Pradesh'},
 '9174874':{'en': 'Begamganj, Madhya Pradesh'},
 '9174875':{'en': 'Begamganj, Madhya Pradesh'},
 '9174876':{'en': 'Begamganj, Madhya Pradesh'},
 '9174877':{'en': 'Begamganj, Madhya Pradesh'},
 '9174902':{'en': 'Pohari, Madhya Pradesh'},
 '9174903':{'en': 'Pohari, Madhya Pradesh'},
 '9174904':{'en': 'Pohari, Madhya Pradesh'},
 '9174905':{'en': 'Pohari, Madhya Pradesh'},
 '9174906':{'en': 'Pohari, Madhya Pradesh'},
 '9174907':{'en': 'Pohari, Madhya Pradesh'},
 '9174912':{'en': 'Narwar, Madhya Pradesh'},
 '9174913':{'en': 'Narwar, Madhya Pradesh'},
 '9174914':{'en': 'Narwar, Madhya Pradesh'},
 '9174915':{'en': 'Narwar, Madhya Pradesh'},
 '9174916':{'en': 'Narwar, Madhya Pradesh'},
 '9174917':{'en': 'Narwar, Madhya Pradesh'},
 '9174922':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174923':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174924':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174925':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174926':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174927':{'en': 'Shivpuri, Madhya Pradesh'},
 '9174932':{'en': 'Karera, Madhya Pradesh'},
 '9174933':{'en': 'Karera, Madhya Pradesh'},
 '9174934':{'en': 'Karera, Madhya Pradesh'},
 '9174935':{'en': 'Karera, Madhya Pradesh'},
 '9174936':{'en': 'Karera, Madhya Pradesh'},
 '9174937':{'en': 'Karera, Madhya Pradesh'},
 '9174942':{'en': 'Kolaras, Madhya Pradesh'},
 '9174943':{'en': 'Kolaras, Madhya Pradesh'},
 '9174944':{'en': 'Kolaras, Madhya Pradesh'},
 '9174945':{'en': 'Kolaras, Madhya Pradesh'},
 '9174946':{'en': 'Kolaras, Madhya Pradesh'},
 '9174947':{'en': 'Kolaras, Madhya Pradesh'},
 '9174952':{'en': 'Badarwas, Madhya Pradesh'},
 '9174953':{'en': 'Badarwas, Madhya Pradesh'},
 '9174954':{'en': 'Badarwas, Madhya Pradesh'},
 '9174955':{'en': 'Badarwas, Madhya Pradesh'},
 '9174956':{'en': 'Badarwas, Madhya Pradesh'},
 '9174957':{'en': 'Badarwas, Madhya Pradesh'},
 '9174962':{'en': 'Pichhore, Madhya Pradesh'},
 '9174963':{'en': 'Pichhore, Madhya Pradesh'},
 '9174964':{'en': 'Pichhore, Madhya Pradesh'},
 '9174965':{'en': 'Pichhore, Madhya Pradesh'},
 '9174966':{'en': 'Pichhore, Madhya Pradesh'},
 '9174967':{'en': 'Pichhore, Madhya Pradesh'},
 '9174972':{'en': 'Khaniadhana, Madhya Pradesh'},
 '9174973':{'en': 'Khaniadhana, Madhya Pradesh'},
 '9174974':{'en': 'Khaniadhana, Madhya Pradesh'},
 '9174975':{'en': 'Khaniadhana, Madhya Pradesh'},
 '9174976':{'en': 'Khaniadhana, Madhya Pradesh'},
 '9174977':{'en': 'Khaniadhana, Madhya Pradesh'},
 '917512':{'en': 'Gwalior, Madhya Pradesh'},
 '917513':{'en': 'Gwalior, Madhya Pradesh'},
 '917514':{'en': 'Gwalior, Madhya Pradesh'},
 '917515':{'en': 'Gwalior, Madhya Pradesh'},
 '917516':{'en': 'Gwalior, Madhya Pradesh'},
 '917517':{'en': 'Gwalior, Madhya Pradesh'},
 '9175212':{'en': 'Seondha, Madhya Pradesh'},
 '9175213':{'en': 'Seondha, Madhya Pradesh'},
 '9175214':{'en': 'Seondha, Madhya Pradesh'},
 '9175215':{'en': 'Seondha, Madhya Pradesh'},
 '9175216':{'en': 'Seondha, Madhya Pradesh'},
 '9175217':{'en': 'Seondha, Madhya Pradesh'},
 '9175222':{'en': 'Datia, Madhya Pradesh'},
 '9175223':{'en': 'Datia, Madhya Pradesh'},
 '9175224':{'en': 'Datia, Madhya Pradesh'},
 '9175225':{'en': 'Datia, Madhya Pradesh'},
 '9175226':{'en': 'Datia, Madhya Pradesh'},
 '9175227':{'en': 'Datia, Madhya Pradesh'},
 '9175232':{'en': 'Bhander, Madhya Pradesh'},
 '9175233':{'en': 'Bhander, Madhya Pradesh'},
 '9175234':{'en': 'Bhander, Madhya Pradesh'},
 '9175235':{'en': 'Bhander, Madhya Pradesh'},
 '9175236':{'en': 'Bhander, Madhya Pradesh'},
 '9175237':{'en': 'Bhander, Madhya Pradesh'},
 '9175242':{'en': 'Dabra, Madhya Pradesh'},
 '9175243':{'en': 'Dabra, Madhya Pradesh'},
 '9175244':{'en': 'Dabra, Madhya Pradesh'},
 '9175245':{'en': 'Dabra, Madhya Pradesh'},
 '9175246':{'en': 'Dabra, Madhya Pradesh'},
 '9175247':{'en': 'Dabra, Madhya Pradesh'},
 '9175252':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175253':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175254':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175255':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175256':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175257':{'en': 'Bhitarwar, Madhya Pradesh'},
 '9175262':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175263':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175264':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175265':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175266':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175267':{'en': 'Ghatigaon, Madhya Pradesh'},
 '9175272':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175273':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175274':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175275':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175276':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175277':{'en': 'Mehgaon, Madhya Pradesh'},
 '9175282':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175283':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175284':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175285':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175286':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175287':{'en': 'Bijaypur, Madhya Pradesh'},
 '9175292':{'en': 'Laher, Madhya Pradesh'},
 '9175293':{'en': 'Laher, Madhya Pradesh'},
 '9175294':{'en': 'Laher, Madhya Pradesh'},
 '9175295':{'en': 'Laher, Madhya Pradesh'},
 '9175296':{'en': 'Laher, Madhya Pradesh'},
 '9175297':{'en': 'Laher, Madhya Pradesh'},
 '9175302':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175303':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175304':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175305':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175306':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175307':{'en': 'Sheopurkalan, Madhya Pradesh'},
 '9175312':{'en': 'Baroda, Madhya Pradesh'},
 '9175313':{'en': 'Baroda, Madhya Pradesh'},
 '9175314':{'en': 'Baroda, Madhya Pradesh'},
 '9175315':{'en': 'Baroda, Madhya Pradesh'},
 '9175316':{'en': 'Baroda, Madhya Pradesh'},
 '9175317':{'en': 'Baroda, Madhya Pradesh'},
 '9175322':{'en': 'Morena, Madhya Pradesh'},
 '9175323':{'en': 'Morena, Madhya Pradesh'},
 '9175324':{'en': 'Morena, Madhya Pradesh'},
 '9175325':{'en': 'Morena, Madhya Pradesh'},
 '9175326':{'en': 'Morena, Madhya Pradesh'},
 '9175327':{'en': 'Morena, Madhya Pradesh'},
 '9175332':{'en': 'Karhal, Madhya Pradesh'},
 '9175333':{'en': 'Karhal, Madhya Pradesh'},
 '9175334':{'en': 'Karhal, Madhya Pradesh'},
 '9175335':{'en': 'Karhal, Madhya Pradesh'},
 '9175336':{'en': 'Karhal, Madhya Pradesh'},
 '9175337':{'en': 'Karhal, Madhya Pradesh'},
 '9175342':{'en': 'Bhind, Madhya Pradesh'},
 '9175343':{'en': 'Bhind, Madhya Pradesh'},
 '9175344':{'en': 'Bhind, Madhya Pradesh'},
 '9175345':{'en': 'Bhind, Madhya Pradesh'},
 '9175346':{'en': 'Bhind, Madhya Pradesh'},
 '9175347':{'en': 'Bhind, Madhya Pradesh'},
 '9175352':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175353':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175354':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175355':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175356':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175357':{'en': 'Raghunathpur, Madhya Pradesh'},
 '9175362':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175363':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175364':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175365':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175366':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175367':{'en': 'Sabalgarh, Madhya Pradesh'},
 '9175372':{'en': 'Jora, Madhya Pradesh'},
 '9175373':{'en': 'Jora, Madhya Pradesh'},
 '9175374':{'en': 'Jora, Madhya Pradesh'},
 '9175375':{'en': 'Jora, Madhya Pradesh'},
 '9175376':{'en': 'Jora, Madhya Pradesh'},
 '9175377':{'en': 'Jora, Madhya Pradesh'},
 '9175382':{'en': 'Ambah, Madhya Pradesh'},
 '9175383':{'en': 'Ambah, Madhya Pradesh'},
 '9175384':{'en': 'Ambah, Madhya Pradesh'},
 '9175385':{'en': 'Ambah, Madhya Pradesh'},
 '9175386':{'en': 'Ambah, Madhya Pradesh'},
 '9175387':{'en': 'Ambah, Madhya Pradesh'},
 '9175392':{'en': 'Gohad, Madhya Pradesh'},
 '9175393':{'en': 'Gohad, Madhya Pradesh'},
 '9175394':{'en': 'Gohad, Madhya Pradesh'},
 '9175395':{'en': 'Gohad, Madhya Pradesh'},
 '9175396':{'en': 'Gohad, Madhya Pradesh'},
 '9175397':{'en': 'Gohad, Madhya Pradesh'},
 '9175402':{'en': 'Bamori, Madhya Pradesh'},
 '9175403':{'en': 'Bamori, Madhya Pradesh'},
 '9175404':{'en': 'Bamori, Madhya Pradesh'},
 '9175405':{'en': 'Bamori, Madhya Pradesh'},
 '9175406':{'en': 'Bamori, Madhya Pradesh'},
 '9175407':{'en': 'Bamori, Madhya Pradesh'},
 '9175412':{'en': 'Isagarh, Madhya Pradesh'},
 '9175413':{'en': 'Isagarh, Madhya Pradesh'},
 '9175414':{'en': 'Isagarh, Madhya Pradesh'},
 '9175415':{'en': 'Isagarh, Madhya Pradesh'},
 '9175416':{'en': 'Isagarh, Madhya Pradesh'},
 '9175417':{'en': 'Isagarh, Madhya Pradesh'},
 '9175422':{'en': 'Guna, Madhya Pradesh'},
 '9175423':{'en': 'Guna, Madhya Pradesh'},
 '9175424':{'en': 'Guna, Madhya Pradesh'},
 '9175425':{'en': 'Guna, Madhya Pradesh'},
 '9175426':{'en': 'Guna, Madhya Pradesh'},
 '9175427':{'en': 'Guna, Madhya Pradesh'},
 '9175432':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175433':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175434':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175435':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175436':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175437':{'en': 'Ashoknagar, Madhya Pradesh'},
 '9175442':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175443':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175444':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175445':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175446':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175447':{'en': 'Raghogarh, Madhya Pradesh'},
 '9175452':{'en': 'Arone, Madhya Pradesh'},
 '9175453':{'en': 'Arone, Madhya Pradesh'},
 '9175454':{'en': 'Arone, Madhya Pradesh'},
 '9175455':{'en': 'Arone, Madhya Pradesh'},
 '9175456':{'en': 'Arone, Madhya Pradesh'},
 '9175457':{'en': 'Arone, Madhya Pradesh'},
 '9175462':{'en': 'Chachaura, Madhya Pradesh'},
 '9175463':{'en': 'Chachaura, Madhya Pradesh'},
 '9175464':{'en': 'Chachaura, Madhya Pradesh'},
 '9175465':{'en': 'Chachaura, Madhya Pradesh'},
 '9175466':{'en': 'Chachaura, Madhya Pradesh'},
 '9175467':{'en': 'Chachaura, Madhya Pradesh'},
 '9175472':{'en': 'Chanderi, Madhya Pradesh'},
 '9175473':{'en': 'Chanderi, Madhya Pradesh'},
 '9175474':{'en': 'Chanderi, Madhya Pradesh'},
 '9175475':{'en': 'Chanderi, Madhya Pradesh'},
 '9175476':{'en': 'Chanderi, Madhya Pradesh'},
 '9175477':{'en': 'Chanderi, Madhya Pradesh'},
 '9175482':{'en': 'Mungaoli, Madhya Pradesh'},
 '9175483':{'en': 'Mungaoli, Madhya Pradesh'},
 '9175484':{'en': 'Mungaoli, Madhya Pradesh'},
 '9175485':{'en': 'Mungaoli, Madhya Pradesh'},
 '9175486':{'en': 'Mungaoli, Madhya Pradesh'},
 '9175487':{'en': 'Mungaoli, Madhya Pradesh'},
 '917552':{'en': 'Bhopal, Madhya Pradesh'},
 '917553':{'en': 'Bhopal, Madhya Pradesh'},
 '917554':{'en': 'Bhopal, Madhya Pradesh'},
 '917555':{'en': 'Bhopal, Madhya Pradesh'},
 '917556':{'en': 'Bhopal, Madhya Pradesh'},
 '917557':{'en': 'Bhopal, Madhya Pradesh'},
 '9175602':{'en': 'Ashta, Madhya Pradesh'},
 '9175603':{'en': 'Ashta, Madhya Pradesh'},
 '9175604':{'en': 'Ashta, Madhya Pradesh'},
 '9175605':{'en': 'Ashta, Madhya Pradesh'},
 '9175606':{'en': 'Ashta, Madhya Pradesh'},
 '9175607':{'en': 'Ashta, Madhya Pradesh'},
 '9175612':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175613':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175614':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175615':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175616':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175617':{'en': 'Ichhawar, Madhya Pradesh'},
 '9175622':{'en': 'Sehore, Madhya Pradesh'},
 '9175623':{'en': 'Sehore, Madhya Pradesh'},
 '9175624':{'en': 'Sehore, Madhya Pradesh'},
 '9175625':{'en': 'Sehore, Madhya Pradesh'},
 '9175626':{'en': 'Sehore, Madhya Pradesh'},
 '9175627':{'en': 'Sehore, Madhya Pradesh'},
 '9175632':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175633':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175634':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175635':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175636':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175637':{'en': 'Nasrullaganj, Madhya Pradesh'},
 '9175642':{'en': 'Budhni, Madhya Pradesh'},
 '9175643':{'en': 'Budhni, Madhya Pradesh'},
 '9175644':{'en': 'Budhni, Madhya Pradesh'},
 '9175645':{'en': 'Budhni, Madhya Pradesh'},
 '9175646':{'en': 'Budhni, Madhya Pradesh'},
 '9175647':{'en': 'Budhni, Madhya Pradesh'},
 '9175652':{'en': 'Berasia, Madhya Pradesh'},
 '9175653':{'en': 'Berasia, Madhya Pradesh'},
 '9175654':{'en': 'Berasia, Madhya Pradesh'},
 '9175655':{'en': 'Berasia, Madhya Pradesh'},
 '9175656':{'en': 'Berasia, Madhya Pradesh'},
 '9175657':{'en': 'Berasia, Madhya Pradesh'},
 '9175702':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175703':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175704':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175705':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175706':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175707':{'en': 'Seonimalwa, Madhya Pradesh'},
 '9175712':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175713':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175714':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175715':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175716':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175717':{'en': 'Khirkiya, Madhya Pradesh'},
 '9175722':{'en': 'Itarsi, Madhya Pradesh'},
 '9175723':{'en': 'Itarsi, Madhya Pradesh'},
 '9175724':{'en': 'Itarsi, Madhya Pradesh'},
 '9175725':{'en': 'Itarsi, Madhya Pradesh'},
 '9175726':{'en': 'Itarsi, Madhya Pradesh'},
 '9175727':{'en': 'Itarsi, Madhya Pradesh'},
 '9175732':{'en': 'Timarani, Madhya Pradesh'},
 '9175733':{'en': 'Timarani, Madhya Pradesh'},
 '9175734':{'en': 'Timarani, Madhya Pradesh'},
 '9175735':{'en': 'Timarani, Madhya Pradesh'},
 '9175736':{'en': 'Timarani, Madhya Pradesh'},
 '9175737':{'en': 'Timarani, Madhya Pradesh'},
 '9175742':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175743':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175744':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175745':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175746':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175747':{'en': 'Hoshangabad, Madhya Pradesh'},
 '9175752':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175753':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175754':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175755':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175756':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175757':{'en': 'Sohagpur, Madhya Pradesh'},
 '9175762':{'en': 'Piparia, Madhya Pradesh'},
 '9175763':{'en': 'Piparia, Madhya Pradesh'},
 '9175764':{'en': 'Piparia, Madhya Pradesh'},
 '9175765':{'en': 'Piparia, Madhya Pradesh'},
 '9175766':{'en': 'Piparia, Madhya Pradesh'},
 '9175767':{'en': 'Piparia, Madhya Pradesh'},
 '9175772':{'en': 'Harda, Madhya Pradesh'},
 '9175773':{'en': 'Harda, Madhya Pradesh'},
 '9175774':{'en': 'Harda, Madhya Pradesh'},
 '9175775':{'en': 'Harda, Madhya Pradesh'},
 '9175776':{'en': 'Harda, Madhya Pradesh'},
 '9175777':{'en': 'Harda, Madhya Pradesh'},
 '9175782':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175783':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175784':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175785':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175786':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175787':{'en': 'Pachmarhi, Madhya Pradesh'},
 '9175802':{'en': 'Bina, Madhya Pradesh'},
 '9175803':{'en': 'Bina, Madhya Pradesh'},
 '9175804':{'en': 'Bina, Madhya Pradesh'},
 '9175805':{'en': 'Bina, Madhya Pradesh'},
 '9175806':{'en': 'Bina, Madhya Pradesh'},
 '9175807':{'en': 'Bina, Madhya Pradesh'},
 '9175812':{'en': 'Khurai, Madhya Pradesh'},
 '9175813':{'en': 'Khurai, Madhya Pradesh'},
 '9175814':{'en': 'Khurai, Madhya Pradesh'},
 '9175815':{'en': 'Khurai, Madhya Pradesh'},
 '9175816':{'en': 'Khurai, Madhya Pradesh'},
 '9175817':{'en': 'Khurai, Madhya Pradesh'},
 '9175822':{'en': 'Sagar, Madhya Pradesh'},
 '9175823':{'en': 'Sagar, Madhya Pradesh'},
 '9175824':{'en': 'Sagar, Madhya Pradesh'},
 '9175825':{'en': 'Sagar, Madhya Pradesh'},
 '9175826':{'en': 'Sagar, Madhya Pradesh'},
 '9175827':{'en': 'Sagar, Madhya Pradesh'},
 '9175832':{'en': 'Banda, Madhya Pradesh'},
 '9175833':{'en': 'Banda, Madhya Pradesh'},
 '9175834':{'en': 'Banda, Madhya Pradesh'},
 '9175835':{'en': 'Banda, Madhya Pradesh'},
 '9175836':{'en': 'Banda, Madhya Pradesh'},
 '9175837':{'en': 'Banda, Madhya Pradesh'},
 '9175842':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175843':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175844':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175845':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175846':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175847':{'en': 'Rahatgarh, Madhya Pradesh'},
 '9175852':{'en': 'Rehli, Madhya Pradesh'},
 '9175853':{'en': 'Rehli, Madhya Pradesh'},
 '9175854':{'en': 'Rehli, Madhya Pradesh'},
 '9175855':{'en': 'Rehli, Madhya Pradesh'},
 '9175856':{'en': 'Rehli, Madhya Pradesh'},
 '9175857':{'en': 'Rehli, Madhya Pradesh'},
 '9175862':{'en': 'Deori, Madhya Pradesh'},
 '9175863':{'en': 'Deori, Madhya Pradesh'},
 '9175864':{'en': 'Deori, Madhya Pradesh'},
 '9175865':{'en': 'Deori, Madhya Pradesh'},
 '9175866':{'en': 'Deori, Madhya Pradesh'},
 '9175867':{'en': 'Deori, Madhya Pradesh'},
 '9175902':{'en': 'Lateri, Madhya Pradesh'},
 '9175903':{'en': 'Lateri, Madhya Pradesh'},
 '9175904':{'en': 'Lateri, Madhya Pradesh'},
 '9175905':{'en': 'Lateri, Madhya Pradesh'},
 '9175906':{'en': 'Lateri, Madhya Pradesh'},
 '9175907':{'en': 'Lateri, Madhya Pradesh'},
 '9175912':{'en': 'Sironj, Madhya Pradesh'},
 '9175913':{'en': 'Sironj, Madhya Pradesh'},
 '9175914':{'en': 'Sironj, Madhya Pradesh'},
 '9175915':{'en': 'Sironj, Madhya Pradesh'},
 '9175916':{'en': 'Sironj, Madhya Pradesh'},
 '9175917':{'en': 'Sironj, Madhya Pradesh'},
 '9175922':{'en': 'Vidisha, Madhya Pradesh'},
 '9175923':{'en': 'Vidisha, Madhya Pradesh'},
 '9175924':{'en': 'Vidisha, Madhya Pradesh'},
 '9175925':{'en': 'Vidisha, Madhya Pradesh'},
 '9175926':{'en': 'Vidisha, Madhya Pradesh'},
 '9175927':{'en': 'Vidisha, Madhya Pradesh'},
 '9175932':{'en': 'Kurwai, Madhya Pradesh'},
 '9175933':{'en': 'Kurwai, Madhya Pradesh'},
 '9175934':{'en': 'Kurwai, Madhya Pradesh'},
 '9175935':{'en': 'Kurwai, Madhya Pradesh'},
 '9175936':{'en': 'Kurwai, Madhya Pradesh'},
 '9175937':{'en': 'Kurwai, Madhya Pradesh'},
 '9175942':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175943':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175944':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175945':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175946':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175947':{'en': 'Ganjbasoda, Madhya Pradesh'},
 '9175952':{'en': 'Nateran, Madhya Pradesh'},
 '9175953':{'en': 'Nateran, Madhya Pradesh'},
 '9175954':{'en': 'Nateran, Madhya Pradesh'},
 '9175955':{'en': 'Nateran, Madhya Pradesh'},
 '9175956':{'en': 'Nateran, Madhya Pradesh'},
 '9175957':{'en': 'Nateran, Madhya Pradesh'},
 '9175962':{'en': 'Gyraspur, Madhya Pradesh'},
 '9175963':{'en': 'Gyraspur, Madhya Pradesh'},
 '9175964':{'en': 'Gyraspur, Madhya Pradesh'},
 '9175965':{'en': 'Gyraspur, Madhya Pradesh'},
 '9175966':{'en': 'Gyraspur, Madhya Pradesh'},
 '9175967':{'en': 'Gyraspur, Madhya Pradesh'},
 '9176012':{'en': 'Patharia, Madhya Pradesh'},
 '9176013':{'en': 'Patharia, Madhya Pradesh'},
 '9176014':{'en': 'Patharia, Madhya Pradesh'},
 '9176015':{'en': 'Patharia, Madhya Pradesh'},
 '9176016':{'en': 'Patharia, Madhya Pradesh'},
 '9176017':{'en': 'Patharia, Madhya Pradesh'},
 '9176032':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176033':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176034':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176035':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176036':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176037':{'en': 'Tendukheda, Madhya Pradesh'},
 '9176042':{'en': 'Hatta, Madhya Pradesh'},
 '9176043':{'en': 'Hatta, Madhya Pradesh'},
 '9176044':{'en': 'Hatta, Madhya Pradesh'},
 '9176045':{'en': 'Hatta, Madhya Pradesh'},
 '9176046':{'en': 'Hatta, Madhya Pradesh'},
 '9176047':{'en': 'Hatta, Madhya Pradesh'},
 '9176052':{'en': 'Patera, Madhya Pradesh'},
 '9176053':{'en': 'Patera, Madhya Pradesh'},
 '9176054':{'en': 'Patera, Madhya Pradesh'},
 '9176055':{'en': 'Patera, Madhya Pradesh'},
 '9176056':{'en': 'Patera, Madhya Pradesh'},
 '9176057':{'en': 'Patera, Madhya Pradesh'},
 '9176062':{'en': 'Jabera, Madhya Pradesh'},
 '9176063':{'en': 'Jabera, Madhya Pradesh'},
 '9176064':{'en': 'Jabera, Madhya Pradesh'},
 '9176065':{'en': 'Jabera, Madhya Pradesh'},
 '9176066':{'en': 'Jabera, Madhya Pradesh'},
 '9176067':{'en': 'Jabera, Madhya Pradesh'},
 '9176082':{'en': 'Bijawar, Madhya Pradesh'},
 '9176083':{'en': 'Bijawar, Madhya Pradesh'},
 '9176084':{'en': 'Bijawar, Madhya Pradesh'},
 '9176085':{'en': 'Bijawar, Madhya Pradesh'},
 '9176086':{'en': 'Bijawar, Madhya Pradesh'},
 '9176087':{'en': 'Bijawar, Madhya Pradesh'},
 '9176092':{'en': 'Buxwaha, Madhya Pradesh'},
 '9176093':{'en': 'Buxwaha, Madhya Pradesh'},
 '9176094':{'en': 'Buxwaha, Madhya Pradesh'},
 '9176095':{'en': 'Buxwaha, Madhya Pradesh'},
 '9176096':{'en': 'Buxwaha, Madhya Pradesh'},
 '9176097':{'en': 'Buxwaha, Madhya Pradesh'},
 '917612':{'en': 'Jabalpur, Madhya Pradesh'},
 '917613':{'en': 'Jabalpur, Madhya Pradesh'},
 '917614':{'en': 'Jabalpur, Madhya Pradesh'},
 '917615':{'en': 'Jabalpur, Madhya Pradesh'},
 '917616':{'en': 'Jabalpur, Madhya Pradesh'},
 '917617':{'en': 'Jabalpur, Madhya Pradesh'},
 '9176212':{'en': 'Patan, Madhya Pradesh'},
 '9176213':{'en': 'Patan, Madhya Pradesh'},
 '9176214':{'en': 'Patan, Madhya Pradesh'},
 '9176215':{'en': 'Patan, Madhya Pradesh'},
 '9176216':{'en': 'Patan, Madhya Pradesh'},
 '9176217':{'en': 'Patan, Madhya Pradesh'},
 '9176222':{'en': 'Katni, Madhya Pradesh'},
 '9176223':{'en': 'Katni, Madhya Pradesh'},
 '9176224':{'en': 'Katni, Madhya Pradesh'},
 '9176225':{'en': 'Katni, Madhya Pradesh'},
 '9176226':{'en': 'Katni, Madhya Pradesh'},
 '9176227':{'en': 'Katni, Madhya Pradesh'},
 '9176232':{'en': 'Kundam, Madhya Pradesh'},
 '9176233':{'en': 'Kundam, Madhya Pradesh'},
 '9176234':{'en': 'Kundam, Madhya Pradesh'},
 '9176235':{'en': 'Kundam, Madhya Pradesh'},
 '9176236':{'en': 'Kundam, Madhya Pradesh'},
 '9176237':{'en': 'Kundam, Madhya Pradesh'},
 '9176242':{'en': 'Sihora, Madhya Pradesh'},
 '9176243':{'en': 'Sihora, Madhya Pradesh'},
 '9176244':{'en': 'Sihora, Madhya Pradesh'},
 '9176245':{'en': 'Sihora, Madhya Pradesh'},
 '9176246':{'en': 'Sihora, Madhya Pradesh'},
 '9176247':{'en': 'Sihora, Madhya Pradesh'},
 '9176252':{'en': 'Umariapan, Madhya Pradesh'},
 '9176253':{'en': 'Umariapan, Madhya Pradesh'},
 '9176254':{'en': 'Umariapan, Madhya Pradesh'},
 '9176255':{'en': 'Umariapan, Madhya Pradesh'},
 '9176256':{'en': 'Umariapan, Madhya Pradesh'},
 '9176257':{'en': 'Umariapan, Madhya Pradesh'},
 '9176262':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176263':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176264':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176265':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176266':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176267':{'en': 'Vijayraghogarh, Madhya Pradesh'},
 '9176272':{'en': 'Manpur, Madhya Pradesh'},
 '9176273':{'en': 'Manpur, Madhya Pradesh'},
 '9176274':{'en': 'Manpur, Madhya Pradesh'},
 '9176275':{'en': 'Manpur, Madhya Pradesh'},
 '9176276':{'en': 'Manpur, Madhya Pradesh'},
 '9176277':{'en': 'Manpur, Madhya Pradesh'},
 '9176282':{'en': 'Karpa, Madhya Pradesh'},
 '9176283':{'en': 'Karpa, Madhya Pradesh'},
 '9176284':{'en': 'Karpa, Madhya Pradesh'},
 '9176285':{'en': 'Karpa, Madhya Pradesh'},
 '9176286':{'en': 'Karpa, Madhya Pradesh'},
 '9176287':{'en': 'Karpa, Madhya Pradesh'},
 '9176292':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176293':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176294':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176295':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176296':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176297':{'en': 'Pushprajgarh, Madhya Pradesh'},
 '9176302':{'en': 'Katangi, Madhya Pradesh'},
 '9176303':{'en': 'Katangi, Madhya Pradesh'},
 '9176304':{'en': 'Katangi, Madhya Pradesh'},
 '9176305':{'en': 'Katangi, Madhya Pradesh'},
 '9176306':{'en': 'Katangi, Madhya Pradesh'},
 '9176307':{'en': 'Katangi, Madhya Pradesh'},
 '9176322':{'en': 'Balaghat, Madhya Pradesh'},
 '9176323':{'en': 'Balaghat, Madhya Pradesh'},
 '9176324':{'en': 'Balaghat, Madhya Pradesh'},
 '9176325':{'en': 'Balaghat, Madhya Pradesh'},
 '9176326':{'en': 'Balaghat, Madhya Pradesh'},
 '9176327':{'en': 'Balaghat, Madhya Pradesh'},
 '9176332':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176333':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176334':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176335':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176336':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176337':{'en': 'Waraseoni, Madhya Pradesh'},
 '9176342':{'en': 'Lamta, Madhya Pradesh'},
 '9176343':{'en': 'Lamta, Madhya Pradesh'},
 '9176344':{'en': 'Lamta, Madhya Pradesh'},
 '9176345':{'en': 'Lamta, Madhya Pradesh'},
 '9176346':{'en': 'Lamta, Madhya Pradesh'},
 '9176347':{'en': 'Lamta, Madhya Pradesh'},
 '9176352':{'en': 'Lanji, Madhya Pradesh'},
 '9176353':{'en': 'Lanji, Madhya Pradesh'},
 '9176354':{'en': 'Lanji, Madhya Pradesh'},
 '9176355':{'en': 'Lanji, Madhya Pradesh'},
 '9176356':{'en': 'Lanji, Madhya Pradesh'},
 '9176357':{'en': 'Lanji, Madhya Pradesh'},
 '9176362':{'en': 'Baihar, Madhya Pradesh'},
 '9176363':{'en': 'Baihar, Madhya Pradesh'},
 '9176364':{'en': 'Baihar, Madhya Pradesh'},
 '9176365':{'en': 'Baihar, Madhya Pradesh'},
 '9176366':{'en': 'Baihar, Madhya Pradesh'},
 '9176367':{'en': 'Baihar, Madhya Pradesh'},
 '9176372':{'en': 'Birsa, Madhya Pradesh'},
 '9176373':{'en': 'Birsa, Madhya Pradesh'},
 '9176374':{'en': 'Birsa, Madhya Pradesh'},
 '9176375':{'en': 'Birsa, Madhya Pradesh'},
 '9176376':{'en': 'Birsa, Madhya Pradesh'},
 '9176377':{'en': 'Birsa, Madhya Pradesh'},
 '9176382':{'en': 'Damoh, Madhya Pradesh'},
 '9176383':{'en': 'Damoh, Madhya Pradesh'},
 '9176384':{'en': 'Damoh, Madhya Pradesh'},
 '9176385':{'en': 'Damoh, Madhya Pradesh'},
 '9176386':{'en': 'Damoh, Madhya Pradesh'},
 '9176387':{'en': 'Damoh, Madhya Pradesh'},
 '9176402':{'en': 'Shahpur, Madhya Pradesh'},
 '9176403':{'en': 'Shahpur, Madhya Pradesh'},
 '9176404':{'en': 'Shahpur, Madhya Pradesh'},
 '9176405':{'en': 'Shahpur, Madhya Pradesh'},
 '9176406':{'en': 'Shahpur, Madhya Pradesh'},
 '9176407':{'en': 'Shahpur, Madhya Pradesh'},
 '9176412':{'en': 'Niwas, Madhya Pradesh'},
 '9176413':{'en': 'Niwas, Madhya Pradesh'},
 '9176414':{'en': 'Niwas, Madhya Pradesh'},
 '9176415':{'en': 'Niwas, Madhya Pradesh'},
 '9176416':{'en': 'Niwas, Madhya Pradesh'},
 '9176417':{'en': 'Niwas, Madhya Pradesh'},
 '9176422':{'en': 'Mandla, Madhya Pradesh'},
 '9176423':{'en': 'Mandla, Madhya Pradesh'},
 '9176424':{'en': 'Mandla, Madhya Pradesh'},
 '9176425':{'en': 'Mandla, Madhya Pradesh'},
 '9176426':{'en': 'Mandla, Madhya Pradesh'},
 '9176427':{'en': 'Mandla, Madhya Pradesh'},
 '9176432':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176433':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176434':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176435':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176436':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176437':{'en': 'Bijadandi, Madhya Pradesh'},
 '9176442':{'en': 'Dindori, Madhya Pradesh'},
 '9176443':{'en': 'Dindori, Madhya Pradesh'},
 '9176444':{'en': 'Dindori, Madhya Pradesh'},
 '9176445':{'en': 'Dindori, Madhya Pradesh'},
 '9176446':{'en': 'Dindori, Madhya Pradesh'},
 '9176447':{'en': 'Dindori, Madhya Pradesh'},
 '9176452':{'en': 'Karanjia, Madhya Pradesh'},
 '9176453':{'en': 'Karanjia, Madhya Pradesh'},
 '9176454':{'en': 'Karanjia, Madhya Pradesh'},
 '9176455':{'en': 'Karanjia, Madhya Pradesh'},
 '9176456':{'en': 'Karanjia, Madhya Pradesh'},
 '9176457':{'en': 'Karanjia, Madhya Pradesh'},
 '9176462':{'en': 'Nainpur, Madhya Pradesh'},
 '9176463':{'en': 'Nainpur, Madhya Pradesh'},
 '9176464':{'en': 'Nainpur, Madhya Pradesh'},
 '9176465':{'en': 'Nainpur, Madhya Pradesh'},
 '9176466':{'en': 'Nainpur, Madhya Pradesh'},
 '9176467':{'en': 'Nainpur, Madhya Pradesh'},
 '9176472':{'en': 'Ghughari, Madhya Pradesh'},
 '9176473':{'en': 'Ghughari, Madhya Pradesh'},
 '9176474':{'en': 'Ghughari, Madhya Pradesh'},
 '9176475':{'en': 'Ghughari, Madhya Pradesh'},
 '9176476':{'en': 'Ghughari, Madhya Pradesh'},
 '9176477':{'en': 'Ghughari, Madhya Pradesh'},
 '9176482':{'en': 'Mawai, Madhya Pradesh'},
 '9176483':{'en': 'Mawai, Madhya Pradesh'},
 '9176484':{'en': 'Mawai, Madhya Pradesh'},
 '9176485':{'en': 'Mawai, Madhya Pradesh'},
 '9176486':{'en': 'Mawai, Madhya Pradesh'},
 '9176487':{'en': 'Mawai, Madhya Pradesh'},
 '9176492':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176493':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176494':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176495':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176496':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176497':{'en': 'Kakaiya, Madhya Pradesh'},
 '9176502':{'en': 'Beohari, Madhya Pradesh'},
 '9176503':{'en': 'Beohari, Madhya Pradesh'},
 '9176504':{'en': 'Beohari, Madhya Pradesh'},
 '9176505':{'en': 'Beohari, Madhya Pradesh'},
 '9176506':{'en': 'Beohari, Madhya Pradesh'},
 '9176507':{'en': 'Beohari, Madhya Pradesh'},
 '9176512':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176513':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176514':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176515':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176516':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176517':{'en': 'Jaisinghnagar, Madhya Pradesh'},
 '9176522':{'en': 'Shahdol, Madhya Pradesh'},
 '9176523':{'en': 'Shahdol, Madhya Pradesh'},
 '9176524':{'en': 'Shahdol, Madhya Pradesh'},
 '9176525':{'en': 'Shahdol, Madhya Pradesh'},
 '9176526':{'en': 'Shahdol, Madhya Pradesh'},
 '9176527':{'en': 'Shahdol, Madhya Pradesh'},
 '9176532':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176533':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176534':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176535':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176536':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176537':{'en': 'Bandhavgarh, Madhya Pradesh'},
 '9176552':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176553':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176554':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176555':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176556':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176557':{'en': 'Birsinghpur, Madhya Pradesh'},
 '9176562':{'en': 'Kannodi, Madhya Pradesh'},
 '9176563':{'en': 'Kannodi, Madhya Pradesh'},
 '9176564':{'en': 'Kannodi, Madhya Pradesh'},
 '9176565':{'en': 'Kannodi, Madhya Pradesh'},
 '9176566':{'en': 'Kannodi, Madhya Pradesh'},
 '9176567':{'en': 'Kannodi, Madhya Pradesh'},
 '9176572':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176573':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176574':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176575':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176576':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176577':{'en': 'Jaitpur, Madhya Pradesh'},
 '9176582':{'en': 'Kotma, Madhya Pradesh'},
 '9176583':{'en': 'Kotma, Madhya Pradesh'},
 '9176584':{'en': 'Kotma, Madhya Pradesh'},
 '9176585':{'en': 'Kotma, Madhya Pradesh'},
 '9176586':{'en': 'Kotma, Madhya Pradesh'},
 '9176587':{'en': 'Kotma, Madhya Pradesh'},
 '9176592':{'en': 'Jaithari, Madhya Pradesh'},
 '9176593':{'en': 'Jaithari, Madhya Pradesh'},
 '9176594':{'en': 'Jaithari, Madhya Pradesh'},
 '9176595':{'en': 'Jaithari, Madhya Pradesh'},
 '9176596':{'en': 'Jaithari, Madhya Pradesh'},
 '9176597':{'en': 'Jaithari, Madhya Pradesh'},
 '9176602':{'en': 'Sirmour, Madhya Pradesh'},
 '9176603':{'en': 'Sirmour, Madhya Pradesh'},
 '9176604':{'en': 'Sirmour, Madhya Pradesh'},
 '9176605':{'en': 'Sirmour, Madhya Pradesh'},
 '9176606':{'en': 'Sirmour, Madhya Pradesh'},
 '9176607':{'en': 'Sirmour, Madhya Pradesh'},
 '9176612':{'en': 'Teonthar, Madhya Pradesh'},
 '9176613':{'en': 'Teonthar, Madhya Pradesh'},
 '9176614':{'en': 'Teonthar, Madhya Pradesh'},
 '9176615':{'en': 'Teonthar, Madhya Pradesh'},
 '9176616':{'en': 'Teonthar, Madhya Pradesh'},
 '9176617':{'en': 'Teonthar, Madhya Pradesh'},
 '9176622':{'en': 'Rewa, Madhya Pradesh'},
 '9176623':{'en': 'Rewa, Madhya Pradesh'},
 '9176624':{'en': 'Rewa, Madhya Pradesh'},
 '9176625':{'en': 'Rewa, Madhya Pradesh'},
 '9176626':{'en': 'Rewa, Madhya Pradesh'},
 '9176627':{'en': 'Rewa, Madhya Pradesh'},
 '9176632':{'en': 'Mauganj, Madhya Pradesh'},
 '9176633':{'en': 'Mauganj, Madhya Pradesh'},
 '9176634':{'en': 'Mauganj, Madhya Pradesh'},
 '9176635':{'en': 'Mauganj, Madhya Pradesh'},
 '9176636':{'en': 'Mauganj, Madhya Pradesh'},
 '9176637':{'en': 'Mauganj, Madhya Pradesh'},
 '9176642':{'en': 'Hanumana, Madhya Pradesh'},
 '9176643':{'en': 'Hanumana, Madhya Pradesh'},
 '9176644':{'en': 'Hanumana, Madhya Pradesh'},
 '9176645':{'en': 'Hanumana, Madhya Pradesh'},
 '9176646':{'en': 'Hanumana, Madhya Pradesh'},
 '9176647':{'en': 'Hanumana, Madhya Pradesh'},
 '9176702':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176703':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176704':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176705':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176706':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176707':{'en': 'Majhagwan, Madhya Pradesh'},
 '9176712':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176713':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176714':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176715':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176716':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176717':{'en': 'Jaitwara, Madhya Pradesh'},
 '9176722':{'en': 'Satna, Madhya Pradesh'},
 '9176723':{'en': 'Satna, Madhya Pradesh'},
 '9176724':{'en': 'Satna, Madhya Pradesh'},
 '9176725':{'en': 'Satna, Madhya Pradesh'},
 '9176726':{'en': 'Satna, Madhya Pradesh'},
 '9176727':{'en': 'Satna, Madhya Pradesh'},
 '9176732':{'en': 'Nagod, Madhya Pradesh'},
 '9176733':{'en': 'Nagod, Madhya Pradesh'},
 '9176734':{'en': 'Nagod, Madhya Pradesh'},
 '9176735':{'en': 'Nagod, Madhya Pradesh'},
 '9176736':{'en': 'Nagod, Madhya Pradesh'},
 '9176737':{'en': 'Nagod, Madhya Pradesh'},
 '9176742':{'en': 'Maihar, Madhya Pradesh'},
 '9176743':{'en': 'Maihar, Madhya Pradesh'},
 '9176744':{'en': 'Maihar, Madhya Pradesh'},
 '9176745':{'en': 'Maihar, Madhya Pradesh'},
 '9176746':{'en': 'Maihar, Madhya Pradesh'},
 '9176747':{'en': 'Maihar, Madhya Pradesh'},
 '9176752':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176753':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176754':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176755':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176756':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176757':{'en': 'Amarpatan, Madhya Pradesh'},
 '9176802':{'en': 'Niwari, Madhya Pradesh'},
 '9176803':{'en': 'Niwari, Madhya Pradesh'},
 '9176804':{'en': 'Niwari, Madhya Pradesh'},
 '9176805':{'en': 'Niwari, Madhya Pradesh'},
 '9176806':{'en': 'Niwari, Madhya Pradesh'},
 '9176807':{'en': 'Niwari, Madhya Pradesh'},
 '9176812':{'en': 'Jatara, Madhya Pradesh'},
 '9176813':{'en': 'Jatara, Madhya Pradesh'},
 '9176814':{'en': 'Jatara, Madhya Pradesh'},
 '9176815':{'en': 'Jatara, Madhya Pradesh'},
 '9176816':{'en': 'Jatara, Madhya Pradesh'},
 '9176817':{'en': 'Jatara, Madhya Pradesh'},
 '9176822':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176823':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176824':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176825':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176826':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176827':{'en': 'Chhatarpur, Madhya Pradesh'},
 '9176832':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176833':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176834':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176835':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176836':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176837':{'en': 'Tikamgarh, Madhya Pradesh'},
 '9176842':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176843':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176844':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176845':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176846':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176847':{'en': 'Baldeogarh, Madhya Pradesh'},
 '9176852':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176853':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176854':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176855':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176856':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176857':{'en': 'Nowgaon, Madhya Pradesh'},
 '9176862':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176863':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176864':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176865':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176866':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176867':{'en': 'Khajuraho, Madhya Pradesh'},
 '9176872':{'en': 'Laundi, Madhya Pradesh'},
 '9176873':{'en': 'Laundi, Madhya Pradesh'},
 '9176874':{'en': 'Laundi, Madhya Pradesh'},
 '9176875':{'en': 'Laundi, Madhya Pradesh'},
 '9176876':{'en': 'Laundi, Madhya Pradesh'},
 '9176877':{'en': 'Laundi, Madhya Pradesh'},
 '9176882':{'en': 'Gourihar, Madhya Pradesh'},
 '9176883':{'en': 'Gourihar, Madhya Pradesh'},
 '9176884':{'en': 'Gourihar, Madhya Pradesh'},
 '9176885':{'en': 'Gourihar, Madhya Pradesh'},
 '9176886':{'en': 'Gourihar, Madhya Pradesh'},
 '9176887':{'en': 'Gourihar, Madhya Pradesh'},
 '9176892':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176893':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176894':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176895':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176896':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176897':{'en': 'Badamalhera, Madhya Pradesh'},
 '9176902':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176903':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176904':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176905':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176906':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176907':{'en': 'Lakhnadon, Madhya Pradesh'},
 '9176912':{'en': 'Chhapara, Madhya Pradesh'},
 '9176913':{'en': 'Chhapara, Madhya Pradesh'},
 '9176914':{'en': 'Chhapara, Madhya Pradesh'},
 '9176915':{'en': 'Chhapara, Madhya Pradesh'},
 '9176916':{'en': 'Chhapara, Madhya Pradesh'},
 '9176917':{'en': 'Chhapara, Madhya Pradesh'},
 '9176922':{'en': 'Seoni, Madhya Pradesh'},
 '9176923':{'en': 'Seoni, Madhya Pradesh'},
 '9176924':{'en': 'Seoni, Madhya Pradesh'},
 '9176925':{'en': 'Seoni, Madhya Pradesh'},
 '9176926':{'en': 'Seoni, Madhya Pradesh'},
 '9176927':{'en': 'Seoni, Madhya Pradesh'},
 '9176932':{'en': 'Ghansour, Madhya Pradesh'},
 '9176933':{'en': 'Ghansour, Madhya Pradesh'},
 '9176934':{'en': 'Ghansour, Madhya Pradesh'},
 '9176935':{'en': 'Ghansour, Madhya Pradesh'},
 '9176936':{'en': 'Ghansour, Madhya Pradesh'},
 '9176937':{'en': 'Ghansour, Madhya Pradesh'},
 '9176942':{'en': 'Keolari, Madhya Pradesh'},
 '9176943':{'en': 'Keolari, Madhya Pradesh'},
 '9176944':{'en': 'Keolari, Madhya Pradesh'},
 '9176945':{'en': 'Keolari, Madhya Pradesh'},
 '9176946':{'en': 'Keolari, Madhya Pradesh'},
 '9176947':{'en': 'Keolari, Madhya Pradesh'},
 '9176952':{'en': 'Gopalganj, Madhya Pradesh'},
 '9176953':{'en': 'Gopalganj, Madhya Pradesh'},
 '9176954':{'en': 'Gopalganj, Madhya Pradesh'},
 '9176955':{'en': 'Gopalganj, Madhya Pradesh'},
 '9176956':{'en': 'Gopalganj, Madhya Pradesh'},
 '9176957':{'en': 'Gopalganj, Madhya Pradesh'},
 '9177002':{'en': 'Nagri, Madhya Pradesh'},
 '9177003':{'en': 'Nagri, Madhya Pradesh'},
 '9177004':{'en': 'Nagri, Madhya Pradesh'},
 '9177005':{'en': 'Nagri, Madhya Pradesh'},
 '9177006':{'en': 'Nagri, Madhya Pradesh'},
 '9177007':{'en': 'Nagri, Madhya Pradesh'},
 '9177012':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177013':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177014':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177015':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177016':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177017':{'en': 'Pingeshwar, Madhya Pradesh'},
 '9177032':{'en': 'Manpur, Madhya Pradesh'},
 '9177033':{'en': 'Manpur, Madhya Pradesh'},
 '9177034':{'en': 'Manpur, Madhya Pradesh'},
 '9177035':{'en': 'Manpur, Madhya Pradesh'},
 '9177036':{'en': 'Manpur, Madhya Pradesh'},
 '9177037':{'en': 'Manpur, Madhya Pradesh'},
 '9177042':{'en': 'Deobhog, Madhya Pradesh'},
 '9177043':{'en': 'Deobhog, Madhya Pradesh'},
 '9177044':{'en': 'Deobhog, Madhya Pradesh'},
 '9177045':{'en': 'Deobhog, Madhya Pradesh'},
 '9177046':{'en': 'Deobhog, Madhya Pradesh'},
 '9177047':{'en': 'Deobhog, Madhya Pradesh'},
 '9177052':{'en': 'Kurud, Madhya Pradesh'},
 '9177053':{'en': 'Kurud, Madhya Pradesh'},
 '9177054':{'en': 'Kurud, Madhya Pradesh'},
 '9177055':{'en': 'Kurud, Madhya Pradesh'},
 '9177056':{'en': 'Kurud, Madhya Pradesh'},
 '9177057':{'en': 'Kurud, Madhya Pradesh'},
 '9177062':{'en': 'Gariaband, Madhya Pradesh'},
 '9177063':{'en': 'Gariaband, Madhya Pradesh'},
 '9177064':{'en': 'Gariaband, Madhya Pradesh'},
 '9177065':{'en': 'Gariaband, Madhya Pradesh'},
 '9177066':{'en': 'Gariaband, Madhya Pradesh'},
 '9177067':{'en': 'Gariaband, Madhya Pradesh'},
 '9177072':{'en': 'Bagbahera, Madhya Pradesh'},
 '9177073':{'en': 'Bagbahera, Madhya Pradesh'},
 '9177074':{'en': 'Bagbahera, Madhya Pradesh'},
 '9177075':{'en': 'Bagbahera, Madhya Pradesh'},
 '9177076':{'en': 'Bagbahera, Madhya Pradesh'},
 '9177077':{'en': 'Bagbahera, Madhya Pradesh'},
 '917712':{'en': 'Raipur, Madhya Pradesh'},
 '917713':{'en': 'Raipur, Madhya Pradesh'},
 '917714':{'en': 'Raipur, Madhya Pradesh'},
 '917715':{'en': 'Raipur, Madhya Pradesh'},
 '917716':{'en': 'Raipur, Madhya Pradesh'},
 '917717':{'en': 'Raipur, Madhya Pradesh'},
 '9177202':{'en': 'Arang, Madhya Pradesh'},
 '9177203':{'en': 'Arang, Madhya Pradesh'},
 '9177204':{'en': 'Arang, Madhya Pradesh'},
 '9177205':{'en': 'Arang, Madhya Pradesh'},
 '9177206':{'en': 'Arang, Madhya Pradesh'},
 '9177207':{'en': 'Arang, Madhya Pradesh'},
 '9177212':{'en': 'Neora, Madhya Pradesh'},
 '9177213':{'en': 'Neora, Madhya Pradesh'},
 '9177214':{'en': 'Neora, Madhya Pradesh'},
 '9177215':{'en': 'Neora, Madhya Pradesh'},
 '9177216':{'en': 'Neora, Madhya Pradesh'},
 '9177217':{'en': 'Neora, Madhya Pradesh'},
 '9177222':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177223':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177224':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177225':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177226':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177227':{'en': 'Dhamtari, Madhya Pradesh'},
 '9177232':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177233':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177234':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177235':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177236':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177237':{'en': 'Mahasamund, Madhya Pradesh'},
 '9177242':{'en': 'Basana, Madhya Pradesh'},
 '9177243':{'en': 'Basana, Madhya Pradesh'},
 '9177244':{'en': 'Basana, Madhya Pradesh'},
 '9177245':{'en': 'Basana, Madhya Pradesh'},
 '9177246':{'en': 'Basana, Madhya Pradesh'},
 '9177247':{'en': 'Basana, Madhya Pradesh'},
 '9177252':{'en': 'Saraipali, Madhya Pradesh'},
 '9177253':{'en': 'Saraipali, Madhya Pradesh'},
 '9177254':{'en': 'Saraipali, Madhya Pradesh'},
 '9177255':{'en': 'Saraipali, Madhya Pradesh'},
 '9177256':{'en': 'Saraipali, Madhya Pradesh'},
 '9177257':{'en': 'Saraipali, Madhya Pradesh'},
 '9177262':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177263':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177264':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177265':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177266':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177267':{'en': 'Bhatapara, Madhya Pradesh'},
 '9177272':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177273':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177274':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177275':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177276':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177277':{'en': 'Balodabazar, Madhya Pradesh'},
 '9177282':{'en': 'Kasdol, Madhya Pradesh'},
 '9177283':{'en': 'Kasdol, Madhya Pradesh'},
 '9177284':{'en': 'Kasdol, Madhya Pradesh'},
 '9177285':{'en': 'Kasdol, Madhya Pradesh'},
 '9177286':{'en': 'Kasdol, Madhya Pradesh'},
 '9177287':{'en': 'Kasdol, Madhya Pradesh'},
 '9177292':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177293':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177294':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177295':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177296':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177297':{'en': 'Bhilaigarh, Madhya Pradesh'},
 '9177302':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177303':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177304':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177305':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177306':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177307':{'en': 'Ajaigarh, Madhya Pradesh'},
 '9177312':{'en': 'Gunnore, Madhya Pradesh'},
 '9177313':{'en': 'Gunnore, Madhya Pradesh'},
 '9177314':{'en': 'Gunnore, Madhya Pradesh'},
 '9177315':{'en': 'Gunnore, Madhya Pradesh'},
 '9177316':{'en': 'Gunnore, Madhya Pradesh'},
 '9177317':{'en': 'Gunnore, Madhya Pradesh'},
 '9177322':{'en': 'Panna, Madhya Pradesh'},
 '9177323':{'en': 'Panna, Madhya Pradesh'},
 '9177324':{'en': 'Panna, Madhya Pradesh'},
 '9177325':{'en': 'Panna, Madhya Pradesh'},
 '9177326':{'en': 'Panna, Madhya Pradesh'},
 '9177327':{'en': 'Panna, Madhya Pradesh'},
 '9177332':{'en': 'Pawai, Madhya Pradesh'},
 '9177333':{'en': 'Pawai, Madhya Pradesh'},
 '9177334':{'en': 'Pawai, Madhya Pradesh'},
 '9177335':{'en': 'Pawai, Madhya Pradesh'},
 '9177336':{'en': 'Pawai, Madhya Pradesh'},
 '9177337':{'en': 'Pawai, Madhya Pradesh'},
 '9177342':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177343':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177344':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177345':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177346':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177347':{'en': 'Shahnagar, Madhya Pradesh'},
 '9177402':{'en': 'Bodla, Madhya Pradesh'},
 '9177403':{'en': 'Bodla, Madhya Pradesh'},
 '9177404':{'en': 'Bodla, Madhya Pradesh'},
 '9177405':{'en': 'Bodla, Madhya Pradesh'},
 '9177406':{'en': 'Bodla, Madhya Pradesh'},
 '9177407':{'en': 'Bodla, Madhya Pradesh'},
 '9177412':{'en': 'Kawardha, Madhya Pradesh'},
 '9177413':{'en': 'Kawardha, Madhya Pradesh'},
 '9177414':{'en': 'Kawardha, Madhya Pradesh'},
 '9177415':{'en': 'Kawardha, Madhya Pradesh'},
 '9177416':{'en': 'Kawardha, Madhya Pradesh'},
 '9177417':{'en': 'Kawardha, Madhya Pradesh'},
 '9177432':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177433':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177434':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177435':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177436':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177437':{'en': 'Chuikhadan, Madhya Pradesh'},
 '9177442':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177443':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177444':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177445':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177446':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177447':{'en': 'Rajandgaon, Madhya Pradesh'},
 '9177452':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177453':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177454':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177455':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177456':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177457':{'en': 'Chhuriakala, Madhya Pradesh'},
 '9177462':{'en': 'Manpur, Madhya Pradesh'},
 '9177463':{'en': 'Manpur, Madhya Pradesh'},
 '9177464':{'en': 'Manpur, Madhya Pradesh'},
 '9177465':{'en': 'Manpur, Madhya Pradesh'},
 '9177466':{'en': 'Manpur, Madhya Pradesh'},
 '9177467':{'en': 'Manpur, Madhya Pradesh'},
 '9177472':{'en': 'Mohla, Madhya Pradesh'},
 '9177473':{'en': 'Mohla, Madhya Pradesh'},
 '9177474':{'en': 'Mohla, Madhya Pradesh'},
 '9177475':{'en': 'Mohla, Madhya Pradesh'},
 '9177476':{'en': 'Mohla, Madhya Pradesh'},
 '9177477':{'en': 'Mohla, Madhya Pradesh'},
 '9177482':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177483':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177484':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177485':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177486':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177487':{'en': 'Dallirajhara, Madhya Pradesh'},
 '9177492':{'en': 'Balod, Madhya Pradesh'},
 '9177493':{'en': 'Balod, Madhya Pradesh'},
 '9177494':{'en': 'Balod, Madhya Pradesh'},
 '9177495':{'en': 'Balod, Madhya Pradesh'},
 '9177496':{'en': 'Balod, Madhya Pradesh'},
 '9177497':{'en': 'Balod, Madhya Pradesh'},
 '9177502':{'en': 'Marwahi, Madhya Pradesh'},
 '9177503':{'en': 'Marwahi, Madhya Pradesh'},
 '9177504':{'en': 'Marwahi, Madhya Pradesh'},
 '9177505':{'en': 'Marwahi, Madhya Pradesh'},
 '9177506':{'en': 'Marwahi, Madhya Pradesh'},
 '9177507':{'en': 'Marwahi, Madhya Pradesh'},
 '9177512':{'en': 'Pendra, Madhya Pradesh'},
 '9177513':{'en': 'Pendra, Madhya Pradesh'},
 '9177514':{'en': 'Pendra, Madhya Pradesh'},
 '9177515':{'en': 'Pendra, Madhya Pradesh'},
 '9177516':{'en': 'Pendra, Madhya Pradesh'},
 '9177517':{'en': 'Pendra, Madhya Pradesh'},
 '9177522':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177523':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177524':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177525':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177526':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177527':{'en': 'Bilaspur, Madhya Pradesh'},
 '9177532':{'en': 'Kota, Madhya Pradesh'},
 '9177533':{'en': 'Kota, Madhya Pradesh'},
 '9177534':{'en': 'Kota, Madhya Pradesh'},
 '9177535':{'en': 'Kota, Madhya Pradesh'},
 '9177536':{'en': 'Kota, Madhya Pradesh'},
 '9177537':{'en': 'Kota, Madhya Pradesh'},
 '9177542':{'en': 'Pandaria, Madhya Pradesh'},
 '9177543':{'en': 'Pandaria, Madhya Pradesh'},
 '9177544':{'en': 'Pandaria, Madhya Pradesh'},
 '9177545':{'en': 'Pandaria, Madhya Pradesh'},
 '9177546':{'en': 'Pandaria, Madhya Pradesh'},
 '9177547':{'en': 'Pandaria, Madhya Pradesh'},
 '9177552':{'en': 'Mungeli, Madhya Pradesh'},
 '9177553':{'en': 'Mungeli, Madhya Pradesh'},
 '9177554':{'en': 'Mungeli, Madhya Pradesh'},
 '9177555':{'en': 'Mungeli, Madhya Pradesh'},
 '9177556':{'en': 'Mungeli, Madhya Pradesh'},
 '9177557':{'en': 'Mungeli, Madhya Pradesh'},
 '9177562':{'en': 'Lormi, Madhya Pradesh'},
 '9177563':{'en': 'Lormi, Madhya Pradesh'},
 '9177564':{'en': 'Lormi, Madhya Pradesh'},
 '9177565':{'en': 'Lormi, Madhya Pradesh'},
 '9177566':{'en': 'Lormi, Madhya Pradesh'},
 '9177567':{'en': 'Lormi, Madhya Pradesh'},
 '9177572':{'en': 'Shakti, Madhya Pradesh'},
 '9177573':{'en': 'Shakti, Madhya Pradesh'},
 '9177574':{'en': 'Shakti, Madhya Pradesh'},
 '9177575':{'en': 'Shakti, Madhya Pradesh'},
 '9177576':{'en': 'Shakti, Madhya Pradesh'},
 '9177577':{'en': 'Shakti, Madhya Pradesh'},
 '9177582':{'en': 'Dabhara, Madhya Pradesh'},
 '9177583':{'en': 'Dabhara, Madhya Pradesh'},
 '9177584':{'en': 'Dabhara, Madhya Pradesh'},
 '9177585':{'en': 'Dabhara, Madhya Pradesh'},
 '9177586':{'en': 'Dabhara, Madhya Pradesh'},
 '9177587':{'en': 'Dabhara, Madhya Pradesh'},
 '9177592':{'en': 'Korba, Madhya Pradesh'},
 '9177593':{'en': 'Korba, Madhya Pradesh'},
 '9177594':{'en': 'Korba, Madhya Pradesh'},
 '9177595':{'en': 'Korba, Madhya Pradesh'},
 '9177596':{'en': 'Korba, Madhya Pradesh'},
 '9177597':{'en': 'Korba, Madhya Pradesh'},
 '9177612':{'en': 'Tapkara, Madhya Pradesh'},
 '9177613':{'en': 'Tapkara, Madhya Pradesh'},
 '9177614':{'en': 'Tapkara, Madhya Pradesh'},
 '9177615':{'en': 'Tapkara, Madhya Pradesh'},
 '9177616':{'en': 'Tapkara, Madhya Pradesh'},
 '9177617':{'en': 'Tapkara, Madhya Pradesh'},
 '9177622':{'en': 'Raigarh, Madhya Pradesh'},
 '9177623':{'en': 'Raigarh, Madhya Pradesh'},
 '9177624':{'en': 'Raigarh, Madhya Pradesh'},
 '9177625':{'en': 'Raigarh, Madhya Pradesh'},
 '9177626':{'en': 'Raigarh, Madhya Pradesh'},
 '9177627':{'en': 'Raigarh, Madhya Pradesh'},
 '9177632':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177633':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177634':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177635':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177636':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177637':{'en': 'Jashpurnagar, Madhya Pradesh'},
 '9177642':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177643':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177644':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177645':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177646':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177647':{'en': 'Kunkuri, Madhya Pradesh'},
 '9177652':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177653':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177654':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177655':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177656':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177657':{'en': 'Pathalgaon, Madhya Pradesh'},
 '9177662':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177663':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177664':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177665':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177666':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177667':{'en': 'Dharamjaigarh, Madhya Pradesh'},
 '9177672':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177673':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177674':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177675':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177676':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177677':{'en': 'Gharghoda, Madhya Pradesh'},
 '9177682':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177683':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177684':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177685':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177686':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177687':{'en': 'Saranggarh, Madhya Pradesh'},
 '9177692':{'en': 'Bagicha, Madhya Pradesh'},
 '9177693':{'en': 'Bagicha, Madhya Pradesh'},
 '9177694':{'en': 'Bagicha, Madhya Pradesh'},
 '9177695':{'en': 'Bagicha, Madhya Pradesh'},
 '9177696':{'en': 'Bagicha, Madhya Pradesh'},
 '9177697':{'en': 'Bagicha, Madhya Pradesh'},
 '9177702':{'en': 'Kathdol, Madhya Pradesh'},
 '9177703':{'en': 'Kathdol, Madhya Pradesh'},
 '9177704':{'en': 'Kathdol, Madhya Pradesh'},
 '9177705':{'en': 'Kathdol, Madhya Pradesh'},
 '9177706':{'en': 'Kathdol, Madhya Pradesh'},
 '9177707':{'en': 'Kathdol, Madhya Pradesh'},
 '9177712':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177713':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177714':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177715':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177716':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177717':{'en': 'Manendragarh, Madhya Pradesh'},
 '9177722':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177723':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177724':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177725':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177726':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177727':{'en': 'Wadrainagar, Madhya Pradesh'},
 '9177732':{'en': 'Odgi, Madhya Pradesh'},
 '9177733':{'en': 'Odgi, Madhya Pradesh'},
 '9177734':{'en': 'Odgi, Madhya Pradesh'},
 '9177735':{'en': 'Odgi, Madhya Pradesh'},
 '9177736':{'en': 'Odgi, Madhya Pradesh'},
 '9177737':{'en': 'Odgi, Madhya Pradesh'},
 '9177742':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177743':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177744':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177745':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177746':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177747':{'en': 'Ambikapur, Madhya Pradesh'},
 '9177752':{'en': 'Surajpur, Madhya Pradesh'},
 '9177753':{'en': 'Surajpur, Madhya Pradesh'},
 '9177754':{'en': 'Surajpur, Madhya Pradesh'},
 '9177755':{'en': 'Surajpur, Madhya Pradesh'},
 '9177756':{'en': 'Surajpur, Madhya Pradesh'},
 '9177757':{'en': 'Surajpur, Madhya Pradesh'},
 '9177762':{'en': 'Premnagar, Madhya Pradesh'},
 '9177763':{'en': 'Premnagar, Madhya Pradesh'},
 '9177764':{'en': 'Premnagar, Madhya Pradesh'},
 '9177765':{'en': 'Premnagar, Madhya Pradesh'},
 '9177766':{'en': 'Premnagar, Madhya Pradesh'},
 '9177767':{'en': 'Premnagar, Madhya Pradesh'},
 '9177772':{'en': 'Pratappur, Madhya Pradesh'},
 '9177773':{'en': 'Pratappur, Madhya Pradesh'},
 '9177774':{'en': 'Pratappur, Madhya Pradesh'},
 '9177775':{'en': 'Pratappur, Madhya Pradesh'},
 '9177776':{'en': 'Pratappur, Madhya Pradesh'},
 '9177777':{'en': 'Pratappur, Madhya Pradesh'},
 '9177782':{'en': 'Semaria, Madhya Pradesh'},
 '9177783':{'en': 'Semaria, Madhya Pradesh'},
 '9177784':{'en': 'Semaria, Madhya Pradesh'},
 '9177785':{'en': 'Semaria, Madhya Pradesh'},
 '9177786':{'en': 'Semaria, Madhya Pradesh'},
 '9177787':{'en': 'Semaria, Madhya Pradesh'},
 '9177792':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177793':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177794':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177795':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177796':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177797':{'en': 'Ramchandrapur, Madhya Pradesh'},
 '9177812':{'en': 'Narainpur, Madhya Pradesh'},
 '9177813':{'en': 'Narainpur, Madhya Pradesh'},
 '9177814':{'en': 'Narainpur, Madhya Pradesh'},
 '9177815':{'en': 'Narainpur, Madhya Pradesh'},
 '9177816':{'en': 'Narainpur, Madhya Pradesh'},
 '9177817':{'en': 'Narainpur, Madhya Pradesh'},
 '9177822':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177823':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177824':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177825':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177826':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177827':{'en': 'Jagdalpur, Madhya Pradesh'},
 '9177832':{'en': 'Padamkot, Madhya Pradesh'},
 '9177833':{'en': 'Padamkot, Madhya Pradesh'},
 '9177834':{'en': 'Padamkot, Madhya Pradesh'},
 '9177835':{'en': 'Padamkot, Madhya Pradesh'},
 '9177836':{'en': 'Padamkot, Madhya Pradesh'},
 '9177837':{'en': 'Padamkot, Madhya Pradesh'},
 '9177842':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177843':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177844':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177845':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177846':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177847':{'en': 'Parasgaon, Madhya Pradesh'},
 '9177852':{'en': 'Makodi, Madhya Pradesh'},
 '9177853':{'en': 'Makodi, Madhya Pradesh'},
 '9177854':{'en': 'Makodi, Madhya Pradesh'},
 '9177855':{'en': 'Makodi, Madhya Pradesh'},
 '9177856':{'en': 'Makodi, Madhya Pradesh'},
 '9177857':{'en': 'Makodi, Madhya Pradesh'},
 '9177862':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177863':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177864':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177865':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177866':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177867':{'en': 'Kondagaon, Madhya Pradesh'},
 '9177872':{'en': 'Jarwa, Madhya Pradesh'},
 '9177873':{'en': 'Jarwa, Madhya Pradesh'},
 '9177874':{'en': 'Jarwa, Madhya Pradesh'},
 '9177875':{'en': 'Jarwa, Madhya Pradesh'},
 '9177876':{'en': 'Jarwa, Madhya Pradesh'},
 '9177877':{'en': 'Jarwa, Madhya Pradesh'},
 '9177882':{'en': 'Luckwada, Madhya Pradesh'},
 '9177883':{'en': 'Luckwada, Madhya Pradesh'},
 '9177884':{'en': 'Luckwada, Madhya Pradesh'},
 '9177885':{'en': 'Luckwada, Madhya Pradesh'},
 '9177886':{'en': 'Luckwada, Madhya Pradesh'},
 '9177887':{'en': 'Luckwada, Madhya Pradesh'},
 '9177892':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177893':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177894':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177895':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177896':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177897':{'en': 'Bhairongarh, Madhya Pradesh'},
 '9177902':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177903':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177904':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177905':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177906':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177907':{'en': 'Babaichichli, Madhya Pradesh'},
 '9177912':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177913':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177914':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177915':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177916':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177917':{'en': 'Gadarwara, Madhya Pradesh'},
 '9177922':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177923':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177924':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177925':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177926':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177927':{'en': 'Narsinghpur, Madhya Pradesh'},
 '9177932':{'en': 'Kareli, Madhya Pradesh'},
 '9177933':{'en': 'Kareli, Madhya Pradesh'},
 '9177934':{'en': 'Kareli, Madhya Pradesh'},
 '9177935':{'en': 'Kareli, Madhya Pradesh'},
 '9177936':{'en': 'Kareli, Madhya Pradesh'},
 '9177937':{'en': 'Kareli, Madhya Pradesh'},
 '9177942':{'en': 'Gotegaon, Madhya Pradesh'},
 '9177943':{'en': 'Gotegaon, Madhya Pradesh'},
 '9177944':{'en': 'Gotegaon, Madhya Pradesh'},
 '9177945':{'en': 'Gotegaon, Madhya Pradesh'},
 '9177946':{'en': 'Gotegaon, Madhya Pradesh'},
 '9177947':{'en': 'Gotegaon, Madhya Pradesh'},
 '9178012':{'en': 'Deosar, Madhya Pradesh'},
 '9178013':{'en': 'Deosar, Madhya Pradesh'},
 '9178014':{'en': 'Deosar, Madhya Pradesh'},
 '9178015':{'en': 'Deosar, Madhya Pradesh'},
 '9178016':{'en': 'Deosar, Madhya Pradesh'},
 '9178017':{'en': 'Deosar, Madhya Pradesh'},
 '9178022':{'en': 'Churhat, Madhya Pradesh'},
 '9178023':{'en': 'Churhat, Madhya Pradesh'},
 '9178024':{'en': 'Churhat, Madhya Pradesh'},
 '9178025':{'en': 'Churhat, Madhya Pradesh'},
 '9178026':{'en': 'Churhat, Madhya Pradesh'},
 '9178027':{'en': 'Churhat, Madhya Pradesh'},
 '9178032':{'en': 'Majholi, Madhya Pradesh'},
 '9178033':{'en': 'Majholi, Madhya Pradesh'},
 '9178034':{'en': 'Majholi, Madhya Pradesh'},
 '9178035':{'en': 'Majholi, Madhya Pradesh'},
 '9178036':{'en': 'Majholi, Madhya Pradesh'},
 '9178037':{'en': 'Majholi, Madhya Pradesh'},
 '9178042':{'en': 'Kusmi, Madhya Pradesh'},
 '9178043':{'en': 'Kusmi, Madhya Pradesh'},
 '9178044':{'en': 'Kusmi, Madhya Pradesh'},
 '9178045':{'en': 'Kusmi, Madhya Pradesh'},
 '9178046':{'en': 'Kusmi, Madhya Pradesh'},
 '9178047':{'en': 'Kusmi, Madhya Pradesh'},
 '9178052':{'en': 'Singrauli, Madhya Pradesh'},
 '9178053':{'en': 'Singrauli, Madhya Pradesh'},
 '9178054':{'en': 'Singrauli, Madhya Pradesh'},
 '9178055':{'en': 'Singrauli, Madhya Pradesh'},
 '9178056':{'en': 'Singrauli, Madhya Pradesh'},
 '9178057':{'en': 'Singrauli, Madhya Pradesh'},
 '9178062':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178063':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178064':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178065':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178066':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178067':{'en': 'Chitrangi, Madhya Pradesh'},
 '9178102':{'en': 'Uproda, Madhya Pradesh'},
 '9178103':{'en': 'Uproda, Madhya Pradesh'},
 '9178104':{'en': 'Uproda, Madhya Pradesh'},
 '9178105':{'en': 'Uproda, Madhya Pradesh'},
 '9178106':{'en': 'Uproda, Madhya Pradesh'},
 '9178107':{'en': 'Uproda, Madhya Pradesh'},
 '9178112':{'en': 'Pasan, Madhya Pradesh'},
 '9178113':{'en': 'Pasan, Madhya Pradesh'},
 '9178114':{'en': 'Pasan, Madhya Pradesh'},
 '9178115':{'en': 'Pasan, Madhya Pradesh'},
 '9178116':{'en': 'Pasan, Madhya Pradesh'},
 '9178117':{'en': 'Pasan, Madhya Pradesh'},
 '9178122':{'en': 'Damoh, Madhya Pradesh'},
 '9178123':{'en': 'Damoh, Madhya Pradesh'},
 '9178124':{'en': 'Damoh, Madhya Pradesh'},
 '9178125':{'en': 'Damoh, Madhya Pradesh'},
 '9178126':{'en': 'Damoh, Madhya Pradesh'},
 '9178127':{'en': 'Damoh, Madhya Pradesh'},
 '9178132':{'en': 'Barpalli, Madhya Pradesh'},
 '9178133':{'en': 'Barpalli, Madhya Pradesh'},
 '9178134':{'en': 'Barpalli, Madhya Pradesh'},
 '9178135':{'en': 'Barpalli, Madhya Pradesh'},
 '9178136':{'en': 'Barpalli, Madhya Pradesh'},
 '9178137':{'en': 'Barpalli, Madhya Pradesh'},
 '9178152':{'en': 'Kathghora, Madhya Pradesh'},
 '9178153':{'en': 'Kathghora, Madhya Pradesh'},
 '9178154':{'en': 'Kathghora, Madhya Pradesh'},
 '9178155':{'en': 'Kathghora, Madhya Pradesh'},
 '9178156':{'en': 'Kathghora, Madhya Pradesh'},
 '9178157':{'en': 'Kathghora, Madhya Pradesh'},
 '9178162':{'en': 'Pali, Madhya Pradesh'},
 '9178163':{'en': 'Pali, Madhya Pradesh'},
 '9178164':{'en': 'Pali, Madhya Pradesh'},
 '9178165':{'en': 'Pali, Madhya Pradesh'},
 '9178166':{'en': 'Pali, Madhya Pradesh'},
 '9178167':{'en': 'Pali, Madhya Pradesh'},
 '9178172':{'en': 'Janjgir, Madhya Pradesh'},
 '9178173':{'en': 'Janjgir, Madhya Pradesh'},
 '9178174':{'en': 'Janjgir, Madhya Pradesh'},
 '9178175':{'en': 'Janjgir, Madhya Pradesh'},
 '9178176':{'en': 'Janjgir, Madhya Pradesh'},
 '9178177':{'en': 'Janjgir, Madhya Pradesh'},
 '9178182':{'en': 'Chandipara, Madhya Pradesh'},
 '9178183':{'en': 'Chandipara, Madhya Pradesh'},
 '9178184':{'en': 'Chandipara, Madhya Pradesh'},
 '9178185':{'en': 'Chandipara, Madhya Pradesh'},
 '9178186':{'en': 'Chandipara, Madhya Pradesh'},
 '9178187':{'en': 'Chandipara, Madhya Pradesh'},
 '9178192':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178193':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178194':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178195':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178196':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178197':{'en': 'Pandishankar, Madhya Pradesh'},
 '9178202':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178203':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178204':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178205':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178206':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178207':{'en': 'Khairagarh, Madhya Pradesh'},
 '9178212':{'en': 'Dhamda, Madhya Pradesh'},
 '9178213':{'en': 'Dhamda, Madhya Pradesh'},
 '9178214':{'en': 'Dhamda, Madhya Pradesh'},
 '9178215':{'en': 'Dhamda, Madhya Pradesh'},
 '9178216':{'en': 'Dhamda, Madhya Pradesh'},
 '9178217':{'en': 'Dhamda, Madhya Pradesh'},
 '9178222':{'en': 'Sidhi, Madhya Pradesh'},
 '9178223':{'en': 'Sidhi, Madhya Pradesh'},
 '9178224':{'en': 'Sidhi, Madhya Pradesh'},
 '9178225':{'en': 'Sidhi, Madhya Pradesh'},
 '9178226':{'en': 'Sidhi, Madhya Pradesh'},
 '9178227':{'en': 'Sidhi, Madhya Pradesh'},
 '9178232':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178233':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178234':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178235':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178236':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178237':{'en': 'Dongargarh, Madhya Pradesh'},
 '9178242':{'en': 'Bemetara, Madhya Pradesh'},
 '9178243':{'en': 'Bemetara, Madhya Pradesh'},
 '9178244':{'en': 'Bemetara, Madhya Pradesh'},
 '9178245':{'en': 'Bemetara, Madhya Pradesh'},
 '9178246':{'en': 'Bemetara, Madhya Pradesh'},
 '9178247':{'en': 'Bemetara, Madhya Pradesh'},
 '9178252':{'en': 'Berla, Madhya Pradesh'},
 '9178253':{'en': 'Berla, Madhya Pradesh'},
 '9178254':{'en': 'Berla, Madhya Pradesh'},
 '9178255':{'en': 'Berla, Madhya Pradesh'},
 '9178256':{'en': 'Berla, Madhya Pradesh'},
 '9178257':{'en': 'Berla, Madhya Pradesh'},
 '9178262':{'en': 'Patan, Madhya Pradesh'},
 '9178263':{'en': 'Patan, Madhya Pradesh'},
 '9178264':{'en': 'Patan, Madhya Pradesh'},
 '9178265':{'en': 'Patan, Madhya Pradesh'},
 '9178266':{'en': 'Patan, Madhya Pradesh'},
 '9178267':{'en': 'Patan, Madhya Pradesh'},
 '9178312':{'en': 'Balrampur, Madhya Pradesh'},
 '9178313':{'en': 'Balrampur, Madhya Pradesh'},
 '9178314':{'en': 'Balrampur, Madhya Pradesh'},
 '9178315':{'en': 'Balrampur, Madhya Pradesh'},
 '9178316':{'en': 'Balrampur, Madhya Pradesh'},
 '9178317':{'en': 'Balrampur, Madhya Pradesh'},
 '9178322':{'en': 'Rajpur, Madhya Pradesh'},
 '9178323':{'en': 'Rajpur, Madhya Pradesh'},
 '9178324':{'en': 'Rajpur, Madhya Pradesh'},
 '9178325':{'en': 'Rajpur, Madhya Pradesh'},
 '9178326':{'en': 'Rajpur, Madhya Pradesh'},
 '9178327':{'en': 'Rajpur, Madhya Pradesh'},
 '9178332':{'en': 'Udaipur, Madhya Pradesh'},
 '9178333':{'en': 'Udaipur, Madhya Pradesh'},
 '9178334':{'en': 'Udaipur, Madhya Pradesh'},
 '9178335':{'en': 'Udaipur, Madhya Pradesh'},
 '9178336':{'en': 'Udaipur, Madhya Pradesh'},
 '9178337':{'en': 'Udaipur, Madhya Pradesh'},
 '9178342':{'en': 'Sitapur, Madhya Pradesh'},
 '9178343':{'en': 'Sitapur, Madhya Pradesh'},
 '9178344':{'en': 'Sitapur, Madhya Pradesh'},
 '9178345':{'en': 'Sitapur, Madhya Pradesh'},
 '9178346':{'en': 'Sitapur, Madhya Pradesh'},
 '9178347':{'en': 'Sitapur, Madhya Pradesh'},
 '9178352':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178353':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178354':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178355':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178356':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178357':{'en': 'Bharathpur, Madhya Pradesh'},
 '9178362':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178363':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178364':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178365':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178366':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178367':{'en': 'Baikunthpur, Madhya Pradesh'},
 '9178402':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178403':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178404':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178405':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178406':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178407':{'en': 'Koyelibeda, Madhya Pradesh'},
 '9178412':{'en': 'Sarona, Madhya Pradesh'},
 '9178413':{'en': 'Sarona, Madhya Pradesh'},
 '9178414':{'en': 'Sarona, Madhya Pradesh'},
 '9178415':{'en': 'Sarona, Madhya Pradesh'},
 '9178416':{'en': 'Sarona, Madhya Pradesh'},
 '9178417':{'en': 'Sarona, Madhya Pradesh'},
 '9178432':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178433':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178434':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178435':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178436':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178437':{'en': 'Durgakondal, Madhya Pradesh'},
 '9178442':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178443':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178444':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178445':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178446':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178447':{'en': 'Pakhanjur, Madhya Pradesh'},
 '9178462':{'en': 'Garpa, Madhya Pradesh'},
 '9178463':{'en': 'Garpa, Madhya Pradesh'},
 '9178464':{'en': 'Garpa, Madhya Pradesh'},
 '9178465':{'en': 'Garpa, Madhya Pradesh'},
 '9178466':{'en': 'Garpa, Madhya Pradesh'},
 '9178467':{'en': 'Garpa, Madhya Pradesh'},
 '9178472':{'en': 'Antagarh, Madhya Pradesh'},
 '9178473':{'en': 'Antagarh, Madhya Pradesh'},
 '9178474':{'en': 'Antagarh, Madhya Pradesh'},
 '9178475':{'en': 'Antagarh, Madhya Pradesh'},
 '9178476':{'en': 'Antagarh, Madhya Pradesh'},
 '9178477':{'en': 'Antagarh, Madhya Pradesh'},
 '9178482':{'en': 'Keskal, Madhya Pradesh'},
 '9178483':{'en': 'Keskal, Madhya Pradesh'},
 '9178484':{'en': 'Keskal, Madhya Pradesh'},
 '9178485':{'en': 'Keskal, Madhya Pradesh'},
 '9178486':{'en': 'Keskal, Madhya Pradesh'},
 '9178487':{'en': 'Keskal, Madhya Pradesh'},
 '9178492':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178493':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178494':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178495':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178496':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178497':{'en': 'Baderajpur, Madhya Pradesh'},
 '9178502':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178503':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178504':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178505':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178506':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178507':{'en': 'Bhanupratappur, Madhya Pradesh'},
 '9178512':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178513':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178514':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178515':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178516':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178517':{'en': 'Bhopalpatnam, Madhya Pradesh'},
 '9178522':{'en': 'Toynar, Madhya Pradesh'},
 '9178523':{'en': 'Toynar, Madhya Pradesh'},
 '9178524':{'en': 'Toynar, Madhya Pradesh'},
 '9178525':{'en': 'Toynar, Madhya Pradesh'},
 '9178526':{'en': 'Toynar, Madhya Pradesh'},
 '9178527':{'en': 'Toynar, Madhya Pradesh'},
 '9178532':{'en': 'Bijapur, Madhya Pradesh'},
 '9178533':{'en': 'Bijapur, Madhya Pradesh'},
 '9178534':{'en': 'Bijapur, Madhya Pradesh'},
 '9178535':{'en': 'Bijapur, Madhya Pradesh'},
 '9178536':{'en': 'Bijapur, Madhya Pradesh'},
 '9178537':{'en': 'Bijapur, Madhya Pradesh'},
 '9178542':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178543':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178544':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178545':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178546':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178547':{'en': 'Ilamidi, Madhya Pradesh'},
 '9178552':{'en': 'Chingmut, Madhya Pradesh'},
 '9178553':{'en': 'Chingmut, Madhya Pradesh'},
 '9178554':{'en': 'Chingmut, Madhya Pradesh'},
 '9178555':{'en': 'Chingmut, Madhya Pradesh'},
 '9178556':{'en': 'Chingmut, Madhya Pradesh'},
 '9178557':{'en': 'Chingmut, Madhya Pradesh'},
 '9178562':{'en': 'Dantewada, Madhya Pradesh'},
 '9178563':{'en': 'Dantewada, Madhya Pradesh'},
 '9178564':{'en': 'Dantewada, Madhya Pradesh'},
 '9178565':{'en': 'Dantewada, Madhya Pradesh'},
 '9178566':{'en': 'Dantewada, Madhya Pradesh'},
 '9178567':{'en': 'Dantewada, Madhya Pradesh'},
 '9178572':{'en': 'Bacheli, Madhya Pradesh'},
 '9178573':{'en': 'Bacheli, Madhya Pradesh'},
 '9178574':{'en': 'Bacheli, Madhya Pradesh'},
 '9178575':{'en': 'Bacheli, Madhya Pradesh'},
 '9178576':{'en': 'Bacheli, Madhya Pradesh'},
 '9178577':{'en': 'Bacheli, Madhya Pradesh'},
 '9178582':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178583':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178584':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178585':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178586':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178587':{'en': 'Kuakunda, Madhya Pradesh'},
 '9178592':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178593':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178594':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178595':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178596':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178597':{'en': 'Lohadigundah, Madhya Pradesh'},
 '9178612':{'en': 'Netanar, Madhya Pradesh'},
 '9178613':{'en': 'Netanar, Madhya Pradesh'},
 '9178614':{'en': 'Netanar, Madhya Pradesh'},
 '9178615':{'en': 'Netanar, Madhya Pradesh'},
 '9178616':{'en': 'Netanar, Madhya Pradesh'},
 '9178617':{'en': 'Netanar, Madhya Pradesh'},
 '9178622':{'en': 'Bastanar, Madhya Pradesh'},
 '9178623':{'en': 'Bastanar, Madhya Pradesh'},
 '9178624':{'en': 'Bastanar, Madhya Pradesh'},
 '9178625':{'en': 'Bastanar, Madhya Pradesh'},
 '9178626':{'en': 'Bastanar, Madhya Pradesh'},
 '9178627':{'en': 'Bastanar, Madhya Pradesh'},
 '9178632':{'en': 'Chingamut, Madhya Pradesh'},
 '9178633':{'en': 'Chingamut, Madhya Pradesh'},
 '9178634':{'en': 'Chingamut, Madhya Pradesh'},
 '9178635':{'en': 'Chingamut, Madhya Pradesh'},
 '9178636':{'en': 'Chingamut, Madhya Pradesh'},
 '9178637':{'en': 'Chingamut, Madhya Pradesh'},
 '9178642':{'en': 'Sukma, Madhya Pradesh'},
 '9178643':{'en': 'Sukma, Madhya Pradesh'},
 '9178644':{'en': 'Sukma, Madhya Pradesh'},
 '9178645':{'en': 'Sukma, Madhya Pradesh'},
 '9178646':{'en': 'Sukma, Madhya Pradesh'},
 '9178647':{'en': 'Sukma, Madhya Pradesh'},
 '9178652':{'en': 'Gogunda, Madhya Pradesh'},
 '9178653':{'en': 'Gogunda, Madhya Pradesh'},
 '9178654':{'en': 'Gogunda, Madhya Pradesh'},
 '9178655':{'en': 'Gogunda, Madhya Pradesh'},
 '9178656':{'en': 'Gogunda, Madhya Pradesh'},
 '9178657':{'en': 'Gogunda, Madhya Pradesh'},
 '9178662':{'en': 'Konta, Madhya Pradesh'},
 '9178663':{'en': 'Konta, Madhya Pradesh'},
 '9178664':{'en': 'Konta, Madhya Pradesh'},
 '9178665':{'en': 'Konta, Madhya Pradesh'},
 '9178666':{'en': 'Konta, Madhya Pradesh'},
 '9178667':{'en': 'Konta, Madhya Pradesh'},
 '9178672':{'en': 'Bokaband, Madhya Pradesh'},
 '9178673':{'en': 'Bokaband, Madhya Pradesh'},
 '9178674':{'en': 'Bokaband, Madhya Pradesh'},
 '9178675':{'en': 'Bokaband, Madhya Pradesh'},
 '9178676':{'en': 'Bokaband, Madhya Pradesh'},
 '9178677':{'en': 'Bokaband, Madhya Pradesh'},
 '9178682':{'en': 'Kanker, Madhya Pradesh'},
 '9178683':{'en': 'Kanker, Madhya Pradesh'},
 '9178684':{'en': 'Kanker, Madhya Pradesh'},
 '9178685':{'en': 'Kanker, Madhya Pradesh'},
 '9178686':{'en': 'Kanker, Madhya Pradesh'},
 '9178687':{'en': 'Kanker, Madhya Pradesh'},
 '9178802':{'en': 'Durg, Madhya Pradesh'},
 '9178803':{'en': 'Durg, Madhya Pradesh'},
 '9178804':{'en': 'Durg, Madhya Pradesh'},
 '9178805':{'en': 'Durg, Madhya Pradesh'},
 '9178806':{'en': 'Durg, Madhya Pradesh'},
 '9178807':{'en': 'Durg, Madhya Pradesh'},
 '9178812':{'en': 'Durg, Madhya Pradesh'},
 '9178813':{'en': 'Durg, Madhya Pradesh'},
 '9178814':{'en': 'Durg, Madhya Pradesh'},
 '9178815':{'en': 'Durg, Madhya Pradesh'},
 '9178816':{'en': 'Durg, Madhya Pradesh'},
 '9178817':{'en': 'Durg, Madhya Pradesh'},
 '917882':{'en': 'Durg, Madhya Pradesh'},
 '917883':{'en': 'Durg, Madhya Pradesh'},
 '917884':{'en': 'Durg, Madhya Pradesh'},
 '917885':{'en': 'Durg, Madhya Pradesh'},
 '917886':{'en': 'Durg, Madhya Pradesh'},
 '917887':{'en': 'Durg, Madhya Pradesh'},
 '9178882':{'en': 'Durg, Madhya Pradesh'},
 '9178883':{'en': 'Durg, Madhya Pradesh'},
 '9178884':{'en': 'Durg, Madhya Pradesh'},
 '9178885':{'en': 'Durg, Madhya Pradesh'},
 '9178886':{'en': 'Durg, Madhya Pradesh'},
 '9178887':{'en': 'Durg, Madhya Pradesh'},
 '9178892':{'en': 'Durg, Madhya Pradesh'},
 '9178893':{'en': 'Durg, Madhya Pradesh'},
 '9178894':{'en': 'Durg, Madhya Pradesh'},
 '9178895':{'en': 'Durg, Madhya Pradesh'},
 '9178896':{'en': 'Durg, Madhya Pradesh'},
 '9178897':{'en': 'Durg, Madhya Pradesh'},
 '9179002':{'en': 'Ahmedabad Local, Gujarat'},
 '9179003':{'en': 'Ahmedabad Local, Gujarat'},
 '9179004':{'en': 'Ahmedabad Local, Gujarat'},
 '9179005':{'en': 'Ahmedabad Local, Gujarat'},
 '9179006':{'en': 'Ahmedabad Local, Gujarat'},
 '9179007':{'en': 'Ahmedabad Local, Gujarat'},
 '9179012':{'en': 'Ahmedabad Local, Gujarat'},
 '9179013':{'en': 'Ahmedabad Local, Gujarat'},
 '9179014':{'en': 'Ahmedabad Local, Gujarat'},
 '9179015':{'en': 'Ahmedabad Local, Gujarat'},
 '9179016':{'en': 'Ahmedabad Local, Gujarat'},
 '9179017':{'en': 'Ahmedabad Local, Gujarat'},
 '9179022':{'en': 'Ahmedabad Local, Gujarat'},
 '9179023':{'en': 'Ahmedabad Local, Gujarat'},
 '9179024':{'en': 'Ahmedabad Local, Gujarat'},
 '9179025':{'en': 'Ahmedabad Local, Gujarat'},
 '9179026':{'en': 'Ahmedabad Local, Gujarat'},
 '9179027':{'en': 'Ahmedabad Local, Gujarat'},
 '9179032':{'en': 'Ahmedabad Local, Gujarat'},
 '9179033':{'en': 'Ahmedabad Local, Gujarat'},
 '9179034':{'en': 'Ahmedabad Local, Gujarat'},
 '9179035':{'en': 'Ahmedabad Local, Gujarat'},
 '9179036':{'en': 'Ahmedabad Local, Gujarat'},
 '9179037':{'en': 'Ahmedabad Local, Gujarat'},
 '9179042':{'en': 'Ahmedabad Local, Gujarat'},
 '9179043':{'en': 'Ahmedabad Local, Gujarat'},
 '9179044':{'en': 'Ahmedabad Local, Gujarat'},
 '9179045':{'en': 'Ahmedabad Local, Gujarat'},
 '9179046':{'en': 'Ahmedabad Local, Gujarat'},
 '9179047':{'en': 'Ahmedabad Local, Gujarat'},
 '9179052':{'en': 'Ahmedabad Local, Gujarat'},
 '9179053':{'en': 'Ahmedabad Local, Gujarat'},
 '9179054':{'en': 'Ahmedabad Local, Gujarat'},
 '9179055':{'en': 'Ahmedabad Local, Gujarat'},
 '9179056':{'en': 'Ahmedabad Local, Gujarat'},
 '9179057':{'en': 'Ahmedabad Local, Gujarat'},
 '9179062':{'en': 'Ahmedabad Local, Gujarat'},
 '9179063':{'en': 'Ahmedabad Local, Gujarat'},
 '9179064':{'en': 'Ahmedabad Local, Gujarat'},
 '9179065':{'en': 'Ahmedabad Local, Gujarat'},
 '9179066':{'en': 'Ahmedabad Local, Gujarat'},
 '9179067':{'en': 'Ahmedabad Local, Gujarat'},
 '9179072':{'en': 'Ahmedabad Local, Gujarat'},
 '9179073':{'en': 'Ahmedabad Local, Gujarat'},
 '9179074':{'en': 'Ahmedabad Local, Gujarat'},
 '9179075':{'en': 'Ahmedabad Local, Gujarat'},
 '9179076':{'en': 'Ahmedabad Local, Gujarat'},
 '9179077':{'en': 'Ahmedabad Local, Gujarat'},
 '9179082':{'en': 'Ahmedabad Local, Gujarat'},
 '9179083':{'en': 'Ahmedabad Local, Gujarat'},
 '9179084':{'en': 'Ahmedabad Local, Gujarat'},
 '9179085':{'en': 'Ahmedabad Local, Gujarat'},
 '9179086':{'en': 'Ahmedabad Local, Gujarat'},
 '9179087':{'en': 'Ahmedabad Local, Gujarat'},
 '9179092':{'en': 'Ahmedabad Local, Gujarat'},
 '9179093':{'en': 'Ahmedabad Local, Gujarat'},
 '9179094':{'en': 'Ahmedabad Local, Gujarat'},
 '9179095':{'en': 'Ahmedabad Local, Gujarat'},
 '9179096':{'en': 'Ahmedabad Local, Gujarat'},
 '9179097':{'en': 'Ahmedabad Local, Gujarat'},
 '917912':{'en': 'Ahmedabad Local, Gujarat'},
 '917913':{'en': 'Ahmedabad Local, Gujarat'},
 '917914':{'en': 'Ahmedabad Local, Gujarat'},
 '917915':{'en': 'Ahmedabad Local, Gujarat'},
 '917916':{'en': 'Ahmedabad Local, Gujarat'},
 '917917':{'en': 'Ahmedabad Local, Gujarat'},
 '91792':{'en': 'Ahmedabad Local, Gujarat'},
 '91793':{'en': 'Ahmedabad Local, Gujarat'},
 '91794':{'en': 'Ahmedabad Local, Gujarat'},
 '91795':{'en': 'Ahmedabad Local, Gujarat'},
 '91796':{'en': 'Ahmedabad Local, Gujarat'},
 '91797':{'en': 'Ahmedabad Local, Gujarat'},
 '9179802':{'en': 'Ahmedabad Local, Gujarat'},
 '9179803':{'en': 'Ahmedabad Local, Gujarat'},
 '9179804':{'en': 'Ahmedabad Local, Gujarat'},
 '9179805':{'en': 'Ahmedabad Local, Gujarat'},
 '9179806':{'en': 'Ahmedabad Local, Gujarat'},
 '9179807':{'en': 'Ahmedabad Local, Gujarat'},
 '9179812':{'en': 'Ahmedabad Local, Gujarat'},
 '9179813':{'en': 'Ahmedabad Local, Gujarat'},
 '9179814':{'en': 'Ahmedabad Local, Gujarat'},
 '9179815':{'en': 'Ahmedabad Local, Gujarat'},
 '9179816':{'en': 'Ahmedabad Local, Gujarat'},
 '9179817':{'en': 'Ahmedabad Local, Gujarat'},
 '9179822':{'en': 'Ahmedabad Local, Gujarat'},
 '9179823':{'en': 'Ahmedabad Local, Gujarat'},
 '9179824':{'en': 'Ahmedabad Local, Gujarat'},
 '9179825':{'en': 'Ahmedabad Local, Gujarat'},
 '9179826':{'en': 'Ahmedabad Local, Gujarat'},
 '9179827':{'en': 'Ahmedabad Local, Gujarat'},
 '9179832':{'en': 'Ahmedabad Local, Gujarat'},
 '9179833':{'en': 'Ahmedabad Local, Gujarat'},
 '9179834':{'en': 'Ahmedabad Local, Gujarat'},
 '9179835':{'en': 'Ahmedabad Local, Gujarat'},
 '9179836':{'en': 'Ahmedabad Local, Gujarat'},
 '9179837':{'en': 'Ahmedabad Local, Gujarat'},
 '9179842':{'en': 'Ahmedabad Local, Gujarat'},
 '9179843':{'en': 'Ahmedabad Local, Gujarat'},
 '9179844':{'en': 'Ahmedabad Local, Gujarat'},
 '9179845':{'en': 'Ahmedabad Local, Gujarat'},
 '9179846':{'en': 'Ahmedabad Local, Gujarat'},
 '9179847':{'en': 'Ahmedabad Local, Gujarat'},
 '9179852':{'en': 'Ahmedabad Local, Gujarat'},
 '9179853':{'en': 'Ahmedabad Local, Gujarat'},
 '9179854':{'en': 'Ahmedabad Local, Gujarat'},
 '9179855':{'en': 'Ahmedabad Local, Gujarat'},
 '9179856':{'en': 'Ahmedabad Local, Gujarat'},
 '9179857':{'en': 'Ahmedabad Local, Gujarat'},
 '9179862':{'en': 'Ahmedabad Local, Gujarat'},
 '9179863':{'en': 'Ahmedabad Local, Gujarat'},
 '9179864':{'en': 'Ahmedabad Local, Gujarat'},
 '9179865':{'en': 'Ahmedabad Local, Gujarat'},
 '9179866':{'en': 'Ahmedabad Local, Gujarat'},
 '9179867':{'en': 'Ahmedabad Local, Gujarat'},
 '9179872':{'en': 'Ahmedabad Local, Gujarat'},
 '9179873':{'en': 'Ahmedabad Local, Gujarat'},
 '9179874':{'en': 'Ahmedabad Local, Gujarat'},
 '9179875':{'en': 'Ahmedabad Local, Gujarat'},
 '9179876':{'en': 'Ahmedabad Local, Gujarat'},
 '9179877':{'en': 'Ahmedabad Local, Gujarat'},
 '9179882':{'en': 'Ahmedabad Local, Gujarat'},
 '9179883':{'en': 'Ahmedabad Local, Gujarat'},
 '9179884':{'en': 'Ahmedabad Local, Gujarat'},
 '9179885':{'en': 'Ahmedabad Local, Gujarat'},
 '9179886':{'en': 'Ahmedabad Local, Gujarat'},
 '9179887':{'en': 'Ahmedabad Local, Gujarat'},
 '9179892':{'en': 'Ahmedabad Local, Gujarat'},
 '9179893':{'en': 'Ahmedabad Local, Gujarat'},
 '9179894':{'en': 'Ahmedabad Local, Gujarat'},
 '9179895':{'en': 'Ahmedabad Local, Gujarat'},
 '9179896':{'en': 'Ahmedabad Local, Gujarat'},
 '9179897':{'en': 'Ahmedabad Local, Gujarat'},
 '9179902':{'en': 'Ahmedabad Local, Gujarat'},
 '9179903':{'en': 'Ahmedabad Local, Gujarat'},
 '9179904':{'en': 'Ahmedabad Local, Gujarat'},
 '9179905':{'en': 'Ahmedabad Local, Gujarat'},
 '9179906':{'en': 'Ahmedabad Local, Gujarat'},
 '9179907':{'en': 'Ahmedabad Local, Gujarat'},
 '9179912':{'en': 'Ahmedabad Local, Gujarat'},
 '9179913':{'en': 'Ahmedabad Local, Gujarat'},
 '9179914':{'en': 'Ahmedabad Local, Gujarat'},
 '9179915':{'en': 'Ahmedabad Local, Gujarat'},
 '9179916':{'en': 'Ahmedabad Local, Gujarat'},
 '9179917':{'en': 'Ahmedabad Local, Gujarat'},
 '9179922':{'en': 'Ahmedabad Local, Gujarat'},
 '9179923':{'en': 'Ahmedabad Local, Gujarat'},
 '9179924':{'en': 'Ahmedabad Local, Gujarat'},
 '9179925':{'en': 'Ahmedabad Local, Gujarat'},
 '9179926':{'en': 'Ahmedabad Local, Gujarat'},
 '9179927':{'en': 'Ahmedabad Local, Gujarat'},
 '9179932':{'en': 'Ahmedabad Local, Gujarat'},
 '9179933':{'en': 'Ahmedabad Local, Gujarat'},
 '9179934':{'en': 'Ahmedabad Local, Gujarat'},
 '9179935':{'en': 'Ahmedabad Local, Gujarat'},
 '9179936':{'en': 'Ahmedabad Local, Gujarat'},
 '9179937':{'en': 'Ahmedabad Local, Gujarat'},
 '9179942':{'en': 'Ahmedabad Local, Gujarat'},
 '9179943':{'en': 'Ahmedabad Local, Gujarat'},
 '9179944':{'en': 'Ahmedabad Local, Gujarat'},
 '9179945':{'en': 'Ahmedabad Local, Gujarat'},
 '9179946':{'en': 'Ahmedabad Local, Gujarat'},
 '9179947':{'en': 'Ahmedabad Local, Gujarat'},
 '9179952':{'en': 'Ahmedabad Local, Gujarat'},
 '9179953':{'en': 'Ahmedabad Local, Gujarat'},
 '9179954':{'en': 'Ahmedabad Local, Gujarat'},
 '9179955':{'en': 'Ahmedabad Local, Gujarat'},
 '9179956':{'en': 'Ahmedabad Local, Gujarat'},
 '9179957':{'en': 'Ahmedabad Local, Gujarat'},
 '9179962':{'en': 'Ahmedabad Local, Gujarat'},
 '9179963':{'en': 'Ahmedabad Local, Gujarat'},
 '9179964':{'en': 'Ahmedabad Local, Gujarat'},
 '9179965':{'en': 'Ahmedabad Local, Gujarat'},
 '9179966':{'en': 'Ahmedabad Local, Gujarat'},
 '9179967':{'en': 'Ahmedabad Local, Gujarat'},
 '9179972':{'en': 'Ahmedabad Local, Gujarat'},
 '9179973':{'en': 'Ahmedabad Local, Gujarat'},
 '9179974':{'en': 'Ahmedabad Local, Gujarat'},
 '9179975':{'en': 'Ahmedabad Local, Gujarat'},
 '9179976':{'en': 'Ahmedabad Local, Gujarat'},
 '9179977':{'en': 'Ahmedabad Local, Gujarat'},
 '9179982':{'en': 'Ahmedabad Local, Gujarat'},
 '9179983':{'en': 'Ahmedabad Local, Gujarat'},
 '9179984':{'en': 'Ahmedabad Local, Gujarat'},
 '9179985':{'en': 'Ahmedabad Local, Gujarat'},
 '9179986':{'en': 'Ahmedabad Local, Gujarat'},
 '9179987':{'en': 'Ahmedabad Local, Gujarat'},
 '9179992':{'en': 'Ahmedabad Local, Gujarat'},
 '9179993':{'en': 'Ahmedabad Local, Gujarat'},
 '9179994':{'en': 'Ahmedabad Local, Gujarat'},
 '9179995':{'en': 'Ahmedabad Local, Gujarat'},
 '9179996':{'en': 'Ahmedabad Local, Gujarat'},
 '9179997':{'en': 'Ahmedabad Local, Gujarat'},
 '91802':{'en': 'Bangalore, Karnataka'},
 '91803':{'en': 'Bangalore, Karnataka'},
 '91804':{'en': 'Bangalore, Karnataka'},
 '91805':{'en': 'Bangalore, Karnataka'},
 '91806':{'en': 'Bangalore, Karnataka'},
 '91807':{'en': 'Bangalore, Karnataka'},
 '9181102':{'en': 'Anekal, Karnataka'},
 '9181103':{'en': 'Anekal, Karnataka'},
 '9181104':{'en': 'Anekal, Karnataka'},
 '9181105':{'en': 'Anekal, Karnataka'},
 '9181106':{'en': 'Anekal, Karnataka'},
 '9181107':{'en': 'Anekal, Karnataka'},
 '9181112':{'en': 'Hosakote, Karnataka'},
 '9181113':{'en': 'Hosakote, Karnataka'},
 '9181114':{'en': 'Hosakote, Karnataka'},
 '9181115':{'en': 'Hosakote, Karnataka'},
 '9181116':{'en': 'Hosakote, Karnataka'},
 '9181117':{'en': 'Hosakote, Karnataka'},
 '9181132':{'en': 'Channapatna, Karnataka'},
 '9181133':{'en': 'Channapatna, Karnataka'},
 '9181134':{'en': 'Channapatna, Karnataka'},
 '9181135':{'en': 'Channapatna, Karnataka'},
 '9181136':{'en': 'Channapatna, Karnataka'},
 '9181137':{'en': 'Channapatna, Karnataka'},
 '9181172':{'en': 'Kanakapura, Karnataka'},
 '9181173':{'en': 'Kanakapura, Karnataka'},
 '9181174':{'en': 'Kanakapura, Karnataka'},
 '9181175':{'en': 'Kanakapura, Karnataka'},
 '9181176':{'en': 'Kanakapura, Karnataka'},
 '9181177':{'en': 'Kanakapura, Karnataka'},
 '9181182':{'en': 'Nelamangala, Karnataka'},
 '9181183':{'en': 'Nelamangala, Karnataka'},
 '9181184':{'en': 'Nelamangala, Karnataka'},
 '9181185':{'en': 'Nelamangala, Karnataka'},
 '9181186':{'en': 'Nelamangala, Karnataka'},
 '9181187':{'en': 'Nelamangala, Karnataka'},
 '9181192':{'en': 'Doddaballapur, Karnataka'},
 '9181193':{'en': 'Doddaballapur, Karnataka'},
 '9181194':{'en': 'Doddaballapur, Karnataka'},
 '9181195':{'en': 'Doddaballapur, Karnataka'},
 '9181196':{'en': 'Doddaballapur, Karnataka'},
 '9181197':{'en': 'Doddaballapur, Karnataka'},
 '9181312':{'en': 'Gubbi, Karnataka'},
 '9181313':{'en': 'Gubbi, Karnataka'},
 '9181314':{'en': 'Gubbi, Karnataka'},
 '9181315':{'en': 'Gubbi, Karnataka'},
 '9181316':{'en': 'Gubbi, Karnataka'},
 '9181317':{'en': 'Gubbi, Karnataka'},
 '9181322':{'en': 'Kunigal, Karnataka'},
 '9181323':{'en': 'Kunigal, Karnataka'},
 '9181324':{'en': 'Kunigal, Karnataka'},
 '9181325':{'en': 'Kunigal, Karnataka'},
 '9181326':{'en': 'Kunigal, Karnataka'},
 '9181327':{'en': 'Kunigal, Karnataka'},
 '9181332':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181333':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181334':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181335':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181336':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181337':{'en': 'Chikkanayakanahalli, Karnataka'},
 '9181342':{'en': 'Tiptur, Karnataka'},
 '9181343':{'en': 'Tiptur, Karnataka'},
 '9181344':{'en': 'Tiptur, Karnataka'},
 '9181345':{'en': 'Tiptur, Karnataka'},
 '9181346':{'en': 'Tiptur, Karnataka'},
 '9181347':{'en': 'Tiptur, Karnataka'},
 '9181352':{'en': 'Sira, Karnataka'},
 '9181353':{'en': 'Sira, Karnataka'},
 '9181354':{'en': 'Sira, Karnataka'},
 '9181355':{'en': 'Sira, Karnataka'},
 '9181356':{'en': 'Sira, Karnataka'},
 '9181357':{'en': 'Sira, Karnataka'},
 '9181362':{'en': 'Pavagada, Karnataka'},
 '9181363':{'en': 'Pavagada, Karnataka'},
 '9181364':{'en': 'Pavagada, Karnataka'},
 '9181365':{'en': 'Pavagada, Karnataka'},
 '9181366':{'en': 'Pavagada, Karnataka'},
 '9181367':{'en': 'Pavagada, Karnataka'},
 '9181372':{'en': 'Madugiri, Karnataka'},
 '9181373':{'en': 'Madugiri, Karnataka'},
 '9181374':{'en': 'Madugiri, Karnataka'},
 '9181375':{'en': 'Madugiri, Karnataka'},
 '9181376':{'en': 'Madugiri, Karnataka'},
 '9181377':{'en': 'Madugiri, Karnataka'},
 '9181382':{'en': 'Koratageri, Karnataka'},
 '9181383':{'en': 'Koratageri, Karnataka'},
 '9181384':{'en': 'Koratageri, Karnataka'},
 '9181385':{'en': 'Koratageri, Karnataka'},
 '9181386':{'en': 'Koratageri, Karnataka'},
 '9181387':{'en': 'Koratageri, Karnataka'},
 '9181392':{'en': 'Turuvekere, Karnataka'},
 '9181393':{'en': 'Turuvekere, Karnataka'},
 '9181394':{'en': 'Turuvekere, Karnataka'},
 '9181395':{'en': 'Turuvekere, Karnataka'},
 '9181396':{'en': 'Turuvekere, Karnataka'},
 '9181397':{'en': 'Turuvekere, Karnataka'},
 '9181502':{'en': 'Bagepalli, Karnataka'},
 '9181503':{'en': 'Bagepalli, Karnataka'},
 '9181504':{'en': 'Bagepalli, Karnataka'},
 '9181505':{'en': 'Bagepalli, Karnataka'},
 '9181506':{'en': 'Bagepalli, Karnataka'},
 '9181507':{'en': 'Bagepalli, Karnataka'},
 '9181512':{'en': 'Malur, Karnataka'},
 '9181513':{'en': 'Malur, Karnataka'},
 '9181514':{'en': 'Malur, Karnataka'},
 '9181515':{'en': 'Malur, Karnataka'},
 '9181516':{'en': 'Malur, Karnataka'},
 '9181517':{'en': 'Malur, Karnataka'},
 '9181522':{'en': 'Kolar, Karnataka'},
 '9181523':{'en': 'Kolar, Karnataka'},
 '9181524':{'en': 'Kolar, Karnataka'},
 '9181525':{'en': 'Kolar, Karnataka'},
 '9181526':{'en': 'Kolar, Karnataka'},
 '9181527':{'en': 'Kolar, Karnataka'},
 '9181532':{'en': 'Bangarpet, Karnataka'},
 '9181533':{'en': 'Bangarpet, Karnataka'},
 '9181534':{'en': 'Bangarpet, Karnataka'},
 '9181535':{'en': 'Bangarpet, Karnataka'},
 '9181536':{'en': 'Bangarpet, Karnataka'},
 '9181537':{'en': 'Bangarpet, Karnataka'},
 '9181542':{'en': 'Chintamani, Karnataka'},
 '9181543':{'en': 'Chintamani, Karnataka'},
 '9181544':{'en': 'Chintamani, Karnataka'},
 '9181545':{'en': 'Chintamani, Karnataka'},
 '9181546':{'en': 'Chintamani, Karnataka'},
 '9181547':{'en': 'Chintamani, Karnataka'},
 '9181552':{'en': 'Gowribidanur, Karnataka'},
 '9181553':{'en': 'Gowribidanur, Karnataka'},
 '9181554':{'en': 'Gowribidanur, Karnataka'},
 '9181555':{'en': 'Gowribidanur, Karnataka'},
 '9181556':{'en': 'Gowribidanur, Karnataka'},
 '9181557':{'en': 'Gowribidanur, Karnataka'},
 '9181562':{'en': 'Chikkaballapur, Karnataka'},
 '9181563':{'en': 'Chikkaballapur, Karnataka'},
 '9181564':{'en': 'Chikkaballapur, Karnataka'},
 '9181565':{'en': 'Chikkaballapur, Karnataka'},
 '9181566':{'en': 'Chikkaballapur, Karnataka'},
 '9181567':{'en': 'Chikkaballapur, Karnataka'},
 '9181572':{'en': 'Srinivasapur, Karnataka'},
 '9181573':{'en': 'Srinivasapur, Karnataka'},
 '9181574':{'en': 'Srinivasapur, Karnataka'},
 '9181575':{'en': 'Srinivasapur, Karnataka'},
 '9181576':{'en': 'Srinivasapur, Karnataka'},
 '9181577':{'en': 'Srinivasapur, Karnataka'},
 '9181582':{'en': 'Sidlaghatta, Karnataka'},
 '9181583':{'en': 'Sidlaghatta, Karnataka'},
 '9181584':{'en': 'Sidlaghatta, Karnataka'},
 '9181585':{'en': 'Sidlaghatta, Karnataka'},
 '9181586':{'en': 'Sidlaghatta, Karnataka'},
 '9181587':{'en': 'Sidlaghatta, Karnataka'},
 '9181592':{'en': 'Mulbagal, Karnataka'},
 '9181593':{'en': 'Mulbagal, Karnataka'},
 '9181594':{'en': 'Mulbagal, Karnataka'},
 '9181595':{'en': 'Mulbagal, Karnataka'},
 '9181596':{'en': 'Mulbagal, Karnataka'},
 '9181597':{'en': 'Mulbagal, Karnataka'},
 '918162':{'en': 'Tumkur, Karnataka'},
 '918163':{'en': 'Tumkur, Karnataka'},
 '918164':{'en': 'Tumkur, Karnataka'},
 '918165':{'en': 'Tumkur, Karnataka'},
 '918166':{'en': 'Tumkur, Karnataka'},
 '918167':{'en': 'Tumkur, Karnataka'},
 '9181702':{'en': 'Alur, Karnataka'},
 '9181703':{'en': 'Alur, Karnataka'},
 '9181704':{'en': 'Alur, Karnataka'},
 '9181705':{'en': 'Alur, Karnataka'},
 '9181706':{'en': 'Alur, Karnataka'},
 '9181707':{'en': 'Alur, Karnataka'},
 '9181722':{'en': 'Hassan, Karnataka'},
 '9181723':{'en': 'Hassan, Karnataka'},
 '9181724':{'en': 'Hassan, Karnataka'},
 '9181725':{'en': 'Hassan, Karnataka'},
 '9181726':{'en': 'Hassan, Karnataka'},
 '9181727':{'en': 'Hassan, Karnataka'},
 '9181732':{'en': 'Sakleshpur, Karnataka'},
 '9181733':{'en': 'Sakleshpur, Karnataka'},
 '9181734':{'en': 'Sakleshpur, Karnataka'},
 '9181735':{'en': 'Sakleshpur, Karnataka'},
 '9181736':{'en': 'Sakleshpur, Karnataka'},
 '9181737':{'en': 'Sakleshpur, Karnataka'},
 '9181742':{'en': 'Arsikere, Karnataka'},
 '9181743':{'en': 'Arsikere, Karnataka'},
 '9181744':{'en': 'Arsikere, Karnataka'},
 '9181745':{'en': 'Arsikere, Karnataka'},
 '9181746':{'en': 'Arsikere, Karnataka'},
 '9181747':{'en': 'Arsikere, Karnataka'},
 '9181752':{'en': 'Holenarasipur, Karnataka'},
 '9181753':{'en': 'Holenarasipur, Karnataka'},
 '9181754':{'en': 'Holenarasipur, Karnataka'},
 '9181755':{'en': 'Holenarasipur, Karnataka'},
 '9181756':{'en': 'Holenarasipur, Karnataka'},
 '9181757':{'en': 'Holenarasipur, Karnataka'},
 '9181762':{'en': 'Cannarayapatna, Karnataka'},
 '9181763':{'en': 'Cannarayapatna, Karnataka'},
 '9181764':{'en': 'Cannarayapatna, Karnataka'},
 '9181765':{'en': 'Cannarayapatna, Karnataka'},
 '9181766':{'en': 'Cannarayapatna, Karnataka'},
 '9181767':{'en': 'Cannarayapatna, Karnataka'},
 '9181772':{'en': 'Belur, Karnataka'},
 '9181773':{'en': 'Belur, Karnataka'},
 '9181774':{'en': 'Belur, Karnataka'},
 '9181775':{'en': 'Belur, Karnataka'},
 '9181776':{'en': 'Belur, Karnataka'},
 '9181777':{'en': 'Belur, Karnataka'},
 '9181802':{'en': 'Basavapatna, Karnataka'},
 '9181803':{'en': 'Basavapatna, Karnataka'},
 '9181804':{'en': 'Basavapatna, Karnataka'},
 '9181805':{'en': 'Basavapatna, Karnataka'},
 '9181806':{'en': 'Basavapatna, Karnataka'},
 '9181807':{'en': 'Basavapatna, Karnataka'},
 '9181812':{'en': 'Thirthahalli, Karnataka'},
 '9181813':{'en': 'Thirthahalli, Karnataka'},
 '9181814':{'en': 'Thirthahalli, Karnataka'},
 '9181815':{'en': 'Thirthahalli, Karnataka'},
 '9181816':{'en': 'Thirthahalli, Karnataka'},
 '9181817':{'en': 'Thirthahalli, Karnataka'},
 '9181822':{'en': 'Shimoga, Karnataka'},
 '9181823':{'en': 'Shimoga, Karnataka'},
 '9181824':{'en': 'Shimoga, Karnataka'},
 '9181825':{'en': 'Shimoga, Karnataka'},
 '9181826':{'en': 'Shimoga, Karnataka'},
 '9181827':{'en': 'Shimoga, Karnataka'},
 '9181832':{'en': 'Sagar, Karnataka'},
 '9181833':{'en': 'Sagar, Karnataka'},
 '9181834':{'en': 'Sagar, Karnataka'},
 '9181835':{'en': 'Sagar, Karnataka'},
 '9181836':{'en': 'Sagar, Karnataka'},
 '9181837':{'en': 'Sagar, Karnataka'},
 '9181842':{'en': 'Sorab, Karnataka'},
 '9181843':{'en': 'Sorab, Karnataka'},
 '9181844':{'en': 'Sorab, Karnataka'},
 '9181845':{'en': 'Sorab, Karnataka'},
 '9181846':{'en': 'Sorab, Karnataka'},
 '9181847':{'en': 'Sorab, Karnataka'},
 '9181852':{'en': 'Hosanagara, Karnataka'},
 '9181853':{'en': 'Hosanagara, Karnataka'},
 '9181854':{'en': 'Hosanagara, Karnataka'},
 '9181855':{'en': 'Hosanagara, Karnataka'},
 '9181856':{'en': 'Hosanagara, Karnataka'},
 '9181857':{'en': 'Hosanagara, Karnataka'},
 '9181862':{'en': 'Kargal, Karnataka'},
 '9181863':{'en': 'Kargal, Karnataka'},
 '9181864':{'en': 'Kargal, Karnataka'},
 '9181865':{'en': 'Kargal, Karnataka'},
 '9181866':{'en': 'Kargal, Karnataka'},
 '9181867':{'en': 'Kargal, Karnataka'},
 '9181872':{'en': 'Shikaripura, Karnataka'},
 '9181873':{'en': 'Shikaripura, Karnataka'},
 '9181874':{'en': 'Shikaripura, Karnataka'},
 '9181875':{'en': 'Shikaripura, Karnataka'},
 '9181876':{'en': 'Shikaripura, Karnataka'},
 '9181877':{'en': 'Shikaripura, Karnataka'},
 '9181882':{'en': 'Honnali, Karnataka'},
 '9181883':{'en': 'Honnali, Karnataka'},
 '9181884':{'en': 'Honnali, Karnataka'},
 '9181885':{'en': 'Honnali, Karnataka'},
 '9181886':{'en': 'Honnali, Karnataka'},
 '9181887':{'en': 'Honnali, Karnataka'},
 '9181892':{'en': 'Channagiri, Karnataka'},
 '9181893':{'en': 'Channagiri, Karnataka'},
 '9181894':{'en': 'Channagiri, Karnataka'},
 '9181895':{'en': 'Channagiri, Karnataka'},
 '9181896':{'en': 'Channagiri, Karnataka'},
 '9181897':{'en': 'Channagiri, Karnataka'},
 '9181902':{'en': 'Tallak, Karnataka'},
 '9181903':{'en': 'Tallak, Karnataka'},
 '9181904':{'en': 'Tallak, Karnataka'},
 '9181905':{'en': 'Tallak, Karnataka'},
 '9181906':{'en': 'Tallak, Karnataka'},
 '9181907':{'en': 'Tallak, Karnataka'},
 '9181912':{'en': 'Holalkere, Karnataka'},
 '9181913':{'en': 'Holalkere, Karnataka'},
 '9181914':{'en': 'Holalkere, Karnataka'},
 '9181915':{'en': 'Holalkere, Karnataka'},
 '9181916':{'en': 'Holalkere, Karnataka'},
 '9181917':{'en': 'Holalkere, Karnataka'},
 '9181922':{'en': 'Davangere, Karnataka'},
 '9181923':{'en': 'Davangere, Karnataka'},
 '9181924':{'en': 'Davangere, Karnataka'},
 '9181925':{'en': 'Davangere, Karnataka'},
 '9181926':{'en': 'Davangere, Karnataka'},
 '9181927':{'en': 'Davangere, Karnataka'},
 '9181932':{'en': 'Hiriyur, Karnataka'},
 '9181933':{'en': 'Hiriyur, Karnataka'},
 '9181934':{'en': 'Hiriyur, Karnataka'},
 '9181935':{'en': 'Hiriyur, Karnataka'},
 '9181936':{'en': 'Hiriyur, Karnataka'},
 '9181937':{'en': 'Hiriyur, Karnataka'},
 '9181942':{'en': 'Chitradurga, Karnataka'},
 '9181943':{'en': 'Chitradurga, Karnataka'},
 '9181944':{'en': 'Chitradurga, Karnataka'},
 '9181945':{'en': 'Chitradurga, Karnataka'},
 '9181946':{'en': 'Chitradurga, Karnataka'},
 '9181947':{'en': 'Chitradurga, Karnataka'},
 '9181952':{'en': 'Challakere, Karnataka'},
 '9181953':{'en': 'Challakere, Karnataka'},
 '9181954':{'en': 'Challakere, Karnataka'},
 '9181955':{'en': 'Challakere, Karnataka'},
 '9181956':{'en': 'Challakere, Karnataka'},
 '9181957':{'en': 'Challakere, Karnataka'},
 '9181962':{'en': 'Jagalur, Karnataka'},
 '9181963':{'en': 'Jagalur, Karnataka'},
 '9181964':{'en': 'Jagalur, Karnataka'},
 '9181965':{'en': 'Jagalur, Karnataka'},
 '9181966':{'en': 'Jagalur, Karnataka'},
 '9181967':{'en': 'Jagalur, Karnataka'},
 '9181982':{'en': 'Molkalmuru, Karnataka'},
 '9181983':{'en': 'Molkalmuru, Karnataka'},
 '9181984':{'en': 'Molkalmuru, Karnataka'},
 '9181985':{'en': 'Molkalmuru, Karnataka'},
 '9181986':{'en': 'Molkalmuru, Karnataka'},
 '9181987':{'en': 'Molkalmuru, Karnataka'},
 '9181992':{'en': 'Hosadurga, Karnataka'},
 '9181993':{'en': 'Hosadurga, Karnataka'},
 '9181994':{'en': 'Hosadurga, Karnataka'},
 '9181995':{'en': 'Hosadurga, Karnataka'},
 '9181996':{'en': 'Hosadurga, Karnataka'},
 '9181997':{'en': 'Hosadurga, Karnataka'},
 '918202':{'en': 'Udupi, Karnataka'},
 '918203':{'en': 'Udupi, Karnataka'},
 '918204':{'en': 'Udupi, Karnataka'},
 '918205':{'en': 'Udupi, Karnataka'},
 '918206':{'en': 'Udupi, Karnataka'},
 '918207':{'en': 'Udupi, Karnataka'},
 '918212':{'en': 'Mysore, Karnataka'},
 '918213':{'en': 'Mysore, Karnataka'},
 '918214':{'en': 'Mysore, Karnataka'},
 '918215':{'en': 'Mysore, Karnataka'},
 '918216':{'en': 'Mysore, Karnataka'},
 '918217':{'en': 'Mysore, Karnataka'},
 '9182202':{'en': 'Gundlupet, Karnataka'},
 '9182203':{'en': 'Gundlupet, Karnataka'},
 '9182204':{'en': 'Gundlupet, Karnataka'},
 '9182205':{'en': 'Gundlupet, Karnataka'},
 '9182206':{'en': 'Gundlupet, Karnataka'},
 '9182207':{'en': 'Gundlupet, Karnataka'},
 '9182212':{'en': 'Nanjangud, Karnataka'},
 '9182213':{'en': 'Nanjangud, Karnataka'},
 '9182214':{'en': 'Nanjangud, Karnataka'},
 '9182215':{'en': 'Nanjangud, Karnataka'},
 '9182216':{'en': 'Nanjangud, Karnataka'},
 '9182217':{'en': 'Nanjangud, Karnataka'},
 '9182222':{'en': 'Hunsur, Karnataka'},
 '9182223':{'en': 'Hunsur, Karnataka'},
 '9182224':{'en': 'Hunsur, Karnataka'},
 '9182225':{'en': 'Hunsur, Karnataka'},
 '9182226':{'en': 'Hunsur, Karnataka'},
 '9182227':{'en': 'Hunsur, Karnataka'},
 '9182232':{'en': 'K.R.Nagar, Karnataka'},
 '9182233':{'en': 'K.R.Nagar, Karnataka'},
 '9182234':{'en': 'K.R.Nagar, Karnataka'},
 '9182235':{'en': 'K.R.Nagar, Karnataka'},
 '9182236':{'en': 'K.R.Nagar, Karnataka'},
 '9182237':{'en': 'K.R.Nagar, Karnataka'},
 '9182242':{'en': 'Kollegal, Karnataka'},
 '9182243':{'en': 'Kollegal, Karnataka'},
 '9182244':{'en': 'Kollegal, Karnataka'},
 '9182245':{'en': 'Kollegal, Karnataka'},
 '9182246':{'en': 'Kollegal, Karnataka'},
 '9182247':{'en': 'Kollegal, Karnataka'},
 '9182252':{'en': 'Cowdahalli, Karnataka'},
 '9182253':{'en': 'Cowdahalli, Karnataka'},
 '9182254':{'en': 'Cowdahalli, Karnataka'},
 '9182255':{'en': 'Cowdahalli, Karnataka'},
 '9182256':{'en': 'Cowdahalli, Karnataka'},
 '9182257':{'en': 'Cowdahalli, Karnataka'},
 '9182262':{'en': 'Chamrajnagar, Karnataka'},
 '9182263':{'en': 'Chamrajnagar, Karnataka'},
 '9182264':{'en': 'Chamrajnagar, Karnataka'},
 '9182265':{'en': 'Chamrajnagar, Karnataka'},
 '9182266':{'en': 'Chamrajnagar, Karnataka'},
 '9182267':{'en': 'Chamrajnagar, Karnataka'},
 '9182272':{'en': 'T.Narsipur, Karnataka'},
 '9182273':{'en': 'T.Narsipur, Karnataka'},
 '9182274':{'en': 'T.Narsipur, Karnataka'},
 '9182275':{'en': 'T.Narsipur, Karnataka'},
 '9182276':{'en': 'T.Narsipur, Karnataka'},
 '9182277':{'en': 'T.Narsipur, Karnataka'},
 '9182282':{'en': 'H.D.Kote, Karnataka'},
 '9182283':{'en': 'H.D.Kote, Karnataka'},
 '9182284':{'en': 'H.D.Kote, Karnataka'},
 '9182285':{'en': 'H.D.Kote, Karnataka'},
 '9182286':{'en': 'H.D.Kote, Karnataka'},
 '9182287':{'en': 'H.D.Kote, Karnataka'},
 '9182292':{'en': 'Gundlupet, Karnataka'},
 '9182293':{'en': 'Gundlupet, Karnataka'},
 '9182294':{'en': 'Gundlupet, Karnataka'},
 '9182295':{'en': 'Gundlupet, Karnataka'},
 '9182296':{'en': 'Gundlupet, Karnataka'},
 '9182297':{'en': 'Gundlupet, Karnataka'},
 '9182302':{'en': 'Krishnarajapet, Karnataka'},
 '9182303':{'en': 'Krishnarajapet, Karnataka'},
 '9182304':{'en': 'Krishnarajapet, Karnataka'},
 '9182305':{'en': 'Krishnarajapet, Karnataka'},
 '9182306':{'en': 'Krishnarajapet, Karnataka'},
 '9182307':{'en': 'Krishnarajapet, Karnataka'},
 '9182312':{'en': 'Malavalli, Karnataka'},
 '9182313':{'en': 'Malavalli, Karnataka'},
 '9182314':{'en': 'Malavalli, Karnataka'},
 '9182315':{'en': 'Malavalli, Karnataka'},
 '9182316':{'en': 'Malavalli, Karnataka'},
 '9182317':{'en': 'Malavalli, Karnataka'},
 '9182322':{'en': 'Mandya, Karnataka'},
 '9182323':{'en': 'Mandya, Karnataka'},
 '9182324':{'en': 'Mandya, Karnataka'},
 '9182325':{'en': 'Mandya, Karnataka'},
 '9182326':{'en': 'Mandya, Karnataka'},
 '9182327':{'en': 'Mandya, Karnataka'},
 '9182342':{'en': 'Nagamangala, Karnataka'},
 '9182343':{'en': 'Nagamangala, Karnataka'},
 '9182344':{'en': 'Nagamangala, Karnataka'},
 '9182345':{'en': 'Nagamangala, Karnataka'},
 '9182346':{'en': 'Nagamangala, Karnataka'},
 '9182347':{'en': 'Nagamangala, Karnataka'},
 '9182362':{'en': 'Pandavpura, Karnataka'},
 '9182363':{'en': 'Pandavpura, Karnataka'},
 '9182364':{'en': 'Pandavpura, Karnataka'},
 '9182365':{'en': 'Pandavpura, Karnataka'},
 '9182366':{'en': 'Pandavpura, Karnataka'},
 '9182367':{'en': 'Pandavpura, Karnataka'},
 '918242':{'en': 'Mangalore, Karnataka'},
 '918243':{'en': 'Mangalore, Karnataka'},
 '918244':{'en': 'Mangalore, Karnataka'},
 '918245':{'en': 'Mangalore, Karnataka'},
 '918246':{'en': 'Mangalore, Karnataka'},
 '918247':{'en': 'Mangalore, Karnataka'},
 '9182512':{'en': 'Puttur, Karnataka'},
 '9182513':{'en': 'Puttur, Karnataka'},
 '9182514':{'en': 'Puttur, Karnataka'},
 '9182515':{'en': 'Puttur, Karnataka'},
 '9182516':{'en': 'Puttur, Karnataka'},
 '9182517':{'en': 'Puttur, Karnataka'},
 '9182532':{'en': 'Hebri, Karnataka'},
 '9182533':{'en': 'Hebri, Karnataka'},
 '9182534':{'en': 'Hebri, Karnataka'},
 '9182535':{'en': 'Hebri, Karnataka'},
 '9182536':{'en': 'Hebri, Karnataka'},
 '9182537':{'en': 'Hebri, Karnataka'},
 '9182542':{'en': 'Kundapur, Karnataka'},
 '9182543':{'en': 'Kundapur, Karnataka'},
 '9182544':{'en': 'Kundapur, Karnataka'},
 '9182545':{'en': 'Kundapur, Karnataka'},
 '9182546':{'en': 'Kundapur, Karnataka'},
 '9182547':{'en': 'Kundapur, Karnataka'},
 '9182552':{'en': 'Bantwal, Karnataka'},
 '9182553':{'en': 'Bantwal, Karnataka'},
 '9182554':{'en': 'Bantwal, Karnataka'},
 '9182555':{'en': 'Bantwal, Karnataka'},
 '9182556':{'en': 'Bantwal, Karnataka'},
 '9182557':{'en': 'Bantwal, Karnataka'},
 '9182562':{'en': 'Belthangady, Karnataka'},
 '9182563':{'en': 'Belthangady, Karnataka'},
 '9182564':{'en': 'Belthangady, Karnataka'},
 '9182565':{'en': 'Belthangady, Karnataka'},
 '9182566':{'en': 'Belthangady, Karnataka'},
 '9182567':{'en': 'Belthangady, Karnataka'},
 '9182572':{'en': 'Sullia, Karnataka'},
 '9182573':{'en': 'Sullia, Karnataka'},
 '9182574':{'en': 'Sullia, Karnataka'},
 '9182575':{'en': 'Sullia, Karnataka'},
 '9182576':{'en': 'Sullia, Karnataka'},
 '9182577':{'en': 'Sullia, Karnataka'},
 '9182582':{'en': 'Karkala, Karnataka'},
 '9182583':{'en': 'Karkala, Karnataka'},
 '9182584':{'en': 'Karkala, Karnataka'},
 '9182585':{'en': 'Karkala, Karnataka'},
 '9182586':{'en': 'Karkala, Karnataka'},
 '9182587':{'en': 'Karkala, Karnataka'},
 '9182592':{'en': 'Shankarnarayana, Karnataka'},
 '9182593':{'en': 'Shankarnarayana, Karnataka'},
 '9182594':{'en': 'Shankarnarayana, Karnataka'},
 '9182595':{'en': 'Shankarnarayana, Karnataka'},
 '9182596':{'en': 'Shankarnarayana, Karnataka'},
 '9182597':{'en': 'Shankarnarayana, Karnataka'},
 '9182612':{'en': 'Tarikere, Karnataka'},
 '9182613':{'en': 'Tarikere, Karnataka'},
 '9182614':{'en': 'Tarikere, Karnataka'},
 '9182615':{'en': 'Tarikere, Karnataka'},
 '9182616':{'en': 'Tarikere, Karnataka'},
 '9182617':{'en': 'Tarikere, Karnataka'},
 '9182622':{'en': 'Chikmagalur, Karnataka'},
 '9182623':{'en': 'Chikmagalur, Karnataka'},
 '9182624':{'en': 'Chikmagalur, Karnataka'},
 '9182625':{'en': 'Chikmagalur, Karnataka'},
 '9182626':{'en': 'Chikmagalur, Karnataka'},
 '9182627':{'en': 'Chikmagalur, Karnataka'},
 '9182632':{'en': 'Mudigere, Karnataka'},
 '9182633':{'en': 'Mudigere, Karnataka'},
 '9182634':{'en': 'Mudigere, Karnataka'},
 '9182635':{'en': 'Mudigere, Karnataka'},
 '9182636':{'en': 'Mudigere, Karnataka'},
 '9182637':{'en': 'Mudigere, Karnataka'},
 '9182652':{'en': 'Koppa, Karnataka'},
 '9182653':{'en': 'Koppa, Karnataka'},
 '9182654':{'en': 'Koppa, Karnataka'},
 '9182655':{'en': 'Koppa, Karnataka'},
 '9182656':{'en': 'Koppa, Karnataka'},
 '9182657':{'en': 'Koppa, Karnataka'},
 '9182662':{'en': 'Narsimharajapur, Karnataka'},
 '9182663':{'en': 'Narsimharajapur, Karnataka'},
 '9182664':{'en': 'Narsimharajapur, Karnataka'},
 '9182665':{'en': 'Narsimharajapur, Karnataka'},
 '9182666':{'en': 'Narsimharajapur, Karnataka'},
 '9182667':{'en': 'Narsimharajapur, Karnataka'},
 '9182672':{'en': 'Kadur, Karnataka'},
 '9182673':{'en': 'Kadur, Karnataka'},
 '9182674':{'en': 'Kadur, Karnataka'},
 '9182675':{'en': 'Kadur, Karnataka'},
 '9182676':{'en': 'Kadur, Karnataka'},
 '9182677':{'en': 'Kadur, Karnataka'},
 '9182722':{'en': 'Madikeri, Karnataka'},
 '9182723':{'en': 'Madikeri, Karnataka'},
 '9182724':{'en': 'Madikeri, Karnataka'},
 '9182725':{'en': 'Madikeri, Karnataka'},
 '9182726':{'en': 'Madikeri, Karnataka'},
 '9182727':{'en': 'Madikeri, Karnataka'},
 '9182742':{'en': 'Virajpet, Karnataka'},
 '9182743':{'en': 'Virajpet, Karnataka'},
 '9182744':{'en': 'Virajpet, Karnataka'},
 '9182745':{'en': 'Virajpet, Karnataka'},
 '9182746':{'en': 'Virajpet, Karnataka'},
 '9182747':{'en': 'Virajpet, Karnataka'},
 '9182762':{'en': 'Somwarpet, Karnataka'},
 '9182763':{'en': 'Somwarpet, Karnataka'},
 '9182764':{'en': 'Somwarpet, Karnataka'},
 '9182765':{'en': 'Somwarpet, Karnataka'},
 '9182766':{'en': 'Somwarpet, Karnataka'},
 '9182767':{'en': 'Somwarpet, Karnataka'},
 '9182822':{'en': 'Bhadravati, Karnataka'},
 '9182823':{'en': 'Bhadravati, Karnataka'},
 '9182824':{'en': 'Bhadravati, Karnataka'},
 '9182825':{'en': 'Bhadravati, Karnataka'},
 '9182826':{'en': 'Bhadravati, Karnataka'},
 '9182827':{'en': 'Bhadravati, Karnataka'},
 '9182832':{'en': 'Salkani, Karnataka'},
 '9182833':{'en': 'Salkani, Karnataka'},
 '9182834':{'en': 'Salkani, Karnataka'},
 '9182835':{'en': 'Salkani, Karnataka'},
 '9182836':{'en': 'Salkani, Karnataka'},
 '9182837':{'en': 'Salkani, Karnataka'},
 '9182842':{'en': 'Haliyal, Karnataka'},
 '9182843':{'en': 'Haliyal, Karnataka'},
 '9182844':{'en': 'Haliyal, Karnataka'},
 '9182845':{'en': 'Haliyal, Karnataka'},
 '9182846':{'en': 'Haliyal, Karnataka'},
 '9182847':{'en': 'Haliyal, Karnataka'},
 '9182882':{'en': 'Bailhongal, Karnataka'},
 '9182883':{'en': 'Bailhongal, Karnataka'},
 '9182884':{'en': 'Bailhongal, Karnataka'},
 '9182885':{'en': 'Bailhongal, Karnataka'},
 '9182886':{'en': 'Bailhongal, Karnataka'},
 '9182887':{'en': 'Bailhongal, Karnataka'},
 '9182892':{'en': 'Athani, Karnataka'},
 '9182893':{'en': 'Athani, Karnataka'},
 '9182894':{'en': 'Athani, Karnataka'},
 '9182895':{'en': 'Athani, Karnataka'},
 '9182896':{'en': 'Athani, Karnataka'},
 '9182897':{'en': 'Athani, Karnataka'},
 '9183012':{'en': 'Mundagod, Karnataka'},
 '9183013':{'en': 'Mundagod, Karnataka'},
 '9183014':{'en': 'Mundagod, Karnataka'},
 '9183015':{'en': 'Mundagod, Karnataka'},
 '9183016':{'en': 'Mundagod, Karnataka'},
 '9183017':{'en': 'Mundagod, Karnataka'},
 '9183042':{'en': 'Kundgol, Karnataka'},
 '9183043':{'en': 'Kundgol, Karnataka'},
 '9183044':{'en': 'Kundgol, Karnataka'},
 '9183045':{'en': 'Kundgol, Karnataka'},
 '9183046':{'en': 'Kundgol, Karnataka'},
 '9183047':{'en': 'Kundgol, Karnataka'},
 '918312':{'en': 'Belgaum, Karnataka'},
 '918313':{'en': 'Belgaum, Karnataka'},
 '918314':{'en': 'Belgaum, Karnataka'},
 '918315':{'en': 'Belgaum, Karnataka'},
 '918316':{'en': 'Belgaum, Karnataka'},
 '918317':{'en': 'Belgaum, Karnataka'},
 '918322':{'en': 'Goa'},
 '918323':{'en': 'Goa'},
 '918324':{'en': 'Goa'},
 '918325':{'en': 'Goa'},
 '918326':{'en': 'Goa'},
 '918327':{'en': 'Goa'},
 '9183302':{'en': 'Saundatti, Karnataka'},
 '9183303':{'en': 'Saundatti, Karnataka'},
 '9183304':{'en': 'Saundatti, Karnataka'},
 '9183305':{'en': 'Saundatti, Karnataka'},
 '9183306':{'en': 'Saundatti, Karnataka'},
 '9183307':{'en': 'Saundatti, Karnataka'},
 '9183312':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183313':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183314':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183315':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183316':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183317':{'en': 'Raibag/Kudchi, Karnataka'},
 '9183322':{'en': 'Gokak, Karnataka'},
 '9183323':{'en': 'Gokak, Karnataka'},
 '9183324':{'en': 'Gokak, Karnataka'},
 '9183325':{'en': 'Gokak, Karnataka'},
 '9183326':{'en': 'Gokak, Karnataka'},
 '9183327':{'en': 'Gokak, Karnataka'},
 '9183332':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183333':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183334':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183335':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183336':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183337':{'en': 'Hukkeri/Sankeshwar, Karnataka'},
 '9183342':{'en': 'Mudalgi, Karnataka'},
 '9183343':{'en': 'Mudalgi, Karnataka'},
 '9183344':{'en': 'Mudalgi, Karnataka'},
 '9183345':{'en': 'Mudalgi, Karnataka'},
 '9183346':{'en': 'Mudalgi, Karnataka'},
 '9183347':{'en': 'Mudalgi, Karnataka'},
 '9183352':{'en': 'Ramdurg, Karnataka'},
 '9183353':{'en': 'Ramdurg, Karnataka'},
 '9183354':{'en': 'Ramdurg, Karnataka'},
 '9183355':{'en': 'Ramdurg, Karnataka'},
 '9183356':{'en': 'Ramdurg, Karnataka'},
 '9183357':{'en': 'Ramdurg, Karnataka'},
 '9183362':{'en': 'Khanapur, Karnataka'},
 '9183363':{'en': 'Khanapur, Karnataka'},
 '9183364':{'en': 'Khanapur, Karnataka'},
 '9183365':{'en': 'Khanapur, Karnataka'},
 '9183366':{'en': 'Khanapur, Karnataka'},
 '9183367':{'en': 'Khanapur, Karnataka'},
 '9183372':{'en': 'Murugod, Karnataka'},
 '9183373':{'en': 'Murugod, Karnataka'},
 '9183374':{'en': 'Murugod, Karnataka'},
 '9183375':{'en': 'Murugod, Karnataka'},
 '9183376':{'en': 'Murugod, Karnataka'},
 '9183377':{'en': 'Murugod, Karnataka'},
 '9183382':{'en': 'Chikkodi, Karnataka'},
 '9183383':{'en': 'Chikkodi, Karnataka'},
 '9183384':{'en': 'Chikkodi, Karnataka'},
 '9183385':{'en': 'Chikkodi, Karnataka'},
 '9183386':{'en': 'Chikkodi, Karnataka'},
 '9183387':{'en': 'Chikkodi, Karnataka'},
 '9183392':{'en': 'Ainapur, Karnataka'},
 '9183393':{'en': 'Ainapur, Karnataka'},
 '9183394':{'en': 'Ainapur, Karnataka'},
 '9183395':{'en': 'Ainapur, Karnataka'},
 '9183396':{'en': 'Ainapur, Karnataka'},
 '9183397':{'en': 'Ainapur, Karnataka'},
 '9183502':{'en': 'Mudhol, Karnataka'},
 '9183503':{'en': 'Mudhol, Karnataka'},
 '9183504':{'en': 'Mudhol, Karnataka'},
 '9183505':{'en': 'Mudhol, Karnataka'},
 '9183506':{'en': 'Mudhol, Karnataka'},
 '9183507':{'en': 'Mudhol, Karnataka'},
 '9183512':{'en': 'Hungund, Karnataka'},
 '9183513':{'en': 'Hungund, Karnataka'},
 '9183514':{'en': 'Hungund, Karnataka'},
 '9183515':{'en': 'Hungund, Karnataka'},
 '9183516':{'en': 'Hungund, Karnataka'},
 '9183517':{'en': 'Hungund, Karnataka'},
 '9183522':{'en': 'Bijapur, Karnataka'},
 '9183523':{'en': 'Bijapur, Karnataka'},
 '9183524':{'en': 'Bijapur, Karnataka'},
 '9183525':{'en': 'Bijapur, Karnataka'},
 '9183526':{'en': 'Bijapur, Karnataka'},
 '9183527':{'en': 'Bijapur, Karnataka'},
 '9183532':{'en': 'Jamkhandi, Karnataka'},
 '9183533':{'en': 'Jamkhandi, Karnataka'},
 '9183534':{'en': 'Jamkhandi, Karnataka'},
 '9183535':{'en': 'Jamkhandi, Karnataka'},
 '9183536':{'en': 'Jamkhandi, Karnataka'},
 '9183537':{'en': 'Jamkhandi, Karnataka'},
 '9183542':{'en': 'Bagalkot, Karnataka'},
 '9183543':{'en': 'Bagalkot, Karnataka'},
 '9183544':{'en': 'Bagalkot, Karnataka'},
 '9183545':{'en': 'Bagalkot, Karnataka'},
 '9183546':{'en': 'Bagalkot, Karnataka'},
 '9183547':{'en': 'Bagalkot, Karnataka'},
 '9183552':{'en': 'Bableshwar, Karnataka'},
 '9183553':{'en': 'Bableshwar, Karnataka'},
 '9183554':{'en': 'Bableshwar, Karnataka'},
 '9183555':{'en': 'Bableshwar, Karnataka'},
 '9183556':{'en': 'Bableshwar, Karnataka'},
 '9183557':{'en': 'Bableshwar, Karnataka'},
 '9183562':{'en': 'Muddebihal, Karnataka'},
 '9183563':{'en': 'Muddebihal, Karnataka'},
 '9183564':{'en': 'Muddebihal, Karnataka'},
 '9183565':{'en': 'Muddebihal, Karnataka'},
 '9183566':{'en': 'Muddebihal, Karnataka'},
 '9183567':{'en': 'Muddebihal, Karnataka'},
 '9183572':{'en': 'Badami, Karnataka'},
 '9183573':{'en': 'Badami, Karnataka'},
 '9183574':{'en': 'Badami, Karnataka'},
 '9183575':{'en': 'Badami, Karnataka'},
 '9183576':{'en': 'Badami, Karnataka'},
 '9183577':{'en': 'Badami, Karnataka'},
 '9183582':{'en': 'Basavanabagewadi, Karnataka'},
 '9183583':{'en': 'Basavanabagewadi, Karnataka'},
 '9183584':{'en': 'Basavanabagewadi, Karnataka'},
 '9183585':{'en': 'Basavanabagewadi, Karnataka'},
 '9183586':{'en': 'Basavanabagewadi, Karnataka'},
 '9183587':{'en': 'Basavanabagewadi, Karnataka'},
 '9183592':{'en': 'Indi, Karnataka'},
 '9183593':{'en': 'Indi, Karnataka'},
 '9183594':{'en': 'Indi, Karnataka'},
 '9183595':{'en': 'Indi, Karnataka'},
 '9183596':{'en': 'Indi, Karnataka'},
 '9183597':{'en': 'Indi, Karnataka'},
 '918362':{'en': 'Hubli, Karnataka'},
 '918363':{'en': 'Hubli, Karnataka'},
 '918364':{'en': 'Hubli, Karnataka'},
 '918365':{'en': 'Hubli, Karnataka'},
 '918366':{'en': 'Hubli, Karnataka'},
 '918367':{'en': 'Hubli, Karnataka'},
 '9183702':{'en': 'Kalghatagi, Karnataka'},
 '9183703':{'en': 'Kalghatagi, Karnataka'},
 '9183704':{'en': 'Kalghatagi, Karnataka'},
 '9183705':{'en': 'Kalghatagi, Karnataka'},
 '9183706':{'en': 'Kalghatagi, Karnataka'},
 '9183707':{'en': 'Kalghatagi, Karnataka'},
 '9183712':{'en': 'Mundargi, Karnataka'},
 '9183713':{'en': 'Mundargi, Karnataka'},
 '9183714':{'en': 'Mundargi, Karnataka'},
 '9183715':{'en': 'Mundargi, Karnataka'},
 '9183716':{'en': 'Mundargi, Karnataka'},
 '9183717':{'en': 'Mundargi, Karnataka'},
 '9183722':{'en': 'Gadag, Karnataka'},
 '9183723':{'en': 'Gadag, Karnataka'},
 '9183724':{'en': 'Gadag, Karnataka'},
 '9183725':{'en': 'Gadag, Karnataka'},
 '9183726':{'en': 'Gadag, Karnataka'},
 '9183727':{'en': 'Gadag, Karnataka'},
 '9183732':{'en': 'Ranebennur, Karnataka'},
 '9183733':{'en': 'Ranebennur, Karnataka'},
 '9183734':{'en': 'Ranebennur, Karnataka'},
 '9183735':{'en': 'Ranebennur, Karnataka'},
 '9183736':{'en': 'Ranebennur, Karnataka'},
 '9183737':{'en': 'Ranebennur, Karnataka'},
 '9183752':{'en': 'Haveri, Karnataka'},
 '9183753':{'en': 'Haveri, Karnataka'},
 '9183754':{'en': 'Haveri, Karnataka'},
 '9183755':{'en': 'Haveri, Karnataka'},
 '9183756':{'en': 'Haveri, Karnataka'},
 '9183757':{'en': 'Haveri, Karnataka'},
 '9183762':{'en': 'Hirekerur, Karnataka'},
 '9183763':{'en': 'Hirekerur, Karnataka'},
 '9183764':{'en': 'Hirekerur, Karnataka'},
 '9183765':{'en': 'Hirekerur, Karnataka'},
 '9183766':{'en': 'Hirekerur, Karnataka'},
 '9183767':{'en': 'Hirekerur, Karnataka'},
 '9183772':{'en': 'Nargund, Karnataka'},
 '9183773':{'en': 'Nargund, Karnataka'},
 '9183774':{'en': 'Nargund, Karnataka'},
 '9183775':{'en': 'Nargund, Karnataka'},
 '9183776':{'en': 'Nargund, Karnataka'},
 '9183777':{'en': 'Nargund, Karnataka'},
 '9183782':{'en': 'Savanur, Karnataka'},
 '9183783':{'en': 'Savanur, Karnataka'},
 '9183784':{'en': 'Savanur, Karnataka'},
 '9183785':{'en': 'Savanur, Karnataka'},
 '9183786':{'en': 'Savanur, Karnataka'},
 '9183787':{'en': 'Savanur, Karnataka'},
 '9183792':{'en': 'Hangal, Karnataka'},
 '9183793':{'en': 'Hangal, Karnataka'},
 '9183794':{'en': 'Hangal, Karnataka'},
 '9183795':{'en': 'Hangal, Karnataka'},
 '9183796':{'en': 'Hangal, Karnataka'},
 '9183797':{'en': 'Hangal, Karnataka'},
 '9183802':{'en': 'Navalgund, Karnataka'},
 '9183803':{'en': 'Navalgund, Karnataka'},
 '9183804':{'en': 'Navalgund, Karnataka'},
 '9183805':{'en': 'Navalgund, Karnataka'},
 '9183806':{'en': 'Navalgund, Karnataka'},
 '9183807':{'en': 'Navalgund, Karnataka'},
 '9183812':{'en': 'Ron, Karnataka'},
 '9183813':{'en': 'Ron, Karnataka'},
 '9183814':{'en': 'Ron, Karnataka'},
 '9183815':{'en': 'Ron, Karnataka'},
 '9183816':{'en': 'Ron, Karnataka'},
 '9183817':{'en': 'Ron, Karnataka'},
 '9183822':{'en': 'Karwar, Karnataka'},
 '9183823':{'en': 'Karwar, Karnataka'},
 '9183824':{'en': 'Karwar, Karnataka'},
 '9183825':{'en': 'Karwar, Karnataka'},
 '9183826':{'en': 'Karwar, Karnataka'},
 '9183827':{'en': 'Karwar, Karnataka'},
 '9183832':{'en': 'Joida, Karnataka'},
 '9183833':{'en': 'Joida, Karnataka'},
 '9183834':{'en': 'Joida, Karnataka'},
 '9183835':{'en': 'Joida, Karnataka'},
 '9183836':{'en': 'Joida, Karnataka'},
 '9183837':{'en': 'Joida, Karnataka'},
 '9183842':{'en': 'Sirsi, Karnataka'},
 '9183843':{'en': 'Sirsi, Karnataka'},
 '9183844':{'en': 'Sirsi, Karnataka'},
 '9183845':{'en': 'Sirsi, Karnataka'},
 '9183846':{'en': 'Sirsi, Karnataka'},
 '9183847':{'en': 'Sirsi, Karnataka'},
 '9183852':{'en': 'Bhatkal, Karnataka'},
 '9183853':{'en': 'Bhatkal, Karnataka'},
 '9183854':{'en': 'Bhatkal, Karnataka'},
 '9183855':{'en': 'Bhatkal, Karnataka'},
 '9183856':{'en': 'Bhatkal, Karnataka'},
 '9183857':{'en': 'Bhatkal, Karnataka'},
 '9183862':{'en': 'Kumta, Karnataka'},
 '9183863':{'en': 'Kumta, Karnataka'},
 '9183864':{'en': 'Kumta, Karnataka'},
 '9183865':{'en': 'Kumta, Karnataka'},
 '9183866':{'en': 'Kumta, Karnataka'},
 '9183867':{'en': 'Kumta, Karnataka'},
 '9183872':{'en': 'Honnavar, Karnataka'},
 '9183873':{'en': 'Honnavar, Karnataka'},
 '9183874':{'en': 'Honnavar, Karnataka'},
 '9183875':{'en': 'Honnavar, Karnataka'},
 '9183876':{'en': 'Honnavar, Karnataka'},
 '9183877':{'en': 'Honnavar, Karnataka'},
 '9183882':{'en': 'Ankola, Karnataka'},
 '9183883':{'en': 'Ankola, Karnataka'},
 '9183884':{'en': 'Ankola, Karnataka'},
 '9183885':{'en': 'Ankola, Karnataka'},
 '9183886':{'en': 'Ankola, Karnataka'},
 '9183887':{'en': 'Ankola, Karnataka'},
 '9183892':{'en': 'Siddapur, Karnataka'},
 '9183893':{'en': 'Siddapur, Karnataka'},
 '9183894':{'en': 'Siddapur, Karnataka'},
 '9183895':{'en': 'Siddapur, Karnataka'},
 '9183896':{'en': 'Siddapur, Karnataka'},
 '9183897':{'en': 'Siddapur, Karnataka'},
 '9183912':{'en': 'Kudligi, Karnataka'},
 '9183913':{'en': 'Kudligi, Karnataka'},
 '9183914':{'en': 'Kudligi, Karnataka'},
 '9183915':{'en': 'Kudligi, Karnataka'},
 '9183916':{'en': 'Kudligi, Karnataka'},
 '9183917':{'en': 'Kudligi, Karnataka'},
 '9183922':{'en': 'Bellary, Karnataka'},
 '9183923':{'en': 'Bellary, Karnataka'},
 '9183924':{'en': 'Bellary, Karnataka'},
 '9183925':{'en': 'Bellary, Karnataka'},
 '9183926':{'en': 'Bellary, Karnataka'},
 '9183927':{'en': 'Bellary, Karnataka'},
 '9183932':{'en': 'Kurugodu, Karnataka'},
 '9183933':{'en': 'Kurugodu, Karnataka'},
 '9183934':{'en': 'Kurugodu, Karnataka'},
 '9183935':{'en': 'Kurugodu, Karnataka'},
 '9183936':{'en': 'Kurugodu, Karnataka'},
 '9183937':{'en': 'Kurugodu, Karnataka'},
 '9183942':{'en': 'Hospet, Karnataka'},
 '9183943':{'en': 'Hospet, Karnataka'},
 '9183944':{'en': 'Hospet, Karnataka'},
 '9183945':{'en': 'Hospet, Karnataka'},
 '9183946':{'en': 'Hospet, Karnataka'},
 '9183947':{'en': 'Hospet, Karnataka'},
 '9183952':{'en': 'Sandur, Karnataka'},
 '9183953':{'en': 'Sandur, Karnataka'},
 '9183954':{'en': 'Sandur, Karnataka'},
 '9183955':{'en': 'Sandur, Karnataka'},
 '9183956':{'en': 'Sandur, Karnataka'},
 '9183957':{'en': 'Sandur, Karnataka'},
 '9183962':{'en': 'Siruguppa, Karnataka'},
 '9183963':{'en': 'Siruguppa, Karnataka'},
 '9183964':{'en': 'Siruguppa, Karnataka'},
 '9183965':{'en': 'Siruguppa, Karnataka'},
 '9183966':{'en': 'Siruguppa, Karnataka'},
 '9183967':{'en': 'Siruguppa, Karnataka'},
 '9183972':{'en': 'H.B.Halli, Karnataka'},
 '9183973':{'en': 'H.B.Halli, Karnataka'},
 '9183974':{'en': 'H.B.Halli, Karnataka'},
 '9183975':{'en': 'H.B.Halli, Karnataka'},
 '9183976':{'en': 'H.B.Halli, Karnataka'},
 '9183977':{'en': 'H.B.Halli, Karnataka'},
 '9183982':{'en': 'Harapanahalli, Karnataka'},
 '9183983':{'en': 'Harapanahalli, Karnataka'},
 '9183984':{'en': 'Harapanahalli, Karnataka'},
 '9183985':{'en': 'Harapanahalli, Karnataka'},
 '9183986':{'en': 'Harapanahalli, Karnataka'},
 '9183987':{'en': 'Harapanahalli, Karnataka'},
 '9183992':{'en': 'Huvinahadagali, Karnataka'},
 '9183993':{'en': 'Huvinahadagali, Karnataka'},
 '9183994':{'en': 'Huvinahadagali, Karnataka'},
 '9183995':{'en': 'Huvinahadagali, Karnataka'},
 '9183996':{'en': 'Huvinahadagali, Karnataka'},
 '9183997':{'en': 'Huvinahadagali, Karnataka'},
 '9184022':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184023':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184024':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184025':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184026':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184027':{'en': 'Kanigiri, Andhra Pradesh'},
 '9184032':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184033':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184034':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184035':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184036':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184037':{'en': 'Yerragondapalem, Andhra Pradesh'},
 '9184042':{'en': 'Marturu, Andhra Pradesh'},
 '9184043':{'en': 'Marturu, Andhra Pradesh'},
 '9184044':{'en': 'Marturu, Andhra Pradesh'},
 '9184045':{'en': 'Marturu, Andhra Pradesh'},
 '9184046':{'en': 'Marturu, Andhra Pradesh'},
 '9184047':{'en': 'Marturu, Andhra Pradesh'},
 '9184052':{'en': 'Giddalur, Andhra Pradesh'},
 '9184053':{'en': 'Giddalur, Andhra Pradesh'},
 '9184054':{'en': 'Giddalur, Andhra Pradesh'},
 '9184055':{'en': 'Giddalur, Andhra Pradesh'},
 '9184056':{'en': 'Giddalur, Andhra Pradesh'},
 '9184057':{'en': 'Giddalur, Andhra Pradesh'},
 '9184062':{'en': 'Cumbum, Andhra Pradesh'},
 '9184063':{'en': 'Cumbum, Andhra Pradesh'},
 '9184064':{'en': 'Cumbum, Andhra Pradesh'},
 '9184065':{'en': 'Cumbum, Andhra Pradesh'},
 '9184066':{'en': 'Cumbum, Andhra Pradesh'},
 '9184067':{'en': 'Cumbum, Andhra Pradesh'},
 '9184072':{'en': 'Darsi, Andhra Pradesh'},
 '9184073':{'en': 'Darsi, Andhra Pradesh'},
 '9184074':{'en': 'Darsi, Andhra Pradesh'},
 '9184075':{'en': 'Darsi, Andhra Pradesh'},
 '9184076':{'en': 'Darsi, Andhra Pradesh'},
 '9184077':{'en': 'Darsi, Andhra Pradesh'},
 '9184082':{'en': 'Donakonda, Andhra Pradesh'},
 '9184083':{'en': 'Donakonda, Andhra Pradesh'},
 '9184084':{'en': 'Donakonda, Andhra Pradesh'},
 '9184085':{'en': 'Donakonda, Andhra Pradesh'},
 '9184086':{'en': 'Donakonda, Andhra Pradesh'},
 '9184087':{'en': 'Donakonda, Andhra Pradesh'},
 '9184112':{'en': 'Tanduru, Andhra Pradesh'},
 '9184113':{'en': 'Tanduru, Andhra Pradesh'},
 '9184114':{'en': 'Tanduru, Andhra Pradesh'},
 '9184115':{'en': 'Tanduru, Andhra Pradesh'},
 '9184116':{'en': 'Tanduru, Andhra Pradesh'},
 '9184117':{'en': 'Tanduru, Andhra Pradesh'},
 '9184122':{'en': 'Pargi, Andhra Pradesh'},
 '9184123':{'en': 'Pargi, Andhra Pradesh'},
 '9184124':{'en': 'Pargi, Andhra Pradesh'},
 '9184125':{'en': 'Pargi, Andhra Pradesh'},
 '9184126':{'en': 'Pargi, Andhra Pradesh'},
 '9184127':{'en': 'Pargi, Andhra Pradesh'},
 '9184132':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184133':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184134':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184135':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184136':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184137':{'en': 'Hyderabad West/Shamshabad, Andhra Pradesh'},
 '9184142':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184143':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184144':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184145':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184146':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184147':{'en': 'Ibrahimpatnam, Andhra Pradesh'},
 '9184152':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184153':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184154':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184155':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184156':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184157':{'en': 'Hyderabad East/Ghatkeswar, Andhra Pradesh'},
 '9184162':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184163':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184164':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184165':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184166':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184167':{'en': 'Vikrabad, Andhra Pradesh'},
 '9184172':{'en': 'Chevella, Andhra Pradesh'},
 '9184173':{'en': 'Chevella, Andhra Pradesh'},
 '9184174':{'en': 'Chevella, Andhra Pradesh'},
 '9184175':{'en': 'Chevella, Andhra Pradesh'},
 '9184176':{'en': 'Chevella, Andhra Pradesh'},
 '9184177':{'en': 'Chevella, Andhra Pradesh'},
 '9184182':{'en': 'Medchal, Andhra Pradesh'},
 '9184183':{'en': 'Medchal, Andhra Pradesh'},
 '9184184':{'en': 'Medchal, Andhra Pradesh'},
 '9184185':{'en': 'Medchal, Andhra Pradesh'},
 '9184186':{'en': 'Medchal, Andhra Pradesh'},
 '9184187':{'en': 'Medchal, Andhra Pradesh'},
 '9184192':{'en': 'Yellapur, Karnataka'},
 '9184193':{'en': 'Yellapur, Karnataka'},
 '9184194':{'en': 'Yellapur, Karnataka'},
 '9184195':{'en': 'Yellapur, Karnataka'},
 '9184196':{'en': 'Yellapur, Karnataka'},
 '9184197':{'en': 'Yellapur, Karnataka'},
 '9184222':{'en': 'Chadchan, Karnataka'},
 '9184223':{'en': 'Chadchan, Karnataka'},
 '9184224':{'en': 'Chadchan, Karnataka'},
 '9184225':{'en': 'Chadchan, Karnataka'},
 '9184226':{'en': 'Chadchan, Karnataka'},
 '9184227':{'en': 'Chadchan, Karnataka'},
 '9184242':{'en': 'Devarahippargi, Karnataka'},
 '9184243':{'en': 'Devarahippargi, Karnataka'},
 '9184244':{'en': 'Devarahippargi, Karnataka'},
 '9184245':{'en': 'Devarahippargi, Karnataka'},
 '9184246':{'en': 'Devarahippargi, Karnataka'},
 '9184247':{'en': 'Devarahippargi, Karnataka'},
 '9184252':{'en': 'Biligi, Karnataka'},
 '9184253':{'en': 'Biligi, Karnataka'},
 '9184254':{'en': 'Biligi, Karnataka'},
 '9184255':{'en': 'Biligi, Karnataka'},
 '9184256':{'en': 'Biligi, Karnataka'},
 '9184257':{'en': 'Biligi, Karnataka'},
 '9184262':{'en': 'Telgi, Karnataka'},
 '9184263':{'en': 'Telgi, Karnataka'},
 '9184264':{'en': 'Telgi, Karnataka'},
 '9184265':{'en': 'Telgi, Karnataka'},
 '9184266':{'en': 'Telgi, Karnataka'},
 '9184267':{'en': 'Telgi, Karnataka'},
 '9184402':{'en': 'Nimburga, Karnataka'},
 '9184403':{'en': 'Nimburga, Karnataka'},
 '9184404':{'en': 'Nimburga, Karnataka'},
 '9184405':{'en': 'Nimburga, Karnataka'},
 '9184406':{'en': 'Nimburga, Karnataka'},
 '9184407':{'en': 'Nimburga, Karnataka'},
 '9184412':{'en': 'Sedam, Karnataka'},
 '9184413':{'en': 'Sedam, Karnataka'},
 '9184414':{'en': 'Sedam, Karnataka'},
 '9184415':{'en': 'Sedam, Karnataka'},
 '9184416':{'en': 'Sedam, Karnataka'},
 '9184417':{'en': 'Sedam, Karnataka'},
 '9184422':{'en': 'Jewargi, Karnataka'},
 '9184423':{'en': 'Jewargi, Karnataka'},
 '9184424':{'en': 'Jewargi, Karnataka'},
 '9184425':{'en': 'Jewargi, Karnataka'},
 '9184426':{'en': 'Jewargi, Karnataka'},
 '9184427':{'en': 'Jewargi, Karnataka'},
 '9184432':{'en': 'Shorapur, Karnataka'},
 '9184433':{'en': 'Shorapur, Karnataka'},
 '9184434':{'en': 'Shorapur, Karnataka'},
 '9184435':{'en': 'Shorapur, Karnataka'},
 '9184436':{'en': 'Shorapur, Karnataka'},
 '9184437':{'en': 'Shorapur, Karnataka'},
 '9184442':{'en': 'Hunsagi, Karnataka'},
 '9184443':{'en': 'Hunsagi, Karnataka'},
 '9184444':{'en': 'Hunsagi, Karnataka'},
 '9184445':{'en': 'Hunsagi, Karnataka'},
 '9184446':{'en': 'Hunsagi, Karnataka'},
 '9184447':{'en': 'Hunsagi, Karnataka'},
 '9184502':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184503':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184504':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184505':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184506':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184507':{'en': 'Andole/Jogipet, Andhra Pradesh'},
 '9184512':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184513':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184514':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184515':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184516':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184517':{'en': 'Zahirabad, Andhra Pradesh'},
 '9184522':{'en': 'Medak, Andhra Pradesh'},
 '9184523':{'en': 'Medak, Andhra Pradesh'},
 '9184524':{'en': 'Medak, Andhra Pradesh'},
 '9184525':{'en': 'Medak, Andhra Pradesh'},
 '9184526':{'en': 'Medak, Andhra Pradesh'},
 '9184527':{'en': 'Medak, Andhra Pradesh'},
 '9184532':{'en': 'Medak, Andhra Pradesh'},
 '9184533':{'en': 'Medak, Andhra Pradesh'},
 '9184534':{'en': 'Medak, Andhra Pradesh'},
 '9184535':{'en': 'Medak, Andhra Pradesh'},
 '9184536':{'en': 'Medak, Andhra Pradesh'},
 '9184537':{'en': 'Medak, Andhra Pradesh'},
 '9184542':{'en': 'Gajwel, Andhra Pradesh'},
 '9184543':{'en': 'Gajwel, Andhra Pradesh'},
 '9184544':{'en': 'Gajwel, Andhra Pradesh'},
 '9184545':{'en': 'Gajwel, Andhra Pradesh'},
 '9184546':{'en': 'Gajwel, Andhra Pradesh'},
 '9184547':{'en': 'Gajwel, Andhra Pradesh'},
 '9184552':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184553':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184554':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184555':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184556':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184557':{'en': 'Sangareddy, Andhra Pradesh'},
 '9184562':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184563':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184564':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184565':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184566':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184567':{'en': 'Narayankhed, Andhra Pradesh'},
 '9184572':{'en': 'Siddipet, Andhra Pradesh'},
 '9184573':{'en': 'Siddipet, Andhra Pradesh'},
 '9184574':{'en': 'Siddipet, Andhra Pradesh'},
 '9184575':{'en': 'Siddipet, Andhra Pradesh'},
 '9184576':{'en': 'Siddipet, Andhra Pradesh'},
 '9184577':{'en': 'Siddipet, Andhra Pradesh'},
 '9184582':{'en': 'Narsapur, Andhra Pradesh'},
 '9184583':{'en': 'Narsapur, Andhra Pradesh'},
 '9184584':{'en': 'Narsapur, Andhra Pradesh'},
 '9184585':{'en': 'Narsapur, Andhra Pradesh'},
 '9184586':{'en': 'Narsapur, Andhra Pradesh'},
 '9184587':{'en': 'Narsapur, Andhra Pradesh'},
 '9184612':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184613':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184614':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184615':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184616':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184617':{'en': 'Dichpalli, Andhra Pradesh'},
 '9184622':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184623':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184624':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184625':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184626':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184627':{'en': 'Nizamabad, Andhra Pradesh'},
 '9184632':{'en': 'Armoor, Andhra Pradesh'},
 '9184633':{'en': 'Armoor, Andhra Pradesh'},
 '9184634':{'en': 'Armoor, Andhra Pradesh'},
 '9184635':{'en': 'Armoor, Andhra Pradesh'},
 '9184636':{'en': 'Armoor, Andhra Pradesh'},
 '9184637':{'en': 'Armoor, Andhra Pradesh'},
 '9184642':{'en': 'Madnur, Andhra Pradesh'},
 '9184643':{'en': 'Madnur, Andhra Pradesh'},
 '9184644':{'en': 'Madnur, Andhra Pradesh'},
 '9184645':{'en': 'Madnur, Andhra Pradesh'},
 '9184646':{'en': 'Madnur, Andhra Pradesh'},
 '9184647':{'en': 'Madnur, Andhra Pradesh'},
 '9184652':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184653':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184654':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184655':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184656':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184657':{'en': 'Yellareddy, Andhra Pradesh'},
 '9184662':{'en': 'Banswada, Andhra Pradesh'},
 '9184663':{'en': 'Banswada, Andhra Pradesh'},
 '9184664':{'en': 'Banswada, Andhra Pradesh'},
 '9184665':{'en': 'Banswada, Andhra Pradesh'},
 '9184666':{'en': 'Banswada, Andhra Pradesh'},
 '9184667':{'en': 'Banswada, Andhra Pradesh'},
 '9184672':{'en': 'Bodhan, Andhra Pradesh'},
 '9184673':{'en': 'Bodhan, Andhra Pradesh'},
 '9184674':{'en': 'Bodhan, Andhra Pradesh'},
 '9184675':{'en': 'Bodhan, Andhra Pradesh'},
 '9184676':{'en': 'Bodhan, Andhra Pradesh'},
 '9184677':{'en': 'Bodhan, Andhra Pradesh'},
 '9184682':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184683':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184684':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184685':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184686':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184687':{'en': 'Kamareddy, Andhra Pradesh'},
 '9184702':{'en': 'Afzalpur, Karnataka'},
 '9184703':{'en': 'Afzalpur, Karnataka'},
 '9184704':{'en': 'Afzalpur, Karnataka'},
 '9184705':{'en': 'Afzalpur, Karnataka'},
 '9184706':{'en': 'Afzalpur, Karnataka'},
 '9184707':{'en': 'Afzalpur, Karnataka'},
 '9184712':{'en': 'Mashal, Karnataka'},
 '9184713':{'en': 'Mashal, Karnataka'},
 '9184714':{'en': 'Mashal, Karnataka'},
 '9184715':{'en': 'Mashal, Karnataka'},
 '9184716':{'en': 'Mashal, Karnataka'},
 '9184717':{'en': 'Mashal, Karnataka'},
 '9184722':{'en': 'Gulbarga, Karnataka'},
 '9184723':{'en': 'Gulbarga, Karnataka'},
 '9184724':{'en': 'Gulbarga, Karnataka'},
 '9184725':{'en': 'Gulbarga, Karnataka'},
 '9184726':{'en': 'Gulbarga, Karnataka'},
 '9184727':{'en': 'Gulbarga, Karnataka'},
 '9184732':{'en': 'Yadgiri, Karnataka'},
 '9184733':{'en': 'Yadgiri, Karnataka'},
 '9184734':{'en': 'Yadgiri, Karnataka'},
 '9184735':{'en': 'Yadgiri, Karnataka'},
 '9184736':{'en': 'Yadgiri, Karnataka'},
 '9184737':{'en': 'Yadgiri, Karnataka'},
 '9184742':{'en': 'Chittapur, Karnataka'},
 '9184743':{'en': 'Chittapur, Karnataka'},
 '9184744':{'en': 'Chittapur, Karnataka'},
 '9184745':{'en': 'Chittapur, Karnataka'},
 '9184746':{'en': 'Chittapur, Karnataka'},
 '9184747':{'en': 'Chittapur, Karnataka'},
 '9184752':{'en': 'Chincholi, Karnataka'},
 '9184753':{'en': 'Chincholi, Karnataka'},
 '9184754':{'en': 'Chincholi, Karnataka'},
 '9184755':{'en': 'Chincholi, Karnataka'},
 '9184756':{'en': 'Chincholi, Karnataka'},
 '9184757':{'en': 'Chincholi, Karnataka'},
 '9184762':{'en': 'Wadi, Karnataka'},
 '9184763':{'en': 'Wadi, Karnataka'},
 '9184764':{'en': 'Wadi, Karnataka'},
 '9184765':{'en': 'Wadi, Karnataka'},
 '9184766':{'en': 'Wadi, Karnataka'},
 '9184767':{'en': 'Wadi, Karnataka'},
 '9184772':{'en': 'Aland, Karnataka'},
 '9184773':{'en': 'Aland, Karnataka'},
 '9184774':{'en': 'Aland, Karnataka'},
 '9184775':{'en': 'Aland, Karnataka'},
 '9184776':{'en': 'Aland, Karnataka'},
 '9184777':{'en': 'Aland, Karnataka'},
 '9184782':{'en': 'Kamalapur, Karnataka'},
 '9184783':{'en': 'Kamalapur, Karnataka'},
 '9184784':{'en': 'Kamalapur, Karnataka'},
 '9184785':{'en': 'Kamalapur, Karnataka'},
 '9184786':{'en': 'Kamalapur, Karnataka'},
 '9184787':{'en': 'Kamalapur, Karnataka'},
 '9184792':{'en': 'Shahapur, Karnataka'},
 '9184793':{'en': 'Shahapur, Karnataka'},
 '9184794':{'en': 'Shahapur, Karnataka'},
 '9184795':{'en': 'Shahapur, Karnataka'},
 '9184796':{'en': 'Shahapur, Karnataka'},
 '9184797':{'en': 'Shahapur, Karnataka'},
 '9184812':{'en': 'Basavakalyan, Karnataka'},
 '9184813':{'en': 'Basavakalyan, Karnataka'},
 '9184814':{'en': 'Basavakalyan, Karnataka'},
 '9184815':{'en': 'Basavakalyan, Karnataka'},
 '9184816':{'en': 'Basavakalyan, Karnataka'},
 '9184817':{'en': 'Basavakalyan, Karnataka'},
 '9184822':{'en': 'Bidar, Karnataka'},
 '9184823':{'en': 'Bidar, Karnataka'},
 '9184824':{'en': 'Bidar, Karnataka'},
 '9184825':{'en': 'Bidar, Karnataka'},
 '9184826':{'en': 'Bidar, Karnataka'},
 '9184827':{'en': 'Bidar, Karnataka'},
 '9184832':{'en': 'Humnabad, Karnataka'},
 '9184833':{'en': 'Humnabad, Karnataka'},
 '9184834':{'en': 'Humnabad, Karnataka'},
 '9184835':{'en': 'Humnabad, Karnataka'},
 '9184836':{'en': 'Humnabad, Karnataka'},
 '9184837':{'en': 'Humnabad, Karnataka'},
 '9184842':{'en': 'Bhalki, Karnataka'},
 '9184843':{'en': 'Bhalki, Karnataka'},
 '9184844':{'en': 'Bhalki, Karnataka'},
 '9184845':{'en': 'Bhalki, Karnataka'},
 '9184846':{'en': 'Bhalki, Karnataka'},
 '9184847':{'en': 'Bhalki, Karnataka'},
 '9184852':{'en': 'Aurad, Karnataka'},
 '9184853':{'en': 'Aurad, Karnataka'},
 '9184854':{'en': 'Aurad, Karnataka'},
 '9184855':{'en': 'Aurad, Karnataka'},
 '9184856':{'en': 'Aurad, Karnataka'},
 '9184857':{'en': 'Aurad, Karnataka'},
 '9184872':{'en': 'Shirahatti, Karnataka'},
 '9184873':{'en': 'Shirahatti, Karnataka'},
 '9184874':{'en': 'Shirahatti, Karnataka'},
 '9184875':{'en': 'Shirahatti, Karnataka'},
 '9184876':{'en': 'Shirahatti, Karnataka'},
 '9184877':{'en': 'Shirahatti, Karnataka'},
 '9184882':{'en': 'Sindagi, Karnataka'},
 '9184883':{'en': 'Sindagi, Karnataka'},
 '9184884':{'en': 'Sindagi, Karnataka'},
 '9184885':{'en': 'Sindagi, Karnataka'},
 '9184886':{'en': 'Sindagi, Karnataka'},
 '9184887':{'en': 'Sindagi, Karnataka'},
 '9184902':{'en': 'Pamuru, Andhra Pradesh'},
 '9184903':{'en': 'Pamuru, Andhra Pradesh'},
 '9184904':{'en': 'Pamuru, Andhra Pradesh'},
 '9184905':{'en': 'Pamuru, Andhra Pradesh'},
 '9184906':{'en': 'Pamuru, Andhra Pradesh'},
 '9184907':{'en': 'Pamuru, Andhra Pradesh'},
 '9184912':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184913':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184914':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184915':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184916':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184917':{'en': 'Kanaganapalle, Andhra Pradesh'},
 '9184922':{'en': 'Kambadur, Andhra Pradesh'},
 '9184923':{'en': 'Kambadur, Andhra Pradesh'},
 '9184924':{'en': 'Kambadur, Andhra Pradesh'},
 '9184925':{'en': 'Kambadur, Andhra Pradesh'},
 '9184926':{'en': 'Kambadur, Andhra Pradesh'},
 '9184927':{'en': 'Kambadur, Andhra Pradesh'},
 '9184932':{'en': 'Madakasira, Andhra Pradesh'},
 '9184933':{'en': 'Madakasira, Andhra Pradesh'},
 '9184934':{'en': 'Madakasira, Andhra Pradesh'},
 '9184935':{'en': 'Madakasira, Andhra Pradesh'},
 '9184936':{'en': 'Madakasira, Andhra Pradesh'},
 '9184937':{'en': 'Madakasira, Andhra Pradesh'},
 '9184942':{'en': 'Kadiri, Andhra Pradesh'},
 '9184943':{'en': 'Kadiri, Andhra Pradesh'},
 '9184944':{'en': 'Kadiri, Andhra Pradesh'},
 '9184945':{'en': 'Kadiri, Andhra Pradesh'},
 '9184946':{'en': 'Kadiri, Andhra Pradesh'},
 '9184947':{'en': 'Kadiri, Andhra Pradesh'},
 '9184952':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184953':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184954':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184955':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184956':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184957':{'en': 'Rayadurg, Andhra Pradesh'},
 '9184962':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184963':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184964':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184965':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184966':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184967':{'en': 'Uravakonda, Andhra Pradesh'},
 '9184972':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184973':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184974':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184975':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184976':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184977':{'en': 'Kalyandurg, Andhra Pradesh'},
 '9184982':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184983':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184984':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184985':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184986':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184987':{'en': 'Nallacheruvu/Tanakallu, Andhra Pradesh'},
 '9184992':{'en': 'Podili, Andhra Pradesh'},
 '9184993':{'en': 'Podili, Andhra Pradesh'},
 '9184994':{'en': 'Podili, Andhra Pradesh'},
 '9184995':{'en': 'Podili, Andhra Pradesh'},
 '9184996':{'en': 'Podili, Andhra Pradesh'},
 '9184997':{'en': 'Podili, Andhra Pradesh'},
 '9185012':{'en': 'Kollapur, Andhra Pradesh'},
 '9185013':{'en': 'Kollapur, Andhra Pradesh'},
 '9185014':{'en': 'Kollapur, Andhra Pradesh'},
 '9185015':{'en': 'Kollapur, Andhra Pradesh'},
 '9185016':{'en': 'Kollapur, Andhra Pradesh'},
 '9185017':{'en': 'Kollapur, Andhra Pradesh'},
 '9185022':{'en': 'Alampur, Andhra Pradesh'},
 '9185023':{'en': 'Alampur, Andhra Pradesh'},
 '9185024':{'en': 'Alampur, Andhra Pradesh'},
 '9185025':{'en': 'Alampur, Andhra Pradesh'},
 '9185026':{'en': 'Alampur, Andhra Pradesh'},
 '9185027':{'en': 'Alampur, Andhra Pradesh'},
 '9185032':{'en': 'Makthal, Andhra Pradesh'},
 '9185033':{'en': 'Makthal, Andhra Pradesh'},
 '9185034':{'en': 'Makthal, Andhra Pradesh'},
 '9185035':{'en': 'Makthal, Andhra Pradesh'},
 '9185036':{'en': 'Makthal, Andhra Pradesh'},
 '9185037':{'en': 'Makthal, Andhra Pradesh'},
 '9185042':{'en': 'Atmakur, Andhra Pradesh'},
 '9185043':{'en': 'Atmakur, Andhra Pradesh'},
 '9185044':{'en': 'Atmakur, Andhra Pradesh'},
 '9185045':{'en': 'Atmakur, Andhra Pradesh'},
 '9185046':{'en': 'Atmakur, Andhra Pradesh'},
 '9185047':{'en': 'Atmakur, Andhra Pradesh'},
 '9185052':{'en': 'Kodangal, Andhra Pradesh'},
 '9185053':{'en': 'Kodangal, Andhra Pradesh'},
 '9185054':{'en': 'Kodangal, Andhra Pradesh'},
 '9185055':{'en': 'Kodangal, Andhra Pradesh'},
 '9185056':{'en': 'Kodangal, Andhra Pradesh'},
 '9185057':{'en': 'Kodangal, Andhra Pradesh'},
 '9185062':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185063':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185064':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185065':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185066':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185067':{'en': 'Narayanpet, Andhra Pradesh'},
 '9185102':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185103':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185104':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185105':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185106':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185107':{'en': 'Koilkuntla, Andhra Pradesh'},
 '9185122':{'en': 'Adoni, Andhra Pradesh'},
 '9185123':{'en': 'Adoni, Andhra Pradesh'},
 '9185124':{'en': 'Adoni, Andhra Pradesh'},
 '9185125':{'en': 'Adoni, Andhra Pradesh'},
 '9185126':{'en': 'Adoni, Andhra Pradesh'},
 '9185127':{'en': 'Adoni, Andhra Pradesh'},
 '9185132':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185133':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185134':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185135':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185136':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185137':{'en': 'Nandikotkur, Andhra Pradesh'},
 '9185142':{'en': 'Nandyal, Andhra Pradesh'},
 '9185143':{'en': 'Nandyal, Andhra Pradesh'},
 '9185144':{'en': 'Nandyal, Andhra Pradesh'},
 '9185145':{'en': 'Nandyal, Andhra Pradesh'},
 '9185146':{'en': 'Nandyal, Andhra Pradesh'},
 '9185147':{'en': 'Nandyal, Andhra Pradesh'},
 '9185152':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185153':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185154':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185155':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185156':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185157':{'en': 'Banaganapalle, Andhra Pradesh'},
 '9185162':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185163':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185164':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185165':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185166':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185167':{'en': 'Dronachalam, Andhra Pradesh'},
 '9185172':{'en': 'Atmakur, Andhra Pradesh'},
 '9185173':{'en': 'Atmakur, Andhra Pradesh'},
 '9185174':{'en': 'Atmakur, Andhra Pradesh'},
 '9185175':{'en': 'Atmakur, Andhra Pradesh'},
 '9185176':{'en': 'Atmakur, Andhra Pradesh'},
 '9185177':{'en': 'Atmakur, Andhra Pradesh'},
 '9185182':{'en': 'Kurnool, Andhra Pradesh'},
 '9185183':{'en': 'Kurnool, Andhra Pradesh'},
 '9185184':{'en': 'Kurnool, Andhra Pradesh'},
 '9185185':{'en': 'Kurnool, Andhra Pradesh'},
 '9185186':{'en': 'Kurnool, Andhra Pradesh'},
 '9185187':{'en': 'Kurnool, Andhra Pradesh'},
 '9185192':{'en': 'Allagadda, Andhra Pradesh'},
 '9185193':{'en': 'Allagadda, Andhra Pradesh'},
 '9185194':{'en': 'Allagadda, Andhra Pradesh'},
 '9185195':{'en': 'Allagadda, Andhra Pradesh'},
 '9185196':{'en': 'Allagadda, Andhra Pradesh'},
 '9185197':{'en': 'Allagadda, Andhra Pradesh'},
 '9185202':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185203':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185204':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185205':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185206':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185207':{'en': 'Pattikonda, Andhra Pradesh'},
 '9185222':{'en': 'Peapalle, Andhra Pradesh'},
 '9185223':{'en': 'Peapalle, Andhra Pradesh'},
 '9185224':{'en': 'Peapalle, Andhra Pradesh'},
 '9185225':{'en': 'Peapalle, Andhra Pradesh'},
 '9185226':{'en': 'Peapalle, Andhra Pradesh'},
 '9185227':{'en': 'Peapalle, Andhra Pradesh'},
 '9185232':{'en': 'Alur, Andhra Pradesh'},
 '9185233':{'en': 'Alur, Andhra Pradesh'},
 '9185234':{'en': 'Alur, Andhra Pradesh'},
 '9185235':{'en': 'Alur, Andhra Pradesh'},
 '9185236':{'en': 'Alur, Andhra Pradesh'},
 '9185237':{'en': 'Alur, Andhra Pradesh'},
 '9185242':{'en': 'Srisailam, Andhra Pradesh'},
 '9185243':{'en': 'Srisailam, Andhra Pradesh'},
 '9185244':{'en': 'Srisailam, Andhra Pradesh'},
 '9185245':{'en': 'Srisailam, Andhra Pradesh'},
 '9185246':{'en': 'Srisailam, Andhra Pradesh'},
 '9185247':{'en': 'Srisailam, Andhra Pradesh'},
 '9185252':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185253':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185254':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185255':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185256':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185257':{'en': 'Gudur/Kodumur, Andhra Pradesh'},
 '9185312':{'en': 'Deodurga, Karnataka'},
 '9185313':{'en': 'Deodurga, Karnataka'},
 '9185314':{'en': 'Deodurga, Karnataka'},
 '9185315':{'en': 'Deodurga, Karnataka'},
 '9185316':{'en': 'Deodurga, Karnataka'},
 '9185317':{'en': 'Deodurga, Karnataka'},
 '9185322':{'en': 'Raichur, Karnataka'},
 '9185323':{'en': 'Raichur, Karnataka'},
 '9185324':{'en': 'Raichur, Karnataka'},
 '9185325':{'en': 'Raichur, Karnataka'},
 '9185326':{'en': 'Raichur, Karnataka'},
 '9185327':{'en': 'Raichur, Karnataka'},
 '9185332':{'en': 'Gangavathi, Karnataka'},
 '9185333':{'en': 'Gangavathi, Karnataka'},
 '9185334':{'en': 'Gangavathi, Karnataka'},
 '9185335':{'en': 'Gangavathi, Karnataka'},
 '9185336':{'en': 'Gangavathi, Karnataka'},
 '9185337':{'en': 'Gangavathi, Karnataka'},
 '9185342':{'en': 'Yelburga, Karnataka'},
 '9185343':{'en': 'Yelburga, Karnataka'},
 '9185344':{'en': 'Yelburga, Karnataka'},
 '9185345':{'en': 'Yelburga, Karnataka'},
 '9185346':{'en': 'Yelburga, Karnataka'},
 '9185347':{'en': 'Yelburga, Karnataka'},
 '9185352':{'en': 'Sindhanur, Karnataka'},
 '9185353':{'en': 'Sindhanur, Karnataka'},
 '9185354':{'en': 'Sindhanur, Karnataka'},
 '9185355':{'en': 'Sindhanur, Karnataka'},
 '9185356':{'en': 'Sindhanur, Karnataka'},
 '9185357':{'en': 'Sindhanur, Karnataka'},
 '9185362':{'en': 'Kustagi, Karnataka'},
 '9185363':{'en': 'Kustagi, Karnataka'},
 '9185364':{'en': 'Kustagi, Karnataka'},
 '9185365':{'en': 'Kustagi, Karnataka'},
 '9185366':{'en': 'Kustagi, Karnataka'},
 '9185367':{'en': 'Kustagi, Karnataka'},
 '9185372':{'en': 'Lingsugur, Karnataka'},
 '9185373':{'en': 'Lingsugur, Karnataka'},
 '9185374':{'en': 'Lingsugur, Karnataka'},
 '9185375':{'en': 'Lingsugur, Karnataka'},
 '9185376':{'en': 'Lingsugur, Karnataka'},
 '9185377':{'en': 'Lingsugur, Karnataka'},
 '9185382':{'en': 'Manvi, Karnataka'},
 '9185383':{'en': 'Manvi, Karnataka'},
 '9185384':{'en': 'Manvi, Karnataka'},
 '9185385':{'en': 'Manvi, Karnataka'},
 '9185386':{'en': 'Manvi, Karnataka'},
 '9185387':{'en': 'Manvi, Karnataka'},
 '9185392':{'en': 'Koppal, Karnataka'},
 '9185393':{'en': 'Koppal, Karnataka'},
 '9185394':{'en': 'Koppal, Karnataka'},
 '9185395':{'en': 'Koppal, Karnataka'},
 '9185396':{'en': 'Koppal, Karnataka'},
 '9185397':{'en': 'Koppal, Karnataka'},
 '9185402':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185403':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185404':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185405':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185406':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185407':{'en': 'Nagarkurnool, Andhra Pradesh'},
 '9185412':{'en': 'Achampet, Andhra Pradesh'},
 '9185413':{'en': 'Achampet, Andhra Pradesh'},
 '9185414':{'en': 'Achampet, Andhra Pradesh'},
 '9185415':{'en': 'Achampet, Andhra Pradesh'},
 '9185416':{'en': 'Achampet, Andhra Pradesh'},
 '9185417':{'en': 'Achampet, Andhra Pradesh'},
 '9185422':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185423':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185424':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185425':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185426':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185427':{'en': 'Mahabubnagar, Andhra Pradesh'},
 '9185432':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185433':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185434':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185435':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185436':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185437':{'en': 'Wanaparthy, Andhra Pradesh'},
 '9185452':{'en': 'Amangallu, Andhra Pradesh'},
 '9185453':{'en': 'Amangallu, Andhra Pradesh'},
 '9185454':{'en': 'Amangallu, Andhra Pradesh'},
 '9185455':{'en': 'Amangallu, Andhra Pradesh'},
 '9185456':{'en': 'Amangallu, Andhra Pradesh'},
 '9185457':{'en': 'Amangallu, Andhra Pradesh'},
 '9185462':{'en': 'Gadwal, Andhra Pradesh'},
 '9185463':{'en': 'Gadwal, Andhra Pradesh'},
 '9185464':{'en': 'Gadwal, Andhra Pradesh'},
 '9185465':{'en': 'Gadwal, Andhra Pradesh'},
 '9185466':{'en': 'Gadwal, Andhra Pradesh'},
 '9185467':{'en': 'Gadwal, Andhra Pradesh'},
 '9185482':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185483':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185484':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185485':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185486':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185487':{'en': 'Shadnagar, Andhra Pradesh'},
 '9185492':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185493':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185494':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185495':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185496':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185497':{'en': 'Kalwakurthy, Andhra Pradesh'},
 '9185502':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185503':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185504':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185505':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185506':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185507':{'en': 'Yellanuru, Andhra Pradesh'},
 '9185512':{'en': 'Garladinne, Andhra Pradesh'},
 '9185513':{'en': 'Garladinne, Andhra Pradesh'},
 '9185514':{'en': 'Garladinne, Andhra Pradesh'},
 '9185515':{'en': 'Garladinne, Andhra Pradesh'},
 '9185516':{'en': 'Garladinne, Andhra Pradesh'},
 '9185517':{'en': 'Garladinne, Andhra Pradesh'},
 '9185522':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185523':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185524':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185525':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185526':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185527':{'en': 'Gooty/Guntakal, Andhra Pradesh'},
 '9185542':{'en': 'Anantapur, Andhra Pradesh'},
 '9185543':{'en': 'Anantapur, Andhra Pradesh'},
 '9185544':{'en': 'Anantapur, Andhra Pradesh'},
 '9185545':{'en': 'Anantapur, Andhra Pradesh'},
 '9185546':{'en': 'Anantapur, Andhra Pradesh'},
 '9185547':{'en': 'Anantapur, Andhra Pradesh'},
 '9185562':{'en': 'Hindupur, Andhra Pradesh'},
 '9185563':{'en': 'Hindupur, Andhra Pradesh'},
 '9185564':{'en': 'Hindupur, Andhra Pradesh'},
 '9185565':{'en': 'Hindupur, Andhra Pradesh'},
 '9185566':{'en': 'Hindupur, Andhra Pradesh'},
 '9185567':{'en': 'Hindupur, Andhra Pradesh'},
 '9185572':{'en': 'Penukonda, Andhra Pradesh'},
 '9185573':{'en': 'Penukonda, Andhra Pradesh'},
 '9185574':{'en': 'Penukonda, Andhra Pradesh'},
 '9185575':{'en': 'Penukonda, Andhra Pradesh'},
 '9185576':{'en': 'Penukonda, Andhra Pradesh'},
 '9185577':{'en': 'Penukonda, Andhra Pradesh'},
 '9185582':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185583':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185584':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185585':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185586':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185587':{'en': 'Tadipatri, Andhra Pradesh'},
 '9185592':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185593':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185594':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185595':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185596':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185597':{'en': 'Dharmavaram, Andhra Pradesh'},
 '9185602':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185603':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185604':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185605':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185606':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185607':{'en': 'Jammalamadugu, Andhra Pradesh'},
 '9185612':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185613':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185614':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185615':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185616':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185617':{'en': 'Rayachoti, Andhra Pradesh'},
 '9185622':{'en': 'Kadapa, Andhra Pradesh'},
 '9185623':{'en': 'Kadapa, Andhra Pradesh'},
 '9185624':{'en': 'Kadapa, Andhra Pradesh'},
 '9185625':{'en': 'Kadapa, Andhra Pradesh'},
 '9185626':{'en': 'Kadapa, Andhra Pradesh'},
 '9185627':{'en': 'Kadapa, Andhra Pradesh'},
 '9185632':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185633':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185634':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185635':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185636':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185637':{'en': 'Kamalapuram/Yerraguntala, Andhra Pradesh'},
 '9185642':{'en': 'Proddatur, Andhra Pradesh'},
 '9185643':{'en': 'Proddatur, Andhra Pradesh'},
 '9185644':{'en': 'Proddatur, Andhra Pradesh'},
 '9185645':{'en': 'Proddatur, Andhra Pradesh'},
 '9185646':{'en': 'Proddatur, Andhra Pradesh'},
 '9185647':{'en': 'Proddatur, Andhra Pradesh'},
 '9185652':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185653':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185654':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185655':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185656':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185657':{'en': 'Rajampeta, Andhra Pradesh'},
 '9185662':{'en': 'Koduru, Andhra Pradesh'},
 '9185663':{'en': 'Koduru, Andhra Pradesh'},
 '9185664':{'en': 'Koduru, Andhra Pradesh'},
 '9185665':{'en': 'Koduru, Andhra Pradesh'},
 '9185666':{'en': 'Koduru, Andhra Pradesh'},
 '9185667':{'en': 'Koduru, Andhra Pradesh'},
 '9185672':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185673':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185674':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185675':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185676':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185677':{'en': 'Lakkireddipalli, Andhra Pradesh'},
 '9185682':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185683':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185684':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185685':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185686':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185687':{'en': 'Pulivendla, Andhra Pradesh'},
 '9185692':{'en': 'Badvel, Andhra Pradesh'},
 '9185693':{'en': 'Badvel, Andhra Pradesh'},
 '9185694':{'en': 'Badvel, Andhra Pradesh'},
 '9185695':{'en': 'Badvel, Andhra Pradesh'},
 '9185696':{'en': 'Badvel, Andhra Pradesh'},
 '9185697':{'en': 'Badvel, Andhra Pradesh'},
 '9185702':{'en': 'Kuppam, Andhra Pradesh'},
 '9185703':{'en': 'Kuppam, Andhra Pradesh'},
 '9185704':{'en': 'Kuppam, Andhra Pradesh'},
 '9185705':{'en': 'Kuppam, Andhra Pradesh'},
 '9185706':{'en': 'Kuppam, Andhra Pradesh'},
 '9185707':{'en': 'Kuppam, Andhra Pradesh'},
 '9185712':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185713':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185714':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185715':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185716':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185717':{'en': 'Madanapalli, Andhra Pradesh'},
 '9185722':{'en': 'Chittoor, Andhra Pradesh'},
 '9185723':{'en': 'Chittoor, Andhra Pradesh'},
 '9185724':{'en': 'Chittoor, Andhra Pradesh'},
 '9185725':{'en': 'Chittoor, Andhra Pradesh'},
 '9185726':{'en': 'Chittoor, Andhra Pradesh'},
 '9185727':{'en': 'Chittoor, Andhra Pradesh'},
 '9185732':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185733':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185734':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185735':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185736':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185737':{'en': 'Bangarupalem, Andhra Pradesh'},
 '9185762':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185763':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185764':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185765':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185766':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185767':{'en': 'Satyavedu, Andhra Pradesh'},
 '9185772':{'en': 'Putturu, Andhra Pradesh'},
 '9185773':{'en': 'Putturu, Andhra Pradesh'},
 '9185774':{'en': 'Putturu, Andhra Pradesh'},
 '9185775':{'en': 'Putturu, Andhra Pradesh'},
 '9185776':{'en': 'Putturu, Andhra Pradesh'},
 '9185777':{'en': 'Putturu, Andhra Pradesh'},
 '9185782':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185783':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185784':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185785':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185786':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185787':{'en': 'Srikalahasthi, Andhra Pradesh'},
 '9185792':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185793':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185794':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185795':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185796':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185797':{'en': 'Palmaneru, Andhra Pradesh'},
 '9185812':{'en': 'Punganur, Andhra Pradesh'},
 '9185813':{'en': 'Punganur, Andhra Pradesh'},
 '9185814':{'en': 'Punganur, Andhra Pradesh'},
 '9185815':{'en': 'Punganur, Andhra Pradesh'},
 '9185816':{'en': 'Punganur, Andhra Pradesh'},
 '9185817':{'en': 'Punganur, Andhra Pradesh'},
 '9185822':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185823':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185824':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185825':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185826':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185827':{'en': 'B.Kothakota, Andhra Pradesh'},
 '9185832':{'en': 'Sodam, Andhra Pradesh'},
 '9185833':{'en': 'Sodam, Andhra Pradesh'},
 '9185834':{'en': 'Sodam, Andhra Pradesh'},
 '9185835':{'en': 'Sodam, Andhra Pradesh'},
 '9185836':{'en': 'Sodam, Andhra Pradesh'},
 '9185837':{'en': 'Sodam, Andhra Pradesh'},
 '9185842':{'en': 'Piler, Andhra Pradesh'},
 '9185843':{'en': 'Piler, Andhra Pradesh'},
 '9185844':{'en': 'Piler, Andhra Pradesh'},
 '9185845':{'en': 'Piler, Andhra Pradesh'},
 '9185846':{'en': 'Piler, Andhra Pradesh'},
 '9185847':{'en': 'Piler, Andhra Pradesh'},
 '9185852':{'en': 'Pakala, Andhra Pradesh'},
 '9185853':{'en': 'Pakala, Andhra Pradesh'},
 '9185854':{'en': 'Pakala, Andhra Pradesh'},
 '9185855':{'en': 'Pakala, Andhra Pradesh'},
 '9185856':{'en': 'Pakala, Andhra Pradesh'},
 '9185857':{'en': 'Pakala, Andhra Pradesh'},
 '9185862':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185863':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185864':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185865':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185866':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185867':{'en': 'Vayalpad, Andhra Pradesh'},
 '9185872':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185873':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185874':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185875':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185876':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185877':{'en': 'Venkatgirikota, Andhra Pradesh'},
 '9185882':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185883':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185884':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185885':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185886':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185887':{'en': 'Vaimpalli, Andhra Pradesh'},
 '9185892':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185893':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185894':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185895':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185896':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185897':{'en': 'Siddavattam, Andhra Pradesh'},
 '9185922':{'en': 'Ongole, Andhra Pradesh'},
 '9185923':{'en': 'Ongole, Andhra Pradesh'},
 '9185924':{'en': 'Ongole, Andhra Pradesh'},
 '9185925':{'en': 'Ongole, Andhra Pradesh'},
 '9185926':{'en': 'Ongole, Andhra Pradesh'},
 '9185927':{'en': 'Ongole, Andhra Pradesh'},
 '9185932':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185933':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185934':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185935':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185936':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185937':{'en': 'Medarmetla, Andhra Pradesh'},
 '9185942':{'en': 'Chirala, Andhra Pradesh'},
 '9185943':{'en': 'Chirala, Andhra Pradesh'},
 '9185944':{'en': 'Chirala, Andhra Pradesh'},
 '9185945':{'en': 'Chirala, Andhra Pradesh'},
 '9185946':{'en': 'Chirala, Andhra Pradesh'},
 '9185947':{'en': 'Chirala, Andhra Pradesh'},
 '9185962':{'en': 'Markapur, Andhra Pradesh'},
 '9185963':{'en': 'Markapur, Andhra Pradesh'},
 '9185964':{'en': 'Markapur, Andhra Pradesh'},
 '9185965':{'en': 'Markapur, Andhra Pradesh'},
 '9185966':{'en': 'Markapur, Andhra Pradesh'},
 '9185967':{'en': 'Markapur, Andhra Pradesh'},
 '9185982':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185983':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185984':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185985':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185986':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185987':{'en': 'Kandukuru, Andhra Pradesh'},
 '9185992':{'en': 'Ulvapadu, Andhra Pradesh'},
 '9185993':{'en': 'Ulvapadu, Andhra Pradesh'},
 '9185994':{'en': 'Ulvapadu, Andhra Pradesh'},
 '9185995':{'en': 'Ulvapadu, Andhra Pradesh'},
 '9185996':{'en': 'Ulvapadu, Andhra Pradesh'},
 '9185997':{'en': 'Ulvapadu, Andhra Pradesh'},
 '918612':{'en': 'Nellore, Andhra Pradesh'},
 '918613':{'en': 'Nellore, Andhra Pradesh'},
 '918614':{'en': 'Nellore, Andhra Pradesh'},
 '918615':{'en': 'Nellore, Andhra Pradesh'},
 '918616':{'en': 'Nellore, Andhra Pradesh'},
 '918617':{'en': 'Nellore, Andhra Pradesh'},
 '9186202':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186203':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186204':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186205':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186206':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186207':{'en': 'Udaygiri, Andhra Pradesh'},
 '9186212':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186213':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186214':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186215':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186216':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186217':{'en': 'Rapur/Podalakur, Andhra Pradesh'},
 '9186222':{'en': 'Kovvur, Andhra Pradesh'},
 '9186223':{'en': 'Kovvur, Andhra Pradesh'},
 '9186224':{'en': 'Kovvur, Andhra Pradesh'},
 '9186225':{'en': 'Kovvur, Andhra Pradesh'},
 '9186226':{'en': 'Kovvur, Andhra Pradesh'},
 '9186227':{'en': 'Kovvur, Andhra Pradesh'},
 '9186232':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186233':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186234':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186235':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186236':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186237':{'en': 'Sullurpet, Andhra Pradesh'},
 '9186242':{'en': 'Gudur, Andhra Pradesh'},
 '9186243':{'en': 'Gudur, Andhra Pradesh'},
 '9186244':{'en': 'Gudur, Andhra Pradesh'},
 '9186245':{'en': 'Gudur, Andhra Pradesh'},
 '9186246':{'en': 'Gudur, Andhra Pradesh'},
 '9186247':{'en': 'Gudur, Andhra Pradesh'},
 '9186252':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186253':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186254':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186255':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186256':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186257':{'en': 'Venkatgiri, Andhra Pradesh'},
 '9186262':{'en': 'Kavali, Andhra Pradesh'},
 '9186263':{'en': 'Kavali, Andhra Pradesh'},
 '9186264':{'en': 'Kavali, Andhra Pradesh'},
 '9186265':{'en': 'Kavali, Andhra Pradesh'},
 '9186266':{'en': 'Kavali, Andhra Pradesh'},
 '9186267':{'en': 'Kavali, Andhra Pradesh'},
 '9186272':{'en': 'Atmakur, Andhra Pradesh'},
 '9186273':{'en': 'Atmakur, Andhra Pradesh'},
 '9186274':{'en': 'Atmakur, Andhra Pradesh'},
 '9186275':{'en': 'Atmakur, Andhra Pradesh'},
 '9186276':{'en': 'Atmakur, Andhra Pradesh'},
 '9186277':{'en': 'Atmakur, Andhra Pradesh'},
 '9186282':{'en': 'Chejerla, Andhra Pradesh'},
 '9186283':{'en': 'Chejerla, Andhra Pradesh'},
 '9186284':{'en': 'Chejerla, Andhra Pradesh'},
 '9186285':{'en': 'Chejerla, Andhra Pradesh'},
 '9186286':{'en': 'Chejerla, Andhra Pradesh'},
 '9186287':{'en': 'Chejerla, Andhra Pradesh'},
 '9186292':{'en': 'Vinjamuru, Andhra Pradesh'},
 '9186293':{'en': 'Vinjamuru, Andhra Pradesh'},
 '9186294':{'en': 'Vinjamuru, Andhra Pradesh'},
 '9186295':{'en': 'Vinjamuru, Andhra Pradesh'},
 '9186296':{'en': 'Vinjamuru, Andhra Pradesh'},
 '9186297':{'en': 'Vinjamuru, Andhra Pradesh'},
 '918632':{'en': 'Guntur, Andhra Pradesh'},
 '918633':{'en': 'Guntur, Andhra Pradesh'},
 '918634':{'en': 'Guntur, Andhra Pradesh'},
 '918635':{'en': 'Guntur, Andhra Pradesh'},
 '918636':{'en': 'Guntur, Andhra Pradesh'},
 '918637':{'en': 'Guntur, Andhra Pradesh'},
 '9186402':{'en': 'Krosuru, Andhra Pradesh'},
 '9186403':{'en': 'Krosuru, Andhra Pradesh'},
 '9186404':{'en': 'Krosuru, Andhra Pradesh'},
 '9186405':{'en': 'Krosuru, Andhra Pradesh'},
 '9186406':{'en': 'Krosuru, Andhra Pradesh'},
 '9186407':{'en': 'Krosuru, Andhra Pradesh'},
 '9186412':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186413':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186414':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186415':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186416':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186417':{'en': 'Sattenapalli, Andhra Pradesh'},
 '9186422':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186423':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186424':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186425':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186426':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186427':{'en': 'Guntur Palnad/Macherala, Andhra Pradesh'},
 '9186432':{'en': 'Bapatla, Andhra Pradesh'},
 '9186433':{'en': 'Bapatla, Andhra Pradesh'},
 '9186434':{'en': 'Bapatla, Andhra Pradesh'},
 '9186435':{'en': 'Bapatla, Andhra Pradesh'},
 '9186436':{'en': 'Bapatla, Andhra Pradesh'},
 '9186437':{'en': 'Bapatla, Andhra Pradesh'},
 '9186442':{'en': 'Tenali, Andhra Pradesh'},
 '9186443':{'en': 'Tenali, Andhra Pradesh'},
 '9186444':{'en': 'Tenali, Andhra Pradesh'},
 '9186445':{'en': 'Tenali, Andhra Pradesh'},
 '9186446':{'en': 'Tenali, Andhra Pradesh'},
 '9186447':{'en': 'Tenali, Andhra Pradesh'},
 '9186452':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186453':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186454':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186455':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186456':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186457':{'en': 'Mangalagiri, Andhra Pradesh'},
 '9186462':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186463':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186464':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186465':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186466':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186467':{'en': 'Vinukonda, Andhra Pradesh'},
 '9186472':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186473':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186474':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186475':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186476':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186477':{'en': 'Narsaraopet, Andhra Pradesh'},
 '9186482':{'en': 'Repalle, Andhra Pradesh'},
 '9186483':{'en': 'Repalle, Andhra Pradesh'},
 '9186484':{'en': 'Repalle, Andhra Pradesh'},
 '9186485':{'en': 'Repalle, Andhra Pradesh'},
 '9186486':{'en': 'Repalle, Andhra Pradesh'},
 '9186487':{'en': 'Repalle, Andhra Pradesh'},
 '9186492':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186493':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186494':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186495':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186496':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186497':{'en': 'Piduguralla, Andhra Pradesh'},
 '9186542':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186543':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186544':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186545':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186546':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186547':{'en': 'Jaggayyapet, Andhra Pradesh'},
 '9186562':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186563':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186564':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186565':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186566':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186567':{'en': 'Nuzvidu, Andhra Pradesh'},
 '9186592':{'en': 'Mylavaram, Andhra Pradesh'},
 '9186593':{'en': 'Mylavaram, Andhra Pradesh'},
 '9186594':{'en': 'Mylavaram, Andhra Pradesh'},
 '9186595':{'en': 'Mylavaram, Andhra Pradesh'},
 '9186596':{'en': 'Mylavaram, Andhra Pradesh'},
 '9186597':{'en': 'Mylavaram, Andhra Pradesh'},
 '918662':{'en': 'Vijayawada, Andhra Pradesh'},
 '918663':{'en': 'Vijayawada, Andhra Pradesh'},
 '918664':{'en': 'Vijayawada, Andhra Pradesh'},
 '918665':{'en': 'Vijayawada, Andhra Pradesh'},
 '918666':{'en': 'Vijayawada, Andhra Pradesh'},
 '918667':{'en': 'Vijayawada, Andhra Pradesh'},
 '9186712':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186713':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186714':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186715':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186716':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186717':{'en': 'Divi/Challapalli, Andhra Pradesh'},
 '9186722':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186723':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186724':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186725':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186726':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186727':{'en': 'Bandar/Machilipatnam, Andhra Pradesh'},
 '9186732':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186733':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186734':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186735':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186736':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186737':{'en': 'Tirivuru, Andhra Pradesh'},
 '9186742':{'en': 'Gudivada, Andhra Pradesh'},
 '9186743':{'en': 'Gudivada, Andhra Pradesh'},
 '9186744':{'en': 'Gudivada, Andhra Pradesh'},
 '9186745':{'en': 'Gudivada, Andhra Pradesh'},
 '9186746':{'en': 'Gudivada, Andhra Pradesh'},
 '9186747':{'en': 'Gudivada, Andhra Pradesh'},
 '9186762':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186763':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186764':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186765':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186766':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186767':{'en': 'Vuyyuru, Andhra Pradesh'},
 '9186772':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186773':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186774':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186775':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186776':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186777':{'en': 'Kaikaluru, Andhra Pradesh'},
 '9186782':{'en': 'Nandigama, Andhra Pradesh'},
 '9186783':{'en': 'Nandigama, Andhra Pradesh'},
 '9186784':{'en': 'Nandigama, Andhra Pradesh'},
 '9186785':{'en': 'Nandigama, Andhra Pradesh'},
 '9186786':{'en': 'Nandigama, Andhra Pradesh'},
 '9186787':{'en': 'Nandigama, Andhra Pradesh'},
 '9186802':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186803':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186804':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186805':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186806':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186807':{'en': 'Nidamanur/Hillcolony, Andhra Pradesh'},
 '9186812':{'en': 'Chandoor, Andhra Pradesh'},
 '9186813':{'en': 'Chandoor, Andhra Pradesh'},
 '9186814':{'en': 'Chandoor, Andhra Pradesh'},
 '9186815':{'en': 'Chandoor, Andhra Pradesh'},
 '9186816':{'en': 'Chandoor, Andhra Pradesh'},
 '9186817':{'en': 'Chandoor, Andhra Pradesh'},
 '9186822':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186823':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186824':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186825':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186826':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186827':{'en': 'Nalgonda, Andhra Pradesh'},
 '9186832':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186833':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186834':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186835':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186836':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186837':{'en': 'Hazurnagar, Andhra Pradesh'},
 '9186842':{'en': 'Suryapet, Andhra Pradesh'},
 '9186843':{'en': 'Suryapet, Andhra Pradesh'},
 '9186844':{'en': 'Suryapet, Andhra Pradesh'},
 '9186845':{'en': 'Suryapet, Andhra Pradesh'},
 '9186846':{'en': 'Suryapet, Andhra Pradesh'},
 '9186847':{'en': 'Suryapet, Andhra Pradesh'},
 '9186852':{'en': 'Bhongir, Andhra Pradesh'},
 '9186853':{'en': 'Bhongir, Andhra Pradesh'},
 '9186854':{'en': 'Bhongir, Andhra Pradesh'},
 '9186855':{'en': 'Bhongir, Andhra Pradesh'},
 '9186856':{'en': 'Bhongir, Andhra Pradesh'},
 '9186857':{'en': 'Bhongir, Andhra Pradesh'},
 '9186892':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186893':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186894':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186895':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186896':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186897':{'en': 'Miryalguda, Andhra Pradesh'},
 '9186912':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186913':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186914':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186915':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186916':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186917':{'en': 'Devarakonda, Andhra Pradesh'},
 '9186922':{'en': 'Nampalle, Andhra Pradesh'},
 '9186923':{'en': 'Nampalle, Andhra Pradesh'},
 '9186924':{'en': 'Nampalle, Andhra Pradesh'},
 '9186925':{'en': 'Nampalle, Andhra Pradesh'},
 '9186926':{'en': 'Nampalle, Andhra Pradesh'},
 '9186927':{'en': 'Nampalle, Andhra Pradesh'},
 '9186932':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186933':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186934':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186935':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186936':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186937':{'en': 'Thungaturthy, Andhra Pradesh'},
 '9186942':{'en': 'Ramannapet, Andhra Pradesh'},
 '9186943':{'en': 'Ramannapet, Andhra Pradesh'},
 '9186944':{'en': 'Ramannapet, Andhra Pradesh'},
 '9186945':{'en': 'Ramannapet, Andhra Pradesh'},
 '9186946':{'en': 'Ramannapet, Andhra Pradesh'},
 '9186947':{'en': 'Ramannapet, Andhra Pradesh'},
 '918702':{'en': 'Warangal, Andhra Pradesh'},
 '918703':{'en': 'Warangal, Andhra Pradesh'},
 '918704':{'en': 'Warangal, Andhra Pradesh'},
 '918705':{'en': 'Warangal, Andhra Pradesh'},
 '918706':{'en': 'Warangal, Andhra Pradesh'},
 '918707':{'en': 'Warangal, Andhra Pradesh'},
 '9187102':{'en': 'Cherial, Andhra Pradesh'},
 '9187103':{'en': 'Cherial, Andhra Pradesh'},
 '9187104':{'en': 'Cherial, Andhra Pradesh'},
 '9187105':{'en': 'Cherial, Andhra Pradesh'},
 '9187106':{'en': 'Cherial, Andhra Pradesh'},
 '9187107':{'en': 'Cherial, Andhra Pradesh'},
 '9187112':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187113':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187114':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187115':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187116':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187117':{'en': 'Wardhannapet/Ghanapur, Andhra Pradesh'},
 '9187132':{'en': 'Parkal, Andhra Pradesh'},
 '9187133':{'en': 'Parkal, Andhra Pradesh'},
 '9187134':{'en': 'Parkal, Andhra Pradesh'},
 '9187135':{'en': 'Parkal, Andhra Pradesh'},
 '9187136':{'en': 'Parkal, Andhra Pradesh'},
 '9187137':{'en': 'Parkal, Andhra Pradesh'},
 '9187152':{'en': 'Mulug, Andhra Pradesh'},
 '9187153':{'en': 'Mulug, Andhra Pradesh'},
 '9187154':{'en': 'Mulug, Andhra Pradesh'},
 '9187155':{'en': 'Mulug, Andhra Pradesh'},
 '9187156':{'en': 'Mulug, Andhra Pradesh'},
 '9187157':{'en': 'Mulug, Andhra Pradesh'},
 '9187162':{'en': 'Jangaon, Andhra Pradesh'},
 '9187163':{'en': 'Jangaon, Andhra Pradesh'},
 '9187164':{'en': 'Jangaon, Andhra Pradesh'},
 '9187165':{'en': 'Jangaon, Andhra Pradesh'},
 '9187166':{'en': 'Jangaon, Andhra Pradesh'},
 '9187167':{'en': 'Jangaon, Andhra Pradesh'},
 '9187172':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187173':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187174':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187175':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187176':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187177':{'en': 'Eturnagaram, Andhra Pradesh'},
 '9187182':{'en': 'Narasampet, Andhra Pradesh'},
 '9187183':{'en': 'Narasampet, Andhra Pradesh'},
 '9187184':{'en': 'Narasampet, Andhra Pradesh'},
 '9187185':{'en': 'Narasampet, Andhra Pradesh'},
 '9187186':{'en': 'Narasampet, Andhra Pradesh'},
 '9187187':{'en': 'Narasampet, Andhra Pradesh'},
 '9187192':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187193':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187194':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187195':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187196':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187197':{'en': 'Mahabubbad, Andhra Pradesh'},
 '9187202':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187203':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187204':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187205':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187206':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187207':{'en': 'Mahadevapur, Andhra Pradesh'},
 '9187212':{'en': 'Husnabad, Andhra Pradesh'},
 '9187213':{'en': 'Husnabad, Andhra Pradesh'},
 '9187214':{'en': 'Husnabad, Andhra Pradesh'},
 '9187215':{'en': 'Husnabad, Andhra Pradesh'},
 '9187216':{'en': 'Husnabad, Andhra Pradesh'},
 '9187217':{'en': 'Husnabad, Andhra Pradesh'},
 '9187232':{'en': 'Sircilla, Andhra Pradesh'},
 '9187233':{'en': 'Sircilla, Andhra Pradesh'},
 '9187234':{'en': 'Sircilla, Andhra Pradesh'},
 '9187235':{'en': 'Sircilla, Andhra Pradesh'},
 '9187236':{'en': 'Sircilla, Andhra Pradesh'},
 '9187237':{'en': 'Sircilla, Andhra Pradesh'},
 '9187242':{'en': 'Jagtial, Andhra Pradesh'},
 '9187243':{'en': 'Jagtial, Andhra Pradesh'},
 '9187244':{'en': 'Jagtial, Andhra Pradesh'},
 '9187245':{'en': 'Jagtial, Andhra Pradesh'},
 '9187246':{'en': 'Jagtial, Andhra Pradesh'},
 '9187247':{'en': 'Jagtial, Andhra Pradesh'},
 '9187252':{'en': 'Metpalli, Andhra Pradesh'},
 '9187253':{'en': 'Metpalli, Andhra Pradesh'},
 '9187254':{'en': 'Metpalli, Andhra Pradesh'},
 '9187255':{'en': 'Metpalli, Andhra Pradesh'},
 '9187256':{'en': 'Metpalli, Andhra Pradesh'},
 '9187257':{'en': 'Metpalli, Andhra Pradesh'},
 '9187272':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187273':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187274':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187275':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187276':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187277':{'en': 'Huzurabad, Andhra Pradesh'},
 '9187282':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187283':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187284':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187285':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187286':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187287':{'en': 'Peddapalli, Andhra Pradesh'},
 '9187292':{'en': 'Manthani, Andhra Pradesh'},
 '9187293':{'en': 'Manthani, Andhra Pradesh'},
 '9187294':{'en': 'Manthani, Andhra Pradesh'},
 '9187295':{'en': 'Manthani, Andhra Pradesh'},
 '9187296':{'en': 'Manthani, Andhra Pradesh'},
 '9187297':{'en': 'Manthani, Andhra Pradesh'},
 '9187302':{'en': 'Khanapur, Andhra Pradesh'},
 '9187303':{'en': 'Khanapur, Andhra Pradesh'},
 '9187304':{'en': 'Khanapur, Andhra Pradesh'},
 '9187305':{'en': 'Khanapur, Andhra Pradesh'},
 '9187306':{'en': 'Khanapur, Andhra Pradesh'},
 '9187307':{'en': 'Khanapur, Andhra Pradesh'},
 '9187312':{'en': 'Utnor, Andhra Pradesh'},
 '9187313':{'en': 'Utnor, Andhra Pradesh'},
 '9187314':{'en': 'Utnor, Andhra Pradesh'},
 '9187315':{'en': 'Utnor, Andhra Pradesh'},
 '9187316':{'en': 'Utnor, Andhra Pradesh'},
 '9187317':{'en': 'Utnor, Andhra Pradesh'},
 '9187322':{'en': 'Adilabad, Andhra Pradesh'},
 '9187323':{'en': 'Adilabad, Andhra Pradesh'},
 '9187324':{'en': 'Adilabad, Andhra Pradesh'},
 '9187325':{'en': 'Adilabad, Andhra Pradesh'},
 '9187326':{'en': 'Adilabad, Andhra Pradesh'},
 '9187327':{'en': 'Adilabad, Andhra Pradesh'},
 '9187332':{'en': 'Asifabad, Andhra Pradesh'},
 '9187333':{'en': 'Asifabad, Andhra Pradesh'},
 '9187334':{'en': 'Asifabad, Andhra Pradesh'},
 '9187335':{'en': 'Asifabad, Andhra Pradesh'},
 '9187336':{'en': 'Asifabad, Andhra Pradesh'},
 '9187337':{'en': 'Asifabad, Andhra Pradesh'},
 '9187342':{'en': 'Nirmal, Andhra Pradesh'},
 '9187343':{'en': 'Nirmal, Andhra Pradesh'},
 '9187344':{'en': 'Nirmal, Andhra Pradesh'},
 '9187345':{'en': 'Nirmal, Andhra Pradesh'},
 '9187346':{'en': 'Nirmal, Andhra Pradesh'},
 '9187347':{'en': 'Nirmal, Andhra Pradesh'},
 '9187352':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187353':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187354':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187355':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187356':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187357':{'en': 'Bellampalli, Andhra Pradesh'},
 '9187362':{'en': 'Mancherial, Andhra Pradesh'},
 '9187363':{'en': 'Mancherial, Andhra Pradesh'},
 '9187364':{'en': 'Mancherial, Andhra Pradesh'},
 '9187365':{'en': 'Mancherial, Andhra Pradesh'},
 '9187366':{'en': 'Mancherial, Andhra Pradesh'},
 '9187367':{'en': 'Mancherial, Andhra Pradesh'},
 '9187372':{'en': 'Chinnor, Andhra Pradesh'},
 '9187373':{'en': 'Chinnor, Andhra Pradesh'},
 '9187374':{'en': 'Chinnor, Andhra Pradesh'},
 '9187375':{'en': 'Chinnor, Andhra Pradesh'},
 '9187376':{'en': 'Chinnor, Andhra Pradesh'},
 '9187377':{'en': 'Chinnor, Andhra Pradesh'},
 '9187382':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187383':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187384':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187385':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187386':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187387':{'en': 'Sirpurkagaznagar, Andhra Pradesh'},
 '9187392':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187393':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187394':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187395':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187396':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187397':{'en': 'Jannaram/Luxittipet, Andhra Pradesh'},
 '9187402':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187403':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187404':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187405':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187406':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187407':{'en': 'Aswaraopet, Andhra Pradesh'},
 '9187412':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187413':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187414':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187415':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187416':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187417':{'en': 'Sudhimalla/Tekulapalli, Andhra Pradesh'},
 '9187422':{'en': 'Khammam, Andhra Pradesh'},
 '9187423':{'en': 'Khammam, Andhra Pradesh'},
 '9187424':{'en': 'Khammam, Andhra Pradesh'},
 '9187425':{'en': 'Khammam, Andhra Pradesh'},
 '9187426':{'en': 'Khammam, Andhra Pradesh'},
 '9187427':{'en': 'Khammam, Andhra Pradesh'},
 '9187432':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187433':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187434':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187435':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187436':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187437':{'en': 'Bhadrachalam, Andhra Pradesh'},
 '9187442':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187443':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187444':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187445':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187446':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187447':{'en': 'Kothagudem, Andhra Pradesh'},
 '9187452':{'en': 'Yellandu, Andhra Pradesh'},
 '9187453':{'en': 'Yellandu, Andhra Pradesh'},
 '9187454':{'en': 'Yellandu, Andhra Pradesh'},
 '9187455':{'en': 'Yellandu, Andhra Pradesh'},
 '9187456':{'en': 'Yellandu, Andhra Pradesh'},
 '9187457':{'en': 'Yellandu, Andhra Pradesh'},
 '9187462':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187463':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187464':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187465':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187466':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187467':{'en': 'Bhooragamphad/Manuguru, Andhra Pradesh'},
 '9187472':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187473':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187474':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187475':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187476':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187477':{'en': 'Nuguru/Cherla, Andhra Pradesh'},
 '9187482':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187483':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187484':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187485':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187486':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187487':{'en': 'V.R.Puram, Andhra Pradesh'},
 '9187492':{'en': 'Madhira, Andhra Pradesh'},
 '9187493':{'en': 'Madhira, Andhra Pradesh'},
 '9187494':{'en': 'Madhira, Andhra Pradesh'},
 '9187495':{'en': 'Madhira, Andhra Pradesh'},
 '9187496':{'en': 'Madhira, Andhra Pradesh'},
 '9187497':{'en': 'Madhira, Andhra Pradesh'},
 '9187512':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187513':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187514':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187515':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187516':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187517':{'en': 'Boath/Echoda, Andhra Pradesh'},
 '9187522':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187523':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187524':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187525':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187526':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187527':{'en': 'Bhainsa, Andhra Pradesh'},
 '9187532':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187533':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187534':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187535':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187536':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187537':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187592':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187593':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187594':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187595':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187596':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187597':{'en': 'Outsarangapalle, Andhra Pradesh'},
 '9187612':{'en': 'Sathupalli, Andhra Pradesh'},
 '9187613':{'en': 'Sathupalli, Andhra Pradesh'},
 '9187614':{'en': 'Sathupalli, Andhra Pradesh'},
 '9187615':{'en': 'Sathupalli, Andhra Pradesh'},
 '9187616':{'en': 'Sathupalli, Andhra Pradesh'},
 '9187617':{'en': 'Sathupalli, Andhra Pradesh'},
 '918772':{'en': 'Tirupathi, Andhra Pradesh'},
 '918773':{'en': 'Tirupathi, Andhra Pradesh'},
 '918774':{'en': 'Tirupathi, Andhra Pradesh'},
 '918775':{'en': 'Tirupathi, Andhra Pradesh'},
 '918776':{'en': 'Tirupathi, Andhra Pradesh'},
 '918777':{'en': 'Tirupathi, Andhra Pradesh'},
 '918782':{'en': 'Karimnagar, Andhra Pradesh'},
 '918783':{'en': 'Karimnagar, Andhra Pradesh'},
 '918784':{'en': 'Karimnagar, Andhra Pradesh'},
 '918785':{'en': 'Karimnagar, Andhra Pradesh'},
 '918786':{'en': 'Karimnagar, Andhra Pradesh'},
 '918787':{'en': 'Karimnagar, Andhra Pradesh'},
 '9188112':{'en': 'Polavaram, Andhra Pradesh'},
 '9188113':{'en': 'Polavaram, Andhra Pradesh'},
 '9188114':{'en': 'Polavaram, Andhra Pradesh'},
 '9188115':{'en': 'Polavaram, Andhra Pradesh'},
 '9188116':{'en': 'Polavaram, Andhra Pradesh'},
 '9188117':{'en': 'Polavaram, Andhra Pradesh'},
 '9188122':{'en': 'Eluru, Andhra Pradesh'},
 '9188123':{'en': 'Eluru, Andhra Pradesh'},
 '9188124':{'en': 'Eluru, Andhra Pradesh'},
 '9188125':{'en': 'Eluru, Andhra Pradesh'},
 '9188126':{'en': 'Eluru, Andhra Pradesh'},
 '9188127':{'en': 'Eluru, Andhra Pradesh'},
 '9188132':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188133':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188134':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188135':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188136':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188137':{'en': 'Eluru Kovvur/Nidadavolu, Andhra Pradesh'},
 '9188142':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188143':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188144':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188145':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188146':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188147':{'en': 'Eluru Narsapur/Palakole, Andhra Pradesh'},
 '9188162':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188163':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188164':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188165':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188166':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188167':{'en': 'Bhimavaram, Andhra Pradesh'},
 '9188182':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188183':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188184':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188185':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188186':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188187':{'en': 'Tadepalligudem, Andhra Pradesh'},
 '9188192':{'en': 'Tanuku, Andhra Pradesh'},
 '9188193':{'en': 'Tanuku, Andhra Pradesh'},
 '9188194':{'en': 'Tanuku, Andhra Pradesh'},
 '9188195':{'en': 'Tanuku, Andhra Pradesh'},
 '9188196':{'en': 'Tanuku, Andhra Pradesh'},
 '9188197':{'en': 'Tanuku, Andhra Pradesh'},
 '9188212':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188213':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188214':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188215':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188216':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188217':{'en': 'Jangareddygudem, Andhra Pradesh'},
 '9188232':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188233':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188234':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188235':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188236':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188237':{'en': 'Chintalapudi, Andhra Pradesh'},
 '9188292':{'en': 'Bhimadole, Andhra Pradesh'},
 '9188293':{'en': 'Bhimadole, Andhra Pradesh'},
 '9188294':{'en': 'Bhimadole, Andhra Pradesh'},
 '9188295':{'en': 'Bhimadole, Andhra Pradesh'},
 '9188296':{'en': 'Bhimadole, Andhra Pradesh'},
 '9188297':{'en': 'Bhimadole, Andhra Pradesh'},
 '918832':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918833':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918834':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918835':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918836':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918837':{'en': 'Rajahmundri, Andhra Pradesh'},
 '918842':{'en': 'Kakinada, Andhra Pradesh'},
 '918843':{'en': 'Kakinada, Andhra Pradesh'},
 '918844':{'en': 'Kakinada, Andhra Pradesh'},
 '918845':{'en': 'Kakinada, Andhra Pradesh'},
 '918846':{'en': 'Kakinada, Andhra Pradesh'},
 '918847':{'en': 'Kakinada, Andhra Pradesh'},
 '9188522':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188523':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188524':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188525':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188526':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188527':{'en': 'Peddapuram, Andhra Pradesh'},
 '9188542':{'en': 'Tuni, Andhra Pradesh'},
 '9188543':{'en': 'Tuni, Andhra Pradesh'},
 '9188544':{'en': 'Tuni, Andhra Pradesh'},
 '9188545':{'en': 'Tuni, Andhra Pradesh'},
 '9188546':{'en': 'Tuni, Andhra Pradesh'},
 '9188547':{'en': 'Tuni, Andhra Pradesh'},
 '9188552':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188553':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188554':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188555':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188556':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188557':{'en': 'Mandapeta/Ravulapalem, Andhra Pradesh'},
 '9188562':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188563':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188564':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188565':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188566':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188567':{'en': 'Amalapuram, Andhra Pradesh'},
 '9188572':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188573':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188574':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188575':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188576':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188577':{'en': 'Ramachandrapuram, Andhra Pradesh'},
 '9188622':{'en': 'Razole, Andhra Pradesh'},
 '9188623':{'en': 'Razole, Andhra Pradesh'},
 '9188624':{'en': 'Razole, Andhra Pradesh'},
 '9188625':{'en': 'Razole, Andhra Pradesh'},
 '9188626':{'en': 'Razole, Andhra Pradesh'},
 '9188627':{'en': 'Razole, Andhra Pradesh'},
 '9188632':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188633':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188634':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188635':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188636':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188637':{'en': 'Chavitidibbalu, Andhra Pradesh'},
 '9188642':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188643':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188644':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188645':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188646':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188647':{'en': 'Rampachodavaram, Andhra Pradesh'},
 '9188652':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188653':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188654':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188655':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188656':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188657':{'en': 'Yelavaram, Andhra Pradesh'},
 '9188682':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188683':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188684':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188685':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188686':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188687':{'en': 'Yeleswaram, Andhra Pradesh'},
 '9188692':{'en': 'Pithapuram, Andhra Pradesh'},
 '9188693':{'en': 'Pithapuram, Andhra Pradesh'},
 '9188694':{'en': 'Pithapuram, Andhra Pradesh'},
 '9188695':{'en': 'Pithapuram, Andhra Pradesh'},
 '9188696':{'en': 'Pithapuram, Andhra Pradesh'},
 '9188697':{'en': 'Pithapuram, Andhra Pradesh'},
 '918912':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '918913':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '918914':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '918915':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '918916':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '918917':{'en': 'Visakhapatnam, Andhra Pradesh'},
 '9189222':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189223':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189224':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189225':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189226':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189227':{'en': 'Vizayanagaram, Andhra Pradesh'},
 '9189242':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189243':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189244':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189245':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189246':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189247':{'en': 'Anakapalle, Andhra Pradesh'},
 '9189312':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189313':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189314':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189315':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189316':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189317':{'en': 'Yelamanchili, Andhra Pradesh'},
 '9189322':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189323':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189324':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189325':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189326':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189327':{'en': 'Narsipatnam, Andhra Pradesh'},
 '9189332':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189333':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189334':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189335':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189336':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189337':{'en': 'Bheemunipatnam, Andhra Pradesh'},
 '9189342':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189343':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189344':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189345':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189346':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189347':{'en': 'Chodavaram, Andhra Pradesh'},
 '9189352':{'en': 'Paderu, Andhra Pradesh'},
 '9189353':{'en': 'Paderu, Andhra Pradesh'},
 '9189354':{'en': 'Paderu, Andhra Pradesh'},
 '9189355':{'en': 'Paderu, Andhra Pradesh'},
 '9189356':{'en': 'Paderu, Andhra Pradesh'},
 '9189357':{'en': 'Paderu, Andhra Pradesh'},
 '9189362':{'en': 'Araku, Andhra Pradesh'},
 '9189363':{'en': 'Araku, Andhra Pradesh'},
 '9189364':{'en': 'Araku, Andhra Pradesh'},
 '9189365':{'en': 'Araku, Andhra Pradesh'},
 '9189366':{'en': 'Araku, Andhra Pradesh'},
 '9189367':{'en': 'Araku, Andhra Pradesh'},
 '9189372':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189373':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189374':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189375':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189376':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189377':{'en': 'Chintapalle, Andhra Pradesh'},
 '9189382':{'en': 'Sileru, Andhra Pradesh'},
 '9189383':{'en': 'Sileru, Andhra Pradesh'},
 '9189384':{'en': 'Sileru, Andhra Pradesh'},
 '9189385':{'en': 'Sileru, Andhra Pradesh'},
 '9189386':{'en': 'Sileru, Andhra Pradesh'},
 '9189387':{'en': 'Sileru, Andhra Pradesh'},
 '9189412':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189413':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189414':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189415':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189416':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189417':{'en': 'Palakonda/Rajam, Andhra Pradesh'},
 '9189422':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189423':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189424':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189425':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189426':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189427':{'en': 'Srikakulam, Andhra Pradesh'},
 '9189442':{'en': 'Bobbili, Andhra Pradesh'},
 '9189443':{'en': 'Bobbili, Andhra Pradesh'},
 '9189444':{'en': 'Bobbili, Andhra Pradesh'},
 '9189445':{'en': 'Bobbili, Andhra Pradesh'},
 '9189446':{'en': 'Bobbili, Andhra Pradesh'},
 '9189447':{'en': 'Bobbili, Andhra Pradesh'},
 '9189452':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189453':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189454':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189455':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189456':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189457':{'en': 'Tekkali/Palasa, Andhra Pradesh'},
 '9189462':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189463':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189464':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189465':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189466':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189467':{'en': 'Pathapatnam/Hiramandalam, Andhra Pradesh'},
 '9189472':{'en': 'Sompeta, Andhra Pradesh'},
 '9189473':{'en': 'Sompeta, Andhra Pradesh'},
 '9189474':{'en': 'Sompeta, Andhra Pradesh'},
 '9189475':{'en': 'Sompeta, Andhra Pradesh'},
 '9189476':{'en': 'Sompeta, Andhra Pradesh'},
 '9189477':{'en': 'Sompeta, Andhra Pradesh'},
 '92212':{'en': 'Karachi'},
 '92213':{'en': 'Karachi'},
 '92214':{'en': 'Karachi'},
 '92215':{'en': 'Karachi'},
 '92216':{'en': 'Karachi'},
 '92217':{'en': 'Karachi'},
 '92218':{'en': 'Karachi'},
 '92219':{'en': 'Karachi'},
 '92222':{'en': 'Hyderabad'},
 '92223':{'en': 'Hyderabad'},
 '92224':{'en': 'Hyderabad'},
 '92225':{'en': 'Hyderabad'},
 '92226':{'en': 'Hyderabad'},
 '92227':{'en': 'Hyderabad'},
 '92228':{'en': 'Hyderabad'},
 '92229':{'en': 'Hyderabad'},
 '922322':{'en': 'Tharparkar'},
 '922323':{'en': 'Tharparkar'},
 '922324':{'en': 'Tharparkar'},
 '922325':{'en': 'Tharparkar'},
 '922326':{'en': 'Tharparkar'},
 '922327':{'en': 'Tharparkar'},
 '922328':{'en': 'Tharparkar'},
 '922329':{'en': 'Tharparkar'},
 '922332':{'en': 'Mirpur Khas'},
 '922333':{'en': 'Mirpur Khas'},
 '922334':{'en': 'Mirpur Khas'},
 '922335':{'en': 'Mirpur Khas'},
 '922336':{'en': 'Mirpur Khas'},
 '922337':{'en': 'Mirpur Khas'},
 '922338':{'en': 'Mirpur Khas'},
 '922339':{'en': 'Mirpur Khas'},
 '922352':{'en': 'Sanghar'},
 '922353':{'en': 'Sanghar'},
 '922354':{'en': 'Sanghar'},
 '922355':{'en': 'Sanghar'},
 '922356':{'en': 'Sanghar'},
 '922357':{'en': 'Sanghar'},
 '922358':{'en': 'Sanghar'},
 '922359':{'en': 'Sanghar'},
 '922382':{'en': 'Umerkot'},
 '922383':{'en': 'Umerkot'},
 '922384':{'en': 'Umerkot'},
 '922385':{'en': 'Umerkot'},
 '922386':{'en': 'Umerkot'},
 '922387':{'en': 'Umerkot'},
 '922388':{'en': 'Umerkot'},
 '922389':{'en': 'Umerkot'},
 '922422':{'en': 'Naushero Feroze'},
 '922423':{'en': 'Naushero Feroze'},
 '922424':{'en': 'Naushero Feroze'},
 '922425':{'en': 'Naushero Feroze'},
 '922426':{'en': 'Naushero Feroze'},
 '922427':{'en': 'Naushero Feroze'},
 '922428':{'en': 'Naushero Feroze'},
 '922429':{'en': 'Naushero Feroze'},
 '922432':{'en': 'Khairpur'},
 '922433':{'en': 'Khairpur'},
 '922434':{'en': 'Khairpur'},
 '922435':{'en': 'Khairpur'},
 '922436':{'en': 'Khairpur'},
 '922437':{'en': 'Khairpur'},
 '922438':{'en': 'Khairpur'},
 '922439':{'en': 'Khairpur'},
 '922442':{'en': 'Nawabshah'},
 '922443':{'en': 'Nawabshah'},
 '922444':{'en': 'Nawabshah'},
 '922445':{'en': 'Nawabshah'},
 '922446':{'en': 'Nawabshah'},
 '922447':{'en': 'Nawabshah'},
 '922448':{'en': 'Nawabshah'},
 '922449':{'en': 'Nawabshah'},
 '92252':{'en': 'Dadu'},
 '92253':{'en': 'Dadu'},
 '92254':{'en': 'Dadu'},
 '92255':{'en': 'Dadu'},
 '92256':{'en': 'Dadu'},
 '92257':{'en': 'Dadu'},
 '92258':{'en': 'Dadu'},
 '92259':{'en': 'Dadu'},
 '922972':{'en': 'Badin'},
 '922973':{'en': 'Badin'},
 '922974':{'en': 'Badin'},
 '922975':{'en': 'Badin'},
 '922976':{'en': 'Badin'},
 '922977':{'en': 'Badin'},
 '922978':{'en': 'Badin'},
 '922979':{'en': 'Badin'},
 '922982':{'en': 'Thatta'},
 '922983':{'en': 'Thatta'},
 '922984':{'en': 'Thatta'},
 '922985':{'en': 'Thatta'},
 '922986':{'en': 'Thatta'},
 '922987':{'en': 'Thatta'},
 '922988':{'en': 'Thatta'},
 '922989':{'en': 'Thatta'},
 '92402':{'en': 'Sahiwal'},
 '92403':{'en': 'Sahiwal'},
 '92404':{'en': 'Sahiwal'},
 '92405':{'en': 'Sahiwal'},
 '92406':{'en': 'Sahiwal'},
 '92407':{'en': 'Sahiwal'},
 '92408':{'en': 'Sahiwal'},
 '92409':{'en': 'Sahiwal'},
 '92412':{'en': 'Faisalabad'},
 '92413':{'en': 'Faisalabad'},
 '92414':{'en': 'Faisalabad'},
 '92415':{'en': 'Faisalabad'},
 '92416':{'en': 'Faisalabad'},
 '92417':{'en': 'Faisalabad'},
 '92418':{'en': 'Faisalabad'},
 '92419':{'en': 'Faisalabad'},
 '92422':{'en': 'Lahore'},
 '92423':{'en': 'Lahore'},
 '92424':{'en': 'Lahore'},
 '92425':{'en': 'Lahore'},
 '92426':{'en': 'Lahore'},
 '92427':{'en': 'Lahore'},
 '92428':{'en': 'Lahore'},
 '92429':{'en': 'Lahore'},
 '92442':{'en': 'Okara'},
 '92443':{'en': 'Okara'},
 '92444':{'en': 'Okara'},
 '92445':{'en': 'Okara'},
 '92446':{'en': 'Okara'},
 '92447':{'en': 'Okara'},
 '92448':{'en': 'Okara'},
 '92449':{'en': 'Okara'},
 '924532':{'en': 'Bhakkar'},
 '924533':{'en': 'Bhakkar'},
 '924534':{'en': 'Bhakkar'},
 '924535':{'en': 'Bhakkar'},
 '924536':{'en': 'Bhakkar'},
 '924537':{'en': 'Bhakkar'},
 '924538':{'en': 'Bhakkar'},
 '924539':{'en': 'Bhakkar'},
 '924542':{'en': 'Khushab'},
 '924543':{'en': 'Khushab'},
 '924544':{'en': 'Khushab'},
 '924545':{'en': 'Khushab'},
 '924546':{'en': 'Khushab'},
 '924547':{'en': 'Khushab'},
 '924548':{'en': 'Khushab'},
 '924549':{'en': 'Khushab'},
 '924572':{'en': 'Pakpattan'},
 '924573':{'en': 'Pakpattan'},
 '924574':{'en': 'Pakpattan'},
 '924575':{'en': 'Pakpattan'},
 '924576':{'en': 'Pakpattan'},
 '924577':{'en': 'Pakpattan'},
 '924578':{'en': 'Pakpattan'},
 '924579':{'en': 'Pakpattan'},
 '924592':{'en': 'Mianwali'},
 '924593':{'en': 'Mianwali'},
 '924594':{'en': 'Mianwali'},
 '924595':{'en': 'Mianwali'},
 '924596':{'en': 'Mianwali'},
 '924597':{'en': 'Mianwali'},
 '924598':{'en': 'Mianwali'},
 '924599':{'en': 'Mianwali'},
 '92462':{'en': 'Toba Tek Singh'},
 '92463':{'en': 'Toba Tek Singh'},
 '92464':{'en': 'Toba Tek Singh'},
 '92465':{'en': 'Toba Tek Singh'},
 '92466':{'en': 'Toba Tek Singh'},
 '92467':{'en': 'Toba Tek Singh'},
 '92468':{'en': 'Toba Tek Singh'},
 '92469':{'en': 'Toba Tek Singh'},
 '92472':{'en': 'Jhang'},
 '92473':{'en': 'Jhang'},
 '92474':{'en': 'Jhang'},
 '92475':{'en': 'Jhang'},
 '92476':{'en': 'Jhang'},
 '92477':{'en': 'Jhang'},
 '92478':{'en': 'Jhang'},
 '92479':{'en': 'Jhang'},
 '92482':{'en': 'Sargodha'},
 '92483':{'en': 'Sargodha'},
 '92484':{'en': 'Sargodha'},
 '92485':{'en': 'Sargodha'},
 '92486':{'en': 'Sargodha'},
 '92487':{'en': 'Sargodha'},
 '92488':{'en': 'Sargodha'},
 '92489':{'en': 'Sargodha'},
 '92492':{'en': 'Kasur'},
 '92493':{'en': 'Kasur'},
 '92494':{'en': 'Kasur'},
 '92495':{'en': 'Kasur'},
 '92496':{'en': 'Kasur'},
 '92497':{'en': 'Kasur'},
 '92498':{'en': 'Kasur'},
 '92499':{'en': 'Kasur'},
 '92512':{'en': 'Islamabad/Rawalpindi'},
 '92513':{'en': 'Islamabad/Rawalpindi'},
 '92514':{'en': 'Islamabad/Rawalpindi'},
 '92515':{'en': 'Islamabad/Rawalpindi'},
 '92516':{'en': 'Islamabad/Rawalpindi'},
 '92517':{'en': 'Islamabad/Rawalpindi'},
 '92518':{'en': 'Islamabad/Rawalpindi'},
 '92519':{'en': 'Islamabad/Rawalpindi'},
 '92522':{'en': 'Sialkot'},
 '92523':{'en': 'Sialkot'},
 '92524':{'en': 'Sialkot'},
 '92525':{'en': 'Sialkot'},
 '92526':{'en': 'Sialkot'},
 '92527':{'en': 'Sialkot'},
 '92528':{'en': 'Sialkot'},
 '92529':{'en': 'Sialkot'},
 '92532':{'en': 'Gujrat'},
 '92533':{'en': 'Gujrat'},
 '92534':{'en': 'Gujrat'},
 '92535':{'en': 'Gujrat'},
 '92536':{'en': 'Gujrat'},
 '92537':{'en': 'Gujrat'},
 '92538':{'en': 'Gujrat'},
 '92539':{'en': 'Gujrat'},
 '925422':{'en': 'Narowal'},
 '925423':{'en': 'Narowal'},
 '925424':{'en': 'Narowal'},
 '925425':{'en': 'Narowal'},
 '925426':{'en': 'Narowal'},
 '925427':{'en': 'Narowal'},
 '925428':{'en': 'Narowal'},
 '925429':{'en': 'Narowal'},
 '925432':{'en': 'Chakwal'},
 '925433':{'en': 'Chakwal'},
 '925434':{'en': 'Chakwal'},
 '925435':{'en': 'Chakwal'},
 '925436':{'en': 'Chakwal'},
 '925437':{'en': 'Chakwal'},
 '925438':{'en': 'Chakwal'},
 '925439':{'en': 'Chakwal'},
 '925442':{'en': 'Jhelum'},
 '925443':{'en': 'Jhelum'},
 '925444':{'en': 'Jhelum'},
 '925445':{'en': 'Jhelum'},
 '925446':{'en': 'Jhelum'},
 '925447':{'en': 'Jhelum'},
 '925448':{'en': 'Jhelum'},
 '925449':{'en': 'Jhelum'},
 '925462':{'en': 'Mandi Bahauddin'},
 '925463':{'en': 'Mandi Bahauddin'},
 '925464':{'en': 'Mandi Bahauddin'},
 '925465':{'en': 'Mandi Bahauddin'},
 '925466':{'en': 'Mandi Bahauddin'},
 '925467':{'en': 'Mandi Bahauddin'},
 '925468':{'en': 'Mandi Bahauddin'},
 '925469':{'en': 'Mandi Bahauddin'},
 '925472':{'en': 'Hafizabad'},
 '925473':{'en': 'Hafizabad'},
 '925474':{'en': 'Hafizabad'},
 '925475':{'en': 'Hafizabad'},
 '925476':{'en': 'Hafizabad'},
 '925477':{'en': 'Hafizabad'},
 '925478':{'en': 'Hafizabad'},
 '925479':{'en': 'Hafizabad'},
 '92552':{'en': 'Gujranwala'},
 '92553':{'en': 'Gujranwala'},
 '92554':{'en': 'Gujranwala'},
 '92555':{'en': 'Gujranwala'},
 '92556':{'en': 'Gujranwala'},
 '92557':{'en': 'Gujranwala'},
 '92558':{'en': 'Gujranwala'},
 '92559':{'en': 'Gujranwala'},
 '92562':{'en': 'Sheikhupura'},
 '92563':{'en': 'Sheikhupura'},
 '92564':{'en': 'Sheikhupura'},
 '92565':{'en': 'Sheikhupura'},
 '92566':{'en': 'Sheikhupura'},
 '92567':{'en': 'Sheikhupura'},
 '92568':{'en': 'Sheikhupura'},
 '92569':{'en': 'Sheikhupura'},
 '92572':{'en': 'Attock'},
 '92573':{'en': 'Attock'},
 '92574':{'en': 'Attock'},
 '92575':{'en': 'Attock'},
 '92576':{'en': 'Attock'},
 '92577':{'en': 'Attock'},
 '92578':{'en': 'Attock'},
 '92579':{'en': 'Attock'},
 '9258':{'en': 'AJK/FATA'},
 '926042':{'en': 'Rajanpur'},
 '926043':{'en': 'Rajanpur'},
 '926044':{'en': 'Rajanpur'},
 '926045':{'en': 'Rajanpur'},
 '926046':{'en': 'Rajanpur'},
 '926047':{'en': 'Rajanpur'},
 '926048':{'en': 'Rajanpur'},
 '926049':{'en': 'Rajanpur'},
 '926062':{'en': 'Layyah'},
 '926063':{'en': 'Layyah'},
 '926064':{'en': 'Layyah'},
 '926065':{'en': 'Layyah'},
 '926066':{'en': 'Layyah'},
 '926067':{'en': 'Layyah'},
 '926068':{'en': 'Layyah'},
 '926069':{'en': 'Layyah'},
 '926082':{'en': 'Lodhran'},
 '926083':{'en': 'Lodhran'},
 '926084':{'en': 'Lodhran'},
 '926085':{'en': 'Lodhran'},
 '926086':{'en': 'Lodhran'},
 '926087':{'en': 'Lodhran'},
 '926088':{'en': 'Lodhran'},
 '926089':{'en': 'Lodhran'},
 '92612':{'en': 'Multan'},
 '92613':{'en': 'Multan'},
 '92614':{'en': 'Multan'},
 '92615':{'en': 'Multan'},
 '92616':{'en': 'Multan'},
 '92617':{'en': 'Multan'},
 '92618':{'en': 'Multan'},
 '92619':{'en': 'Multan'},
 '92622':{'en': 'Bahawalpur'},
 '92623':{'en': 'Bahawalpur'},
 '92624':{'en': 'Bahawalpur'},
 '92625':{'en': 'Bahawalpur'},
 '92626':{'en': 'Bahawalpur'},
 '92627':{'en': 'Bahawalpur'},
 '92628':{'en': 'Bahawalpur'},
 '92629':{'en': 'Bahawalpur'},
 '92632':{'en': 'Bahawalnagar'},
 '92633':{'en': 'Bahawalnagar'},
 '92634':{'en': 'Bahawalnagar'},
 '92635':{'en': 'Bahawalnagar'},
 '92636':{'en': 'Bahawalnagar'},
 '92637':{'en': 'Bahawalnagar'},
 '92638':{'en': 'Bahawalnagar'},
 '92639':{'en': 'Bahawalnagar'},
 '92642':{'en': 'Dera Ghazi Khan'},
 '92643':{'en': 'Dera Ghazi Khan'},
 '92644':{'en': 'Dera Ghazi Khan'},
 '92645':{'en': 'Dera Ghazi Khan'},
 '92646':{'en': 'Dera Ghazi Khan'},
 '92647':{'en': 'Dera Ghazi Khan'},
 '92648':{'en': 'Dera Ghazi Khan'},
 '92649':{'en': 'Dera Ghazi Khan'},
 '92652':{'en': 'Khanewal'},
 '92653':{'en': 'Khanewal'},
 '92654':{'en': 'Khanewal'},
 '92655':{'en': 'Khanewal'},
 '92656':{'en': 'Khanewal'},
 '92657':{'en': 'Khanewal'},
 '92658':{'en': 'Khanewal'},
 '92659':{'en': 'Khanewal'},
 '92662':{'en': 'Muzaffargarh'},
 '92663':{'en': 'Muzaffargarh'},
 '92664':{'en': 'Muzaffargarh'},
 '92665':{'en': 'Muzaffargarh'},
 '92666':{'en': 'Muzaffargarh'},
 '92667':{'en': 'Muzaffargarh'},
 '92668':{'en': 'Muzaffargarh'},
 '92669':{'en': 'Muzaffargarh'},
 '92672':{'en': 'Vehari'},
 '92673':{'en': 'Vehari'},
 '92674':{'en': 'Vehari'},
 '92675':{'en': 'Vehari'},
 '92676':{'en': 'Vehari'},
 '92677':{'en': 'Vehari'},
 '92678':{'en': 'Vehari'},
 '92679':{'en': 'Vehari'},
 '92682':{'en': 'Rahim Yar Khan'},
 '92683':{'en': 'Rahim Yar Khan'},
 '92684':{'en': 'Rahim Yar Khan'},
 '92685':{'en': 'Rahim Yar Khan'},
 '92686':{'en': 'Rahim Yar Khan'},
 '92687':{'en': 'Rahim Yar Khan'},
 '92688':{'en': 'Rahim Yar Khan'},
 '92689':{'en': 'Rahim Yar Khan'},
 '92712':{'en': 'Sukkur'},
 '92713':{'en': 'Sukkur'},
 '92714':{'en': 'Sukkur'},
 '92715':{'en': 'Sukkur'},
 '92716':{'en': 'Sukkur'},
 '92717':{'en': 'Sukkur'},
 '92718':{'en': 'Sukkur'},
 '92719':{'en': 'Sukkur'},
 '927222':{'en': 'Jacobabad'},
 '927223':{'en': 'Jacobabad'},
 '927224':{'en': 'Jacobabad'},
 '927225':{'en': 'Jacobabad'},
 '927226':{'en': 'Jacobabad'},
 '927227':{'en': 'Jacobabad'},
 '927228':{'en': 'Jacobabad'},
 '927229':{'en': 'Jacobabad'},
 '927232':{'en': 'Ghotki'},
 '927233':{'en': 'Ghotki'},
 '927234':{'en': 'Ghotki'},
 '927235':{'en': 'Ghotki'},
 '927236':{'en': 'Ghotki'},
 '927237':{'en': 'Ghotki'},
 '927238':{'en': 'Ghotki'},
 '927239':{'en': 'Ghotki'},
 '927262':{'en': 'Shikarpur'},
 '927263':{'en': 'Shikarpur'},
 '927264':{'en': 'Shikarpur'},
 '927265':{'en': 'Shikarpur'},
 '927266':{'en': 'Shikarpur'},
 '927267':{'en': 'Shikarpur'},
 '927268':{'en': 'Shikarpur'},
 '927269':{'en': 'Shikarpur'},
 '92742':{'en': 'Larkana'},
 '92743':{'en': 'Larkana'},
 '92744':{'en': 'Larkana'},
 '92745':{'en': 'Larkana'},
 '92746':{'en': 'Larkana'},
 '92747':{'en': 'Larkana'},
 '92748':{'en': 'Larkana'},
 '92749':{'en': 'Larkana'},
 '92812':{'en': 'Quetta'},
 '92813':{'en': 'Quetta'},
 '92814':{'en': 'Quetta'},
 '92815':{'en': 'Quetta'},
 '92816':{'en': 'Quetta'},
 '92817':{'en': 'Quetta'},
 '92818':{'en': 'Quetta'},
 '92819':{'en': 'Quetta'},
 '928222':{'en': 'Zhob'},
 '928223':{'en': 'Zhob'},
 '928224':{'en': 'Zhob'},
 '928225':{'en': 'Zhob'},
 '928226':{'en': 'Zhob'},
 '928227':{'en': 'Zhob'},
 '928228':{'en': 'Zhob'},
 '928229':{'en': 'Zhob'},
 '928232':{'en': 'Killa Saifullah'},
 '928233':{'en': 'Killa Saifullah'},
 '928234':{'en': 'Killa Saifullah'},
 '928235':{'en': 'Killa Saifullah'},
 '928236':{'en': 'Killa Saifullah'},
 '928237':{'en': 'Killa Saifullah'},
 '928238':{'en': 'Killa Saifullah'},
 '928239':{'en': 'Killa Saifullah'},
 '928242':{'en': 'Loralai'},
 '928243':{'en': 'Loralai'},
 '928244':{'en': 'Loralai'},
 '928245':{'en': 'Loralai'},
 '928246':{'en': 'Loralai'},
 '928247':{'en': 'Loralai'},
 '928248':{'en': 'Loralai'},
 '928249':{'en': 'Loralai'},
 '928252':{'en': 'Chagai'},
 '928253':{'en': 'Chagai'},
 '928254':{'en': 'Chagai'},
 '928255':{'en': 'Chagai'},
 '928256':{'en': 'Chagai'},
 '928257':{'en': 'Chagai'},
 '928258':{'en': 'Chagai'},
 '928259':{'en': 'Chagai'},
 '928262':{'en': 'K.Abdullah/Pishin'},
 '928263':{'en': 'K.Abdullah/Pishin'},
 '928264':{'en': 'K.Abdullah/Pishin'},
 '928265':{'en': 'K.Abdullah/Pishin'},
 '928266':{'en': 'K.Abdullah/Pishin'},
 '928267':{'en': 'K.Abdullah/Pishin'},
 '928268':{'en': 'K.Abdullah/Pishin'},
 '928269':{'en': 'K.Abdullah/Pishin'},
 '928282':{'en': 'Musakhel'},
 '928283':{'en': 'Musakhel'},
 '928284':{'en': 'Musakhel'},
 '928285':{'en': 'Musakhel'},
 '928286':{'en': 'Musakhel'},
 '928287':{'en': 'Musakhel'},
 '928288':{'en': 'Musakhel'},
 '928289':{'en': 'Musakhel'},
 '928292':{'en': 'Barkhan/Kohlu'},
 '928293':{'en': 'Barkhan/Kohlu'},
 '928294':{'en': 'Barkhan/Kohlu'},
 '928295':{'en': 'Barkhan/Kohlu'},
 '928296':{'en': 'Barkhan/Kohlu'},
 '928297':{'en': 'Barkhan/Kohlu'},
 '928298':{'en': 'Barkhan/Kohlu'},
 '928299':{'en': 'Barkhan/Kohlu'},
 '928322':{'en': 'Bolan'},
 '928323':{'en': 'Bolan'},
 '928324':{'en': 'Bolan'},
 '928325':{'en': 'Bolan'},
 '928326':{'en': 'Bolan'},
 '928327':{'en': 'Bolan'},
 '928328':{'en': 'Bolan'},
 '928329':{'en': 'Bolan'},
 '928332':{'en': 'Sibi/Ziarat'},
 '928333':{'en': 'Sibi/Ziarat'},
 '928334':{'en': 'Sibi/Ziarat'},
 '928335':{'en': 'Sibi/Ziarat'},
 '928336':{'en': 'Sibi/Ziarat'},
 '928337':{'en': 'Sibi/Ziarat'},
 '928338':{'en': 'Sibi/Ziarat'},
 '928339':{'en': 'Sibi/Ziarat'},
 '928352':{'en': 'Dera Bugti'},
 '928353':{'en': 'Dera Bugti'},
 '928354':{'en': 'Dera Bugti'},
 '928355':{'en': 'Dera Bugti'},
 '928356':{'en': 'Dera Bugti'},
 '928357':{'en': 'Dera Bugti'},
 '928358':{'en': 'Dera Bugti'},
 '928359':{'en': 'Dera Bugti'},
 '928372':{'en': 'Jhal Magsi'},
 '928373':{'en': 'Jhal Magsi'},
 '928374':{'en': 'Jhal Magsi'},
 '928375':{'en': 'Jhal Magsi'},
 '928376':{'en': 'Jhal Magsi'},
 '928377':{'en': 'Jhal Magsi'},
 '928378':{'en': 'Jhal Magsi'},
 '928379':{'en': 'Jhal Magsi'},
 '928382':{'en': 'Jaffarabad/Nasirabad'},
 '928383':{'en': 'Jaffarabad/Nasirabad'},
 '928384':{'en': 'Jaffarabad/Nasirabad'},
 '928385':{'en': 'Jaffarabad/Nasirabad'},
 '928386':{'en': 'Jaffarabad/Nasirabad'},
 '928387':{'en': 'Jaffarabad/Nasirabad'},
 '928388':{'en': 'Jaffarabad/Nasirabad'},
 '928389':{'en': 'Jaffarabad/Nasirabad'},
 '928432':{'en': 'Mastung'},
 '928433':{'en': 'Mastung'},
 '928434':{'en': 'Mastung'},
 '928435':{'en': 'Mastung'},
 '928436':{'en': 'Mastung'},
 '928437':{'en': 'Mastung'},
 '928438':{'en': 'Mastung'},
 '928439':{'en': 'Mastung'},
 '928442':{'en': 'Kalat'},
 '928443':{'en': 'Kalat'},
 '928444':{'en': 'Kalat'},
 '928445':{'en': 'Kalat'},
 '928446':{'en': 'Kalat'},
 '928447':{'en': 'Kalat'},
 '928448':{'en': 'Kalat'},
 '928449':{'en': 'Kalat'},
 '928472':{'en': 'Kharan'},
 '928473':{'en': 'Kharan'},
 '928474':{'en': 'Kharan'},
 '928475':{'en': 'Kharan'},
 '928476':{'en': 'Kharan'},
 '928477':{'en': 'Kharan'},
 '928478':{'en': 'Kharan'},
 '928479':{'en': 'Kharan'},
 '928482':{'en': 'Khuzdar'},
 '928483':{'en': 'Khuzdar'},
 '928484':{'en': 'Khuzdar'},
 '928485':{'en': 'Khuzdar'},
 '928486':{'en': 'Khuzdar'},
 '928487':{'en': 'Khuzdar'},
 '928488':{'en': 'Khuzdar'},
 '928489':{'en': 'Khuzdar'},
 '928522':{'en': 'Kech'},
 '928523':{'en': 'Kech'},
 '928524':{'en': 'Kech'},
 '928525':{'en': 'Kech'},
 '928526':{'en': 'Kech'},
 '928527':{'en': 'Kech'},
 '928528':{'en': 'Kech'},
 '928529':{'en': 'Kech'},
 '928532':{'en': 'Lasbela'},
 '928533':{'en': 'Lasbela'},
 '928534':{'en': 'Lasbela'},
 '928535':{'en': 'Lasbela'},
 '928536':{'en': 'Lasbela'},
 '928537':{'en': 'Lasbela'},
 '928538':{'en': 'Lasbela'},
 '928539':{'en': 'Lasbela'},
 '928552':{'en': 'Panjgur'},
 '928553':{'en': 'Panjgur'},
 '928554':{'en': 'Panjgur'},
 '928555':{'en': 'Panjgur'},
 '928556':{'en': 'Panjgur'},
 '928557':{'en': 'Panjgur'},
 '928558':{'en': 'Panjgur'},
 '928559':{'en': 'Panjgur'},
 '928562':{'en': 'Awaran'},
 '928563':{'en': 'Awaran'},
 '928564':{'en': 'Awaran'},
 '928565':{'en': 'Awaran'},
 '928566':{'en': 'Awaran'},
 '928567':{'en': 'Awaran'},
 '928568':{'en': 'Awaran'},
 '928569':{'en': 'Awaran'},
 '92862':{'en': 'Gwadar'},
 '92863':{'en': 'Gwadar'},
 '92864':{'en': 'Gwadar'},
 '92865':{'en': 'Gwadar'},
 '92866':{'en': 'Gwadar'},
 '92867':{'en': 'Gwadar'},
 '92868':{'en': 'Gwadar'},
 '92869':{'en': 'Gwadar'},
 '92912':{'en': 'Peshawar/Charsadda'},
 '92913':{'en': 'Peshawar/Charsadda'},
 '92914':{'en': 'Peshawar/Charsadda'},
 '92915':{'en': 'Peshawar/Charsadda'},
 '92916':{'en': 'Peshawar/Charsadda'},
 '92917':{'en': 'Peshawar/Charsadda'},
 '92918':{'en': 'Peshawar/Charsadda'},
 '92919':{'en': 'Peshawar/Charsadda'},
 '929222':{'en': 'Kohat'},
 '929223':{'en': 'Kohat'},
 '929224':{'en': 'Kohat'},
 '929225':{'en': 'Kohat'},
 '929226':{'en': 'Kohat'},
 '929227':{'en': 'Kohat'},
 '929228':{'en': 'Kohat'},
 '929229':{'en': 'Kohat'},
 '92923':{'en': 'Nowshera'},
 '92924':{'en': 'Khyber/Mohmand Agy'},
 '92925':{'en': 'Hangu/Orakzai Agy'},
 '92926':{'en': 'Kurram Agency'},
 '92927':{'en': 'Karak'},
 '92928':{'en': 'Bannu/N. Waziristan'},
 '929322':{'en': 'Malakand'},
 '929323':{'en': 'Malakand'},
 '929324':{'en': 'Malakand'},
 '929325':{'en': 'Malakand'},
 '929326':{'en': 'Malakand'},
 '929327':{'en': 'Malakand'},
 '929328':{'en': 'Malakand'},
 '929329':{'en': 'Malakand'},
 '929372':{'en': 'Mardan'},
 '929373':{'en': 'Mardan'},
 '929374':{'en': 'Mardan'},
 '929375':{'en': 'Mardan'},
 '929376':{'en': 'Mardan'},
 '929377':{'en': 'Mardan'},
 '929378':{'en': 'Mardan'},
 '929379':{'en': 'Mardan'},
 '929382':{'en': 'Swabi'},
 '929383':{'en': 'Swabi'},
 '929384':{'en': 'Swabi'},
 '929385':{'en': 'Swabi'},
 '929386':{'en': 'Swabi'},
 '929387':{'en': 'Swabi'},
 '929388':{'en': 'Swabi'},
 '929389':{'en': 'Swabi'},
 '929392':{'en': 'Buner'},
 '929393':{'en': 'Buner'},
 '929394':{'en': 'Buner'},
 '929395':{'en': 'Buner'},
 '929396':{'en': 'Buner'},
 '929397':{'en': 'Buner'},
 '929398':{'en': 'Buner'},
 '929399':{'en': 'Buner'},
 '929422':{'en': 'Bajaur Agency'},
 '929423':{'en': 'Bajaur Agency'},
 '929424':{'en': 'Bajaur Agency'},
 '929425':{'en': 'Bajaur Agency'},
 '929426':{'en': 'Bajaur Agency'},
 '929427':{'en': 'Bajaur Agency'},
 '929428':{'en': 'Bajaur Agency'},
 '929429':{'en': 'Bajaur Agency'},
 '929432':{'en': 'Chitral'},
 '929433':{'en': 'Chitral'},
 '929434':{'en': 'Chitral'},
 '929435':{'en': 'Chitral'},
 '929436':{'en': 'Chitral'},
 '929437':{'en': 'Chitral'},
 '929438':{'en': 'Chitral'},
 '929439':{'en': 'Chitral'},
 '929442':{'en': 'Upper Dir'},
 '929443':{'en': 'Upper Dir'},
 '929444':{'en': 'Upper Dir'},
 '929445':{'en': 'Upper Dir'},
 '929446':{'en': 'Upper Dir'},
 '929447':{'en': 'Upper Dir'},
 '929448':{'en': 'Upper Dir'},
 '929449':{'en': 'Upper Dir'},
 '929452':{'en': 'Lower Dir'},
 '929453':{'en': 'Lower Dir'},
 '929454':{'en': 'Lower Dir'},
 '929455':{'en': 'Lower Dir'},
 '929456':{'en': 'Lower Dir'},
 '929457':{'en': 'Lower Dir'},
 '929458':{'en': 'Lower Dir'},
 '929459':{'en': 'Lower Dir'},
 '929462':{'en': 'Swat'},
 '929463':{'en': 'Swat'},
 '929464':{'en': 'Swat'},
 '929465':{'en': 'Swat'},
 '929466':{'en': 'Swat'},
 '929467':{'en': 'Swat'},
 '929468':{'en': 'Swat'},
 '929469':{'en': 'Swat'},
 '929632':{'en': 'Tank'},
 '929633':{'en': 'Tank'},
 '929634':{'en': 'Tank'},
 '929635':{'en': 'Tank'},
 '929636':{'en': 'Tank'},
 '929637':{'en': 'Tank'},
 '929638':{'en': 'Tank'},
 '929639':{'en': 'Tank'},
 '929652':{'en': 'South Waziristan'},
 '929653':{'en': 'South Waziristan'},
 '929654':{'en': 'South Waziristan'},
 '929655':{'en': 'South Waziristan'},
 '929656':{'en': 'South Waziristan'},
 '929657':{'en': 'South Waziristan'},
 '929658':{'en': 'South Waziristan'},
 '929659':{'en': 'South Waziristan'},
 '929662':{'en': 'D.I. Khan'},
 '929663':{'en': 'D.I. Khan'},
 '929664':{'en': 'D.I. Khan'},
 '929665':{'en': 'D.I. Khan'},
 '929666':{'en': 'D.I. Khan'},
 '929667':{'en': 'D.I. Khan'},
 '929668':{'en': 'D.I. Khan'},
 '929669':{'en': 'D.I. Khan'},
 '929692':{'en': 'Lakki Marwat'},
 '929693':{'en': 'Lakki Marwat'},
 '929694':{'en': 'Lakki Marwat'},
 '929695':{'en': 'Lakki Marwat'},
 '929696':{'en': 'Lakki Marwat'},
 '929697':{'en': 'Lakki Marwat'},
 '929698':{'en': 'Lakki Marwat'},
 '929699':{'en': 'Lakki Marwat'},
 '929922':{'en': 'Abottabad'},
 '929923':{'en': 'Abottabad'},
 '929924':{'en': 'Abottabad'},
 '929925':{'en': 'Abottabad'},
 '929926':{'en': 'Abottabad'},
 '929927':{'en': 'Abottabad'},
 '929928':{'en': 'Abottabad'},
 '929929':{'en': 'Abottabad'},
 '929952':{'en': 'Haripur'},
 '929953':{'en': 'Haripur'},
 '929954':{'en': 'Haripur'},
 '929955':{'en': 'Haripur'},
 '929956':{'en': 'Haripur'},
 '929957':{'en': 'Haripur'},
 '929958':{'en': 'Haripur'},
 '929959':{'en': 'Haripur'},
 '929962':{'en': 'Shangla'},
 '929963':{'en': 'Shangla'},
 '929964':{'en': 'Shangla'},
 '929965':{'en': 'Shangla'},
 '929966':{'en': 'Shangla'},
 '929967':{'en': 'Shangla'},
 '929968':{'en': 'Shangla'},
 '929969':{'en': 'Shangla'},
 '929972':{'en': 'Mansehra/Batagram'},
 '929973':{'en': 'Mansehra/Batagram'},
 '929974':{'en': 'Mansehra/Batagram'},
 '929975':{'en': 'Mansehra/Batagram'},
 '929976':{'en': 'Mansehra/Batagram'},
 '929977':{'en': 'Mansehra/Batagram'},
 '929978':{'en': 'Mansehra/Batagram'},
 '929979':{'en': 'Mansehra/Batagram'},
 '92998':{'en': 'Kohistan'},
 '9320':{'en': 'Kabul', 'fa': u('\u06a9\u0627\u0628\u0644')},
 '9321':{'en': 'Parwan', 'fa': u('\u067e\u0631\u0648\u0627\u0646')},
 '9322':{'en': 'Kapisa', 'fa': u('\u06a9\u0627\u067e\u06cc\u0633\u0627')},
 '9323':{'en': 'Bamian', 'fa': u('\u0628\u0627\u0645\u06cc\u0627\u0646')},
 '9324':{'en': 'Wardak', 'fa': u('\u0648\u0631\u062f\u06a9')},
 '9325':{'en': 'Logar', 'fa': u('\u0644\u0648\u06af\u0631')},
 '9326':{'en': 'Dorkondi', 'fa': u('\u062f\u0627\u06cc\u06a9\u0646\u062f\u06cc')},
 '9327':{'en': 'Khost', 'fa': u('\u062e\u0648\u0633\u062a')},
 '9328':{'en': 'Panjshar', 'fa': u('\u067e\u0646\u062c\u0634\u06cc\u0631')},
 '9330':{'en': 'Kandahar', 'fa': u('\u0642\u0646\u062f\u0647\u0627\u0631')},
 '9331':{'en': 'Ghazni', 'fa': u('\u063a\u0632\u0646\u06cc')},
 '9332':{'en': 'Uruzgan', 'fa': u('\u0627\u0631\u0632\u06af\u0627\u0646')},
 '9333':{'en': 'Zabol', 'fa': u('\u0632\u0627\u0628\u0644')},
 '9334':{'en': 'Helmand', 'fa': u('\u0647\u0644\u0645\u0646\u062f')},
 '9340':{'en': 'Heart', 'fa': u('\u0647\u0631\u0627\u062a')},
 '9341':{'en': 'Badghis', 'fa': u('\u0628\u0627\u062f\u063a\u06cc\u0633')},
 '9342':{'en': 'Ghowr', 'fa': u('\u063a\u0648\u0631')},
 '9343':{'en': 'Farah', 'fa': u('\u0641\u0631\u0627\u0647')},
 '9344':{'en': 'Nimruz', 'fa': u('\u0646\u06cc\u0645\u0631\u0648\u0632')},
 '9350':{'en': 'Balkh', 'fa': u('\u0628\u0644\u062e')},
 '9351':{'en': 'Kunduz', 'fa': u('\u0642\u0646\u062f\u0648\u0632')},
 '9352':{'en': 'Badkhshan', 'fa': u('\u0628\u062f\u062e\u0634\u0627\u0646')},
 '9353':{'en': 'Takhar', 'fa': u('\u062a\u062e\u0627\u0631')},
 '9354':{'en': 'Jowzjan', 'fa': u('\u062c\u0648\u0632\u062c\u0627\u0646')},
 '9355':{'en': 'Samangan', 'fa': u('\u0633\u0645\u0646\u06af\u0627\u0646')},
 '9356':{'en': 'Sar-E Pol', 'fa': u('\u0633\u0631 \u067e\u0644')},
 '9357':{'en': 'Faryab', 'fa': u('\u0641\u0627\u0631\u06cc\u0627\u0628')},
 '9358':{'en': 'Baghlan', 'fa': u('\u0628\u063a\u0644\u0627\u0646')},
 '9360':{'en': 'Nangarhar', 'fa': u('\u0646\u0646\u06af\u0631\u0647\u0627\u0631')},
 '9361':{'en': 'Nurestan', 'fa': u('\u0646\u0648\u0631\u0633\u062a\u0627\u0646')},
 '9362':{'en': 'Kunarha', 'fa': u('\u06a9\u0646\u0631\u0647\u0627')},
 '9363':{'en': 'Laghman', 'fa': u('\u0644\u063a\u0645\u0627\u0646')},
 '9364':{'en': 'Paktia', 'fa': u('\u067e\u06a9\u062a\u06cc\u0627')},
 '9365':{'en': 'Paktika', 'fa': u('\u067e\u06a9\u062a\u06cc\u06a9\u0627')},
 '9411':{'en': 'Colombo'},
 '9421':{'en': 'Jaffna'},
 '9423':{'en': 'Mannar'},
 '9424':{'en': 'Vavuniya'},
 '9425':{'en': 'Anuradhapura'},
 '9426':{'en': 'Trincomalee'},
 '9427':{'en': 'Polonnaruwa'},
 '9431':{'en': 'Negombo, Gampaha'},
 '9432':{'en': 'Chilaw, Puttalam'},
 '9433':{'en': 'Gampaha'},
 '9434':{'en': 'Kalutara'},
 '9435':{'en': 'Kegalle'},
 '9436':{'en': 'Avissawella, Colombo'},
 '9437':{'en': 'Kurunegala'},
 '9438':{'en': 'Panadura, Kalutara'},
 '9441':{'en': 'Matara'},
 '9445':{'en': 'Ratnapura'},
 '9447':{'en': 'Hambantota'},
 '9451':{'en': 'Hatton, Nuwara Eliya'},
 '9452':{'en': 'Nuwara Eliya'},
 '9454':{'en': 'Nawalapitiya, Kandy'},
 '9455':{'en': 'Badulla'},
 '9457':{'en': 'Bandarawela, Badulla'},
 '9463':{'en': 'Ampara'},
 '9465':{'en': 'Batticaloa'},
 '9466':{'en': 'Matale'},
 '9467':{'en': 'Kalmunai, Ampara'},
 '9482':{'en': 'Kandy'},
 '9491':{'en': 'Galle'},
 '9511':{'en': 'Yangon'},
 '951422':{'en': 'Yangon'},
 '951423':{'en': 'Yangon'},
 '951424':{'en': 'Yangon'},
 '951426':{'en': 'Yangon'},
 '951429':{'en': 'Yangon'},
 '951439':{'en': 'Yangon'},
 '951462':{'en': 'Yangon'},
 '951465':{'en': 'Yangon'},
 '951470':{'en': 'Yangon'},
 '951471':{'en': 'Yangon'},
 '951472':{'en': 'Yangon'},
 '951483':{'en': 'Yangon'},
 '951550':{'en': 'Bahan'},
 '951551':{'en': 'Bahan'},
 '951552':{'en': 'Bahan'},
 '951553':{'en': 'Bahan'},
 '951680':{'en': 'Bayintnaung'},
 '951681':{'en': 'Bayintnaung'},
 '951682':{'en': 'Bayintnaung'},
 '951683':{'en': 'Bayintnaung'},
 '951684':{'en': 'Bayintnaung'},
 '951685':{'en': 'Bayintnaung'},
 '951686':{'en': 'Bayintnaung'},
 '951687':{'en': 'Bayintnaung'},
 '951688':{'en': 'Bayintnaung'},
 '9522000':{'en': 'Mingalar Mandalay'},
 '952422':{'en': 'Mandalay'},
 '952424':{'en': 'Mandalay'},
 '952426':{'en': 'Mandalay'},
 '952439':{'en': 'Mandalay'},
 '952462':{'en': 'Mandalay'},
 '952470':{'en': 'Yangon'},
 '952471':{'en': 'Mandalay'},
 '952472':{'en': 'Mandalay'},
 '952483':{'en': 'Mandalay'},
 '95256':{'en': 'Amarapura'},
 '9542480':{'en': 'Pathein'},
 '9542481':{'en': 'Pathein'},
 '9542483':{'en': 'Ayeyarwaddy/Pathein'},
 '9543202':{'en': 'Rakhine'},
 '9543470':{'en': 'Sittwe'},
 '9543483':{'en': 'Sittwe/Thandwe'},
 '954353':{'en': 'Buthidaung'},
 '9543565':{'en': 'Palatwa'},
 '9545470':{'en': 'Pyapon'},
 '95522221':{'en': 'Bago'},
 '95522222':{'en': 'Bago'},
 '95522223':{'en': 'Bago'},
 '95522224':{'en': 'Bago'},
 '95522230':{'en': 'Oathar Myothit'},
 '9552470':{'en': 'Bago'},
 '9552472':{'en': 'Bago'},
 '9553472':{'en': 'Pyay'},
 '9554470':{'en': 'Taungoo'},
 '955620':{'en': 'Mandalay'},
 '955645':{'en': 'Tandar'},
 '9556483':{'en': 'Thanlyin'},
 '9557480':{'en': 'Mawlamyine/Thanbyuzayat'},
 '9557481':{'en': 'Mawlamyine'},
 '9558470':{'en': 'Hpa-An'},
 '9558472':{'en': 'Hpa-An'},
 '955851':{'en': 'Myawaddy'},
 '9559470':{'en': 'Dawei'},
 '9561200':{'en': 'Chauk'},
 '956124620':{'en': 'Chauk'},
 '956124621':{'en': 'Chauk'},
 '956124622':{'en': 'Chauk'},
 '956124623':{'en': 'Chauk'},
 '956124624':{'en': 'Chauk'},
 '956124640':{'en': 'Bagan'},
 '956124641':{'en': 'Bagan'},
 '956124642':{'en': 'Bagan'},
 '956124643':{'en': 'Bagan'},
 '956124644':{'en': 'Bagan'},
 '9562472':{'en': 'Pakokku'},
 '956260':{'en': 'Kanma'},
 '956320':{'en': 'Magway'},
 '956323':{'en': 'Magway'},
 '956324':{'en': 'Magway'},
 '9563470':{'en': 'Magway'},
 '95642487':{'en': 'Shawpin'},
 '9564472':{'en': 'Meiktila'},
 '956525':{'en': 'Ngape'},
 '9567460':{'en': 'Naypyitaw'},
 '9567470':{'en': 'Naypyitaw'},
 '9567550':{'en': 'Naypyidaw'},
 '9569200':{'en': 'Aunglan'},
 '956940':{'en': 'Sinpaungwae'},
 '9570470':{'en': 'Hakha'},
 '95712032':{'en': 'Ohbotaung'},
 '9571470':{'en': 'Monywa'},
 '9571483':{'en': 'Monywa'},
 '9574470':{'en': 'Myitkyinar/Bahmaw'},
 '9575470':{'en': 'Shwebo'},
 '95812820':{'en': 'Moenae'},
 '95812821':{'en': 'Moenae'},
 '95812822':{'en': 'Moenae'},
 '95812823':{'en': 'Moenae'},
 '95812824':{'en': 'Moenae'},
 '958130':{'en': 'Pinlon'},
 '958131':{'en': 'Loilem'},
 '958141':{'en': 'Naungtayar'},
 '9581470':{'en': 'Taunggyi'},
 '9581471':{'en': 'Shan (South)'},
 '958149':{'en': 'Sesin'},
 '9582320':{'en': 'Manton'},
 '958238':{'en': 'Tantyan'},
 '9582490':{'en': 'Shan (North)'},
 '9583470':{'en': 'Loikaw'},
 '958521':{'en': 'Pyinoolwin'},
 '958522':{'en': 'Pyinoolwin'},
 '958523':{'en': 'Pyinoolwin'},
 '958528':{'en': 'Pyinoolwin'},
 '958529':{'en': 'Padaythar Myothit'},
 '958540':{'en': 'Ohn Chaw'},
 '958541':{'en': 'Pyinoolwin'},
 '958542':{'en': 'Pyinoolwin'},
 '958543':{'en': 'Pyinoolwin'},
 '9585440':{'en': 'Pyinoolwin'},
 '9585441':{'en': 'Pyinoolwin'},
 '9585442':{'en': 'Pyinoolwin'},
 '9585443':{'en': 'Pyinoolwin'},
 '9585444':{'en': 'Pyinoolwin'},
 '9585445':{'en': 'Pyinoolwin'},
 '9585447':{'en': 'Pyinoolwin'},
 '9585448':{'en': 'Pyinoolwin'},
 '9585449':{'en': 'Pyinoolwin'},
 '958545':{'en': 'Pyinoolwin'},
 '958546':{'en': 'Pyinoolwin'},
 '958547':{'en': 'Pyinoolwin'},
 '958548':{'en': 'Pyinoolwin'},
 '958549':{'en': 'Pyinoolwin'},
 '958551':{'en': 'Yangon'},
 '958620':{'en': 'Mogoke'},
 '958621':{'en': 'Mogoke'},
 '958625':{'en': 'Kyatpyin'},
 '958630':{'en': 'Thabeikkyin'},
 '958635':{'en': 'Sintkuu'},
 '958639':{'en': 'Letpanhla'},
 '960300':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960301':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960302':{'en': u('Mal\u00e9 Region')},
 '960303':{'en': u('Mal\u00e9 Region')},
 '960304':{'en': u('Mal\u00e9 Region')},
 '960330':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960331':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960332':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960333':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960334':{'en': u('Mal\u00e9/Hulhul\u00e9/Aarah')},
 '960335':{'en': u('Hulhumal\u00e9')},
 '960339':{'en': u('Vilimal\u00e9')},
 '960650':{'en': 'Haa Alifu'},
 '960652':{'en': 'Haa Dhaalu'},
 '960654':{'en': 'Shaviyani'},
 '960656':{'en': 'Noonu'},
 '960658':{'en': 'Raa'},
 '960659':{'en': 'Raa'},
 '960660':{'en': 'Baa'},
 '960662':{'en': 'Lhaviyani'},
 '960664':{'en': 'Kaafu'},
 '960665':{'en': 'Kaafu'},
 '960666':{'en': 'Alifu Alifu'},
 '960668':{'en': 'Alifu Dhaalu'},
 '960670':{'en': 'Vaavu'},
 '960672':{'en': 'Meemu'},
 '960674':{'en': 'Faafu'},
 '960676':{'en': 'Dhaalu'},
 '960678':{'en': 'Thaa'},
 '960680':{'en': 'Laamu'},
 '960682':{'en': 'Gaafu Alifu'},
 '960684':{'en': 'Gaafu Dhaalu'},
 '960686':{'en': 'Gnaviyani'},
 '960688':{'en': 'Addu'},
 '960689':{'en': 'Addu'},
 '96121':{'en': 'Beirut'},
 '96124':{'en': 'Metn'},
 '96125':{'en': 'Chouf'},
 '96126':{'en': 'North Lebanon'},
 '96127':{'en': 'South Lebanon'},
 '96128':{'en': 'Bekaa'},
 '96129':{'en': 'Jbeil & Keserwan'},
 '962262':{'en': 'Mafraq'},
 '962263':{'en': 'Jarash'},
 '962264':{'en': 'Ajloun'},
 '962265':{'en': 'Irbid'},
 '962266':{'en': 'Mafraq'},
 '962267':{'en': 'Jarash'},
 '962268':{'en': 'Ajloun'},
 '962269':{'en': 'Irbid'},
 '96227':{'en': 'Irbid'},
 '962320':{'en': 'Aqaba'},
 '962321':{'en': u('Ma\u2019an')},
 '962322':{'en': 'Tafileh'},
 '962323':{'en': 'Karak'},
 '962324':{'en': 'Aqaba'},
 '962325':{'en': 'Maan'},
 '9623260':{'en': 'Tafileh'},
 '9623262':{'en': 'Southern Region'},
 '962327':{'en': 'Karak'},
 '962530':{'en': 'Zarqa'},
 '962531':{'en': 'Madaba'},
 '962532':{'en': 'Madaba'},
 '962533':{'en': 'Balqa'},
 '962534':{'en': 'Balqa'},
 '962535':{'en': 'Balqa'},
 '962536':{'en': 'Zarqa'},
 '962537':{'en': 'Zarqa'},
 '962538':{'en': 'Zarqa'},
 '962539':{'en': 'Zarqa'},
 '962620':{'en': 'Amman'},
 '962622':{'en': 'Greater Amman'},
 '962625':{'en': 'Amman'},
 '96263':{'en': 'Amman'},
 '96264':{'en': 'Amman'},
 '962647':{'en': 'Greater Amman'},
 '96265':{'en': 'Amman'},
 '96311':{'en': 'Damascus and rural areas'},
 '96312':{'en': 'Al-Nebek'},
 '96313':{'en': 'Al-Zabadani'},
 '96314':{'en': 'Al-Quneitra'},
 '96315':{'en': 'Dara'},
 '96316':{'en': 'Al-Swedaa'},
 '96321':{'en': 'Aleppo'},
 '96322':{'en': 'Al-Rakkah'},
 '96323':{'en': 'Edleb'},
 '96325':{'en': 'Menbej'},
 '96331':{'en': 'Homs'},
 '96333':{'en': 'Hamah'},
 '96334':{'en': 'Palmyra'},
 '96341':{'en': 'Lattakia'},
 '96343':{'en': 'Tartous'},
 '96344':{'en': 'Hamah'},
 '96351':{'en': 'Deir Ezzour'},
 '96352':{'en': 'Alhasakah'},
 '96353':{'en': 'Al-Kameshli'},
 '96611':{'ar': u('\u0627\u0644\u0631\u064a\u0627\u0636/\u0627\u0644\u062e\u0631\u062c'), 'en': 'Riyadh/Kharj'},
 '96612':{'ar': u('\u0645\u0643\u0629/\u062c\u062f\u0629'), 'en': 'Makkah/Jeddah'},
 '96613':{'ar': u('\u0627\u0644\u062f\u0645\u0627\u0645/\u0627\u0644\u062e\u0628\u0631/\u0627\u0644\u0638\u0647\u0631\u0627\u0646'), 'en': 'Dammam/Khobar/Dahran'},
 '96614':{'ar': u('\u0627\u0644\u0645\u062f\u064a\u0646\u0629 \u0627\u0644\u0645\u0646\u0648\u0631\u0629/\u0639\u0631\u0639\u0631/\u062a\u0628\u0648\u0643/\u064a\u0646\u0628\u0639 \u0627\u0644\u0628\u062d\u0631'), 'en': 'Madenah/Arar/Tabuk/Yanbu'},
 '96616':{'ar': u('\u062d\u0627\u0626\u0644/\u0627\u0644\u0642\u0635\u064a\u0645'), 'en': 'Hail/Qasim'},
 '96617':{'ar': u('\u0623\u0628\u0647\u0627/\u0646\u062c\u0631\u0627\u0646/\u062c\u0627\u0632\u0627\u0646'), 'en': 'Abha/Najran/Jezan'},
 '9671':{'en': 'Sanaa'},
 '96722':{'en': 'Aden'},
 '96723':{'en': 'Aden'},
 '96724':{'en': 'Dhalea'},
 '96725':{'en': 'Lahj'},
 '96726':{'en': 'Abyan'},
 '967280':{'en': 'Aden'},
 '967281':{'en': 'Aden'},
 '967282':{'en': 'Aden'},
 '967283':{'en': 'Aden'},
 '967284':{'en': 'Dhalea'},
 '9672840':{'en': 'Aden'},
 '967285':{'en': 'Lahj'},
 '967286':{'en': 'Abyan'},
 '9673':{'en': 'Hodaidah'},
 '96742':{'en': 'Taiz'},
 '96743':{'en': 'Taiz'},
 '967433':{'en': 'Ibb'},
 '96744':{'en': 'Ibb'},
 '96745':{'en': 'Ibb'},
 '967483':{'en': 'Taiz'},
 '967484':{'en': 'Ibb'},
 '9674840':{'en': 'Taiz'},
 '9674841':{'en': 'Taiz'},
 '9674842':{'en': 'Taiz'},
 '9674843':{'en': 'Taiz'},
 '967485':{'en': 'Ibb'},
 '96752':{'en': 'Shabwah'},
 '96753':{'en': 'Hadhrmout'},
 '96754':{'en': 'Hadhrmout'},
 '96755':{'en': 'Hadhrmout'},
 '967566':{'en': 'Soqatrah'},
 '967630':{'en': 'Maareb'},
 '967633':{'en': 'Maareb'},
 '967634':{'en': 'Aljawf'},
 '967636':{'en': 'Maareb'},
 '967638':{'en': 'Maareb'},
 '967639':{'en': 'Dhamar'},
 '96764':{'en': 'Dhamar'},
 '967650':{'en': 'Dhamar'},
 '967651':{'en': 'Dhamar'},
 '967652':{'en': 'Al Baidha'},
 '967653':{'en': 'Al Baidha'},
 '967654':{'en': 'Al Baidha'},
 '967655':{'en': 'Al Baidha'},
 '967656':{'en': 'Al Baidha'},
 '967657':{'en': 'Al Baidha'},
 '967682':{'en': 'Dhamar'},
 '967683':{'en': 'Maareb'},
 '967684':{'en': 'Dhamar'},
 '9676850':{'en': 'Al Baidha'},
 '9676853':{'en': 'Al Baidha'},
 '9676860':{'en': 'Al Baidha'},
 '9676861':{'en': 'Dhamar'},
 '9676862':{'en': 'Al Baidha'},
 '9676863':{'en': 'Maareb'},
 '9676864':{'en': 'Dhamar'},
 '9676865':{'en': 'Dhamar'},
 '9676866':{'en': 'Dhamar'},
 '9676867':{'en': 'Dhamar'},
 '9676868':{'en': 'Al Baidha'},
 '9676869':{'en': 'Al Baidha'},
 '96772':{'en': 'Hajjah'},
 '96774':{'en': 'Al Mahweet'},
 '96775':{'en': 'Saadah'},
 '96776':{'en': 'Amran'},
 '9677845':{'en': 'Al Mahweet'},
 '967785':{'en': 'Saadah'},
 '967786':{'en': 'Amran'},
 '9677870':{'en': 'Hajjah'},
 '9677871':{'en': 'Hajjah'},
 '9677872':{'en': 'Hajjah'},
 '9677873':{'en': 'Hajjah'},
 '9677874':{'en': 'Al Mahweet'},
 '9677875':{'en': 'Saadah'},
 '9677876':{'en': 'Amran'},
 '9677877':{'en': 'Amran'},
 '9677878':{'en': 'Saadah'},
 '9677879':{'en': 'Al Mahweet'},
 '96823':{'en': 'Dhofar & Al Wusta'},
 '96824':{'en': 'Muscat'},
 '96825':{'en': u('A\u2019Dakhliyah, Al Sharqiya & A\u2019Dhahira')},
 '96826':{'en': 'Al Batinah & Musandam'},
 '970222':{'en': 'Jericho/Hebron'},
 '970223':{'en': 'Jerusalem'},
 '970227':{'en': 'Bethlehem'},
 '970229':{'en': 'Ramallah/Al-Bireh'},
 '970424':{'en': 'Jenin'},
 '970820':{'en': 'Khan Yunis'},
 '970821':{'en': 'Rafah'},
 '970824':{'en': 'North Gaza'},
 '970825':{'en': 'Deir al-Balah'},
 '970826':{'en': 'Gaza'},
 '970828':{'en': 'Gaza'},
 '970923':{'en': 'Nablus'},
 '970925':{'en': 'Tubas'},
 '970926':{'en': 'Tulkarm'},
 '970929':{'en': 'Qalqilya/Salfit'},
 '9712':{'en': 'Abu dhabi'},
 '9713':{'en': 'Al Ain'},
 '97142':{'en': 'Dubai'},
 '97143':{'en': 'Dubai'},
 '97144':{'en': 'Dubai'},
 '97145':{'en': 'Dubai'},
 '97146':{'en': 'Dubai'},
 '97147':{'en': 'Dubai'},
 '97148':{'en': 'Dubai'},
 '97162':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97163':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97164':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97165':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97166':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97167':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97168':{'en': 'Sharjah, Ajman, Umm Al-Qaiwain'},
 '97172':{'en': 'Ras Alkhaimah'},
 '97173':{'en': 'Ras Alkhaimah'},
 '97174':{'en': 'Ras Alkhaimah'},
 '97175':{'en': 'Ras Alkhaimah'},
 '97176':{'en': 'Ras Alkhaimah'},
 '97177':{'en': 'Ras Alkhaimah'},
 '97178':{'en': 'Ras Alkhaimah'},
 '97192':{'en': 'Fujairah'},
 '97193':{'en': 'Fujairah'},
 '97194':{'en': 'Fujairah'},
 '97195':{'en': 'Fujairah'},
 '97196':{'en': 'Fujairah'},
 '97197':{'en': 'Fujairah'},
 '97198':{'en': 'Fujairah'},
 '9722':{'en': 'Jerusalem', 'iw': u('\u05d9\u05e8\u05d5\u05e9\u05dc\u05d9\u05dd')},
 '9723':{'en': 'Tel Aviv', 'iw': u('\u05ea\u05dc \u05d0\u05d1\u05d9\u05d1-\u05d9\u05e4\u05d5 \u05d5\u05d4\u05de\u05e8\u05db\u05d6')},
 '9724':{'en': 'Haifa and North Regions', 'iw': u('\u05d7\u05d9\u05e4\u05d4 \u05d5\u05d4\u05e6\u05e4\u05d5\u05df')},
 '9728':{'en': 'Hashfela and South Regions', 'iw': u('\u05d4\u05e9\u05e4\u05dc\u05d4 \u05d5\u05d4\u05d3\u05e8\u05d5\u05dd')},
 '9729':{'en': 'Hasharon', 'iw': u('\u05d4\u05e9\u05e8\u05d5\u05df')},
 '9752':{'en': 'Thimphu'},
 '9753':{'en': 'Trongsa'},
 '9754':{'en': 'Trashigang'},
 '9755':{'en': 'Phuentsholing'},
 '9756':{'en': 'Gelephu'},
 '97572':{'en': 'Samdrup Jongkhar'},
 '97574':{'en': 'Samdrup Jongkhar'},
 '97576':{'en': 'Samdrup Jongkhar'},
 '97582':{'en': 'Paro'},
 '97583':{'en': 'Paro'},
 '97584':{'en': 'Paro'},
 '97611':{'en': 'Ulaanbaatar'},
 '976121':{'en': 'Baganuur'},
 '976122':{'en': 'Bagakhangai'},
 '976123':{'en': 'Nalaikh'},
 '9761272':{'en': 'Zuunmod city, Tuv'},
 '97612741':{'en': 'Altaanbulag, Tuv'},
 '97612742':{'en': 'Argalant, Tuv'},
 '97612743':{'en': 'Arhust, Tuv'},
 '97612744':{'en': 'Batsumber, Tuv'},
 '97612745':{'en': 'Bayan, Tuv'},
 '97612746':{'en': 'Bayandelger, Tuv'},
 '97612747':{'en': 'Bayanjargal, Tuv'},
 '97612748':{'en': 'Bayan-Unjuul, Tuv'},
 '97612749':{'en': 'Bayankhangai, Tuv'},
 '97612751':{'en': 'Bayantsagaan, Tuv'},
 '97612752':{'en': 'Bayantsogt, Tuv'},
 '97612753':{'en': 'Bayanchandmani, Tuv'},
 '97612754':{'en': 'Bornuur, Tuv'},
 '97612755':{'en': 'Buren, Tuv'},
 '97612756':{'en': 'Delgerkhaan, Tuv'},
 '97612757':{'en': 'Jargalant, Tuv'},
 '97612758':{'en': 'Zaamar, Tuv'},
 '97612759':{'en': 'Lun, Tuv'},
 '97612761':{'en': 'Mungunmorit, Tuv'},
 '97612762':{'en': 'Undurshereet, Tuv'},
 '97612763':{'en': 'Sumber, Tuv'},
 '97612764':{'en': 'Sergelen, Tuv'},
 '97612765':{'en': 'Ugtaal, Tuv'},
 '97612766':{'en': 'Tseel, Tuv'},
 '97612767':{'en': 'Erdene, Tuv'},
 '97612768':{'en': 'Erdenesant, Tuv'},
 '9761322':{'en': 'Arvaikheer city, Uvurkhangai'},
 '97613241':{'en': 'Baruun Bayan-Ulaan, Uvurkhangai'},
 '97613242':{'en': 'Bat-Ulzii, Uvurkhangai'},
 '97613243':{'en': 'Bayangol, Uvurkhangai'},
 '97613244':{'en': 'Bayan-Undur, Uvurkhangai'},
 '97613245':{'en': 'Bogd, Uvurkhangai'},
 '97613246':{'en': 'Burd, Uvurkhangai'},
 '97613247':{'en': 'Guchin-Us, Uvurkhangai'},
 '97613248':{'en': 'Zuil, Uvurkhangai'},
 '97613249':{'en': 'Zuunbayan-Ulaan, Uvurkhangai'},
 '97613251':{'en': 'Naariinteel, Uvurkhangai'},
 '97613252':{'en': 'Ulziit, Uvurkhangai'},
 '97613253':{'en': 'Sant, Uvurkhangai'},
 '97613254':{'en': 'Taragt, Uvurkhangai'},
 '97613255':{'en': 'Tugrug, Uvurkhangai'},
 '97613256':{'en': 'Uyanga, Uvurkhangai'},
 '97613257':{'en': 'Hairkhandulaan, Uvurkhangai'},
 '97613258':{'en': 'Kharkhorin, Uvurkhangai'},
 '97613259':{'en': 'Khujirt, Uvurkhangai'},
 '9761332':{'en': 'Tsetserleg city, Arkhangai'},
 '97613341':{'en': 'Battsengel, Arkhangai'},
 '97613342':{'en': 'Bulgan, Arkhangai'},
 '97613343':{'en': 'Jargalant, Arkhangai'},
 '97613344':{'en': 'Ikh-Tamir, Arkhangai'},
 '97613345':{'en': 'Ugii-Nuur, Arkhangai'},
 '97613346':{'en': 'Ulziit, Arkhangai'},
 '97613347':{'en': 'Undur-Ulaan, Arkhangai'},
 '97613348':{'en': 'Tariat, Arkhangai'},
 '97613349':{'en': 'Tuvshruulekh, Arkhangai'},
 '97613351':{'en': 'Khairkhan, Arkhangai'},
 '97613352':{'en': 'Khahgai, Arkhangai'},
 '97613353':{'en': 'Khashaat, Arkhangai'},
 '97613354':{'en': 'Khotont, Arkhangai'},
 '97613355':{'en': 'Tsakhirt, Arkhangai'},
 '97613356':{'en': 'Tsenkher, Arkhangai'},
 '97613357':{'en': 'Tsetserleg, Arkhangai'},
 '97613358':{'en': 'Chuluut, Arkhangai'},
 '97613359':{'en': 'Erdenemandal, Arkhangai'},
 '9761342':{'en': 'Bulgan city, Bulgan'},
 '97613441':{'en': 'Bayanagt, Bulgan'},
 '97613442':{'en': 'Bayannuur, Bulgan'},
 '97613443':{'en': 'Bugat, Bulgan'},
 '97613444':{'en': 'Buregkhangai, Bulgan'},
 '97613445':{'en': 'Gurvanbulag, Bulgan'},
 '97613446':{'en': 'Dashinchilen, Bulgan'},
 '97613447':{'en': 'Mogod, Bulgan'},
 '97613448':{'en': 'Orkhon, Bulgan'},
 '97613449':{'en': 'Rashaant, Bulgan'},
 '97613451':{'en': 'Saikhan, Bulgan'},
 '97613452':{'en': 'Selenge, Bulgan'},
 '97613453':{'en': 'Teshig, Bulgan'},
 '97613454':{'en': 'Khangal, Bulgan'},
 '97613455':{'en': 'Khishig-Undur, Bulgan'},
 '97613456':{'en': 'Khutag-Undur, Bulgan'},
 '9761352':{'en': 'Erdenet city, Orkhon'},
 '97613541':{'en': 'Jargalant, Orkhon'},
 '9761362':{'en': 'Sukhbaatar city, Selenge'},
 '97613641':{'en': 'Altanbulag, Selenge'},
 '97613642':{'en': 'Baruunburen, Selenge'},
 '97613643':{'en': 'Bayangol, Selenge'},
 '97613644':{'en': 'Yereu, Selenge'},
 '97613645':{'en': 'Javkhlant, Selenge'},
 '97613646':{'en': 'Zuunburen, Selenge'},
 '97613647':{'en': 'Mandal, Selenge'},
 '97613648':{'en': 'Orkhon, Selenge'},
 '97613649':{'en': 'Orkhontuul, Selenge'},
 '97613651':{'en': 'Saikhan, Selenge'},
 '97613652':{'en': 'Sant, Selenge'},
 '97613653':{'en': 'Tushig, Selenge'},
 '97613654':{'en': 'Khuder, Selenge'},
 '97613655':{'en': 'Hushaat, Selenge'},
 '97613656':{'en': 'Tsagaannuur, Selenge'},
 '97613657':{'en': 'Shaamar, Selenge'},
 '9761372':{'en': 'Darkhan city, Darkhan-Uul'},
 '97613741':{'en': 'Orkhon, Darkhan-Uul'},
 '97613742':{'en': 'Khongor, Darkhan-Uul'},
 '97613743':{'en': 'Sharingol, Darkhan-Uul'},
 '9761382':{'en': 'Murun city, Khuvsgul'},
 '97613841':{'en': 'Alag-Erdene, Khuvsgul'},
 '97613842':{'en': 'Arbulag, Khuvsgul'},
 '97613843':{'en': 'Bayanzurkh, Khuvsgul'},
 '97613844':{'en': 'Burentogtokh, Khuvsgul'},
 '97613845':{'en': 'Galt, Khuvsgul'},
 '97613846':{'en': 'Jargalant, Khuvsgul'},
 '97613847':{'en': 'Ikh-Uul, Khuvsgul'},
 '97613848':{'en': 'Rashaant, Khuvsgul'},
 '97613849':{'en': 'Renchinlkhumbe, Khuvsgul'},
 '97613851':{'en': 'Tarialan, Khuvsgul'},
 '97613852':{'en': 'Tosontsengel, Khuvsgul'},
 '97613853':{'en': 'Tumurbulag, Khuvsgul'},
 '97613854':{'en': 'Tunel, Khuvsgul'},
 '97613855':{'en': 'Ulaan-Uul, Khuvsgul'},
 '97613856':{'en': 'Khankh, Khuvsgul'},
 '97613857':{'en': 'Khatgal, Khuvsgul'},
 '97613858':{'en': 'Tsagaannuur, Khuvsgul'},
 '97613859':{'en': 'Tsagaan-Uul, Khuvsgul'},
 '97613861':{'en': 'Tsagaan-Uur, Khuvsgul'},
 '97613862':{'en': 'Tsetserleg, Khuvsgul'},
 '97613863':{'en': 'Chaandmani-Undur, Khuvsgul'},
 '97613864':{'en': 'Shine-Ider, Khuvsgul'},
 '97613865':{'en': 'Erdenebulgan, Khuvsgul'},
 '9761422':{'en': 'Ulgii, Bayan-Ulgii'},
 '97614241':{'en': 'Altai, Bayan-Ulgii'},
 '97614242':{'en': 'Altantsugts, Bayan-Ulgii'},
 '97614243':{'en': 'Bayannuur, Bayan-Ulgii'},
 '97614244':{'en': 'Bugat, Bayan-Ulgii'},
 '97614245':{'en': 'Bulgan, Bayan-Ulgii'},
 '97614246':{'en': 'Buyant, Bayan-Ulgii'},
 '97614247':{'en': 'Deluun, Bayan-Ulgii'},
 '97614248':{'en': 'Nogoonnnuur, Bayan-Ulgii'},
 '97614249':{'en': 'Sagsai, Bayan-Ulgii'},
 '97614251':{'en': 'Tolbo, Bayan-Ulgii'},
 '97614252':{'en': 'Ulaankhus, Bayan-Ulgii'},
 '97614253':{'en': 'Tsengel, Bayan-Ulgii'},
 '9761432':{'en': 'Khovd city, Khovd'},
 '97614341':{'en': 'Altai, Khovd'},
 '97614342':{'en': 'Bulgan, Khovd'},
 '97614343':{'en': 'Buyant, Khovd'},
 '97614344':{'en': 'Darvi, Khovd'},
 '97614345':{'en': 'Durgun, Khovd'},
 '97614346':{'en': 'Duut, Khovd'},
 '97614347':{'en': 'Zereg, Khovd'},
 '97614348':{'en': 'Mankhan, Khovd'},
 '97614349':{'en': 'Munkhkhairkhan, Khovd'},
 '97614351':{'en': 'Must, Khovd'},
 '97614352':{'en': 'Myangad, Khovd'},
 '97614353':{'en': 'Uench, Khovd'},
 '97614354':{'en': 'Khovd, Khovd'},
 '97614355':{'en': 'Tsetseg, Khovd'},
 '97614356':{'en': 'Chandmani, Khovd'},
 '97614357':{'en': 'Erdeneburen, Khovd'},
 '9761442':{'en': 'Bayankhongor city, Bayankhongor'},
 '97614441':{'en': 'Baatsagaan, Bayankhongor'},
 '97614442':{'en': 'Bayanbulag, Bayankhongor'},
 '97614443':{'en': 'Bayangovi, Bayankhongor'},
 '97614444':{'en': 'Bayanlig, Bayankhongor'},
 '97614445':{'en': 'Bayan-Ovoo, Bayankhongor'},
 '97614446':{'en': 'Bayan-Undur, Bayankhongor'},
 '97614447':{'en': 'Bayantsagaan, Bayankhongor'},
 '97614448':{'en': 'Bogd, Bayankhongor'},
 '97614449':{'en': 'Bumbugur, Bayankhongor'},
 '97614451':{'en': 'Buutsagaan, Bayankhongor'},
 '97614452':{'en': 'Galuut, Bayankhongor'},
 '97614453':{'en': 'Gurvanbulag, Bayankhongor'},
 '97614454':{'en': 'Jargalant, Bayankhongor'},
 '97614455':{'en': 'Jinst, Bayankhongor'},
 '97614456':{'en': 'Zag, Bayankhongor'},
 '97614457':{'en': 'Ulziit, Bayankhongor'},
 '97614458':{'en': 'Khureemaral, Bayankhongor'},
 '97614459':{'en': 'Shjnejinst, Bayankhongor'},
 '97614461':{'en': 'Erdenetsogt, Bayankhongor'},
 '9761452':{'en': 'Ulaangom city, Uvs'},
 '97614541':{'en': 'Baruunturuun, Uvs'},
 '97614542':{'en': 'Bukhmurun, Uvs'},
 '97614543':{'en': 'Davst, Uvs'},
 '97614544':{'en': 'Zavkhan, Uvs'},
 '97614545':{'en': 'Zuungovi, Uvs'},
 '97614546':{'en': 'Zuunkhangai, Uvs'},
 '97614547':{'en': 'Malchin, Uvs'},
 '97614548':{'en': 'Naranbulag, Uvs'},
 '97614549':{'en': 'Ulgii, Uvs'},
 '97614551':{'en': 'Umnugovi, Uvs'},
 '97614552':{'en': 'Undurkhangai, Uvs'},
 '97614553':{'en': 'Sagili, Uvs'},
 '97614554':{'en': 'Tarialan, Uvs'},
 '97614555':{'en': 'Turgen, Uvs'},
 '97614556':{'en': 'Tes, Uvs'},
 '97614557':{'en': 'Khovd, Uvs'},
 '97614558':{'en': 'Khyargas, Uvs'},
 '97614559':{'en': 'Tsagaankhairkhan, Uvs'},
 '9761462':{'en': 'Uliastal city, Zavkhan'},
 '97614641':{'en': 'Aldarkhaan, Zavkhan'},
 '97614642':{'en': 'Asgat, Zavkhan'},
 '97614643':{'en': 'Bayantest, Zavkhan'},
 '97614644':{'en': 'Bayankhairkhan, Zavkhan'},
 '97614645':{'en': 'Bulnai, Zavkhan'},
 '97614646':{'en': 'Durvuljin, Zavkhan'},
 '97614647':{'en': 'Zavkhanmandal, Zavkhan'},
 '97614648':{'en': 'Ider, Zavkhan'},
 '97614649':{'en': 'Ikh-Uul, Zavkhan'},
 '97614651':{'en': 'Numrug, Zavkhan'},
 '97614652':{'en': 'Otgon, Zavkhan'},
 '97614653':{'en': 'Santmargad, Zavkhan'},
 '97614654':{'en': 'Songino, Zavkhan'},
 '97614655':{'en': 'Tudevtei, Zavkhan'},
 '97614656':{'en': 'Telmen, Zavkhan'},
 '97614657':{'en': 'Tes, Zavkhan'},
 '97614658':{'en': 'Urgamal, Zavkhan'},
 '97614659':{'en': 'Tsegeenkhairkhan, Zavkhan'},
 '97614661':{'en': 'Tsagaanchuluut, Zavkhan'},
 '97614662':{'en': 'Tsetsen-Uul, Zavkhan'},
 '97614663':{'en': 'Shiluustei, Zavkhan'},
 '97614664':{'en': 'Erdenekhaijkhan, Zavkhan'},
 '97614665':{'en': 'Yaruu, Zavkhan'},
 '9761482':{'en': 'Altai city, Govi-Altai'},
 '97614841':{'en': 'Altai, Govi-Altai'},
 '97614842':{'en': 'Bayan-Uul, Govi-Altai'},
 '97614843':{'en': 'Biger, Govi-Altai'},
 '97614844':{'en': 'Bugant, Govi-Altai'},
 '97614845':{'en': 'Darvi, Govi-Altai'},
 '97614846':{'en': 'Delger, Govi-Altai'},
 '97614847':{'en': 'Jargalan, Govi-Altai'},
 '97614848':{'en': 'Taishir, Govi-Altai'},
 '97614849':{'en': 'Tonkhil, Govi-Altai'},
 '97614851':{'en': 'Tugrug, Govi-Altai'},
 '97614852':{'en': 'Khaluun, Govi-Altai'},
 '97614853':{'en': 'Khukhmorit, Govi-Altai'},
 '97614854':{'en': 'Tsogt, Govi-Altai'},
 '97614855':{'en': 'Tseel, Govi-Altai'},
 '97614856':{'en': 'Chandmani, Govi-Altai'},
 '97614857':{'en': 'Sharga, Govi-Altai'},
 '97614858':{'en': 'Erdene, Govi-Altai'},
 '9761512':{'en': 'Baruun-Urt city, Sukhbaatar'},
 '97615141':{'en': 'Asgat, Sukhbaatar'},
 '97615142':{'en': 'Bayandelger, Sukhbaatar'},
 '97615143':{'en': 'Dariganga, Sukhbaatar'},
 '97615144':{'en': 'Munkhkhaan, Sukhbaatar'},
 '97615145':{'en': 'Naran, Sukhbaatar'},
 '97615146':{'en': 'Ongon, Sukhbaatar'},
 '97615147':{'en': 'Sukhbaatar, Sukhbaatar'},
 '97615148':{'en': 'Tuvshin-Shiree, Sukhbaatar'},
 '97615149':{'en': 'Tumentsogt, Sukhbaatar'},
 '97615151':{'en': 'Uulbayan, Sukhbaatar'},
 '97615152':{'en': 'Halzan, Sukhbaatar'},
 '97615153':{'en': 'Erdenetsagaan, Sukhbaatar'},
 '9761522':{'en': 'Sainshand city, Dornogovi'},
 '97615241':{'en': 'Airag, Dornogovi'},
 '97615242':{'en': 'Altanshiree, Dornogovi'},
 '97615243':{'en': 'Dalanjargalan, Dornogovi'},
 '97615244':{'en': 'Delgerekh, Dornogovi'},
 '97615245':{'en': 'Zamiin-Uud, Dornogovi'},
 '97615246':{'en': 'Ikh-Khet, Dornogovi'},
 '97615247':{'en': 'Mandakh, Dornogovi'},
 '97615248':{'en': 'Urgun, Dornogovi'},
 '97615249':{'en': 'Saikhandulaan, Dornogovi'},
 '97615251':{'en': 'Ulaanbadrakh, Dornogovi'},
 '97615252':{'en': 'Khatanbulag, Dornogovi'},
 '97615253':{'en': 'Huvsgul, Dornogovi'},
 '97615254':{'en': 'Erdene, Dornogovi'},
 '9761532':{'en': 'Dalanzadgad, Umnugovi'},
 '97615341':{'en': 'Bayandalai, Umnugovi'},
 '97615342':{'en': 'Bayan-Ovoo, Umnugovi'},
 '97615343':{'en': 'Bulgan, Umnugovi'},
 '97615344':{'en': 'Gurvan tes, Umnugovi'},
 '97615345':{'en': 'Mandal-Ovoo, Umnugovi'},
 '97615346':{'en': 'Manlai, Umnugovi'},
 '97615347':{'en': 'Noyon, Umnugovi'},
 '97615348':{'en': 'Nomgon, Umnugovi'},
 '97615349':{'en': 'Savrai, Umnugovi'},
 '97615351':{'en': 'Khanbogd, Umnugovi'},
 '97615352':{'en': 'Khankhongor, Umnugovi'},
 '97615353':{'en': 'Khurmen, Umnugovi'},
 '97615354':{'en': 'Tsogt-Ovoo, Umnugovi'},
 '97615355':{'en': 'Tsogttsetsii, Umnugovi'},
 '9761542':{'en': 'Choir, Govisumber'},
 '97615441':{'en': 'Bayantal, Govisumber'},
 '97615442':{'en': 'Shivee-Govi, Govisumber'},
 '9761562':{'en': 'Undurkhaan city, Khentii'},
 '97615641':{'en': 'Batnorov, Khentii'},
 '97615642':{'en': 'Batshireet, Khentii'},
 '97615643':{'en': 'Bayan-Adraga, Khentii'},
 '97615644':{'en': 'Bayanmunkh, Khentii'},
 '97615645':{'en': 'Bayan-Ovoo, Khentii'},
 '97615646':{'en': 'Bayankhutagt, Khentii'},
 '97615647':{'en': 'Binder, Khentii'},
 '97615648':{'en': 'Galshir, Khentii'},
 '97615649':{'en': 'Dadal, Khentii'},
 '97615651':{'en': 'Darkhan, Khentii'},
 '97615652':{'en': 'Delgerkhaan, Khentii'},
 '97615653':{'en': 'Jargaltkhaan, Khentii'},
 '97615654':{'en': 'Murun, Khentii'},
 '97615655':{'en': 'Norovlin, Khentii'},
 '97615656':{'en': 'Umnudelger, Khentii'},
 '97615657':{'en': 'Tsenkhermandal, Khentii'},
 '9761582':{'en': 'Choibalsan city, Dornod'},
 '97615841':{'en': 'Bayandun, Dornod'},
 '97615842':{'en': 'Bayantumen, Dornod'},
 '97615843':{'en': 'Bayan-Uul, Dornod'},
 '97615844':{'en': 'Bulgan, Dornod'},
 '97615845':{'en': 'Gurvanzagal, Dornod'},
 '97615846':{'en': 'Dashbalbar, Dornod'},
 '97615847':{'en': 'Matad, Dornod'},
 '97615848':{'en': 'Sereglen, Dornod'},
 '97615849':{'en': 'Khalkh, Dornod'},
 '97615851':{'en': 'Khulunbuyir, Dornod'},
 '97615852':{'en': 'Tsagaan-Ovoo, Dornod'},
 '97615853':{'en': 'Choibalsan, Dornod'},
 '97615854':{'en': 'Chuluunkhoroot, Dornod'},
 '9761592':{'en': 'Mandalgovi city, Dundgovi'},
 '97615941':{'en': 'Adaatsag, Dundgovi'},
 '97615942':{'en': 'Bayanjargalan, Dundgovi'},
 '97615943':{'en': 'Govi-Ugtaal, Dundgovi'},
 '97615944':{'en': 'Gurvansaikhan, Dundgovi'},
 '97615945':{'en': 'Delgerkhangai, Dundgovi'},
 '97615946':{'en': 'Delgertsogt, Dundgovi'},
 '97615947':{'en': 'Deren, Dundgovi'},
 '97615948':{'en': 'Luus, Dundgovi'},
 '97615949':{'en': 'Ulziit, Dundgovi'},
 '97615951':{'en': 'Undurshil, Dundgovi'},
 '97615952':{'en': 'Saikhan-Ovoo, Dundgovi'},
 '97615953':{'en': 'Khuld, Dundgovi'},
 '97615954':{'en': 'Tsagaandelger, Dundgovi'},
 '97615955':{'en': 'Erdenedalai, Dundgovi'},
 '97621':{'en': 'Ulaanbaatar'},
 '976221':{'en': 'Baganuur'},
 '976222':{'en': 'Bagakhangai'},
 '976223':{'en': 'Nalaikh'},
 '9762272':{'en': 'Zuunmod city, Tuv'},
 '97622741':{'en': 'Altaanbulag, Tuv'},
 '97622742':{'en': 'Argalant, Tuv'},
 '97622743':{'en': 'Arhust, Tuv'},
 '97622744':{'en': 'Batsumber, Tuv'},
 '97622745':{'en': 'Bayan, Tuv'},
 '97622746':{'en': 'Bayandelger, Tuv'},
 '97622747':{'en': 'Bayanjargal, Tuv'},
 '97622748':{'en': 'Bayan-Unjuul, Tuv'},
 '97622749':{'en': 'Bayankhangai, Tuv'},
 '97622751':{'en': 'Bayantsagaan, Tuv'},
 '97622752':{'en': 'Bayantsogt, Tuv'},
 '97622753':{'en': 'Bayanchandmani, Tuv'},
 '97622754':{'en': 'Bornuur, Tuv'},
 '97622755':{'en': 'Buren, Tuv'},
 '97622756':{'en': 'Delgerkhaan, Tuv'},
 '97622757':{'en': 'Jargalant, Tuv'},
 '97622758':{'en': 'Zaamar, Tuv'},
 '97622759':{'en': 'Lun, Tuv'},
 '97622761':{'en': 'Mungunmorit, Tuv'},
 '97622762':{'en': 'Undurshereet, Tuv'},
 '97622763':{'en': 'Sumber, Tuv'},
 '97622764':{'en': 'Sergelen, Tuv'},
 '97622765':{'en': 'Ugtaal, Tuv'},
 '97622766':{'en': 'Tseel, Tuv'},
 '97622767':{'en': 'Erdene, Tuv'},
 '97622768':{'en': 'Erdenesant, Tuv'},
 '9762322':{'en': 'Arvaikheer city, Uvurkhangai'},
 '97623241':{'en': 'Baruun Bayan-Ulaan, Uvurkhangai'},
 '97623242':{'en': 'Batulzii, Uvurkhangai'},
 '97623243':{'en': 'Bayangol, Uvurkhangai'},
 '97623244':{'en': 'Bayan-Undur, Uvurkhangai'},
 '97623245':{'en': 'Bogd, Uvurkhangai'},
 '97623246':{'en': 'Burd, Uvurkhangai'},
 '97623247':{'en': 'Guchin-Us, Uvurkhangai'},
 '97623248':{'en': 'Zuil, Uvurkhangai'},
 '97623249':{'en': 'Zuunbayan-Ulaan, Uvurkhangai'},
 '97623251':{'en': 'Naariinteel, Uvurkhangai'},
 '97623252':{'en': 'Ulziit, Uvurkhangai'},
 '97623253':{'en': 'Sant, Uvurkhangai'},
 '97623254':{'en': 'Taragt, Uvurkhangai'},
 '97623255':{'en': 'Tugrug, Uvurkhangai'},
 '97623256':{'en': 'Uyanga, Uvurkhangai'},
 '97623257':{'en': 'Hairkhandulaan, Uvurkhangai'},
 '97623258':{'en': 'Kharkhorin, Uvurkhangai'},
 '97623259':{'en': 'Khujirt, Uvurkhangai'},
 '9762332':{'en': 'Tsetserleg city, Arkhangai'},
 '97623341':{'en': 'Battsengel, Arkhangai'},
 '97623342':{'en': 'Bulgan, Arkhangai'},
 '97623343':{'en': 'Jargalant, Arkhangai'},
 '97623344':{'en': 'Ikh-Tamir, Arkhangai'},
 '97623345':{'en': 'Ugii-Nuur, Arkhangai'},
 '97623346':{'en': 'Ulziit, Arkhangai'},
 '97623347':{'en': 'Undur-Ulaan, Arkhangai'},
 '97623348':{'en': 'Tariat, Arkhangai'},
 '97623349':{'en': 'Tuvshruulekh, Arkhangai'},
 '97623351':{'en': 'Khairkhan, Arkhangai'},
 '97623352':{'en': 'Khahgai, Arkhangai'},
 '97623353':{'en': 'Khashaat, Arkhangai'},
 '97623354':{'en': 'Khotont, Arkhangai'},
 '97623355':{'en': 'Tsakhirt, Arkhangai'},
 '97623356':{'en': 'Tsenkher, Arkhangai'},
 '97623357':{'en': 'Tsetserleg, Arkhangai'},
 '97623358':{'en': 'Chuluut, Arkhangai'},
 '97623359':{'en': 'Erdenemandal, Arkhangai'},
 '9762342':{'en': 'Bulgan city, Bulgan'},
 '97623441':{'en': 'Bayanagt, Bulgan'},
 '97623442':{'en': 'Bayannuur, Bulgan'},
 '97623443':{'en': 'Bugat, Bulgan'},
 '97623444':{'en': 'Buregkhangai, Bulgan'},
 '97623445':{'en': 'Gurvanbulag, Bulgan'},
 '97623446':{'en': 'Dashinchilen, Bulgan'},
 '97623447':{'en': 'Mogod, Bulgan'},
 '97623448':{'en': 'Orkhon, Bulgan'},
 '97623449':{'en': 'Rashaant, Bulgan'},
 '97623451':{'en': 'Saikhan, Bulgan'},
 '97623452':{'en': 'Selenge, Bulgan'},
 '97623453':{'en': 'Teshig, Bulgan'},
 '97623454':{'en': 'Khangal, Bulgan'},
 '97623455':{'en': 'Khishig-Undur, Bulgan'},
 '97623456':{'en': 'Khutag-Undur, Bulgan'},
 '9762352':{'en': 'Erdenet city, Orkhon'},
 '97623541':{'en': 'Jargalant, Orkhon'},
 '9762362':{'en': 'Sukhbaatar city, Selenge'},
 '97623641':{'en': 'Altanbulag, Selenge'},
 '97623642':{'en': 'Baruunburen, Selenge'},
 '97623643':{'en': 'Bayangol, Selenge'},
 '97623644':{'en': 'Yereu, Selenge'},
 '97623645':{'en': 'Javkhlant, Selenge'},
 '97623646':{'en': 'Zuunburen, Selenge'},
 '97623647':{'en': 'Mandal, Selenge'},
 '97623648':{'en': 'Orkhon, Selenge'},
 '97623649':{'en': 'Orkhontuul, Selenge'},
 '97623651':{'en': 'Saikhan, Selenge'},
 '97623652':{'en': 'Sant, Selenge'},
 '97623653':{'en': 'Tushig, Selenge'},
 '97623654':{'en': 'Khuder, Selenge'},
 '97623655':{'en': 'Hushaat, Selenge'},
 '97623656':{'en': 'Tsagaannuur, Selenge'},
 '97623657':{'en': 'Shaamar, Selenge'},
 '9762372':{'en': 'Darkhan city, Darkhan-Uul'},
 '97623741':{'en': 'Orkhon, Darkhan-Uul'},
 '97623742':{'en': 'Khongor, Darkhan-Uul'},
 '97623743':{'en': 'Sharingol, Darkhan-Uul'},
 '9762382':{'en': 'Murun city, Khuvsgul'},
 '97623841':{'en': 'Alag-Erdene, Khuvsgul'},
 '97623842':{'en': 'Arbulag, Khuvsgul'},
 '97623843':{'en': 'Bayanzurkh, Khuvsgul'},
 '97623844':{'en': 'Burentogtokh, Khuvsgul'},
 '97623845':{'en': 'Galt, Khuvsgul'},
 '97623846':{'en': 'Jargalant, Khuvsgul'},
 '97623847':{'en': 'Ikh-Uul, Khuvsgul'},
 '97623848':{'en': 'Rashaant, Khuvsgul'},
 '97623849':{'en': 'Renchinlkhumbe, Khuvsgul'},
 '97623851':{'en': 'Tarialan, Khuvsgul'},
 '97623852':{'en': 'Tosontsengel, Khuvsgul'},
 '97623853':{'en': 'Tumurbulag, Khuvsgul'},
 '97623854':{'en': 'Tunel, Khuvsgul'},
 '97623855':{'en': 'Ulaan-Uul, Khuvsgul'},
 '97623856':{'en': 'Khankh, Khuvsgul'},
 '97623857':{'en': 'Khatgal, Khuvsgul'},
 '97623858':{'en': 'Tsagaannuur, Khuvsgul'},
 '97623859':{'en': 'Tsagaan-Uul, Khuvsgul'},
 '97623861':{'en': 'Tsagaan-Uur, Khuvsgul'},
 '97623862':{'en': 'Tsetserleg, Khuvsgul'},
 '97623863':{'en': 'Chaandmani-Undur, Khuvsgul'},
 '97623864':{'en': 'Shine-Ider, Khuvsgul'},
 '97623865':{'en': 'Erdenebulgan, Khuvsgul'},
 '9762422':{'en': 'Ulgii, Bayan-Ulgii'},
 '97624241':{'en': 'Altai, Bayan-Ulgii'},
 '97624242':{'en': 'Altantsugts, Bayan-Ulgii'},
 '97624243':{'en': 'Bayannuur, Bayan-Ulgii'},
 '97624244':{'en': 'Bugat, Bayan-Ulgii'},
 '97624245':{'en': 'Bulgan, Bayan-Ulgii'},
 '97624246':{'en': 'Buyant, Bayan-Ulgii'},
 '97624247':{'en': 'Deluun, Bayan-Ulgii'},
 '97624248':{'en': 'Nogoonnnuur, Bayan-Ulgii'},
 '97624249':{'en': 'Sagsai, Bayan-Ulgii'},
 '97624251':{'en': 'Tolbo, Bayan-Ulgii'},
 '97624252':{'en': 'Ulaankhus, Bayan-Ulgii'},
 '97624253':{'en': 'Tsengel, Bayan-Ulgii'},
 '9762432':{'en': 'Khovd city, Khovd'},
 '97624341':{'en': 'Altai, Khovd'},
 '97624342':{'en': 'Bulgan, Khovd'},
 '97624343':{'en': 'Buyant, Khovd'},
 '97624344':{'en': 'Darvi, Khovd'},
 '97624345':{'en': 'Durgun, Khovd'},
 '97624346':{'en': 'Duut, Khovd'},
 '97624347':{'en': 'Zereg, Khovd'},
 '97624348':{'en': 'Mankhan, Khovd'},
 '97624349':{'en': 'Munkhkhairkhan, Khovd'},
 '97624351':{'en': 'Must, Khovd'},
 '97624352':{'en': 'Myangad, Khovd'},
 '97624353':{'en': 'Uench, Khovd'},
 '97624354':{'en': 'Khovd, Khovd'},
 '97624355':{'en': 'Tsetseg, Khovd'},
 '97624356':{'en': 'Chandmani, Khovd'},
 '97624357':{'en': 'Erdeneburen, Khovd'},
 '9762442':{'en': 'Bayankhongor city, Bayankhongor'},
 '97624441':{'en': 'Baatsagaan, Bayankhongor'},
 '97624442':{'en': 'Bayanbulag, Bayankhongor'},
 '97624443':{'en': 'Bayangovi, Bayankhongor'},
 '97624444':{'en': 'Bayanlig, Bayankhongor'},
 '97624445':{'en': 'Bayan-Ovoo, Bayankhongor'},
 '97624446':{'en': 'Bayan-Undur, Bayankhongor'},
 '97624447':{'en': 'Bayantsagaan, Bayankhongor'},
 '97624448':{'en': 'Bogd, Bayankhongor'},
 '97624449':{'en': 'Bumbugur, Bayankhongor'},
 '97624451':{'en': 'Buutsagaan, Bayankhongor'},
 '97624452':{'en': 'Galuut, Bayankhongor'},
 '97624453':{'en': 'Gurvanbulag, Bayankhongor'},
 '97624454':{'en': 'Jargalant, Bayankhongor'},
 '97624455':{'en': 'Jinst, Bayankhongor'},
 '97624456':{'en': 'Zag, Bayankhongor'},
 '97624457':{'en': 'Ulziit, Bayankhongor'},
 '97624458':{'en': 'Khureemaral, Bayankhongor'},
 '97624459':{'en': 'Shjnejinst, Bayankhongor'},
 '97624461':{'en': 'Erdenetsogt, Bayankhongor'},
 '9762452':{'en': 'Ulaangom city, Uvs'},
 '97624541':{'en': 'Baruunturuun, Uvs'},
 '97624542':{'en': 'Bukhmurun, Uvs'},
 '97624543':{'en': 'Davst, Uvs'},
 '97624544':{'en': 'Zavkhan, Uvs'},
 '97624545':{'en': 'Zuungovi, Uvs'},
 '97624546':{'en': 'Zuunkhangai, Uvs'},
 '97624547':{'en': 'Malchin, Uvs'},
 '97624548':{'en': 'Naranbulag, Uvs'},
 '97624549':{'en': 'Ulgii, Uvs'},
 '97624551':{'en': 'Umnugovi, Uvs'},
 '97624552':{'en': 'Undurkhangai, Uvs'},
 '97624553':{'en': 'Sagili, Uvs'},
 '97624554':{'en': 'Tarialan, Uvs'},
 '97624555':{'en': 'Turgen, Uvs'},
 '97624556':{'en': 'Tes, Uvs'},
 '97624557':{'en': 'Khovd, Uvs'},
 '97624558':{'en': 'Khyargas, Uvs'},
 '97624559':{'en': 'Tsagaankhairkhan, Uvs'},
 '9762462':{'en': 'Uliastal city, Zavkhan'},
 '97624641':{'en': 'Aldarkhaan, Zavkhan'},
 '97624642':{'en': 'Asgat, Zavkhan'},
 '97624643':{'en': 'Bayantest, Zavkhan'},
 '97624644':{'en': 'Bayankhairkhan, Zavkhan'},
 '97624645':{'en': 'Bulnai, Zavkhan'},
 '97624646':{'en': 'Durvuljin, Zavkhan'},
 '97624647':{'en': 'Zavkhanmandal, Zavkhan'},
 '97624648':{'en': 'Ider, Zavkhan'},
 '97624649':{'en': 'Ikh-Uul, Zavkhan'},
 '97624651':{'en': 'Numrug, Zavkhan'},
 '97624652':{'en': 'Otgon, Zavkhan'},
 '97624653':{'en': 'Santmargad, Zavkhan'},
 '97624654':{'en': 'Songino, Zavkhan'},
 '97624655':{'en': 'Tudevtei, Zavkhan'},
 '97624656':{'en': 'Telmen, Zavkhan'},
 '97624657':{'en': 'Tes, Zavkhan'},
 '97624658':{'en': 'Urgamal, Zavkhan'},
 '97624659':{'en': 'Tsegeenkhairkhan, Zavkhan'},
 '97624661':{'en': 'Tsagaanchuluut, Zavkhan'},
 '97624662':{'en': 'Tsetsen-Uul, Zavkhan'},
 '97624663':{'en': 'Shiluustei, Zavkhan'},
 '97624664':{'en': 'Erdenekhaijkhan, Zavkhan'},
 '97624665':{'en': 'Yaruu, Zavkhan'},
 '9762482':{'en': 'Altai city, Govi-Altai'},
 '97624841':{'en': 'Altai, Govi-Altai'},
 '97624842':{'en': 'Bayan-Uul, Govi-Altai'},
 '97624843':{'en': 'Biger, Govi-Altai'},
 '97624844':{'en': 'Bugant, Govi-Altai'},
 '97624845':{'en': 'Darvi, Govi-Altai'},
 '97624846':{'en': 'Delger, Govi-Altai'},
 '97624847':{'en': 'Jargalan, Govi-Altai'},
 '97624848':{'en': 'Taishir, Govi-Altai'},
 '97624849':{'en': 'Tonkhil, Govi-Altai'},
 '97624851':{'en': 'Tugrug, Govi-Altai'},
 '97624852':{'en': 'Khaluun, Govi-Altai'},
 '97624853':{'en': 'Khukhmorit, Govi-Altai'},
 '97624854':{'en': 'Tsogt, Govi-Altai'},
 '97624855':{'en': 'Tseel, Govi-Altai'},
 '97624856':{'en': 'Chandmani, Govi-Altai'},
 '97624857':{'en': 'Sharga, Govi-Altai'},
 '97624858':{'en': 'Erdene, Govi-Altai'},
 '9762512':{'en': 'Baruun-Urt city, Sukhbaatar'},
 '97625141':{'en': 'Asgat, Sukhbaatar'},
 '97625142':{'en': 'Bayandelger, Sukhbaatar'},
 '97625143':{'en': 'Dariganga, Sukhbaatar'},
 '97625144':{'en': 'Munkhkhaan, Sukhbaatar'},
 '97625145':{'en': 'Naran, Sukhbaatar'},
 '97625146':{'en': 'Ongon, Sukhbaatar'},
 '97625147':{'en': 'Sukhbaatar, Sukhbaatar'},
 '97625148':{'en': 'Tuvshin-Shiree, Sukhbaatar'},
 '97625149':{'en': 'Tumentsogt, Sukhbaatar'},
 '97625151':{'en': 'Uulbayan, Sukhbaatar'},
 '97625152':{'en': 'Halzan, Sukhbaatar'},
 '97625153':{'en': 'Erdenetsagaan, Sukhbaatar'},
 '9762522':{'en': 'Sainshand city, Dornogovi'},
 '97625241':{'en': 'Airag, Dornogovi'},
 '97625242':{'en': 'Altanshiree, Dornogovi'},
 '97625243':{'en': 'Dalanjargalan, Dornogovi'},
 '97625244':{'en': 'Delgerekh, Dornogovi'},
 '97625245':{'en': 'Zamiin-Uud, Dornogovi'},
 '97625246':{'en': 'Ikh-Khet, Dornogovi'},
 '97625247':{'en': 'Mandakh, Dornogovi'},
 '97625248':{'en': 'Urgun, Dornogovi'},
 '97625249':{'en': 'Saikhandulaan, Dornogovi'},
 '97625251':{'en': 'Ulaanbadrakh, Dornogovi'},
 '97625252':{'en': 'Khatanbulag, Dornogovi'},
 '97625253':{'en': 'Huvsgul, Dornogovi'},
 '97625254':{'en': 'Erdene, Dornogovi'},
 '9762532':{'en': 'Dalanzadgad, Umnugovi'},
 '97625341':{'en': 'Bayandalai, Umnugovi'},
 '97625342':{'en': 'Bayan-Ovoo, Umnugovi'},
 '97625343':{'en': 'Bulgan, Umnugovi'},
 '97625344':{'en': 'Gurvan tes, Umnugovi'},
 '97625345':{'en': 'Mandal-Ovoo, Umnugovi'},
 '97625346':{'en': 'Manlai, Umnugovi'},
 '97625347':{'en': 'Noyon, Umnugovi'},
 '97625348':{'en': 'Nomgon, Umnugovi'},
 '97625349':{'en': 'Savrai, Umnugovi'},
 '97625351':{'en': 'Khanbogd, Umnugovi'},
 '97625352':{'en': 'Khankhongor, Umnugovi'},
 '97625353':{'en': 'Khurmen, Umnugovi'},
 '97625354':{'en': 'Tsogt-Ovoo, Umnugovi'},
 '97625355':{'en': 'Tsogt-Tsetsii, Umnugovi'},
 '9762542':{'en': 'Choir, Govisumber'},
 '97625441':{'en': 'Bayantal, Govisumber'},
 '97625442':{'en': 'Shivee-Govi, Govisumber'},
 '9762562':{'en': 'Undurkhaan city, Khentii'},
 '97625641':{'en': 'Batnorov, Khentii'},
 '97625642':{'en': 'Batshireet, Khentii'},
 '97625643':{'en': 'Bayan-Adarga, Khentii'},
 '97625644':{'en': 'Bayanmunkh, Khentii'},
 '97625645':{'en': 'Bayan-Ovoo, Khentii'},
 '97625646':{'en': 'Bayankhutagt, Khentii'},
 '97625647':{'en': 'Binder, Khentii'},
 '97625648':{'en': 'Galshir, Khentii'},
 '97625649':{'en': 'Dadal, Khentii'},
 '97625651':{'en': 'Darkhan, Khentii'},
 '97625652':{'en': 'Delgerkhaan, Khentii'},
 '97625653':{'en': 'Jargaltkhaan, Khentii'},
 '97625654':{'en': 'Murun, Khentii'},
 '97625655':{'en': 'Norovlin, Khentii'},
 '97625656':{'en': 'Umnudelger, Khentii'},
 '97625657':{'en': 'Tsenkhermandal, Khentii'},
 '9762582':{'en': 'Choibalsan city, Dornod'},
 '97625841':{'en': 'Bayandun, Dornod'},
 '97625842':{'en': 'Bayantumen, Dornod'},
 '97625843':{'en': 'Bayan-Uul, Dornod'},
 '97625844':{'en': 'Bulgan, Dornod'},
 '97625845':{'en': 'Gurvanzagal, Dornod'},
 '97625846':{'en': 'Dashbalbar, Dornod'},
 '97625847':{'en': 'Matad, Dornod'},
 '97625848':{'en': 'Sereglen, Dornod'},
 '97625849':{'en': 'Khalkhgol, Dornod'},
 '97625851':{'en': 'Khulunbuyir, Dornod'},
 '97625852':{'en': 'Tsagaan-Ovoo, Dornod'},
 '97625853':{'en': 'Choibalsan, Dornod'},
 '97625854':{'en': 'Chuluunkhoroot, Dornod'},
 '9762592':{'en': 'Mandalgovi city, Dundgovi'},
 '97625941':{'en': 'Adaatsag, Dundgovi'},
 '97625942':{'en': 'Bayanjargalan, Dundgovi'},
 '97625943':{'en': 'Govi-Ugtaal, Dundgovi'},
 '97625944':{'en': 'Gurvansaikhan, Dundgovi'},
 '97625945':{'en': 'Delgerkhangai, Dundgovi'},
 '97625946':{'en': 'Delgertsogt, Dundgovi'},
 '97625947':{'en': 'Deren, Dundgovi'},
 '97625948':{'en': 'Luus, Dundgovi'},
 '97625949':{'en': 'Ulziit, Dundgovi'},
 '97625951':{'en': 'Undurshil, Dundgovi'},
 '97625952':{'en': 'Saikhan-Ovoo, Dundgovi'},
 '97625953':{'en': 'Khuld, Dundgovi'},
 '97625954':{'en': 'Tsagaandelger, Dundgovi'},
 '97625955':{'en': 'Erdenedalai, Dundgovi'},
 '9811':{'en': 'Mazandaran', 'fa': u('\u0645\u0627\u0632\u0646\u062f\u0631\u0627\u0646')},
 '9813':{'en': 'Gilan', 'fa': u('\u06af\u06cc\u0644\u0627\u0646')},
 '9817':{'en': 'Golestan', 'fa': u('\u06af\u0644\u0633\u062a\u0627\u0646')},
 '9821':{'en': 'Tehran province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u062a\u0647\u0631\u0627\u0646')},
 '9823':{'en': 'Semnan province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0633\u0645\u0646\u0627\u0646')},
 '9824':{'en': 'Zanjan province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0632\u0646\u062c\u0627\u0646')},
 '9825':{'en': 'Qom province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0642\u0645')},
 '9826':{'en': 'Alborz', 'fa': u('\u0627\u0644\u0628\u0631\u0632')},
 '9828':{'en': 'Qazvin province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0642\u0632\u0648\u06cc\u0646')},
 '9831':{'en': 'Isfahan province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0627\u0635\u0641\u0647\u0627\u0646')},
 '9834':{'en': 'Kerman province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u06a9\u0631\u0645\u0627\u0646')},
 '9835':{'en': 'Yazd province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u06cc\u0632\u062f')},
 '9838':{'en': 'Chahar-mahal and Bakhtiari', 'fa': u('\u0686\u0647\u0627\u0631\u0645\u062d\u0627\u0644 \u0648 \u0628\u062e\u062a\u06cc\u0627\u0631\u06cc')},
 '9841':{'en': 'East Azarbaijan', 'fa': u('\u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646 \u0634\u0631\u0642\u06cc')},
 '9844':{'en': 'West Azarbaijan', 'fa': u('\u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646 \u063a\u0631\u0628\u06cc')},
 '9845':{'en': 'Ardabil province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0627\u0631\u062f\u0628\u06cc\u0644')},
 '9851':{'en': 'Razavi Khorasan', 'fa': u('\u062e\u0631\u0627\u0633\u0627\u0646 \u0631\u0636\u0648\u06cc')},
 '9854':{'en': 'Sistan and Baluchestan', 'fa': u('\u0633\u06cc\u0633\u062a\u0627\u0646 \u0648 \u0628\u0644\u0648\u0686\u0633\u062a\u0627\u0646')},
 '9856':{'en': 'South Khorasan', 'fa': u('\u062e\u0631\u0627\u0633\u0627\u0646 \u062c\u0646\u0648\u0628\u06cc')},
 '9858':{'en': 'North Khorasan', 'fa': u('\u062e\u0631\u0627\u0633\u0627\u0646 \u0634\u0645\u0627\u0644\u06cc')},
 '9861':{'en': 'Khuzestan', 'fa': u('\u062e\u0648\u0632\u0633\u062a\u0627\u0646')},
 '9866':{'en': 'Lorestan', 'fa': u('\u0644\u0631\u0633\u062a\u0627\u0646')},
 '9871':{'en': 'Fars', 'fa': u('\u0641\u0627\u0631\u0633')},
 '9874':{'en': 'Kohgiluyeh and Boyer-Ahmad', 'fa': u('\u06a9\u0647\u06af\u06cc\u0644\u0648\u06cc\u0647 \u0648 \u0628\u0648\u06cc\u0631\u0627\u062d\u0645\u062f')},
 '9876':{'en': 'Hormozgan', 'fa': u('\u0647\u0631\u0645\u0632\u06af\u0627\u0646')},
 '9877':{'en': 'Bushehr province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0628\u0648\u0634\u0647\u0631')},
 '9881':{'en': 'Hamadan province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0647\u0645\u062f\u0627\u0646')},
 '9883':{'en': 'Kermanshah province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u06a9\u0631\u0645\u0627\u0646\u0634\u0627\u0647')},
 '9884':{'en': 'Ilam province', 'fa': u('\u0627\u0633\u062a\u0627\u0646 \u0627\u06cc\u0644\u0627\u0645')},
 '9886':{'en': 'Markazi', 'fa': u('\u0645\u0631\u06a9\u0632\u06cc')},
 '9887':{'en': 'Kurdistan', 'fa': u('\u06a9\u0631\u062f\u0633\u062a\u0627\u0646')},
 '9923130':{'en': 'Tursun-Zade'},
 '9923131':{'en': 'Rasht'},
 '9923132':{'en': 'Jirgital'},
 '9923133':{'en': 'Nurobod'},
 '9923134':{'en': 'Rogun'},
 '9923135':{'en': 'Fayzabad'},
 '9923136':{'en': 'Vakhdat'},
 '9923137':{'en': 'Rudaki'},
 '9923138':{'en': 'Nurek'},
 '9923139':{'en': 'Hissar'},
 '9923141':{'en': 'Yavan'},
 '9923153':{'en': 'Varzob'},
 '9923154':{'en': 'Tadjikabad'},
 '9923155':{'en': 'Shakhrinav'},
 '9923156':{'en': 'Tavildara'},
 '9923222':{'en': 'Kurgan-Tube'},
 '9923240':{'en': 'Shaartuz'},
 '9923242':{'en': 'Khuroson'},
 '9923243':{'en': 'Abdurakhmana Jami'},
 '9923245':{'en': 'Bokhtar'},
 '9923246':{'en': 'Vakhsh'},
 '9923247':{'en': 'Kolkhozabad'},
 '9923248':{'en': 'Djilikul'},
 '9923249':{'en': 'Kumsangir'},
 '9923250':{'en': 'Sarband'},
 '9923251':{'en': 'Kabodion'},
 '9923252':{'en': 'Panj'},
 '9923311':{'en': 'Vose'},
 '9923312':{'en': 'Dangara'},
 '9923314':{'en': 'Temurmalik'},
 '9923315':{'en': 'M. Khamadoni'},
 '9923316':{'en': 'Parkhar'},
 '992331700':{'en': 'Khovaling'},
 '9923318':{'en': 'Muminobod'},
 '9923322':{'en': 'Kulyab'},
 '9923422':{'en': 'Khujand'},
 '9923441':{'en': 'Spitamen'},
 '9923442':{'en': 'Gafurov'},
 '9923443':{'en': 'Kayrakum'},
 '9923445':{'en': 'Matchinskiy'},
 '9923451':{'en': 'Chkalovsk'},
 '9923452':{'en': 'Zafarabad'},
 '9923453':{'en': 'Asht'},
 '9923454':{'en': 'Istravshan'},
 '9923455':{'en': 'Jabarrasulov'},
 '9923456':{'en': 'Shakhristan'},
 '9923462':{'en': 'Isfara'},
 '9923464':{'en': 'Ganchi'},
 '9923465':{'en': 'Taboshar'},
 '9923467':{'en': 'Kanibadam'},
 '9923475':{'en': 'Pendjikent'},
 '9923479':{'en': 'Ayni'},
 '9923522':{'en': 'Khorog'},
 '9923551':{'en': 'Vanj'},
 '9923552':{'en': 'Darvaz'},
 '9923553':{'en': 'Ishkashim'},
 '9923554':{'en': 'Murgab'},
 '9923555':{'en': 'Roshtkala'},
 '9923556':{'en': 'Rushan'},
 '99237':{'en': 'Dushanbe'},
 '9931':{'en': 'Ahal'},
 '9932':{'en': 'Balkan'},
 '9933':{'en': u('Da\u015foguz')},
 '9934':{'en': 'Lebap'},
 '9935':{'en': 'Mary'},
 '99412':{'en': 'Baku'},
 '99418':{'en': 'Sumgayit'},
 '9942020':{'en': 'Barda'},
 '9942021':{'en': 'Ujar'},
 '9942022':{'en': 'Agsu'},
 '9942023':{'en': 'Agdash'},
 '9942024':{'en': 'Gobustan'},
 '9942025':{'en': 'Kurdamir'},
 '9942026':{'en': 'Shamakhi'},
 '9942027':{'en': 'Goychay'},
 '9942028':{'en': 'Ismayilli'},
 '9942029':{'en': 'Zardab'},
 '9942120':{'en': 'Hajigabul'},
 '9942121':{'en': 'Shirvan'},
 '9942122':{'en': 'Beylagan'},
 '9942123':{'en': 'Sabirabad'},
 '9942124':{'en': 'Imishli'},
 '9942125':{'en': 'Salyan'},
 '9942126':{'en': 'Neftchala'},
 '9942127':{'en': 'Agjabadi'},
 '9942128':{'en': 'Saatli'},
 '994214':{'en': 'Hajigabul'},
 '9942220':{'en': 'Goygol'},
 '9942221':{'en': 'Dashkasan'},
 '9942222':{'en': 'Agstafa'},
 '9942223':{'en': 'Tartar'},
 '9942224':{'en': 'Goranboy'},
 '9942225':{'en': 'Ganja'},
 '9942226':{'en': 'Ganja'},
 '9942227':{'en': 'Samukh'},
 '9942229':{'en': 'Gazakh'},
 '9942230':{'en': 'Shamkir'},
 '9942231':{'en': 'Tovuz'},
 '9942232':{'en': 'Gadabay'},
 '9942233':{'en': 'Yevlakh'},
 '9942235':{'en': 'Naftalan'},
 '994224':{'en': 'Agstafa/Ganja/Yevlakh'},
 '9942330':{'en': 'Siyazan'},
 '9942331':{'en': 'Khizi'},
 '9942332':{'en': 'Khachmaz'},
 '9942333':{'en': 'Guba'},
 '9942335':{'en': 'Shabran'},
 '9942338':{'en': 'Gusar'},
 '9942420':{'en': 'Gabala'},
 '9942421':{'en': 'Oguz'},
 '9942422':{'en': 'Zagatala'},
 '9942424':{'en': 'Shaki'},
 '9942425':{'en': 'Gakh'},
 '9942427':{'en': 'Mingachevir'},
 '9942429':{'en': 'Balakan'},
 '9942520':{'en': 'Yardimli'},
 '9942521':{'en': 'Masalli'},
 '9942522':{'en': 'Astara'},
 '9942524':{'en': 'Jalilabad'},
 '9942525':{'en': 'Lankaran'},
 '9942527':{'en': 'Lerik'},
 '9942529':{'en': 'Bilasuvar'},
 '9942620':{'en': 'Khojali'},
 '9942621':{'en': 'Lachin'},
 '9942622':{'en': 'Khankandi'},
 '9942623':{'en': 'Qubadli'},
 '9942624':{'en': 'Askaran'},
 '9942625':{'en': 'Zangilan'},
 '9942626':{'en': 'Shusha'},
 '9942627':{'en': 'Kalbajar'},
 '9942628':{'en': 'Agdara'},
 '9942629':{'en': 'Khojavand'},
 '9942630':{'en': 'Hadrut'},
 '9942631':{'en': 'Fuzuli'},
 '9942632':{'en': 'Agdam'},
 '9942638':{'en': 'Jabrayil'},
 '99436541':{'en': 'Babek'},
 '99436542':{'en': 'Sharur'},
 '99436543':{'en': 'Shahbuz'},
 '99436544':{'en': 'Nakhchivan city'},
 '99436546':{'en': 'Julfa'},
 '99436547':{'en': 'Ordubad'},
 '99436548':{'en': 'Kangarli'},
 '99436549':{'en': 'Sadarak'},
 '99436550':{'en': 'Nakhchivan city'},
 '99436552':{'en': 'Sharur'},
 '99532':{'en': 'Tbilisi'},
 '995341':{'en': 'Rustavi'},
 '995342':{'en': 'Akhalgori'},
 '995344':{'en': 'Tskhinvali'},
 '995345':{'en': 'Stefanstminda/Kazbegi'},
 '995346':{'en': 'Dusheti'},
 '995347':{'en': 'Djava'},
 '995348':{'en': 'Tianeti'},
 '995349':{'en': 'Akhmeta'},
 '995350':{'en': 'Telavi'},
 '995351':{'en': 'Sagaredjo'},
 '995352':{'en': 'Kvareli'},
 '995353':{'en': 'Gurdjaani'},
 '995354':{'en': 'Lagodekhi'},
 '995355':{'en': 'Signagi'},
 '995356':{'en': 'DedoplisTskaro'},
 '995357':{'en': 'Marneuli'},
 '995358':{'en': 'Bolnisi'},
 '995359':{'en': 'TetriTskaro'},
 '995360':{'en': 'Dmanisi'},
 '995361':{'en': 'Ninotsminda'},
 '995362':{'en': 'Akhalkalaki'},
 '995363':{'en': 'Tsalka'},
 '995364':{'en': 'Aspindza'},
 '995365':{'en': 'Akhaltsikhe'},
 '995366':{'en': 'Adigeni'},
 '995367':{'en': 'Bordjomi'},
 '995368':{'en': 'Khashuri'},
 '995369':{'en': 'Kareli'},
 '995370':{'en': 'Gori'},
 '995371':{'en': 'Kaspi'},
 '995372':{'en': 'Gardabani'},
 '995373':{'en': 'Mtskheta'},
 '995374':{'en': 'Tigvi'},
 '995410':{'en': 'Mestia'},
 '995411':{'en': 'Samtredia'},
 '995412':{'en': 'Abasha'},
 '995413':{'en': 'Senaki'},
 '995414':{'en': 'Xobi'},
 '995415':{'en': 'Zugdidi'},
 '995416':{'en': 'Tsalendjikha'},
 '995417':{'en': 'Chkhorotskhu'},
 '995418':{'en': 'Martvili'},
 '995419':{'en': 'Choxatauri'},
 '995422':{'en': 'Batumi'},
 '995423':{'en': 'Xulo'},
 '995424':{'en': 'Shuaxevi'},
 '995425':{'en': 'Qeda'},
 '995426':{'en': 'Kobuleti'},
 '995427':{'en': 'Xelvachauri'},
 '995431':{'en': 'Kutaisi'},
 '995432':{'en': 'Vani'},
 '995433':{'en': 'Kharagauli'},
 '995434':{'en': 'Bagdati'},
 '995435':{'en': 'Sachkhere'},
 '995436':{'en': 'Tskaltubo'},
 '995437':{'en': 'Lentekhi'},
 '995439':{'en': 'Ambrolauri'},
 '995442':{'en': 'Sukhumi'},
 '995443':{'en': 'Gagra'},
 '995444':{'en': 'Gudauta'},
 '995445':{'en': 'Ochamchire'},
 '995446':{'en': 'Tkvarcheli'},
 '995447':{'en': 'Gali'},
 '995448':{'en': 'Gulripshi'},
 '995472':{'en': 'Tsageri'},
 '995473':{'en': 'Oni'},
 '995479':{'en': 'Chiatura'},
 '995491':{'en': 'Terdjola'},
 '995492':{'en': 'Zestafoni'},
 '995493':{'en': 'Poti'},
 '995494':{'en': 'lanchxuti'},
 '995495':{'en': 'Khoni'},
 '995496':{'en': 'Ozurgeti'},
 '995497':{'en': 'Tkibuli'},
 '9963120':{'en': 'Bishkek, Chuy region'},
 '9963121':{'en': 'Bishkek, Chuy region'},
 '9963122':{'en': 'Bishkek, Chuy region'},
 '9963123':{'en': 'Bishkek, Chuy region'},
 '9963124':{'en': 'Bishkek, Chuy region'},
 '99631250':{'en': 'Bishkek, Chuy region'},
 '99631251':{'en': 'Bishkek, Chuy region'},
 '99631252':{'en': 'Bishkek, Chuy region'},
 '99631253':{'en': 'Bishkek, Chuy region'},
 '99631254':{'en': 'Bishkek, Chuy region'},
 '99631255':{'en': 'Bishkek, Chuy region'},
 '99631256':{'en': 'Bishkek, Chuy region'},
 '99631257':{'en': 'Bishkek, Chuy region'},
 '99631259':{'en': 'Bishkek, Chuy region'},
 '9963126':{'en': 'Bishkek, Chuy region'},
 '9963127':{'en': 'Bishkek, Chuy region'},
 '9963128':{'en': 'Bishkek, Chuy region'},
 '99631290':{'en': 'Bishkek, Chuy region'},
 '99631291':{'en': 'Bishkek, Chuy region'},
 '99631292':{'en': 'Bishkek, Chuy region'},
 '99631293':{'en': 'Bishkek, Chuy region'},
 '99631294':{'en': 'Bishkek, Chuy region'},
 '99631295':{'en': 'Bishkek, Chuy region'},
 '99631296':{'en': 'Bishkek, Chuy region'},
 '996312970':{'en': 'Bishkek, Chuy region'},
 '996312971':{'en': 'Bishkek, Chuy region'},
 '996312972':{'en': 'Bishkek, Chuy region'},
 '996312974':{'en': 'Bishkek, Chuy region'},
 '996312975':{'en': 'Bishkek, Chuy region'},
 '996312976':{'en': 'Bishkek, Chuy region'},
 '996312977':{'en': 'Bishkek, Chuy region'},
 '996312978':{'en': 'Bishkek, Chuy region'},
 '996312979':{'en': 'Bishkek, Chuy region'},
 '99631298':{'en': 'Bishkek, Chuy region'},
 '99631299':{'en': 'Bishkek, Chuy region'},
 '9963131':{'en': 'Belovodskoe, Chuy region'},
 '9963132':{'en': 'Kant, Chuy region'},
 '9963133':{'en': 'Kara-Balta, Chuy region'},
 '9963134':{'en': 'Sokuluk, Chuy region'},
 '9963135':{'en': 'Kemin, Chuy region'},
 '9963137':{'en': 'Kayndy, Chuy region'},
 '9963138':{'en': 'Tokmok, Chuy region'},
 '9963139':{'en': 'Lebedinovka, Chuy region'},
 '996322':{'en': 'Osh'},
 '9963230':{'en': 'Eski-Nookat, Osh region'},
 '9963231':{'en': 'Aravan, Osh region'},
 '9963232':{'en': 'Kara-Suu, Osh region'},
 '9963233':{'en': 'Uzgen, Osh region'},
 '9963234':{'en': 'Gulcha, Osh region'},
 '9963237':{'en': 'Daroot-Korgon, Osh region'},
 '9963239':{'en': 'Kara-Kulja, Osh region'},
 '996342':{'en': 'Talas'},
 '9963456':{'en': 'Kyzyl-Adyr, Talas region'},
 '9963457':{'en': 'Bakay-Ata, Talas region'},
 '9963458':{'en': 'Kokoy, Talas region'},
 '9963459':{'en': 'Pokrovka, Talas region'},
 '996352':{'en': 'Naryn'},
 '9963534':{'en': 'At-Bashy, Naryn region'},
 '9963535':{'en': 'Kochkor, Naryn region'},
 '9963536':{'en': 'Chaek/Minkush, Naryn region'},
 '9963537':{'en': 'Baetov, Naryn region'},
 '996362':{'en': 'Batken, Naryn region'},
 '9963653':{'en': 'Sulukta, Naryn region'},
 '9963655':{'en': 'Pulgon, Naryn region'},
 '9963656':{'en': 'Isfana, Naryn region'},
 '9963657':{'en': 'Kyzylkia, Naryn region'},
 '996372':{'en': 'Jalal-Abat'},
 '9963734':{'en': 'Massy/Kochkor-Ata, Jalal-Abat region'},
 '9963736':{'en': 'Bazarkorgon, Jalal-Abat region'},
 '9963738':{'en': 'Kazarman, Jalal-Abat region'},
 '9963741':{'en': 'Ala-Buka, Jalal-Abat region'},
 '9963742':{'en': 'Kerben, Jalal-Abat region'},
 '9963744':{'en': 'Mailuu-Suu, Jalal-Abat region'},
 '9963745':{'en': 'Tash-Kumyr, Jalal-Abat region'},
 '9963746':{'en': 'Kara-Kul, Jalal-Abat region'},
 '9963747':{'en': 'Toktogul, Jalal-Abat region'},
 '9963748':{'en': 'Kok-Jangak/Suzak, Jalal-Abat region'},
 '9963749':{'en': 'Kanysh-Kya (Chatkal), Jalal-Abat region'},
 '996392':{'en': 'Karakol, Issyk-Ko region'},
 '9963942':{'en': 'Ananyevo, Issyk-Ko region'},
 '9963943':{'en': 'Cholpon-Ata, Issyk-Ko region'},
 '9963944':{'en': 'Balykchy, Issyk-Ko region'},
 '9963945':{'en': 'Tup, Issyk-Ko region'},
 '9963946':{'en': 'Kyzyl-Suu, Issyk-Ko region'},
 '9963947':{'en': 'Bokombaevo/Kadji-Say, Issyk-Ko region'},
 '9963948':{'en': 'Ak-Suu, Issyk-Ko region'},
}
